//
// org.osid.OsidCompendiumQuery
//
//     The OSID Java specification for org.osid.OsidCompendiumQuery.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid;


/**
 *  <p>This is the query interface for searching reports. Each method 
 *  specifies an <code> AND </code> term while multiple invocations of the 
 *  same method produce a nested <code> OR. </code> </p>
 */

public interface OsidCompendiumQuery
    extends org.osid.OsidObjectQuery,
            org.osid.OsidSubjugateableQuery {


    /**
     *  Matches reports whose start date falls in between the given dates 
     *  inclusive. 
     *
     *  @param  start start of date range 
     *  @param  end end of date range 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> start </code> is less 
     *          than <code> end </code> 
     *  @throws org.osid.NullArgumentException <code> start </code> or <code> 
     *          end </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchStartDate(org.osid.calendaring.DateTime start, 
                               org.osid.calendaring.DateTime end, 
                               boolean match);


    /**
     *  Matches reports with any start date set. 
     *
     *  @param  match <code> true </code> to match any start date, <code> 
     *          false </code> to match no start date 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyStartDate(boolean match);


    /**
     *  Clears the start date query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStartDateTerms();


    /**
     *  Matches reports whose effective end date falls in between the given 
     *  dates inclusive. 
     *
     *  @param  start start of date range 
     *  @param  end end of date range 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for negative match 
     *  @throws org.osid.InvalidArgumentException <code> start </code> is less 
     *          than <code> end </code> 
     *  @throws org.osid.NullArgumentException <code> start </code> or <code> 
     *          end </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchEndDate(org.osid.calendaring.DateTime start, 
                             org.osid.calendaring.DateTime end, boolean match);


    /**
     *  Matches reports with any end date set. 
     *
     *  @param  match <code> true </code> to match any end date, <code> false 
     *          </code> to match no start date 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyEndDate(boolean match);


    /**
     *  Clears the end date query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEndDateTerms();


    /**
     *  Match reports that are interpolated. 
     *
     *  @param  match <code> true </code> to match any interpolated reports, 
     *          <code> false </code> to match non-interpolated reports 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchInterpolated(boolean match);


    /**
     *  Clears the interpolated query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearInterpolatedTerms();


    /**
     *  Match reports that are extrapolated. 
     *
     *  @param  match <code> true </code> to match any extrapolated reports, 
     *          <code> false </code> to match non-extrapolated reports 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchExtrapolated(boolean match);


    /**
     *  Clears the extrapolated query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearExtrapolatedTerms();
}
