//
// org.osid.OsidEnablerForm
//
//     The OSID Java specification for org.osid.OsidEnablerForm.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid;


/**
 *  <p>This form is used to create and update enablers. </p>
 */

public interface OsidEnablerForm
    extends org.osid.OsidRuleForm,
            org.osid.OsidTemporalForm {


    /**
     *  Gets the metadata for an associated schedule. 
     *
     *  @return metadata for the schedule 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getScheduleMetadata();


    /**
     *  Sets a schedule. 
     *
     *  @param  scheduleId the new schedule 
     *  @throws org.osid.InvalidArgumentException <code> scheduleId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> scheduleId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setSchedule(org.osid.id.Id scheduleId);


    /**
     *  Removes the schedule. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSchedule();


    /**
     *  Gets the metadata for an associated event. 
     *
     *  @return metadata for the event 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getEventMetadata();


    /**
     *  Sets an event. 
     *
     *  @param  eventId the new event 
     *  @throws org.osid.InvalidArgumentException <code> eventId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> eventId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setEvent(org.osid.id.Id eventId);


    /**
     *  Removes the event. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEvent();


    /**
     *  Gets the metadata for the cyclic event. 
     *
     *  @return metadata for the cyclic event 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getCyclicEventMetadata();


    /**
     *  Sets the cyclic event. 
     *
     *  @param  cyclicEventId the new cyclic event 
     *  @throws org.osid.InvalidArgumentException <code> cyclicEventId </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> cyclicEventId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setCyclicEvent(org.osid.id.Id cyclicEventId);


    /**
     *  Removes the cyclic event. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCyclicEvent();


    /**
     *  Gets the metadata for an associated demographic. 
     *
     *  @return metadata for the resource. 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getDemographicMetadata();


    /**
     *  Sets a resource demographic. 
     *
     *  @param  resourceId the new resource 
     *  @throws org.osid.InvalidArgumentException <code> resourceId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setDemographic(org.osid.id.Id resourceId);


    /**
     *  Removes the resource demographic. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDemographic();
}
