//
// org.osid.OsidEnablerQuery
//
//     The OSID Java specification for org.osid.OsidEnablerQuery.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid;


/**
 *  <p>This is the query interface for searching enablers. Each method 
 *  specifies an <code> AND </code> term while multiple invocations of the 
 *  same method produce a nested <code> OR. </code> </p>
 */

public interface OsidEnablerQuery
    extends org.osid.OsidRuleQuery,
            org.osid.OsidTemporalQuery {


    /**
     *  Match the <code> Id </code> of an associated schedule. 
     *
     *  @param  scheduleId <code> Id </code> to match 
     *  @param  match <code> true </code> if for a positive match, <code> 
     *          false </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> scheduleId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchScheduleId(org.osid.id.Id scheduleId, boolean match);


    /**
     *  Clears all schedule <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearScheduleIdTerms();


    /**
     *  Tests if a <code> ScheduleQuery </code> for the rule is available. 
     *
     *  @return <code> true </code> if a schedule query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsScheduleQuery();


    /**
     *  Gets the query for the schedule. Each retrieval performs a boolean 
     *  <code> OR. </code> 
     *
     *  @param  match <code> true </code> if for a positive match, <code> 
     *          false </code> for a negative match 
     *  @return the schedule query 
     *  @throws org.osid.UnimplementedException <code> supportsScheduleQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsScheduleQuery() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.ScheduleQuery getScheduleQuery(boolean match);


    /**
     *  Match any associated schedule. 
     *
     *  @param  match <code> true </code> to match any schedule, <code> false 
     *          </code> to match no schedules 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnySchedule(boolean match);


    /**
     *  Clears all schedule terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearScheduleTerms();


    /**
     *  Match the <code> Id </code> of an associated event. 
     *
     *  @param  eventId <code> Id </code> to match 
     *  @param  match <code> true </code> if for a positive match, <code> 
     *          false </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> eventId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchEventId(org.osid.id.Id eventId, boolean match);


    /**
     *  Clears all event <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEventIdTerms();


    /**
     *  Tests if a <code> EventQuery </code> for the rule is available. 
     *
     *  @return <code> true </code> if an event query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEventQuery();


    /**
     *  Gets the query for the event. Each retrieval performs a boolean <code> 
     *  OR. </code> 
     *
     *  @param  match <code> true </code> if for a positive match, <code> 
     *          false </code> for a negative match 
     *  @return the event query 
     *  @throws org.osid.UnimplementedException <code> supportsEventQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEventQuery() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.EventQuery getEventQuery(boolean match);


    /**
     *  Match any associated event. 
     *
     *  @param  match <code> true </code> to match any event, <code> false 
     *          </code> to match no events 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyEvent(boolean match);


    /**
     *  Clears all recurirng event terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEventTerms();


    /**
     *  Sets the cyclic event <code> Id </code> for this query. 
     *
     *  @param  cyclicEventId the cyclic event <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> cyclicEventId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCyclicEventId(org.osid.id.Id cyclicEventId, boolean match);


    /**
     *  Clears the cyclic event <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCyclicEventIdTerms();


    /**
     *  Tests if a <code> CyclicEventQuery </code> is available. 
     *
     *  @return <code> true </code> if a cyclic event query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCyclicEventQuery();


    /**
     *  Gets the query for a cyclic event. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the cyclic event query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCyclicEventQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCyclicEventQuery() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.cycle.CyclicEventQuery getCyclicEventQuery();


    /**
     *  Matches any enabler with a cyclic event. 
     *
     *  @param  match <code> true </code> to match any enablers with a cyclic 
     *          event, <code> false </code> to match enablers with no cyclic 
     *          events 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCyclicEvent(boolean match);


    /**
     *  Clears the cyclic event query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCyclicEventTerms();


    /**
     *  Match the <code> Id </code> of the demographic resource. 
     *
     *  @param  resourceId <code> Id </code> to match 
     *  @param  match <code> true </code> if for a positive match, <code> 
     *          false </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDemographicId(org.osid.id.Id resourceId, boolean match);


    /**
     *  Clears all resource <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDemographicIdTerms();


    /**
     *  Tests if a <code> ResourceQuery </code> for the demographic is 
     *  available. 
     *
     *  @return <code> true </code> if a resource query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDemographicQuery();


    /**
     *  Gets the query for the resource. Each retrieval performs a boolean 
     *  <code> OR. </code> 
     *
     *  @param  match <code> true </code> if for a positive match, <code> 
     *          false </code> for a negative match 
     *  @return the resource query 
     *  @throws org.osid.UnimplementedException <code> supportsResourceQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceQuery getDemographicQuery(boolean match);


    /**
     *  Match any associated resource. 
     *
     *  @param  match <code> true </code> to match any demographic, <code> 
     *          false </code> to match no rules 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDemographic(boolean match);


    /**
     *  Clears all demographic terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDemographicTerms();
}
