//
// org.osid.OsidObject
//
//     The OSID Java specification for org.osid.OsidObject.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid;


/**
 *  <p><code> OsidObject </code> is the top level interface for all OSID 
 *  Objects. An OSID Object is an object identified by an OSID <code> Id 
 *  </code> and may implements optional interfaces. OSID Objects also contain 
 *  a display name and a description. These fields are required but may be 
 *  used for a variety of purposes ranging from a primary name and description 
 *  of the object to a more user friendly display of various attributes. </p> 
 *  
 *  <p> Creation of OSID Objects and the modification of their data is managed 
 *  through the associated <code> OsidSession </code> which removes the 
 *  dependency of updating data elements upon object retrieval. <code> </code> 
 *  The <code> OsidManager </code> should be used to test if updates are 
 *  available and determine what <code> PropertyTypes </code> are supported. 
 *  The <code> OsidManager </code> is also used to create the appropriate 
 *  <code> OsidSession </code> for object creation, updates and deletes. </p> 
 *  
 *  <p> All <code> OsidObjects </code> are identified by an immutable <code> 
 *  Id. </code> An <code> Id </code> is assigned to an object upon creation of 
 *  the object and cannot be changed once assigned. </p> 
 *  
 *  <p> An <code> OsidObject </code> may support one or more supplementary 
 *  records which are expressed in the form of interfaces. Each record 
 *  interface is identified by a Type. A record interface may extend another 
 *  record interface where support of the parent record interface is implied. 
 *  In this case of interface inheritance, support of the parent record type 
 *  may be implied through <code> hasRecordType() </code> and not explicit in 
 *  <code> getRecordTypes(). </code> </p> 
 *  
 *  <p> For example, if recordB extends recordA, typeB is a child of typeA. If 
 *  a record implements typeB, than it also implements typeA. An application 
 *  that only knows about typeA retrieves recordA. An application that knows 
 *  about typeB, retrieves recordB which is the union of methods specified in 
 *  typeA and typeB. If an application requests typeA, it may not attempt to 
 *  access methods defined in typeB as they may not exist until explicitly 
 *  requested. The mechanics of this polymorphism is defined by the language 
 *  binder. One mechanism might be the use of casting. </p> 
 *  
 *  <p> In addition to the record <code> Types, </code> OSID Objects also have 
 *  a genus <code> Type. </code> A genus <code> Type </code> indicates a 
 *  classification or kind of the object where an "is a" relationship exists. 
 *  The purpose of of the genus <code> Type </code> is to avoid the creation 
 *  of unnecessary record types that may needlessly complicate an interface 
 *  hierarchy or introduce interoperability issues. For example, an OSID 
 *  object may have a record <code> Type </code> of <code> Publication </code> 
 *  that defines methods pertinent to publications, such as an ISBN number. A 
 *  provider may wish to distinguish between books and journals without having 
 *  the need of new record interfaces. In this case, the genus <code> Type 
 *  </code> may be one of <code> Book </code> or <code> Journal. </code> While 
 *  this distinction can aid a search, these genres should be treated in such 
 *  a way that do not introduce interoperability problems. </p> 
 *  
 *  <p> Like record Types, the genus Types may also exist in an implicit type 
 *  hierarchy. An OSID object always has at least one genus. Genus types 
 *  should not be confused with subject tagging, which is managed externally 
 *  to the object. Unlike record <code> Types, </code> an object's genus may 
 *  be modified. However, once an object's record is created with a record 
 *  <code> Type, </code> it cannot be changed. </p> 
 *  
 *  <p> Methods that return values are not permitted to return nulls. If a 
 *  value is not set, it is indicated in the <code> Metadata </code> of the 
 *  update form. </p>
 */

public interface OsidObject
    extends org.osid.Identifiable,
            org.osid.Extensible,
            org.osid.Browsable {


    /**
     *  Gets the preferred display name associated with this instance of this 
     *  OSID object appropriate for display to the user. 
     *
     *  @return the display name 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  A display name is a string used for identifying an object in 
     *          human terms. A provider may wish to initialize the display 
     *          name based on one or more object attributes. In some cases, 
     *          the display name may not map to a specific or significant 
     *          object attribute but simply be used as a preferred display 
     *          name that can be modified. A provider may also wish to 
     *          translate the display name into a specific locale using the 
     *          Locale service. Some OSIDs define methods for more detailed 
     *          naming. 
     */

    public org.osid.locale.DisplayText getDisplayName();


    /**
     *  Gets the description associated with this instance of this OSID 
     *  object. 
     *
     *  @return the description 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  A description is a string used for describing an object in 
     *          human terms and may not have significance in the underlying 
     *          system. A provider may wish to initialize the description 
     *          based on one or more object attributes and/or treat it as an 
     *          auxiliary piece of data that can be modified. A provider may 
     *          also wish to translate the description into a specific locale 
     *          using the Locale service. 
     */

    public org.osid.locale.DisplayText getDescription();


    /**
     *  Gets the genus type of this object. 
     *
     *  @return the genus type of this object 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getGenusType();


    /**
     *  Tests if this object is of the given genus <code> Type. </code> The 
     *  given genus type may be supported by the object through the type 
     *  hierarchy. 
     *
     *  @param  genusType a genus type 
     *  @return <code> true </code> if this object is of the given genus 
     *          <code> Type, </code> <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> genusType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isOfGenusType(org.osid.type.Type genusType);
}
