//
// org.osid.OsidProfile
//
//     The OSID Java specification for org.osid.OsidProfile.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid;


/**
 *  <p>The <code> OsidProfile </code> defines the interoperability areas of an 
 *  OSID. An <code> OsidProfile </code> is implemented by an <code> 
 *  OsidManager. </code> The top level <code> OsidProfile </code> tests for 
 *  version compatibility. Each OSID extends this interface to include its own 
 *  interoperability definitions within its managers. </p>
 */

public interface OsidProfile
    extends org.osid.Sourceable {


    /**
     *  Gets an identifier for this service implementation. The identifier is 
     *  unique among services but multiple instantiations of the same service 
     *  use the same <code> Id. </code> This identifier is the same identifier 
     *  used in managing OSID installations. 
     *
     *  @return the <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getId();


    /**
     *  Gets a display name for this service implementation. 
     *
     *  @return a display name 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getDisplayName();


    /**
     *  Gets a description of this service implementation. 
     *
     *  @return a description 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getDescription();


    /**
     *  Gets the version of this service implementation. 
     *
     *  @return the service implementation version 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.Version getVersion();


    /**
     *  Gets the date this service implementation was released. 
     *
     *  @return the release date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getReleaseDate();


    /**
     *  Test for support of an OSID specification version. 
     *
     *  @param  version the specification version to test 
     *  @return <code> true </code> if this manager supports the given OSID 
     *          version, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  An implementation may support multiple versions of an OSID. 
     */

    public boolean supportsOSIDVersion(org.osid.installation.Version version);


    /**
     *  Gets the locales supported in this service. 
     *
     *  @return list of locales supported 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.LocaleList getLocales();


    /**
     *  Test for support of a journaling rollback service. 
     *
     *  @return <code> true </code> if this manager supports the journal 
     *          rollback, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJournalRollback();


    /**
     *  Test for support of a journal branching service. 
     *
     *  @return <code> true </code> if this manager supports the journal 
     *          branching, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJournalBranching();


    /**
     *  Gets the <code> Branch Id </code> representing this service branch. 
     *
     *  @return the branch <code> Id </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJournalBranching() </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBranchId();


    /**
     *  Gets this service branch. 
     *
     *  @return the service branch 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJournalBranching() </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.Branch getBranch()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy record <code> Types </code> supported in this service. 
     *  If no proxy manager is available, an empty list is returned. 
     *
     *  @return list of proxy record types supported 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getProxyRecordTypes();


    /**
     *  Test for support of a proxy type. 
     *
     *  @param  proxyRecordType a proxy record type 
     *  @return <code> true </code> if this service supports the given proxy 
     *          record type, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> proxyRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProxyRecordType(org.osid.type.Type proxyRecordType);
}
