//
// org.osid.OsidRule
//
//     The OSID Java specification for org.osid.OsidRule.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid;


/**
 *  <p>An <code> OsidRule </code> identifies an explicit or implicit rule 
 *  evaluation. An associated <code> Rule </code> may be available in cases 
 *  where the behavior of the object can be explicitly modified using a 
 *  defined rule. In many cases, an <code> OsidObject </code> may define 
 *  specific methods to manage certain common behavioral aspects and delegate 
 *  anything above and beyond what has been defined to a rule evaluation. </p> 
 *  
 *  <p> Rules are defined to be operable. In the case of a statement 
 *  evaluation, an enabled rule overrides any evaluation to return <code> true 
 *  </code> and a disabled rule overrides any evaluation to return <code> 
 *  false. </code> </p> 
 *  
 *  <p> <code> Rules </code> are never required to consume or implement. They 
 *  serve as a mechanism to offer a level of management not attainable in the 
 *  immediate service definition. Each Rule implies evaluating a set of facts 
 *  known to the service to produce a resulting beavior. Rule evaluations may 
 *  also accept input data or conditions, however, <code> OsidRules </code> as 
 *  they appear in throughout the services may or may not provide a means of 
 *  supplying <code> OsidConditions </code> directly. In the services where an 
 *  explicit <code> OsidCondition </code> is absent they may be masquerading 
 *  as another interface such as a <code> Proxy </code> or an <code> OsidQuery 
 *  </code> . </p>
 */

public interface OsidRule
    extends org.osid.OsidObject,
            org.osid.Operable {


    /**
     *  Tests if an explicit rule is available. 
     *
     *  @return <code> true </code> if an explicit rule is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasRule();


    /**
     *  Gets the explicit rule <code> Id </code> . 
     *
     *  @return the rule <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> hasRule() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getRuleId();


    /**
     *  Gets the explicit rule. 
     *
     *  @return the rule 
     *  @throws org.osid.IllegalStateException <code> hasRule() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.Rule getRule()
        throws org.osid.OperationFailedException;
}
