//
// org.osid.OsidRuntimeManager
//
//     The OSID Java specification for org.osid.OsidRuntimeManager.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid;


/**
 *  <p>The <code> OsidRuntimeManager </code> represents and OSID platform and 
 *  contains the information required for running OSID implementations such as 
 *  search paths and configurations. </p> 
 *  
 *  <p> The <code> OsidRuntimeManager </code> is defined as an interface to 
 *  provide flexibility for managing an OSID environment. The instantiation of 
 *  a <code> OsidRuntimeManager </code> implementation is defined by the OSID 
 *  platform. </p> 
 *  
 *  <p> The <code> OsidRuntimeManager </code> should be instantiated with a 
 *  string that identifies the application or environment current at the time 
 *  of instantiation. This key is used soley for the purpose of seeding the 
 *  configuration service as a means to enable lower level OSIDs to tune their 
 *  configuration in response to this key, or, it can be used by the 
 *  application to retrieve configuration data for itself. </p>
 */

public interface OsidRuntimeManager
    extends org.osid.OsidManager,
            org.osid.OsidRuntimeProfile {


    /**
     *  Finds, loads and instantiates providers of OSID managers. Providers 
     *  must conform to an OsidManager interface. The interfaces are defined 
     *  in the OSID enumeration. For all OSID requests, an instance of <code> 
     *  OsidManager </code> that implements the <code> OsidManager </code> 
     *  interface is returned. In bindings where permitted, this can be safely 
     *  cast into the requested manager. 
     *
     *  @param  osid represents the OSID 
     *  @param  implClassName the name of the implementation 
     *  @param  version the minimum required OSID specification version 
     *  @return the manager of the service 
     *  @throws org.osid.ConfigurationErrorException an error in configuring 
     *          the implementation 
     *  @throws org.osid.NotFoundException the implementation class was not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> implClassName </code> or 
     *          <code> version </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> implClassName </code> 
     *          does not support the requested OSID 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  After finding and instantiating the requested <code> 
     *          OsidManager, </code> providers must invoke <code> 
     *          OsidManager.initialize(OsidRuntimeManager) </code> where the 
     *          environment is an instance of the current environment that 
     *          includes the configuration for the service being initialized. 
     *          The <code> OsidRuntimeManager </code> passed may include 
     *          information useful for the configuration such as the identity 
     *          of the service being instantiated. 
     */

    public org.osid.OsidManager getManager(org.osid.OSID osid, 
                                           String implClassName, 
                                           org.osid.installation.Version version)
        throws org.osid.ConfigurationErrorException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Finds, loads and instantiates providers of OSID managers. Providers 
     *  must conform to an <code> OsidManager </code> interface. The 
     *  interfaces are defined in the OSID enumeration. For all OSID requests, 
     *  an instance of <code> OsidManager </code> that implements the <code> 
     *  OsidManager </code> interface is returned. In bindings where 
     *  permitted, this can be safely cast into the requested manager. 
     *
     *  @param  osid represents the OSID 
     *  @param  implementation the name of the implementation 
     *  @param  version the minimum required OSID specification version 
     *  @return the manager of the service 
     *  @throws org.osid.ConfigurationErrorException an error in configuring 
     *          the implementation 
     *  @throws org.osid.NotFoundException the implementation class was not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> implementation </code> 
     *          or <code> version </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> implementation </code> 
     *          does not support the requested OSID 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  After finding and instantiating the requested <code> 
     *          OsidManager, </code> providers must invoke <code> 
     *          OsidManager.initialize(OsidRuntimeManager) </code> where the 
     *          environment is an instance of the current environment that 
     *          includes the configuration for the service being initialized. 
     *          The <code> OsidRuntimeManager </code> passed may include 
     *          information useful for the configuration such as the identity 
     *          of the service being instantiated. 
     */

    public org.osid.OsidProxyManager getProxyManager(org.osid.OSID osid, 
                                                     String implementation, 
                                                     org.osid.installation.Version version)
        throws org.osid.ConfigurationErrorException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the current configuration in the runtime environment. 
     *
     *  @return a configuration 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException an authorization failure 
     *          occured 
     *  @throws org.osid.UnimplementedException a configuration service is not 
     *          supported 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsConfiguration() </code> is <code> true. </code> 
     */

    public org.osid.configuration.ValueLookupSession getConfiguration()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
