//
// org.osid.OsidSearch
//
//     The OSID Java specification for org.osid.OsidSearch.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid;


/**
 *  <p><code> OsidSearch </code> specifies search options used to perform OSID 
 *  searches. An <code> OsidSearch </code> is available from an <code> 
 *  OsidSession </code> and defines methods to govern the overall search of 
 *  terms supplied in one or more <code> OsidQuery </code> interfaces. </p> 
 *  
 *  <p> This interface is available from a search session.Example using the 
 *  search interface to retrieve the first 25 results: </p> 
 *  
 *  <pre>
 *       
 *       
 *       OsidSearch os = session.getObjectSearch();
 *       os.limitResultSet(1, 25);
 *       
 *       OsidQuery query;
 *       query = session.getObjectQuery();
 *       query.addDescriptionMatch("*food*", wildcardStringMatchType, true);
 *       
 *       ObjectSearchResults results = session.getObjectsBySearch(query, os);
 *       ObjectList list = results.getObjectList();
 *       
 *                   
 *       
 *  </pre>
 *  
 */

public interface OsidSearch
    extends org.osid.OsidCondition {


    /**
     *  By default, searches return all matching results. This method 
     *  restricts the number of results by setting the start and end of the 
     *  result set, starting from 1. The starting and ending results can be 
     *  used for paging results when a certain ordering is requested. The 
     *  ending position must be greater than the starting position. 
     *
     *  @param  start the start of the result set 
     *  @param  end the end of the result set 
     *  @throws org.osid.InvalidArgumentException <code> end </code> is less 
     *          than or equal to <code> start </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void limitResultSet(long start, long end);
}
