//
// org.osid.OsidSourceableQuery
//
//     The OSID Java specification for org.osid.OsidSourceableQuery.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid;


/**
 *  <p>The <code> OsidSourceableQuery </code> is used to assemble search 
 *  queries for sourceables. </p>
 */

public interface OsidSourceableQuery
    extends org.osid.OsidQuery {


    /**
     *  Match the <code> Id </code> of the provider resource. 
     *
     *  @param  resourceId <code> Id </code> to match 
     *  @param  match <code> true </code> if for a positive match, <code> 
     *          false </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchProviderId(org.osid.id.Id resourceId, boolean match);


    /**
     *  Clears all provider <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProviderIdTerms();


    /**
     *  Tests if a <code> ResourceQuery </code> for the provider is available. 
     *
     *  @return <code> true </code> if a resource query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProviderQuery();


    /**
     *  Gets the query for the provider. Each retrieval performs a boolean 
     *  <code> OR. </code> 
     *
     *  @param  match <code> true </code> if for a positive match, <code> 
     *          false </code> for a negative match 
     *  @return the provider query 
     *  @throws org.osid.UnimplementedException <code> supportsProviderQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProviderQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceQuery getProviderQuery(boolean match);


    /**
     *  Match sourceables with a provider value. 
     *
     *  @param  match <code> true </code> to match sourceables with any 
     *          provider, <code> false </code> to match sourceables with no 
     *          providers 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyProvider(boolean match);


    /**
     *  Clears all provider terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProviderTerms();


    /**
     *  Match the <code> Id </code> of an asset used for branding. 
     *
     *  @param  assetId <code> Id </code> to match 
     *  @param  match <code> true </code> if for a positive match, <code> 
     *          false </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> assetId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBrandingId(org.osid.id.Id assetId, boolean match);


    /**
     *  Clears all asset <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBrandingIdTerms();


    /**
     *  Tests if an <code> AssetQuery </code> for the branding is available. 
     *
     *  @return <code> true </code> if a asset query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrandingQuery();


    /**
     *  Gets the query for an asset. Each retrieval performs a boolean <code> 
     *  OR. </code> 
     *
     *  @param  match <code> true </code> if for a positive match, <code> 
     *          false </code> for a negative match 
     *  @return the asset query 
     *  @throws org.osid.UnimplementedException <code> supportsBrandingQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrandingQuery() </code> is <code> true. </code> 
     */

    public org.osid.repository.AssetQuery getBrandingQuery(boolean match);


    /**
     *  Match sourceables with any branding. 
     *
     *  @param  match <code> true </code> to match any asset, <code> false 
     *          </code> to match no assets 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyBranding(boolean match);


    /**
     *  Clears all branding terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBrandingTerms();


    /**
     *  Adds a license to match. Multiple license matches can be added to 
     *  perform a boolean <code> OR </code> among them. 
     *
     *  @param  license a string to match 
     *  @param  stringMatchType the string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> license </code> is 
     *          not of <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> license </code> or 
     *          <code> stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchLicense(String license, 
                             org.osid.type.Type stringMatchType, boolean match);


    /**
     *  Matches any object with a license. 
     *
     *  @param  match <code> true </code> to match any license, <code> false 
     *          </code> to match objects with no license 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyLicense(boolean match);


    /**
     *  Clears all license terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLicenseTerms();
}
