//
// org.osid.PermissionDeniedException
//
//     Specifies the OSID exception PermissionDeniedException.
//
// Copyright (C) 2006 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid;


/**
 *  An authorization failure occurred. This error should be returned when 
 *  the user cannot perform an operation. Generally, this is deteremined by 
 *  using an Authorization service contained within a service. This error 
 *  implies that if a user was granted authorization, the operation could 
 *  succeed. Permission problems in the a system or database, for example, may 
 *  imply a configuration or operational problem not resulting from a user 
 *  authorization and should result in a different error condition. 
 */

public class PermissionDeniedException
    extends UserException {


    /**
     *  Constructs a <code>PermissionDeniedException</code> with the specified
     *  detail message. The error message string <code>msg</code> can
     *  later be retrieved by the getMessage() method of 
     *  {@link java.lang.Throwable}.
     *  
     *  @param msg the error message
     */

    public PermissionDeniedException(String msg) {
        super(msg);
        return;
    }


    /**
     *  Constructs a <code>PermissionDeniedException</code> with the specified
     *  detail message and cause. The error message string <code>msg</code> can
     *  later be retrieved by the getMessage() method of 
     *  {@link java.lang.Throwable}.
     *
     *  @param msg the error message
     *  @param t the cause of the exception
     */

    public PermissionDeniedException(String msg, Throwable t) {
        super(msg, t);
        return;
    }


    /**
     *  Constructs a <code>PermissionDeniedException</code> with the specified
     *  cause and a detail message of <code>
     *  cause.toString()</code> which typically contains the class and
     *  detail message of <code>cause</code>.
     *
     *  @param t the cause of the exception
     */

    public PermissionDeniedException(Throwable t) {
        super(t);
        return;
    }
}
