//
// org.osid.Property
//
//     The OSID Java specification for org.osid.Property.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid;


/**
 *  <p>A <code> Property </code> is a representation of data in string form. 
 *  Properties are exposed in OSID objects as a means of providing a quick 
 *  gestalt of data elements whose specifics are described through a type 
 *  specification. A view of an OSID object via Properties allows applications 
 *  to browse the content without understanding the type specification in 
 *  place, but any acquisition of specific data, access to an object or other 
 *  primitive type, or changing the data requires the typed interfaces. </p>
 */

public interface Property {


    /**
     *  The display name for this property. 
     *
     *  @return the display name 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getDisplayName();


    /**
     *  A short display label. 
     *
     *  @return the display label 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getDisplayLabel();


    /**
     *  A description of this property. 
     *
     *  @return the description 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getDescription();


    /**
     *  The value of this property. 
     *
     *  @return the value 
     *  @compliance mandatory This method must be implemented. 
     */

    public String getValue();
}
