//
// org.osid.acknowledgement.AcknowledgementManager
//
//     The OSID Java specification for org.osid.acknowledgement.AcknowledgementManager.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.acknowledgement;


/**
 *  <p>The acknowledgement manager provides access to acknowledgement sessions 
 *  and provides interoperability tests for various aspects of this service. 
 *  The sessions included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> CreditLookupSession: </code> a session to lookup credits 
 *      </li> 
 *      <li> <code> CreditQuerySession: </code> a session for querying credits 
 *      </li> 
 *      <li> <code> CreditSearchSession: </code> a session to search credits 
 *      </li> 
 *      <li> <code> CreditAdminSession: </code> a session to manage credits 
 *      </li> 
 *      <li> <code> CreditNotificationSession: </code> a session to subscribe 
 *      to notifications of credit changes </li> 
 *      <li> <code> CreditBillingSession: </code> a session to look up credit 
 *      to billing mappings </li> 
 *      <li> <code> CreditBillingAssignmentSession: </code> a session to 
 *      manage credit to billing mappings </li> 
 *      <li> <code> CreditSmartBillingSession: </code> a session to manage 
 *      dynamic credit to billing mappings </li> 
 *      <li> <code> BillingLookupSession: </code> a session to retrieve 
 *      billings </li> 
 *      <li> <code> BillingQuerySession: </code> a session for querying 
 *      billings </li> 
 *      <li> <code> BillingSearchSession: </code> a session to search for 
 *      billings </li> 
 *      <li> <code> BillingAdminSession: </code> a session to create, update 
 *      and delete billings </li> 
 *      <li> <code> BillingNotificationSession: </code> a session to receive 
 *      notifications for changes in billings </li> 
 *      <li> <code> BillingHierarchyTraversalSession: </code> a session to 
 *      traverse hierarchies of billings </li> 
 *      <li> <code> BillingHierarchyDesignSession: </code> a session to manage 
 *      hierarchies of billings </li> 
 *  </ul>
 *  
 *  
 *  <p> The acknowledgement manager also provides a profile for determing the 
 *  supported search types supported by this service. </p>
 */

public interface AcknowledgementManager
    extends org.osid.OsidManager,
            org.osid.acknowledgement.AcknowledgementProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the credit lookup 
     *  service. 
     *
     *  @return a <code> CreditLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsCreditLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCreditLookup() </code> is <code> true. </code> 
     */

    public org.osid.acknowledgement.CreditLookupSession getCreditLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the credit lookup 
     *  service for the given billing. 
     *
     *  @param  billingId the <code> Id </code> of the <code> Billing </code> 
     *  @return a <code> CreditLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Billing </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> billingId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsCreditLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCreditLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.acknowledgement.CreditLookupSession getCreditLookupSessionForBilling(org.osid.id.Id billingId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the credit query 
     *  service. 
     *
     *  @return a <code> CreditQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsCreditQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCreditQuery() </code> is <code> true. </code> 
     */

    public org.osid.acknowledgement.CreditQuerySession getCreditQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the credit query 
     *  service for the given billing. 
     *
     *  @param  billingId the <code> Id </code> of the <code> Billing </code> 
     *  @return a <code> CreditQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Billing </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> billingId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsCreditQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCreditQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.acknowledgement.CreditQuerySession getCreditQuerySessionForBilling(org.osid.id.Id billingId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the credit search 
     *  service. 
     *
     *  @return a <code> CreditSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsCreditSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCreditSearch() </code> is <code> true. </code> 
     */

    public org.osid.acknowledgement.CreditSearchSession getCreditSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the credit search 
     *  service for the given billing. 
     *
     *  @param  billingId the <code> Id </code> of the <code> Billing </code> 
     *  @return a <code> CreditSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Billing </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> billingId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsCreditSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCreditSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.acknowledgement.CreditSearchSession getCreditSearchSessionForBilling(org.osid.id.Id billingId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the credit 
     *  administration service. 
     *
     *  @return a <code> CreditAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsCreditAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCreditAdmin() </code> is <code> true. </code> 
     */

    public org.osid.acknowledgement.CreditAdminSession getCreditAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the credit 
     *  administration service for the given billing. 
     *
     *  @param  billingId the <code> Id </code> of the <code> Billing </code> 
     *  @return a <code> CreditAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Billing </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> billingId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsCreditAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCreditAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.acknowledgement.CreditAdminSession getCreditAdminSessionForBilling(org.osid.id.Id billingId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the credit 
     *  notification service. 
     *
     *  @param  creditReceiver the receiver 
     *  @return a <code> CreditNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> creditReceiver </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCreditNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCreditNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.acknowledgement.CreditNotificationSession getCreditNotificationSession(org.osid.acknowledgement.CreditReceiver creditReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the credit 
     *  notification service for the given billing. 
     *
     *  @param  creditReceiver the receiver 
     *  @param  billingId the <code> Id </code> of the <code> Billing </code> 
     *  @return a <code> CreditNotificationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Billing </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> creditReceiver </code> 
     *          or <code> billingId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCreditNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCreditNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.acknowledgement.CreditNotificationSession getCreditNotificationSessionForBilling(org.osid.acknowledgement.CreditReceiver creditReceiver, 
                                                                                                     org.osid.id.Id billingId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving credit to billing mappings. 
     *
     *  @return a <code> CreditBillingSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsCreditBilling() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCreditBilling() </code> is <code> true. </code> 
     */

    public org.osid.acknowledgement.CreditBillingSession getCreditBillingSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning credit to billing mappings. 
     *
     *  @return a <code> CreditBillingAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCreditBillingAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCreditBillingAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.acknowledgement.CreditBillingAssignmentSession getCreditBillingAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session associated with the credit smart billing for the 
     *  given billing. 
     *
     *  @param  billingId the <code> Id </code> of the billing 
     *  @return a <code> CreditSmartBillingSession </code> 
     *  @throws org.osid.NotFoundException <code> billingId </code> not found 
     *  @throws org.osid.NullArgumentException <code> billingId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCreditSmartBilling() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCreditSmartBilling() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.acknowledgement.CreditSmartBillingSession getCreditSmartBillingSession(org.osid.id.Id billingId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the billing lookup 
     *  service. 
     *
     *  @return a <code> BillingLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBillingLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBillingLookup() </code> is <code> true. </code> 
     */

    public org.osid.acknowledgement.BillingLookupSession getBillingLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the billing query 
     *  service. 
     *
     *  @return a <code> BillingQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBillingQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBillingQuery() </code> is <code> true. </code> 
     */

    public org.osid.acknowledgement.BillingQuerySession getBillingQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the billing search 
     *  service. 
     *
     *  @return a <code> BillingSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBillingSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBillingSearch() </code> is <code> true. </code> 
     */

    public org.osid.acknowledgement.BillingSearchSession getBillingSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the billing 
     *  administrative service. 
     *
     *  @return a <code> BillingAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBillingAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBillingAdmin() </code> is <code> true. </code> 
     */

    public org.osid.acknowledgement.BillingAdminSession getBillingAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the billing 
     *  notification service. 
     *
     *  @param  billingReceiver the receiver 
     *  @return a <code> BillingNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> billingReceiver </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBillingNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBillingNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.acknowledgement.BillingNotificationSession getBillingNotificationSession(org.osid.acknowledgement.BillingReceiver billingReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the billing 
     *  hierarchy service. 
     *
     *  @return a <code> BillingHierarchySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBillingHierarchy() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBillingHierarchy() </code> is <code> true. </code> 
     */

    public org.osid.acknowledgement.BillingHierarchySession getBillingHierarchySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the billing 
     *  hierarchy design service. 
     *
     *  @return a <code> BillingHierarchyDesignSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBillingHierarchyDesign() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBillingHierarchyDesign() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.acknowledgement.BillingHierarchyDesignSession getBillingHierarchyDesignSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets an <code> AcknowledgementBatchManager. </code> 
     *
     *  @return an <code> AcknowledgementBatchManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAcknowledgementBach() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAcknowledgementBatch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.acknowledgement.batch.AcknowledgementBatchManager getAcknowledgementBatchManager()
        throws org.osid.OperationFailedException;
}
