//
// org.osid.acknowledgement.BillingAdminSession
//
//     The OSID Java specification for org.osid.acknowledgement.BillingAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.acknowledgement;


/**
 *  <p>This session creates, updates, and deletes <code> Billings. </code> The 
 *  data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Billing, </code> a <code> BillingForm </code> is requested using <code> 
 *  getBillingFormForCreate() </code> specifying the desired record <code> 
 *  Types </code> or none if no record <code> Types </code> are needed. The 
 *  returned <code> BillingForm </code> will indicate that it is to be used 
 *  with a create operation and can be used to examine metdata or validate 
 *  data prior to creation. Once the <code> BillingForm </code> is submiited 
 *  to a create operation, it cannot be reused with another create operation 
 *  unless the first operation was unsuccessful. Each <code> BillingForm 
 *  </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> BillingForms </code> are requested to the <code> 
 *  Billing </code> <code> Id </code> that is to be updated using <code> 
 *  getBillingFormForUpdate(). </code> Similarly, the <code> BillingForm 
 *  </code> has metadata about the data that can be updated and it can perform 
 *  validation before submitting the update. The <code> BillingForm </code> 
 *  can only be used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Billings. </code> It is safer to 
 *  remove all mappings to the <code> Billing </code> catalogs before 
 *  deletion. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface BillingAdminSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can create <code> Billings. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> Billing </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not wish to offer create operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Billing </code> creation is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateBillings();


    /**
     *  Tests if this user can create a single <code> Billing </code> using 
     *  the desired record types. While <code> 
     *  AcknowledgementManager.getBillingRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> Billing. </code> Providing 
     *  an empty array tests if a <code> Billing </code> can be created with 
     *  no records. 
     *
     *  @param  billingRecordTypes array of types 
     *  @return <code> true </code> if <code> Billing </code> creation using 
     *          the specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> billingRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateBillingWithRecordTypes(org.osid.type.Type[] billingRecordTypes);


    /**
     *  Gets the billing form for creating new billings. A new form should be 
     *  requested for each create transaction. 
     *
     *  @param  billingRecordTypes array of types 
     *  @return the billing form 
     *  @throws org.osid.NullArgumentException <code> billingRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException cannot get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.BillingForm getBillingFormForCreate(org.osid.type.Type[] billingRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Billing. </code> 
     *
     *  @param  billingForm the form for this <code> Billing </code> 
     *  @return the new <code> Billing </code> 
     *  @throws org.osid.IllegalStateException <code> billingForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> billingForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> billingForm </code> did 
     *          not originate from <code> getBillingFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.Billing createBilling(org.osid.acknowledgement.BillingForm billingForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Billings. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> Billing </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not wish to offer update operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Billing </code> modification is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateBillings();


    /**
     *  Gets the billing form for updating an existing billing. A new billing 
     *  form should be requested for each update transaction. 
     *
     *  @param  billingId the <code> Id </code> of the <code> Billing </code> 
     *  @return the billing form 
     *  @throws org.osid.NotFoundException <code> billingId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> billingId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.BillingForm getBillingFormForUpdate(org.osid.id.Id billingId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing billing. 
     *
     *  @param  billingForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> billingForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> billingForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> billingForm did not 
     *          originate from getBillingFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateBilling(org.osid.acknowledgement.BillingForm billingForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> Billings </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> Billing </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not wish to offer delete operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Billing </code> deletion is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteBillings();


    /**
     *  Deletes a <code> Billing. </code> 
     *
     *  @param  billingId the <code> Id </code> of the <code> Billing </code> 
     *          to remove 
     *  @throws org.osid.NotFoundException <code> billingId </code> not found 
     *  @throws org.osid.NullArgumentException <code> billingId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteBilling(org.osid.id.Id billingId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Billings. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Billing </code> aliasing is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageBillingAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Billing </code> for the purpose 
     *  of creating compatibility. The primary <code> Id </code> of the <code> 
     *  Item </code> is determined by the provider. The new <code> Id </code> 
     *  is an alias to the primary <code> Id. </code> If the alias is a 
     *  pointer to another billing, it is reassigned to the given billing 
     *  <code> Id. </code> 
     *
     *  @param  billingId the <code> Id </code> of a <code> Billing </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is in 
     *          use as a primary <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> billingId </code> not found 
     *  @throws org.osid.NullArgumentException <code> billingId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasBilling(org.osid.id.Id billingId, org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
