//
// org.osid.acknowledgement.BillingQueryInspector
//
//     The OSID Java specification for org.osid.acknowledgement.BillingQueryInspector.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.acknowledgement;


/**
 *  <p>The query inspectors provide a means of accessing the match terms of a 
 *  query. These interfaces are used to examine the actual query terms used in 
 *  a search or that may be used to create a smart catalog. Query inspectors 
 *  may be converted to <code> OsidQuery </code> interfaces for reuse or 
 *  modification in the search sessions. </p>
 */

public interface BillingQueryInspector
    extends org.osid.OsidCatalogQueryInspector {


    /**
     *  Gets the credit <code> Id </code> query terms. 
     *
     *  @return the credit <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getCreditIdTerms();


    /**
     *  Gets the credit query terms. 
     *
     *  @return the credit terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.CreditQueryInspector[] getCreditTerms();


    /**
     *  Gets the ancestor billing <code> Id </code> query terms. 
     *
     *  @return the ancestor billing <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getAncestorBillingIdTerms();


    /**
     *  Gets the ancestor billing query terms. 
     *
     *  @return the ancestor billing terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.BillingQueryInspector[] getAncestorBillingTerms();


    /**
     *  Gets the descendant billing <code> Id </code> query terms. 
     *
     *  @return the descendant billing <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getDescendantBillingIdTerms();


    /**
     *  Gets the descendant billing query terms. 
     *
     *  @return the descendant billing terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.BillingQueryInspector[] getDescendantBillingTerms();


    /**
     *  Gets the record query inspector record corresponding to the given 
     *  <code> Billing </code> record <code> Type. </code> 
     *
     *  @param  billingRecordType a billing record type 
     *  @return the billing query inspector record 
     *  @throws org.osid.NullArgumentException <code> billingRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(billingRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.records.BillingQueryInspectorRecord getBillingQueryInspectorRecord(org.osid.type.Type billingRecordType)
        throws org.osid.OperationFailedException;
}
