//
// org.osid.acknowledgement.BillingSearchSession
//
//     The OSID Java specification for org.osid.acknowledgement.BillingSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.acknowledgement;


/**
 *  <p>This session provides methods for searching <code> Billing </code> 
 *  objects. The search query is constructed using the <code> BillingQuery. 
 *  </code> The billing record <code> Type </code> also specifies the billing 
 *  query record for the billing query. </p> 
 *  
 *  <p> <code> getBillingsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Billing </code> elements. A more advanced search 
 *  may be performed with <code> getBillingsBySearch(). </code> It accepts a 
 *  <code> BillingSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getBillingsBySearch() </code> returns a <code> 
 *  BillingSearchResults </code> that can be used to access the resulting 
 *  <code> BillingList </code> or be used to perform a search within the 
 *  result set through <code> BillingSearch. </code> </p> 
 *  
 *  <p> Billings may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> BillingQuery. </code> 
 *  The returns in this session may not be cast directly to these interfaces. 
 *  </p>
 */

public interface BillingSearchSession
    extends org.osid.acknowledgement.BillingQuerySession {


    /**
     *  Gets a billing search. 
     *
     *  @return the billing search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.BillingSearch getBillingSearch();


    /**
     *  Gets a billing search order. The <code> BillingSearchOrder </code> is 
     *  supplied to a <code> BillingSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the billing search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.BillingSearchOrder getBillingSearchOrder();


    /**
     *  Gets the search results matching the given search. 
     *
     *  @param  billingQuery the billing query 
     *  @param  billingSearch the billing search 
     *  @return the search results 
     *  @throws org.osid.NullArgumentException <code> billingQuery </code> or 
     *          <code> billingSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> billingQuery </code> or 
     *          <code> billingSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.BillingSearchResults getBillingsBySearch(org.osid.acknowledgement.BillingQuery billingQuery, 
                                                                             org.osid.acknowledgement.BillingSearch billingSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a billing query from an inspector. The inspector is available 
     *  from a <code> BillingSearchResults. </code> 
     *
     *  @param  billingQueryInspector a billing query inspector 
     *  @return the billing query 
     *  @throws org.osid.NullArgumentException <code> billingQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> ibillingQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.BillingQuery getBillingQueryFromInspector(org.osid.acknowledgement.BillingQueryInspector billingQueryInspector);
}
