//
// org.osid.acknowledgement.CreditAdminSession
//
//     The OSID Java specification for org.osid.acknowledgement.CreditAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.acknowledgement;


/**
 *  <p>This session creates, updates, and deletes <code> Credits. </code> The 
 *  data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Credit, </code> a <code> CreditForm </code> is requested using <code> 
 *  getCreditFormForCreate() </code> specifying the desired relationship peers 
 *  and record <code> Types </code> or none if no record <code> Types </code> 
 *  are needed. The returned <code> CreditForm </code> will indicate that it 
 *  is to be used with a create operation and can be used to examine metdata 
 *  or validate data prior to creation. Once the <code> CreditForm </code> is 
 *  submiited to a create operation, it cannot be reused with another create 
 *  operation unless the first operation was unsuccessful. Each <code> 
 *  CreditForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> CreditForms </code> are requested to the <code> 
 *  Credit </code> <code> Id </code> that is to be updated using <code> 
 *  getCreditFormForUpdate(). </code> Similarly, the <code> CreditForm </code> 
 *  has metadata about the data that can be updated and it can perform 
 *  validation before submitting the update. The <code> CreditForm </code> can 
 *  only be used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Credits. </code> To unmap a <code> 
 *  Credit </code> from the current <code> Billing, </code> the <code> 
 *  CreditBillingAssignmentSession </code> should be used. These delete 
 *  operations attempt to remove the <code> Credit </code> itself thus 
 *  removing it from all known <code> Billing </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface CreditAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Billing </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Billing Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBillingId();


    /**
     *  Gets the <code> Billing </code> associated with this session. 
     *
     *  @return the billing 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.Billing getBilling()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create credits. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known creating a <code> Credit </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer create operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Credit </code> creation is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateCredits();


    /**
     *  Tests if this user can create a single <code> Credit </code> using the 
     *  desired record types. While <code> 
     *  AcknowledgementManager.getCreditRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> Credit. </code> Providing 
     *  an empty array tests if a <code> Credit </code> can be created with no 
     *  records. 
     *
     *  @param  creditRecordTypes array of credit record types 
     *  @return <code> true </code> if <code> Credit </code> creation using 
     *          the specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> creditRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateCreditWithRecordTypes(org.osid.type.Type[] creditRecordTypes);


    /**
     *  Gets the credit form for creating new credits. A new form should be 
     *  requested for each create transaction. 
     *
     *  @param  referenceId the reference <code> Id </code> 
     *  @param  resourceId the resource <code> Id </code> 
     *  @param  creditRecordTypes array of credit record types to be included 
     *          in the create operation or an empty list if none 
     *  @return the credit form 
     *  @throws org.osid.NotFoundException <code> referenceId </code> or 
     *          <code> resourceId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> referenceId, resourceId 
     *          </code> or <code> creditRecordTypes </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException cannot get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.CreditForm getCreditFormForCreate(org.osid.id.Id referenceId, 
                                                                      org.osid.id.Id resourceId, 
                                                                      org.osid.type.Type[] creditRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Credit. </code> 
     *
     *  @param  creditForm the form for this <code> Credit </code> 
     *  @return the new <code> Credit </code> 
     *  @throws org.osid.IllegalStateException <code> creditForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> creditForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> creditForm </code> did 
     *          not originate from <code> getCreditFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.Credit createCredit(org.osid.acknowledgement.CreditForm creditForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update credits. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known updating a <code> Credit </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer update operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Credit </code> modification is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateCredits();


    /**
     *  Gets the credit form for updating an existing credit. A new credit 
     *  form should be requested for each update transaction. 
     *
     *  @param  creditId the <code> Id </code> of the <code> Credit </code> 
     *  @return the credit form 
     *  @throws org.osid.NotFoundException <code> creditId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> creditId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.CreditForm getCreditFormForUpdate(org.osid.id.Id creditId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing credit. 
     *
     *  @param  creditForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> creditForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> creditForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> creditForm </code> did 
     *          not originate from <code> getCreditFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateCredit(org.osid.acknowledgement.CreditForm creditForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete credits. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known deleting an <code> Credit </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer delete operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Credit </code> deletion is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteCredits();


    /**
     *  Deletes a <code> Credit. </code> 
     *
     *  @param  creditId the <code> Id </code> of the <code> Credit </code> to 
     *          remove 
     *  @throws org.osid.NotFoundException <code> creditId </code> not found 
     *  @throws org.osid.NullArgumentException <code> creditId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteCredit(org.osid.id.Id creditId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Credits. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Credit </code> aliasing is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageCreditAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Credit </code> for the purpose 
     *  of creating compatibility. The primary <code> Id </code> of the <code> 
     *  Credit </code> is determined by the provider. The new <code> Id 
     *  </code> is an alias to the primary <code> Id. </code> If the alias is 
     *  a pointer to another credit, it is reassigned to the given credit 
     *  <code> Id. </code> 
     *
     *  @param  creditId the <code> Id </code> of a <code> Credit </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is in 
     *          use as a primary <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> creditId </code> not found 
     *  @throws org.osid.NullArgumentException <code> creditId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasCredit(org.osid.id.Id creditId, org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
