//
// org.osid.acknowledgement.CreditBillingAssignmentSession
//
//     The OSID Java specification for org.osid.acknowledgement.CreditBillingAssignmentSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.acknowledgement;


/**
 *  <p>This session provides methods to re-assign <code> Credits </code> to 
 *  <code> Bilings. </code> A <code> Credit </code> may map to multiple <code> 
 *  Billings </code> and removing the last reference to a <code> Credit 
 *  </code> is the equivalent of deleting it. Each <code> Billing </code> may 
 *  have its own authorizations governing who is allowed to operate on it. 
 *  </p> 
 *  
 *  <p> Adding a reference of a <code> Credit </code> to another <code> 
 *  Billing </code> is not a copy operation (eg: does not change its <code> Id 
 *  </code> ). </p>
 */

public interface CreditBillingAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter credit/billing mappings. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignCredits();


    /**
     *  Tests if this user can alter credit/billing mappings. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @param  billingId the <code> Id </code> of the <code> Billing </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> billingId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignCreditsToBilling(org.osid.id.Id billingId);


    /**
     *  Gets a list of billings including and under the given billing node in 
     *  which any credit can be assigned. 
     *
     *  @param  billingId the <code> Id </code> of the <code> Billing </code> 
     *  @return list of assignable billing <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> billingId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableBillingIds(org.osid.id.Id billingId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of billings including and under the given billing node in 
     *  which a specific credit can be assigned. 
     *
     *  @param  billingId the <code> Id </code> of the <code> Billing </code> 
     *  @param  creditId the <code> Id </code> of the <code> Credit </code> 
     *  @return list of assignable billing <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> billingId </code> or 
     *          <code> creditId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableBillingIdsForCredit(org.osid.id.Id billingId, 
                                                               org.osid.id.Id creditId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> Credit </code> to a <code> Billing. </code> 
     *
     *  @param  creditId the <code> Id </code> of the <code> Credit </code> 
     *  @param  billingId the <code> Id </code> of the <code> Billing </code> 
     *  @throws org.osid.AlreadyExistsException <code> creditId </code> 
     *          already assigned to <code> billingId </code> 
     *  @throws org.osid.NotFoundException <code> creditId </code> or <code> 
     *          billingId </code> not found 
     *  @throws org.osid.NullArgumentException <code> creditId </code> or 
     *          <code> billingId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignCreditToBilling(org.osid.id.Id creditId, 
                                      org.osid.id.Id billingId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> Credit </code> from a <code> Billing. </code> 
     *
     *  @param  creditId the <code> Id </code> of the <code> Credit </code> 
     *  @param  billingId the <code> Id </code> of the <code> Billing </code> 
     *  @throws org.osid.NotFoundException <code> creditId </code> or <code> 
     *          billingId </code> not found or <code> creditId </code> not 
     *          mapped to <code> billingId </code> 
     *  @throws org.osid.NullArgumentException <code> creditId </code> or 
     *          <code> billingId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignCreditFromBilling(org.osid.id.Id creditId, 
                                          org.osid.id.Id billingId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Moves a <code> Credit </code> from one <code> Billing </code> to 
     *  another. Mappings to other <code> Billings </code> are unaffected. 
     *
     *  @param  creditId the <code> Id </code> of the <code> Credit </code> 
     *  @param  fromBillingId the <code> Id </code> of the current <code> 
     *          Billing </code> 
     *  @param  toBiillingId the <code> Id </code> of the destination <code> 
     *          Billing </code> 
     *  @throws org.osid.NotFoundException <code> creditId, fromBillingId, 
     *          </code> or <code> toBillingId </code> not found or <code> 
     *          creditId </code> not mapped to <code> fromBillingId </code> 
     *  @throws org.osid.NullArgumentException <code> creditId, billingId, 
     *          </code> or <code> toBillingId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void reassignCreditToBilling(org.osid.id.Id creditId, 
                                        org.osid.id.Id fromBillingId, 
                                        org.osid.id.Id toBiillingId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
