//
// org.osid.acknowledgement.CreditSmartBillingSession
//
//     The OSID Java specification for org.osid.acknowledgement.CreditSmartBillingSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.acknowledgement;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. A <code> CreditQuery </code> can be retrieved from this session 
 *  and mapped to this <code> Billing </code> to create a virtual collection 
 *  of <code> Credits. </code> The credits may be sequenced using the <code> 
 *  CreditSearchOrder </code> from this session. </p> 
 *  
 *  <p> This <code> Billing </code> has a default query that matches any 
 *  credit and a default search order that specifies no sequencing. The 
 *  queries may be examined using a <code> CreditQueryInspector. </code> The 
 *  query may be modified by converting the inspector back to a <code> 
 *  CreditQuery. </code> </p>
 */

public interface CreditSmartBillingSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Billing </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Billing Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBillingId();


    /**
     *  Gets the <code> Billing </code> associated with this session. 
     *
     *  @return the <code> Billing </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.Billing getBilling()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart billings. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart billing management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartBillings();


    /**
     *  Gets a credit query. 
     *
     *  @return the credit query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.CreditQuery getCreditQuery();


    /**
     *  Gets a credit search order. 
     *
     *  @return the credit search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.CreditSearchOrder getCreditSearchOrder();


    /**
     *  Applies a credit query to this billing. 
     *
     *  @param  creditQuery the credit query 
     *  @throws org.osid.NullArgumentException <code> creditQuery </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> creditQuery </code> not 
     *          of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyCreditQuery(org.osid.acknowledgement.CreditQuery creditQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a credit query inspector for this billing. 
     *
     *  @return the credit query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.CreditQueryInspector inspectCreditQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a credit search order to this billing. 
     *
     *  @param  creditSearchOrder the credit search order 
     *  @throws org.osid.NullArgumentException <code> creditSearchOrder 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> creditSearchOrder </code> 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyCreditSequencing(org.osid.acknowledgement.CreditSearchOrder creditSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a credit query from an inspector. 
     *
     *  @param  creditQueryInspector a query inspector 
     *  @return the credit query 
     *  @throws org.osid.NullArgumentException <code> creditQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> creditQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.CreditQuery getCreditQueryFromInspector(org.osid.acknowledgement.CreditQueryInspector creditQueryInspector);
}
