//
// org.osid.assessment.Assessment
//
//     The OSID Java specification for org.osid.assessment.Assessment.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment;


/**
 *  <p>An <code> Assessment </code> represents a sequence of assessment items. 
 *  Like all OSID objects, an <code> Assessment </code> is identified by its 
 *  <code> Id </code> and any persisted references should use the <code> Id. 
 *  </code> </p> 
 *  
 *  <p> An <code> Assessment </code> may have an accompanying rubric used for 
 *  assessing performance. The rubric assessment is established canonically in 
 *  this <code> Assessment. </code> </p>
 */

public interface Assessment
    extends org.osid.OsidObject {


    /**
     *  Gets the <code> Id </code> of a <code> Grade </code> corresponding to 
     *  the assessment difficulty. 
     *
     *  @return a grade <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getLevelId();


    /**
     *  Gets the <code> Grade </code> corresponding to the assessment 
     *  difficulty. 
     *
     *  @return the level 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.Grade getLevel()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if a rubric assessment is associated with this assessment. 
     *
     *  @return <code> true </code> if a rubric is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasRubric();


    /**
     *  Gets the <code> Id </code> of the rubric. 
     *
     *  @return an assessment <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> hasRubric() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getRubricId();


    /**
     *  Gets the rubric. 
     *
     *  @return the assessment 
     *  @throws org.osid.IllegalStateException <code> hasRubric() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.Assessment getRubric()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the assessment record corresponding to the given <code> 
     *  Assessment </code> record <code> Type. </code> This method is used to 
     *  retrieve an object implementing the requested record. The <code> 
     *  assessmentRecordType </code> may be the <code> Type </code> returned 
     *  in <code> getRecordTypes() </code> or any of its parents in a <code> 
     *  Type </code> hierarchy where <code> 
     *  hasRecordType(assessmentRecordType) </code> is <code> true </code> . 
     *
     *  @param  assessmentRecordType the type of the record to retrieve 
     *  @return the assessment record 
     *  @throws org.osid.NullArgumentException <code> assessmentRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(assessmentRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.records.AssessmentRecord getAssessmentRecord(org.osid.type.Type assessmentRecordType)
        throws org.osid.OperationFailedException;
}
