//
// org.osid.assessment.AssessmentBankAssignmentSession
//
//     The OSID Java specification for org.osid.assessment.AssessmentBankAssignmentSession.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment;


/**
 *  <p>This session provides methods to re-assign <code> Assessments </code> 
 *  to <code> Banks. </code> An <code> Assessment </code> may map to multiple 
 *  <code> Banks </code> and removing the last reference to an <code> 
 *  Assessment </code> is the equivalent of deleting it. Each <code> Bank 
 *  </code> may have its own authorizations governing who is allowed to 
 *  operate on it. </p> 
 *  
 *  <p> Moving or adding a reference of an <code> Assessment </code> to 
 *  another <code> Bank </code> is not a copy operation (eg: does not change 
 *  its <code> Id </code> ). </p>
 */

public interface AssessmentBankAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter assessment/bank mappings. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignAssessments();


    /**
     *  Tests if this user can alter assessment/bank mappings. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @param  bankId the <code> Id </code> of the <code> Bank </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> bankId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignAssessmentsToBank(org.osid.id.Id bankId);


    /**
     *  Gets a list of banks including and under the given banks node in which 
     *  any assessment can be assigned. 
     *
     *  @param  bankId the <code> Id </code> of the <code> Bank </code> 
     *  @return list of assignable bank <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> bankId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableBankIds(org.osid.id.Id bankId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of bank including and under the given bank node in which a 
     *  specific assessment can be assigned. 
     *
     *  @param  bankId the <code> Id </code> of the <code> Bank </code> 
     *  @param  assessmentId the <code> Id </code> of the <code> Assessment 
     *          </code> 
     *  @return list of assignable bank <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> bankId </code> or <code> 
     *          assessmentId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableBankIdsForAssessment(org.osid.id.Id bankId, 
                                                                org.osid.id.Id assessmentId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> Assessment </code> to a <code> Bank. </code> 
     *
     *  @param  assessmentId the <code> Id </code> of the <code> Assessment 
     *          </code> 
     *  @param  bankId the <code> Id </code> of the <code> Bank </code> 
     *  @throws org.osid.AlreadyExistsException <code> assessmentId </code> is 
     *          already assigned to <code> bankId </code> 
     *  @throws org.osid.NotFoundException <code> assessmentId </code> or 
     *          <code> bankId </code> not found 
     *  @throws org.osid.NullArgumentException <code> assessmentId </code> or 
     *          <code> bankId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignAssessmentToBank(org.osid.id.Id assessmentId, 
                                       org.osid.id.Id bankId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes an <code> Assessment </code> from a <code> Bank. </code> 
     *
     *  @param  assessmentId the <code> Id </code> of the <code> Assessment 
     *          </code> 
     *  @param  bankId the <code> Id </code> of the <code> Bank </code> 
     *  @throws org.osid.NotFoundException <code> assessmentId </code> or 
     *          <code> bankId </code> not found or <code> assessmentId </code> 
     *          not assigned to <code> bankId </code> 
     *  @throws org.osid.NullArgumentException <code> assessmentId </code> or 
     *          <code> bankId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignAssessmentFromBank(org.osid.id.Id assessmentId, 
                                           org.osid.id.Id bankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Moves an <code> Assessment </code> from one <code> Bank </code> to 
     *  another. Mappings to other <code> Banks </code> are unaffected. 
     *
     *  @param  assessmentId the <code> Id </code> of the <code> Assessment 
     *          </code> 
     *  @param  fromBankId the <code> Id </code> of the current <code> Bank 
     *          </code> 
     *  @param  toBankId the <code> Id </code> of the destination <code> Bank 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> assessmentId, fromBankId, 
     *          </code> or <code> toBankId </code> not found or <code> 
     *          assessmentId </code> not mapped to <code> fromBankId </code> 
     *  @throws org.osid.NullArgumentException <code> assessmentId, 
     *          fromBankId, </code> or <code> toBankId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void reassignAssessmentToBilling(org.osid.id.Id assessmentId, 
                                            org.osid.id.Id fromBankId, 
                                            org.osid.id.Id toBankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
