//
// org.osid.assessment.AssessmentOffered
//
//     The OSID Java specification for org.osid.assessment.AssessmentOffered.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment;


/**
 *  <p>An <code> AssessmentOffered </code> represents a sequence of assessment 
 *  items. Like all OSID objects, an <code> AssessmentOffered </code> is 
 *  identified by its <code> Id </code> and any persisted references should 
 *  use the <code> Id. </code> </p>
 */

public interface AssessmentOffered
    extends org.osid.OsidObject,
            org.osid.Subjugateable {


    /**
     *  Gets the assessment <code> Id </code> corresponding to this assessment 
     *  offering. 
     *
     *  @return the assessment id 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAssessmentId();


    /**
     *  Gets the assessment corresponding to this assessment offereng. 
     *
     *  @return the assessment 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.Assessment getAssessment()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of a <code> Grade </code> corresponding to 
     *  the assessment difficulty. 
     *
     *  @return a grade id 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getLevelId();


    /**
     *  Gets the <code> Grade </code> corresponding to the assessment 
     *  difficulty. 
     *
     *  @return the level 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.Grade getLevel()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if the items or parts in this assessment are taken sequentially. 
     *
     *  @return <code> true </code> if the items are taken sequentially, 
     *          <code> false </code> if the items can be skipped and revisited 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean areItemsSequential();


    /**
     *  Tests if the items or parts appear in a random order. 
     *
     *  @return <code> true </code> if the items appear in a random order, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean areItemsShuffled();


    /**
     *  Tests if there is a fixed start time for this assessment. 
     *
     *  @return <code> true </code> if there is a fixed start time, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasStartTime();


    /**
     *  Gets the start time for this assessment. 
     *
     *  @return the designated start time 
     *  @throws org.osid.IllegalStateException <code> hasStartTime() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getStartTime();


    /**
     *  Tests if there is a fixed end time for this assessment. 
     *
     *  @return <code> true </code> if there is a fixed end time, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasDeadline();


    /**
     *  Gets the end time for this assessment. 
     *
     *  @return the designated end time 
     *  @throws org.osid.IllegalStateException <code> hasDeadline() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getDeadline();


    /**
     *  Tests if there is a fixed duration for this assessment. 
     *
     *  @return <code> true </code> if there is a fixed duration, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasDuration();


    /**
     *  Gets the duration for this assessment. 
     *
     *  @return the duration 
     *  @throws org.osid.IllegalStateException <code> hasDuration() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Duration getDuration();


    /**
     *  Tests if this assessment will be scored. 
     *
     *  @return <code> true </code> if this assessment will be scored <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isScored();


    /**
     *  Gets the grade system <code> Id </code> for the score. 
     *
     *  @return the grade system <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> isScored() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getScoreSystemId();


    /**
     *  Gets the grade system for the score. 
     *
     *  @return the grade system 
     *  @throws org.osid.IllegalStateException <code> isScored() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeSystem getScoreSystem()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this assessment will be graded. 
     *
     *  @return <code> true </code> if this assessment will be graded, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isGraded();


    /**
     *  Gets the grade system <code> Id </code> for the grade. 
     *
     *  @return the grade system <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> isGraded() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getGradeSystemId();


    /**
     *  Gets the grade system for the grade. 
     *
     *  @return the grade system 
     *  @throws org.osid.IllegalStateException <code> isGraded() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeSystem getGradeSystem()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if a rubric assessment is associated with this assessment. 
     *
     *  @return <code> true </code> if a rubric is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasRubric();


    /**
     *  Gets the <code> Id </code> of the rubric. 
     *
     *  @return an assessment offered <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> hasRubric() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getRubricId();


    /**
     *  Gets the rubric. 
     *
     *  @return the assessment offered 
     *  @throws org.osid.IllegalStateException <code> hasRubric() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentOffered getRubric()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the assessment offered record corresponding to the given <code> 
     *  AssessmentOffered </code> record <code> Type. </code> This method is 
     *  used to retrieve an object implementing the requested record. The 
     *  <code> assessmentOfferedRecordType </code> may be the <code> Type 
     *  </code> returned in <code> getRecordTypes() </code> or any of its 
     *  parents in a <code> Type </code> hierarchy where <code> 
     *  hasRecordType(assessmentOfferedRecordType) </code> is <code> true 
     *  </code> . 
     *
     *  @param  assessmentTakenRecordType an assessment offered record type 
     *  @return the assessment offered record 
     *  @throws org.osid.NullArgumentException <code> 
     *          assessmentOfferedRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(assessmentOfferedRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.records.AssessmentOfferedRecord getAssessmentOfferedRecord(org.osid.type.Type assessmentTakenRecordType)
        throws org.osid.OperationFailedException;
}
