//
// org.osid.assessment.AssessmentOfferedBankSession
//
//     The OSID Java specification for org.osid.assessment.AssessmentOfferedBankSession.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment;


/**
 *  <p>This session provides methods to retrieve <code> AssessmentOffered 
 *  </code> to <code> Bank </code> mappings. An <code> AssessmentOffered 
 *  </code> may appear in multiple <code> Banks. </code> Each <code> Bank 
 *  </code> may have its own authorizations governing who is allowed to look 
 *  at it. </p> 
 *  
 *  <p> This lookup session defines two views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *  </ul>
 *  
 */

public interface AssessmentOfferedBankSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can perform lookups of assessment offered/bank 
     *  mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known lookup 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if looking up mappings is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupAssessmentOfferedBankMappings();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as assessment, and not result in an error. 
     *  This view is used when greater interoperability is desired at the 
     *  expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeBankView();


    /**
     *  A complete view of the <code> AssessmentOffered </code> and <code> 
     *  Bank </code> returns is desired. Methods will return what is requested 
     *  or result in an error. This view is used when greater precision is 
     *  desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryBankView();


    /**
     *  Gets the list of <code> AssessmentOffered </code> <code> Ids </code> 
     *  associated with a <code> Bank. </code> 
     *
     *  @param  bankId <code> Id </code> of the <code> Bank </code> 
     *  @return list of related assessment offered <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> bankId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> bankId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssessmentOfferedIdsByBank(org.osid.id.Id bankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> AssessmentOffereds </code> associated with a 
     *  <code> Bank. </code> 
     *
     *  @param  bankId <code> Id </code> of the <code> Bank </code> 
     *  @return list of related assessments offered 
     *  @throws org.osid.NotFoundException <code> bankId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> bankId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentOfferedList getAssessmentsOfferedByBank(org.osid.id.Id bankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> AssessmentOffered Ids </code> corresponding to 
     *  a list of <code> Banks. </code> 
     *
     *  @param  bankIds list of bank <code> Ids </code> 
     *  @return list of bank <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> bankIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssessmentOfferedIdsByBanks(org.osid.id.IdList bankIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> AssessmentOffered </code> objects 
     *  corresponding to a list of <code> Banks. </code> 
     *
     *  @param  bankIds list of bank <code> Ids </code> 
     *  @return list of assessments offered 
     *  @throws org.osid.NullArgumentException <code> bankIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentOfferedList getAssessmentsOfferedByBanks(org.osid.id.IdList bankIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> Bank </code> <code> Ids </code> mapped to an 
     *  <code> AssessmentOffered. </code> 
     *
     *  @param  assessmentOfferedId <code> Id </code> of an <code> 
     *          AssessmentOffered </code> 
     *  @return list of bank <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> assessmentOfferedId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> assessmentOfferedId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getBankIdsByAssessmentOffered(org.osid.id.Id assessmentOfferedId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> Banks </code> mapped to an <code> 
     *  AssessmentOffered. </code> 
     *
     *  @param  assessmentOfferedId <code> Id </code> of an <code> 
     *          AssessmentOffered </code> 
     *  @return list of banks 
     *  @throws org.osid.NotFoundException <code> assessmentOfferedId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> assessmentOfferedId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.BankList getBanksByAssessmentOffered(org.osid.id.Id assessmentOfferedId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
