//
// org.osid.assessment.AssessmentOfferedForm
//
//     The OSID Java specification for org.osid.assessment.AssessmentOfferedForm.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment;


/**
 *  <p>This is the form for creating and updating an <code> AssessmentOffered. 
 *  </code> Like all <code> OsidForm </code> objects, various data elements 
 *  may be set here for use in the create and update methods in the <code> 
 *  AssessmentOfferedAdminSession. </code> For each data element that may be 
 *  set, metadata may be examined to provide display hints or data 
 *  constraints. </p>
 */

public interface AssessmentOfferedForm
    extends org.osid.OsidObjectForm,
            org.osid.OsidSubjugateableForm {


    /**
     *  Gets the metadata for a grade level. 
     *
     *  @return metadata for the grade level 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getLevelMetadata();


    /**
     *  Sets the level of difficulty expressed as a <code> Grade. </code> 
     *
     *  @param  gradeId the grade level 
     *  @throws org.osid.InvalidArgumentException <code> gradeId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setLevel(org.osid.id.Id gradeId);


    /**
     *  Clears the level. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLevel();


    /**
     *  Gets the metadata for sequential operation. 
     *
     *  @return metadata for the sequential flag 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getItemsSequentialMetadata();


    /**
     *  Sets the items sequential flag. 
     *
     *  @param  sequential <code> true </code> if the items are taken 
     *          sequentially, <code> false </code> if the items can be skipped 
     *          and revisited 
     *  @throws org.osid.InvalidArgumentException <code> sequential </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setItemsSequential(boolean sequential);


    /**
     *  Clears the items sequential flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearItemsSequential();


    /**
     *  Gets the metadata for shuffling items. 
     *
     *  @return metadata for the shuffled flag 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getItemsShuffledMetadata();


    /**
     *  Sets the shuffle flag. The shuffle flag may be overidden by other 
     *  assessment sequencing rules. 
     *
     *  @param  shuffle <code> true </code> if the items are shuffled, <code> 
     *          false </code> if the items appear in the designated order 
     *  @throws org.osid.InvalidArgumentException <code> shuffle </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setItemsShuffled(boolean shuffle);


    /**
     *  Clears the shuffle flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearItemsShuffled();


    /**
     *  Gets the metadata for the assessment start time. 
     *
     *  @return metadata for the start time 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getStartTimeMetadata();


    /**
     *  Sets the assessment start time. 
     *
     *  @param  start assessment start time 
     *  @throws org.osid.InvalidArgumentException <code> start </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setStartTime(org.osid.calendaring.DateTime start);


    /**
     *  Clears the start time. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStartTime();


    /**
     *  Gets the metadata for the assessment deadline. 
     *
     *  @return metadata for the end time 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getDeadlineMetadata();


    /**
     *  Sets the assessment end time. 
     *
     *  @param  end assessment end time 
     *  @throws org.osid.InvalidArgumentException <code> end </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setDeadline(java.util.Date end);


    /**
     *  Clears the deadline. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDeadline();


    /**
     *  Gets the metadata for the assessment duration 
     *
     *  @return metadata for the duration 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getDurationMetadata();


    /**
     *  Sets the assessment duration. 
     *
     *  @param  duration assessment duration 
     *  @throws org.osid.InvalidArgumentException <code> duration </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setDuration(org.osid.calendaring.Duration duration);


    /**
     *  Clears the duration. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDuration();


    /**
     *  Gets the metadata for a score system. 
     *
     *  @return metadata for the grade system 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getScoreSystemMetadata();


    /**
     *  Sets the scoring system. 
     *
     *  @param  gradeSystemId the grade system 
     *  @throws org.osid.InvalidArgumentException <code> gradeSystemId </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setScoreSystem(org.osid.id.Id gradeSystemId);


    /**
     *  Clears the score system. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearScoreSystem();


    /**
     *  Gets the metadata for a grading system. 
     *
     *  @return metadata for the grade system 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getGradeSystemMetadata();


    /**
     *  Sets the grading system. 
     *
     *  @param  gradeSystemId the grade system 
     *  @throws org.osid.InvalidArgumentException <code> gradeSystemId </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setGradeSystem(org.osid.id.Id gradeSystemId);


    /**
     *  Clears the grading system. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGradeSystem();


    /**
     *  Gets the <code> AssessmentOfferedFormRecord </code> corresponding to 
     *  the given assessment record <code> Type. </code> 
     *
     *  @param  assessmentOfferedRecordType the assessment offered record type 
     *  @return the assessment offered record 
     *  @throws org.osid.NullArgumentException <code> 
     *          assessmentOfferedRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(assessmentOfferedRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.records.AssessmentOfferedFormRecord getAssessmentOfferedFormRecord(org.osid.type.Type assessmentOfferedRecordType)
        throws org.osid.OperationFailedException;
}
