//
// org.osid.assessment.AssessmentOfferedLookupSession
//
//     The OSID Java specification for org.osid.assessment.AssessmentOfferedLookupSession.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment;


/**
 *  <p>This session defines methods for retrieving assessments offered. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated bank view: All assessment methods in this session 
 *      operate, retrieve and pertain to assessments defined explicitly in the 
 *      current bank. Using an isolated view is useful for managing <code> 
 *      Assessments </code> with the <code> AssessmentAdminSession. </code> 
 *      </li> 
 *      <li> federated bank view: All assessment methods in this session 
 *      operate, retrieve and pertain to all assessments defined in this bank 
 *      and any other assessments implicitly available in this bank through 
 *      bank inheritence. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedBankView() </code> and <code> 
 *  useIsolatedBankView() </code> behave as a radio group and one should be 
 *  selected before invoking any lookup methods. </p> 
 *  
 *  <p> Assessments offered may have a record indicated by their respective 
 *  types. The record is accessed via the <code> AssessmentOffered. </code> 
 *  The returns may not be cast directly from the returns in the lookup 
 *  methods. </p>
 */

public interface AssessmentOfferedLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Bank </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Bank Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBankId();


    /**
     *  Gets the <code> Bank </code> associated with this session. 
     *
     *  @return the <code> Bank </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.Bank getBank()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> AssessmentOffered </code> 
     *  lookups. A return of true does not guarantee successful authorization. 
     *  A return of false indicates that it is known all methods in this 
     *  session will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer lookup 
     *  operations to unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupAssessmentsOffered();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as assessment, and not result in an error. 
     *  This view is used when greater interoperability is desired at the 
     *  expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeAssessmentOfferedView();


    /**
     *  A complete view of the <code> AssessmentOffered </code> returns is 
     *  desired. Methods will return what is requested or result in an error. 
     *  This view is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryAssessmentOfferedView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include assessments in banks which are children of this bank in the 
     *  bank hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedBankView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this bank only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedBankView();


    /**
     *  Gets the <code> AssessmentOffered </code> specified by its <code> Id. 
     *  </code> In plenary mode, the exact <code> Id </code> is found or a 
     *  <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  AssessmentOffered </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to an <code> AssessmentOffered </code> and retained for 
     *  compatibility. 
     *
     *  @param  assessmentOfferedId <code> Id </code> of the <code> 
     *          AssessmentOffered </code> 
     *  @return the assessment offered 
     *  @throws org.osid.NotFoundException <code> assessmentOfferedId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> assessmentOfferedId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.assessment.AssessmentOffered getAssessmentOffered(org.osid.id.Id assessmentOfferedId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AssessmentOfferedList </code> corresponding to the 
     *  given <code> IdList. </code> In plenary mode, the returned list 
     *  contains all of the assessments specified in the <code> Id </code> 
     *  list, in the order of the list, including duplicates, or an error 
     *  results if an <code> Id </code> in the supplied list is not found or 
     *  inaccessible. Otherwise, inaccessible <code> AssessmentOffered </code> 
     *  objects may be omitted from the list and may present the elements in 
     *  any order including returning a unique set. 
     *
     *  @param  assessmentOfferedIds the list of <code> Ids </code> to 
     *          retrieve 
     *  @return the returned <code> AssessmentOffered </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> assessmentOfferedIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException assessment failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentOfferedList getAssessmentsOfferedByIds(org.osid.id.IdList assessmentOfferedIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AssessmentOfferedList </code> corresponding to the 
     *  given assessment offered genus <code> Type </code> which does not 
     *  include assessments of types derived from the specified <code> Type. 
     *  </code> In plenary mode, the returned list contains all known 
     *  assessments offered or an error results. Otherwise, the returned list 
     *  may contain only those assessments offered that are accessible through 
     *  this session. 
     *
     *  @param  assessmentOfferedGenusType an assessment offered genus type 
     *  @return the returned <code> AssessmentOffered </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          assessmentOfferedGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentOfferedList getAssessmentsOfferedByGenusType(org.osid.type.Type assessmentOfferedGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AssessmentOfferedList </code> corresponding to the 
     *  given assessment offered genus <code> Type </code> and include any 
     *  additional assessments with genus types derived from the specified 
     *  <code> Type. </code> In plenary mode, the returned list contains all 
     *  known assessments or an error results. Otherwise, the returned list 
     *  may contain only those assessments offered that are accessible through 
     *  this session. 
     *
     *  @param  assessmentOfferedGenusType an assessment offered genus type 
     *  @return the returned <code> AssessmentOffered </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          assessmentOfferedGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentOfferedList getAssessmentsOfferedByParentGenusType(org.osid.type.Type assessmentOfferedGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AssessmentOfferedList </code> corresponding to the 
     *  given assessment offered record <code> Type. </code> The set of 
     *  assessments implementing the given record type is returned. In plenary 
     *  mode, the returned list contains all known assessments offered or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  assessments offered that are accessible through this session. 
     *
     *  @param  assessmentRecordType an assessment offered record type 
     *  @return the returned <code> AssessmentOffered </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          assessmentOfferedRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentOfferedList getAssessmentsOfferedByRecordType(org.osid.type.Type assessmentRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AssessmentOfferedList </code> that have designated 
     *  start times where the start times fall in the given range inclusive. 
     *  In plenary mode, the returned list contains all known assessments 
     *  offered or an error results. Otherwise, the returned list may contain 
     *  only those assessments offered that are accessible through this 
     *  session. 
     *
     *  @param  start start of time range 
     *  @param  end end of time range 
     *  @return the returned <code> AssessmentOffered </code> list 
     *  @throws org.osid.InvalidArgumentException <code> end </code> is less 
     *          than <code> start </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentOfferedList getAssessmentsOfferedByDate(org.osid.calendaring.DateTime start, 
                                                                                 org.osid.calendaring.DateTime end)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AssessmentOfferedList </code> by the given assessment. 
     *  In plenary mode, the returned list contains all known assessments 
     *  offered or an error results. Otherwise, the returned list may contain 
     *  only those assessments offered that are accessible through this 
     *  session. 
     *
     *  @param  assessmentId <code> Id </code> of an <code> Assessment </code> 
     *  @return the returned <code> AssessmentOffered </code> list 
     *  @throws org.osid.NullArgumentException <code> assessmentId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentOfferedList getAssessmentsOfferedForAssessment(org.osid.id.Id assessmentId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> AssessmentOffered </code> elements. In plenary mode, 
     *  the returned list contains all known assessments offered or an error 
     *  results. Otherwise, the returned list may contain only those 
     *  assessments offered that are accessible through this session. 
     *
     *  @return a list of <code> AssessmentOffered </code> elements 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentOfferedList getAssessmentsOffered()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
