//
// org.osid.assessment.AssessmentOfferedQuery
//
//     The OSID Java specification for org.osid.assessment.AssessmentOfferedQuery.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment;


/**
 *  <p>This is the query for searching assessments. Each method match request 
 *  produces an <code> AND </code> term while multiple invocations of a method 
 *  produces a nested <code> OR. </code> </p>
 */

public interface AssessmentOfferedQuery
    extends org.osid.OsidObjectQuery,
            org.osid.OsidSubjugateableQuery {


    /**
     *  Sets the assessment <code> Id </code> for this query. 
     *
     *  @param  assessmentId an assessment <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> assessmentId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAssessmentId(org.osid.id.Id assessmentId, boolean match);


    /**
     *  Clears all assessment <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAssessmentIdTerms();


    /**
     *  Tests if an <code> AssessmentQuery </code> is available. 
     *
     *  @return <code> true </code> if an assessment query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentQuery();


    /**
     *  Gets the query for an assessment. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the assessment query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentQuery() </code> is <code> true. </code> 
     */

    public org.osid.assessment.AssessmentQuery getAssessmentQuery();


    /**
     *  Clears all assessment terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAssessmentTerms();


    /**
     *  Sets the level grade <code> Id </code> for this query. 
     *
     *  @param  gradeId a grade <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> gradeId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchLevelId(org.osid.id.Id gradeId, boolean match);


    /**
     *  Clears all level <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLevelIdTerms();


    /**
     *  Tests if a <code> GradeQuery </code> is available. 
     *
     *  @return <code> true </code> if a grade query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLevelQuery();


    /**
     *  Gets the query for a grade. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the grade query 
     *  @throws org.osid.UnimplementedException <code> supportsLevelQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLevelQuery() </code> is <code> true. </code> 
     */

    public org.osid.grading.GradeQuery getLevelQuery();


    /**
     *  Matches an assessment offered that has any level assigned. 
     *
     *  @param  match <code> true </code> to match offerings with any level, 
     *          <code> false </code> to match offerings with no levsls 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyLevel(boolean match);


    /**
     *  Clears all level terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLevelTerms();


    /**
     *  Match sequential assessments. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchItemsSequential(boolean match);


    /**
     *  Clears all sequential terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearItemsSequentialTerms();


    /**
     *  Match shuffled item assessments. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchItemsShuffled(boolean match);


    /**
     *  Clears all shuffled terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearItemsShuffledTerms();


    /**
     *  Matches assessments whose start time falls between the specified range 
     *  inclusive. 
     *
     *  @param  start start of range 
     *  @param  end end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> end </code> is less 
     *          than <code> start </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchStartTime(org.osid.calendaring.DateTime start, 
                               org.osid.calendaring.DateTime end, 
                               boolean match);


    /**
     *  Matches offerings that has any start time assigned. 
     *
     *  @param  match <code> true </code> to match offerings with any start 
     *          time, <code> false </code> to match offerings with no start 
     *          time 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyStartTime(boolean match);


    /**
     *  Clears all scheduled terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStartTimeTerms();


    /**
     *  Matches assessments whose end time falls between the specified range 
     *  inclusive. 
     *
     *  @param  start start of range 
     *  @param  end end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> end </code> is less 
     *          than <code> start </code> 
     *  @throws org.osid.NullArgumentException <code> start </code> or <code> 
     *          end </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDeadline(org.osid.calendaring.DateTime start, 
                              org.osid.calendaring.DateTime end, boolean match);


    /**
     *  Matches offerings that have any deadline assigned. 
     *
     *  @param  match <code> true </code> to match offerings with any 
     *          deadline, <code> false </code> to match offerings with no 
     *          deadline 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDeadline(boolean match);


    /**
     *  Clears all deadline terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDeadlineTerms();


    /**
     *  Matches assessments whose duration falls between the specified range 
     *  inclusive. 
     *
     *  @param  low start range of duration 
     *  @param  high end range of duration 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> end </code> is less 
     *          than <code> start </code> 
     *  @throws org.osid.NullArgumentException <code> start </code> or <code> 
     *          end </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDuration(org.osid.calendaring.Duration low, 
                              org.osid.calendaring.Duration high, 
                              boolean match);


    /**
     *  Matches offerings that have any duration assigned. 
     *
     *  @param  match <code> true </code> to match offerings with any 
     *          duration, <code> false </code> to match offerings with no 
     *          duration 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDuration(boolean match);


    /**
     *  Clears all duration terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDurationTerms();


    /**
     *  Sets the grade system <code> Id </code> for this query. 
     *
     *  @param  gradeSystemId a grade system <code> Id </code> 
     *  @param  match <code> true for a positive match, false for a negative 
     *          match </code> 
     *  @throws org.osid.NullArgumentException <code> gradeSystemId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchScoreSystemId(org.osid.id.Id gradeSystemId, boolean match);


    /**
     *  Clears all grade system <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearScoreSystemIdTerms();


    /**
     *  Tests if a <code> GradeSystemQuery </code> is available. 
     *
     *  @return <code> true </code> if a grade system query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsScoreSystemQuery();


    /**
     *  Gets the query for a grade system. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the grade system query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsScoreSystemQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsScoreSystemQuery() </code> is <code> true. </code> 
     */

    public org.osid.grading.GradeSystemQuery getScoreSystemQuery();


    /**
     *  Matches taken assessments that have any grade system assigned. 
     *
     *  @param  match <code> true </code> to match assessments with any grade 
     *          system, <code> false </code> to match assessments with no 
     *          grade system 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyScoreSystem(boolean match);


    /**
     *  Clears all grade system terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearScoreSystemTerms();


    /**
     *  Sets the grade system <code> Id </code> for this query. 
     *
     *  @param  gradeSystemId a grade system <code> Id </code> 
     *  @param  match <code> true for a positive match, false for a negative 
     *          match </code> 
     *  @throws org.osid.NullArgumentException <code> gradeSystemId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchGradeSystemId(org.osid.id.Id gradeSystemId, boolean match);


    /**
     *  Clears all grade system <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGradeSystemIdTerms();


    /**
     *  Tests if a <code> GradeSystemQuery </code> is available. 
     *
     *  @return <code> true </code> if a grade system query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradeSystemQuery();


    /**
     *  Gets the query for a grade system. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the grade system query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsScoreSystemQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsScoreSystemQuery() </code> is <code> true. </code> 
     */

    public org.osid.grading.GradeSystemQuery getGradeSystemQuery();


    /**
     *  Matches taken assessments that have any grade system assigned. 
     *
     *  @param  match <code> true </code> to match assessments with any grade 
     *          system, <code> false </code> to match assessments with no 
     *          grade system 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyGradeSystem(boolean match);


    /**
     *  Clears all grade system terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGradeSystemTerms();


    /**
     *  Sets the rubric assessment offered <code> Id </code> for this query. 
     *
     *  @param  assessmentOfferedId an assessment offered <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> assessmentOfferedId 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRubricId(org.osid.id.Id assessmentOfferedId, 
                              boolean match);


    /**
     *  Clears all rubric assessment offered <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRubricIdTerms();


    /**
     *  Tests if an <code> AssessmentOfferedQuery </code> is available. 
     *
     *  @return <code> true </code> if a rubric assessment offered query is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRubricQuery();


    /**
     *  Gets the query for a rubric assessment. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the assessment offered query 
     *  @throws org.osid.UnimplementedException <code> supportsRubricQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRubricQuery() </code> is <code> true. </code> 
     */

    public org.osid.assessment.AssessmentOfferedQuery getRubricQuery();


    /**
     *  Matches an assessment offered that has any rubric assessment assigned. 
     *
     *  @param  match <code> true </code> to match assessments offered with 
     *          any rubric, <code> false </code> to match assessments offered 
     *          with no rubric 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRubric(boolean match);


    /**
     *  Clears all rubric assessment terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRubricTerms();


    /**
     *  Sets the assessment taken <code> Id </code> for this query. 
     *
     *  @param  assessmentTakenId an assessment taken <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> assessmentTakenId 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAssessmentTakenId(org.osid.id.Id assessmentTakenId, 
                                       boolean match);


    /**
     *  Clears all assessment taken <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAssessmentTakenIdTerms();


    /**
     *  Tests if an <code> AssessmentTakenQuery </code> is available. 
     *
     *  @return <code> true </code> if an assessment taken query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentTakenQuery();


    /**
     *  Gets the query for an assessment taken. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the assessment taken query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentTakenQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentTakenQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.assessment.AssessmentTakenQuery getAssessmentTakenQuery();


    /**
     *  Matches offerings that have any taken assessment version. 
     *
     *  @param  match <code> true </code> to match offerings with any taken 
     *          assessment, <code> false </code> to match offerings with no 
     *          assessmen taken 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAssessmentTaken(boolean match);


    /**
     *  Clears all assessment taken terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAssessmentTakenTerms();


    /**
     *  Sets the bank <code> Id </code> for this query. 
     *
     *  @param  bankId a bank <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> bankId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBankId(org.osid.id.Id bankId, boolean match);


    /**
     *  Clears all bank <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBankIdTerms();


    /**
     *  Tests if a <code> BankQuery </code> is available. 
     *
     *  @return <code> true </code> if a bank query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBankQuery();


    /**
     *  Gets the query for a bank. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the bank query 
     *  @throws org.osid.UnimplementedException <code> supportsBankQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBankQuery() </code> is <code> true. </code> 
     */

    public org.osid.assessment.BankQuery getBankQuery();


    /**
     *  Clears all bank terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBankTerms();


    /**
     *  Gets the assessment offered query record corresponding to the given 
     *  <code> AssessmentOffered </code> record <code> Type. </code> Multiple 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  assessmentOfferedRecordType an assessment offered record type 
     *  @return the assessment offered query record 
     *  @throws org.osid.NullArgumentException <code> 
     *          assessmentOfferedRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(assessmentOfferedRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.records.AssessmentOfferedQueryRecord getAssessmentOfferedQueryRecord(org.osid.type.Type assessmentOfferedRecordType)
        throws org.osid.OperationFailedException;
}
