//
// org.osid.assessment.AssessmentQuery
//
//     The OSID Java specification for org.osid.assessment.AssessmentQuery.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment;


/**
 *  <p>This is the query for searching assessments. Each method match request 
 *  produces an <code> AND </code> term while multiple invocations of a method 
 *  produces a nested <code> OR. </code> </p>
 */

public interface AssessmentQuery
    extends org.osid.OsidObjectQuery {


    /**
     *  Sets the level grade <code> Id </code> for this query. 
     *
     *  @param  gradeId a grade <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> gradeId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchLevelId(org.osid.id.Id gradeId, boolean match);


    /**
     *  Clears all level <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLevelIdTerms();


    /**
     *  Tests if a <code> GradeQuery </code> is available. 
     *
     *  @return <code> true </code> if a grade query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLevelQuery();


    /**
     *  Gets the query for a grade. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the grade query 
     *  @throws org.osid.UnimplementedException <code> supportsLevelQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLevelQuery() </code> is <code> true. </code> 
     */

    public org.osid.grading.GradeQuery getLevelQuery();


    /**
     *  Matches an assessment that has any level assigned. 
     *
     *  @param  match <code> true </code> to match assessments with any level, 
     *          <code> false </code> to match assessments with no level 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyLevel(boolean match);


    /**
     *  Clears all level terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLevelTerms();


    /**
     *  Sets the rubric assessment <code> Id </code> for this query. 
     *
     *  @param  assessmentId an assessment <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> assessmentId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRubricId(org.osid.id.Id assessmentId, boolean match);


    /**
     *  Clears all rubric assessment <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRubricIdTerms();


    /**
     *  Tests if an <code> AssessmentQuery </code> is available. 
     *
     *  @return <code> true </code> if a rubric assessment query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRubricQuery();


    /**
     *  Gets the query for a rubric assessment. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the assessment query 
     *  @throws org.osid.UnimplementedException <code> supportsRubricQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRubricQuery() </code> is <code> true. </code> 
     */

    public org.osid.assessment.AssessmentQuery getRubricQuery();


    /**
     *  Matches an assessment that has any rubric assessment assigned. 
     *
     *  @param  match <code> true </code> to match assessments with any 
     *          rubric, <code> false </code> to match assessments with no 
     *          rubric 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRubric(boolean match);


    /**
     *  Clears all rubric assessment terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRubricTerms();


    /**
     *  Sets the item <code> Id </code> for this query. 
     *
     *  @param  itemId an item <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> itemId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchItemId(org.osid.id.Id itemId, boolean match);


    /**
     *  Clears all item <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearItemIdTerms();


    /**
     *  Tests if an <code> ItemQuery </code> is available. 
     *
     *  @return <code> true </code> if an item query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsItemQuery();


    /**
     *  Gets the query for an item. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the item query 
     *  @throws org.osid.UnimplementedException <code> supportsItemQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsItemQuery() </code> is <code> true. </code> 
     */

    public org.osid.assessment.ItemQuery getItemQuery();


    /**
     *  Matches an assessment that has any item. 
     *
     *  @param  match <code> true </code> to match assessments with any item, 
     *          <code> false </code> to match assessments with no items 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyItem(boolean match);


    /**
     *  Clears all item terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearItemTerms();


    /**
     *  Sets the assessment offered <code> Id </code> for this query. 
     *
     *  @param  assessmentOfferedId an assessment offered <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> assessmentOfferedId 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAssessmentOfferedId(org.osid.id.Id assessmentOfferedId, 
                                         boolean match);


    /**
     *  Clears all assessment offered <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAssessmentOfferedIdTerms();


    /**
     *  Tests if an <code> AssessmentOfferedQuery </code> is available. 
     *
     *  @return <code> true </code> if an assessment offered query is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentOfferedQuery();


    /**
     *  Gets the query for an assessment offered. Multiple retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @return the assessment offered query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentOfferedQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentOfferedQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.assessment.AssessmentOfferedQuery getAssessmentOfferedQuery();


    /**
     *  Matches an assessment that has any offering. 
     *
     *  @param  match <code> true </code> to match assessments with any 
     *          offering, <code> false </code> to match assessments with no 
     *          offerings 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAssessmentOffered(boolean match);


    /**
     *  Clears all assessment offered terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAssessmentOfferedTerms();


    /**
     *  Sets the assessment taken <code> Id </code> for this query. 
     *
     *  @param  assessmentTakenId an assessment taken <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> assessmentTakenId 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAssessmentTakenId(org.osid.id.Id assessmentTakenId, 
                                       boolean match);


    /**
     *  Clears all assessment taken <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAssessmentTakenIdTerms();


    /**
     *  Tests if an <code> AssessmentTakenQuery </code> is available. 
     *
     *  @return <code> true </code> if an assessment taken query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentTakenQuery();


    /**
     *  Gets the query for an assessment taken. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the assessment taken query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentTakenQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentTakenQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.assessment.AssessmentTakenQuery getAssessmentTakenQuery();


    /**
     *  Matches an assessment that has any taken version. 
     *
     *  @param  match <code> true </code> to match assessments with any taken 
     *          assessments, <code> false </code> to match assessments with no 
     *          taken assessments 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAssessmentTaken(boolean match);


    /**
     *  Clears all assessment taken terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAssessmentTakenTerms();


    /**
     *  Sets the bank <code> Id </code> for this query. 
     *
     *  @param  bankId a bank <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> bankId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBankId(org.osid.id.Id bankId, boolean match);


    /**
     *  Clears all bank <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBankIdTerms();


    /**
     *  Tests if a <code> BankQuery </code> is available. 
     *
     *  @return <code> true </code> if a bank query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBankQuery();


    /**
     *  Gets the query for a bank. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the bank query 
     *  @throws org.osid.UnimplementedException <code> supportsBankQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBankQuery() </code> is <code> true. </code> 
     */

    public org.osid.assessment.BankQuery getBankQuery();


    /**
     *  Clears all bank terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBankTerms();


    /**
     *  Gets the assessment query record corresponding to the given <code> 
     *  Assessment </code> record <code> Type. </code> Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @param  assessmentRecordType an assessment record type 
     *  @return the assessment query record 
     *  @throws org.osid.NullArgumentException <code> assessmentRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(assessmentRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.records.AssessmentQueryRecord getAssessmentQueryRecord(org.osid.type.Type assessmentRecordType)
        throws org.osid.OperationFailedException;
}
