//
// org.osid.assessment.AssessmentSection
//
//     The OSID Java specification for org.osid.assessment.AssessmentSection.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment;


/**
 *  <p>Represents an assessment section. An assessment section represents a 
 *  cluster of questions used to organize the execution of an assessment. The 
 *  section is the student aspect of an assessment part. </p>
 */

public interface AssessmentSection
    extends org.osid.OsidObject {


    /**
     *  Tests if this section must be completed within an allocated time. 
     *
     *  @return <code> true </code> if this section has an allocated time, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasAllocatedTime();


    /**
     *  Gets the allocated time for this section. 
     *
     *  @return allocated time 
     *  @throws org.osid.IllegalStateException <code> hasAllocatedTime() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Duration getAllocatedTime();


    /**
     *  Tests if the items or parts in this section are taken sequentially. 
     *
     *  @return <code> true </code> if the items are taken sequentially, 
     *          <code> false </code> if the items can be skipped and revisited 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean areItemsSequential();


    /**
     *  Tests if the items or parts appear in a random order. 
     *
     *  @return <code> true </code> if the items appear in a random order, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean areItemsShuffled();


    /**
     *  Gets the assessment section record corresponding to the given <code> 
     *  AssessmentSection </code> record <code> Type. </code> This method is 
     *  used to retrieve an object implementing the requested record. The 
     *  <code> assessmentSectionRecordType </code> may be the <code> Type 
     *  </code> returned in <code> getRecordTypes() </code> or any of its 
     *  parents in a <code> Type </code> hierarchy where <code> 
     *  hasRecordType(assessmentSectionRecordType) </code> is <code> true 
     *  </code> . 
     *
     *  @param  assessmentSectionRecordType an assessment section record type 
     *  @return the assessment section record 
     *  @throws org.osid.NullArgumentException <code> 
     *          assessmentSectionRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(assessmentSectionRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.records.AssessmentSectionRecord getAssessmentSectionRecord(org.osid.type.Type assessmentSectionRecordType)
        throws org.osid.OperationFailedException;
}
