//
// org.osid.assessment.AssessmentSession
//
//     The OSID Java specification for org.osid.assessment.AssessmentSession.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment;


/**
 *  <p>This session is used to take an assessment. The assessment associated 
 *  with this session represents the "assessment taken" by an <code> Agent. 
 *  </code> This session may be created using an <code> AssessmentOffered 
 *  </code> <code> Id </code> retrieved from an assessment bank, and 
 *  instantiating this session represents the transaction of taking an 
 *  assessment. Resuming an assessment, if permitted, is performed through 
 *  instantiating this session with the <code> AssessmentTaken </code> <code> 
 *  Id. </code> </p> 
 *  
 *  <p> <code> Assessment Items </code> are accessed via the <code> Question 
 *  </code> interface. A <code> Question </code> <code> Id </code> is the same 
 *  as the <code> Item </code> Id. </p> 
 *  
 *  <p> This session manages the flow of control for the assessment taking 
 *  process. It allows for two types of processes: </p> 
 *  
 *  <ul>
 *      <li> synchronous response: Each consecutive question is only available 
 *      after the previous item was submitted or skipped. </li> 
 *      <li> asynchronous response: Questions may be accessed independently of 
 *      response submission. </li> 
 *  </ul>
 *  
 *  
 *  <p> It may be the case that it is allowed to suspend and resume an 
 *  assessment. <code> canSuspend() </code> indicates the availability of this 
 *  feature. <code> finished() </code> indicates the assessment is complete. 
 *  </p> 
 *  
 *  <p> This session is used in the context of an <code> AssessmentSection. 
 *  </code> An assessment with no sections defined is assumed to have a single 
 *  default section that maps to the entire assessment. </p>
 */

public interface AssessmentSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Bank </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Bank Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBankId();


    /**
     *  Gets the <code> Bank </code> associated with this session. 
     *
     *  @return the <code> Bank </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.Bank getBank()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can take this assessment section. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer assessment operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if assessment methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canTakeAssessments();


    /**
     *  Tests if this assessment has started. An assessment begins from the 
     *  designated start time if a start time is defined. If no start time is 
     *  defined the assessment may begin at any time. Assessment sections 
     *  cannot be accessed if the return for this method is <code> false. 
     *  </code> 
     *
     *  @param  assessmentTakenId <code> Id </code> of the <code> 
     *          AssessmentTaken </code> 
     *  @return <code> true </code> if this assessment has begun, <code> false 
     *          </code> otherwise 
     *  @throws org.osid.NotFoundException <code> assessmentTakenId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> assessmentTakenId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasAssessmentBegun(org.osid.id.Id assessmentTakenId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this assessment is over. An assessment is over if <code> 
     *  finishedAssessment() </code> is invoked or the designated finish time 
     *  has expired. 
     *
     *  @param  assessmentTakenId <code> Id </code> of the <code> 
     *          AssessmentTaken </code> 
     *  @return <code> true </code> if this assessment is over, <code> false 
     *          </code> otherwise 
     *  @throws org.osid.NotFoundException <code> assessmentTakenId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> assessmentTakenId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isAssessmentOver(org.osid.id.Id assessmentTakenId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Indicates the entire assessment is complete. 
     *
     *  @param  assessmentTakenId <code> Id </code> of the <code> 
     *          AssessmentTaken </code> 
     *  @throws org.osid.IllegalStateException <code> hasBegun() </code> is 
     *          <code> false or isOver() </code> is <code> true </code> 
     *  @throws org.osid.NotFoundException <code> assessmentTakenId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> assessmentTakenId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void finishedAssessment(org.osid.id.Id assessmentTakenId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if synchronous sections are required. This method should be 
     *  checked to determine if all sections are available when requested, or 
     *  the next sections becomes available only after the previous section is 
     *  complete. 
     *  
     *  There are two methods for retrieving sections. One is using the 
     *  built-in hasNextSection() and getNextSection() methods. In synchronous 
     *  mode, hasNextSection() is false until the current section is 
     *  completed. In asynchronous mode, <code> hasNextSection() </code> 
     *  returns true until the end of the assessment. 
     *  
     *  <code> AssessmentSections </code> may also be accessed via an <code> 
     *  AssessmentSectionList. </code> If syncronous sections are required, 
     *  <code> AssessmentSectionList.available() == 0 </code> and <code> 
     *  AssessmentSectionList.getNextQuestion() </code> blocks until the 
     *  section is complete. <code> AssessmentSectionList.hasNext() </code> is 
     *  always true until the end of the assessment is reached. 
     *
     *  @return <code> true </code> if this synchronous sections are required, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean requiresSynchronousSections();


    /**
     *  Gets the first assessment section in this assesment. 
     *
     *  @param  assessmentTakenId <code> Id </code> of the <code> 
     *          AssessmentTaken </code> 
     *  @return the first assessment section 
     *  @throws org.osid.IllegalStateException <code> hasAssessmentBegun() 
     *          </code> is <code> false </code> 
     *  @throws org.osid.NotFoundException <code> assessmentTakenId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> assessmentTakenId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentSection getFirstAssessmentSection(org.osid.id.Id assessmentTakenId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if there is a next assessment section in the assessment 
     *  following the given assessment section <code> Id. </code> 
     *
     *  @param  assessmentSectionId <code> Id </code> of the <code> 
     *          AssessmentSection </code> 
     *  @return <code> true </code> if there is a next section, <code> false 
     *          </code> otherwise 
     *  @throws org.osid.IllegalStateException <code> hasAssessmentBegun() 
     *          </code> is <code> false </code> 
     *  @throws org.osid.NullArgumentException <code> sectionId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasNextAssessmentSection(org.osid.id.Id assessmentSectionId);


    /**
     *  Gets the next assessemnt section following the given assesment 
     *  section. 
     *
     *  @param  assessmentSectionId <code> Id </code> of the <code> 
     *          AssessmentSection </code> 
     *  @return the next section 
     *  @throws org.osid.IllegalStateException <code> 
     *          hasNextAssessmentSection() </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.NotFoundException <code> assessmentSectionId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> assessmentSectionId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentSection getNextAssessmentSection(org.osid.id.Id assessmentSectionId)
        throws org.osid.OperationFailedException,
               org.osid.NotFoundException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if there is a previous assessment section in the assessment 
     *  following the given assessment section <code> Id. </code> 
     *
     *  @param  assessmentSectionId <code> Id </code> of the <code> 
     *          AssessmentSection </code> 
     *  @return <code> true </code> if there is a previous assessment section, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.IllegalStateException <code> hasAssessmentBegun() 
     *          </code> is <code> false </code> 
     *  @throws org.osid.NullArgumentException <code> sectionId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasPreviousAssessmentSection(org.osid.id.Id assessmentSectionId);


    /**
     *  Gets the next assessemnt section following the given assesment 
     *  section. 
     *
     *  @param  assessmentSectionId <code> Id </code> of the <code> 
     *          AssessmentSection </code> 
     *  @return the previous assessment section 
     *  @throws org.osid.IllegalStateException <code> 
     *          hasNextAssessmentSection() </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.NotFoundException <code> assessmentSectionId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> assessmentSectionId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentSection getPreviousAssessmentSection(org.osid.id.Id assessmentSectionId)
        throws org.osid.OperationFailedException,
               org.osid.NotFoundException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an assessemnts section by <code> Id. </code> 
     *
     *  @param  assessmentSectionId <code> Id </code> of the <code> 
     *          AssessmentSection </code> 
     *  @return the assessment section 
     *  @throws org.osid.IllegalStateException <code> hasAssessmentBegun() 
     *          </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.NotFoundException <code> assessmentSectionId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> assessmentSectionId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentSection getAssessmentSection(org.osid.id.Id assessmentSectionId)
        throws org.osid.OperationFailedException,
               org.osid.NotFoundException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the assessment sections of this assessment. 
     *
     *  @param  assessmentTakenId <code> Id </code> of the <code> 
     *          AssessmentTaken </code> 
     *  @return the list of assessment sections 
     *  @throws org.osid.IllegalStateException <code> hasAssessmentBegun() 
     *          </code> is <code> false </code> 
     *  @throws org.osid.NotFoundException <code> assessmentTakenId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> assessmentTakenId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentSectionList getAssessmentSections(org.osid.id.Id assessmentTakenId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if the given assessment section is complete. 
     *
     *  @param  assessmentSectionId <code> Id </code> of the <code> 
     *          AssessmentSection </code> 
     *  @return <code> true </code> if this assessment section is complete, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.IllegalStateException <code> isAssessmentOver() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NotFoundException <code> assessmentSectionId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> assessmentSectionId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isAssessmentSectionComplete(org.osid.id.Id assessmentSectionId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the incomplete assessment sections of this assessment. 
     *
     *  @return the list of incomplete assessment sections 
     *  @throws org.osid.IllegalStateException <code> hasAssessmentBegun() 
     *          </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentSectionList getIncompleteAssessmentSections()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this assessment section has started. A section begins from 
     *  the designated start time if a start time is defined. If no start time 
     *  is defined the section may begin at any time. Assessment items cannot 
     *  be accessed or submitted if the return for this method is <code> 
     *  false. </code> 
     *
     *  @param  assessmentSectionId <code> Id </code> of the <code> 
     *          AssessmentSection </code> 
     *  @return <code> true </code> if this assessment section has begun, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.IllegalStateException <code> hasAssessmentBegun() 
     *          </code> is <code> false or isAssessmentOver() </code> is 
     *          <code> true </code> 
     *  @throws org.osid.NotFoundException <code> assessmentSectionId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> assessmentSectionId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasAssessmentSectionBegun(org.osid.id.Id assessmentSectionId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this assessment section is over. An assessment section is 
     *  over if <code> finishedAssessmentSection() </code> is invoked or the 
     *  designated finish time has expired. 
     *
     *  @param  assessmentSectionId <code> Id </code> of the <code> 
     *          AssessmentSection </code> 
     *  @return <code> true </code> if this assessment is over, <code> false 
     *          </code> otherwise 
     *  @throws org.osid.IllegalStateException <code> 
     *          hasAssessmenSectiontBegun() </code> is <code> false or 
     *          isAssessmentSectionOver() </code> is <code> true </code> 
     *  @throws org.osid.NotFoundException <code> assessmentSectionId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> assessmentSectionId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isAssessmentSectionOver(org.osid.id.Id assessmentSectionId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Indicates an assessment section is complete. 
     *
     *  @param  assessmentSectionId <code> Id </code> of the <code> 
     *          AssessmentSection </code> 
     *  @throws org.osid.IllegalStateException <code> 
     *          hasAssessmentSectionBegun() </code> is <code> false or 
     *          isAssessmentSectionOver() </code> is <code> true </code> 
     *  @throws org.osid.NotFoundException <code> assessmentSectionId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> assessmentSectionId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void finishedAssessmentSection(org.osid.id.Id assessmentSectionId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if synchronous responses are required in this assessment 
     *  section. This method should be checked to determine if all items are 
     *  available when requested, or the next item becomes available only 
     *  after the response to the current item is submitted. 
     *  
     *  There are two methods for retrieving questions. One is using the 
     *  built-in <code> hasNextQuestion() </code> and <code> getNextQuestion() 
     *  </code> methods. In synchronous mode, <code> hasNextQuestion() </code> 
     *  is <code> false </code> until the response for the current question is 
     *  submitted. In asynchronous mode, <code> hasNextQuestion() </code> 
     *  returns <code> true </code> until the end of the assessment. 
     *  
     *  <code> Questions </code> may also be accessed via a <code> 
     *  QuestionList. </code> If syncronous responses are required, <code> 
     *  QuestionList.available() == 0 </code> and <code> 
     *  QuestionList.getNextQuestion() </code> blocks until the response is 
     *  submitted. <code> QuestionList.hasNext() </code> is always true until 
     *  the end of the assessment is reached. 
     *
     *  @param  assessmentSectionId <code> Id </code> of the <code> 
     *          AssessmentSection </code> 
     *  @return <code> true </code> if this synchronous responses are 
     *          required, <code> false </code> otherwise 
     *  @throws org.osid.IllegalStateException <code> hasAssessmentBegun() 
     *          </code> is <code> false or isAssessmentOver() </code> is 
     *          <code> true </code> 
     *  @throws org.osid.NotFoundException <code> assessmentSectionId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> assessmentSectionId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean requiresSynchronousResponses(org.osid.id.Id assessmentSectionId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the first question in this assesment section. 
     *
     *  @return the first question 
     *  @throws org.osid.IllegalStateException <code> 
     *          hasAssessmentSectionBegun() </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.Question getFirstQuestion()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if there is a next question following the given question <code> 
     *  Id. </code> 
     *
     *  @param  itemId <code> Id </code> of the <code> Item </code> 
     *  @return <code> true </code> if there is a next question, <code> false 
     *          </code> otherwise 
     *  @throws org.osid.IllegalStateException <code> 
     *          hasAssessmentSectionBegun() </code> is <code> false </code> 
     *  @throws org.osid.NullArgumentException <code> itemId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasNextQuestion(org.osid.id.Id itemId);


    /**
     *  Gets the next question in this assesment section. 
     *
     *  @param  itemId <code> Id </code> of the <code> Item </code> 
     *  @return the next question 
     *  @throws org.osid.IllegalStateException <code> 
     *          hasAssessmentSectionBegun() </code> or <code> 
     *          hasNextQuestion() </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.NotFoundException <code> itemId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> itemId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.Question getNextQuestion(org.osid.id.Id itemId)
        throws org.osid.OperationFailedException,
               org.osid.NotFoundException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if there is a previous question preceeding the given question 
     *  <code> Id. </code> 
     *
     *  @param  itemId <code> Id </code> of the <code> Item </code> 
     *  @return <code> true </code> if there is a previous question, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.IllegalStateException <code> 
     *          hasAssessmentSectionBegun() </code> is <code> false </code> 
     *  @throws org.osid.NullArgumentException <code> itemId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasPreviousQuestion(org.osid.id.Id itemId);


    /**
     *  Gets the previous question in this assesment section. 
     *
     *  @param  itemId <code> Id </code> of the <code> Item </code> 
     *  @return the previous question 
     *  @throws org.osid.IllegalStateException <code> hasBegun() </code> or 
     *          <code> hasPreviousQuestion() </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.NotFoundException <code> itemId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> itemId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.Question getPreviousQuestion(org.osid.id.Id itemId)
        throws org.osid.OperationFailedException,
               org.osid.NotFoundException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Question </code> specified by its <code> Id. </code> 
     *
     *  @param  itemId the <code> Id </code> of the <code> Question </code> to 
     *          retrieve 
     *  @return the returned <code> Question </code> 
     *  @throws org.osid.IllegalStateException <code> 
     *          hasAssessmentSectionBegun() </code> is <code> false </code> 
     *  @throws org.osid.NotFoundException no <code> Question </code> found 
     *          with the given <code> Id </code> in this section 
     *  @throws org.osid.NullArgumentException <code> itemId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.Question getQuestion(org.osid.id.Id itemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the questions of this assessment section. 
     *
     *  @return the list of assessment questions 
     *  @throws org.osid.IllegalStateException <code> 
     *          hasAssessmentSectionBegun() </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.QuestionList getQuestions()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the response form for submitting an answer. 
     *
     *  @param  itemId <code> Id </code> of the <code> Item </code> 
     *  @return an answer form 
     *  @throws org.osid.IllegalStateException <code> 
     *          hasAssessmentSectionBegun() </code> is <code> false or 
     *          isAssessmentSectionOver() </code> is <code> true </code> 
     *  @throws org.osid.NotFoundException <code> itemId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> itemId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AnswerForm getResponseForm(org.osid.id.Id itemId)
        throws org.osid.NotFoundException;


    /**
     *  Submits an answer to an item. 
     *
     *  @param  itemId <code> Id </code> of the <code> Item </code> 
     *  @param  answer the response 
     *  @throws org.osid.IllegalStateException <code> 
     *          hasAssessmentSectionBegun() </code> is <code> false or 
     *          isAssessmentSectionOver() </code> is <code> true </code> 
     *  @throws org.osid.InvalidArgumentException one or more of the elements 
     *          in the form is invalid 
     *  @throws org.osid.NotFoundException <code> itemId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> itemId </code> or <code> 
     *          response </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> answerForm </code> is not 
     *          of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void submitResponse(org.osid.id.Id itemId, 
                               org.osid.assessment.AnswerForm answer)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Skips an item. 
     *
     *  @param  itemId <code> Id </code> of the <code> Item </code> 
     *  @return the response 
     *  @throws org.osid.IllegalStateException <code> 
     *          hasAssessmentSectionBegun() </code> is <code> false or 
     *          isAssessmentSectionOver() </code> is <code> true </code> 
     *  @throws org.osid.NotFoundException <code> itemId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> itemId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.Response skipItem(org.osid.id.Id itemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if the given item has a response. 
     *
     *  @param  itemId <code> Id </code> of the <code> Item </code> 
     *  @return <code> true </code> if this item has a response, <code> false 
     *          </code> otherwise 
     *  @throws org.osid.IllegalStateException <code> 
     *          hasAssessmentSectionBegun() </code> is <code> false or 
     *          isAssessmentSectionOver() </code> is <code> true </code> 
     *  @throws org.osid.NotFoundException <code> itemId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> itemId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isQuestionAnswered(org.osid.id.Id itemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the unanswered questions of this assessment section. 
     *
     *  @return the list of questions with no rsponses 
     *  @throws org.osid.IllegalStateException <code> 
     *          hasAssessmentSectionBegun() </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.QuestionList getUnansweredQuestions()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if there are unanswered questions in this assessment section. 
     *
     *  @return <code> true </code> if there are unanswered questions, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.IllegalStateException <code> hasBegun() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasUnansweredQuestions();


    /**
     *  Gets the first unanswered question in this assesment section. 
     *
     *  @return the first unanswered question 
     *  @throws org.osid.IllegalStateException <code> 
     *          hasAssessmentSectionBegun() </code> or <code> 
     *          hasUnansweredQuestions() </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.Question getFirstUnansweredQuestion()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if there is a next unanswered question following the given 
     *  question <code> Id. </code> 
     *
     *  @param  itemId <code> Id </code> of the <code> Item </code> 
     *  @return <code> true </code> if there is a next unanswered question, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.IllegalStateException <code> 
     *          hasAssessmentSectionBegun() </code> is <code> false </code> 
     *  @throws org.osid.NullArgumentException <code> itemId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasNextUnansweredQuestion(org.osid.id.Id itemId);


    /**
     *  Gets the next unanswered question in this assesment section. 
     *
     *  @param  itemId <code> Id </code> of the <code> Item </code> 
     *  @return the next unanswered question 
     *  @throws org.osid.IllegalStateException <code> 
     *          hasAssessmentSectionBegun() </code> or <code> 
     *          hasNextUnansweredQuestion() </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.NotFoundException <code> itemId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> itemId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.Question getNextUnansweredQuestion(org.osid.id.Id itemId)
        throws org.osid.OperationFailedException,
               org.osid.NotFoundException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if there is a previous unanswered question preceeding the given 
     *  question <code> Id. </code> 
     *
     *  @param  itemId <code> Id </code> of the <code> Item </code> 
     *  @return <code> true </code> if there is a previous unanswered 
     *          question, <code> false </code> otherwise 
     *  @throws org.osid.IllegalStateException <code> 
     *          hasAssessmentSectionBegun() </code> is <code> false </code> 
     *  @throws org.osid.NullArgumentException <code> itemId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasPreviousUnansweredQuestion(org.osid.id.Id itemId);


    /**
     *  Gets the previous unanswered question in this assesment section. 
     *
     *  @param  itemId <code> Id </code> of the <code> Item </code> 
     *  @return the previous unanswered question 
     *  @throws org.osid.IllegalStateException <code> 
     *          hasAssessmnetSectionBegun() </code> or <code> 
     *          hasPreviousUnansweredQuestion() </code> is <code> false 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.NotFoundException <code> itemId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> itemId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.Question getPreviousUnansweredQuestion(org.osid.id.Id itemId)
        throws org.osid.OperationFailedException,
               org.osid.NotFoundException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the submitted response to the associated item. 
     *
     *  @param  itemId <code> Id </code> of the <code> Item </code> 
     *  @return the response 
     *  @throws org.osid.IllegalStateException <code> 
     *          hasAssessmentSectionBegun() </code> is <code> false or 
     *          isAssessmentSectionOver() </code> is <code> true </code> 
     *  @throws org.osid.NotFoundException <code> itemId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> itemId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.Response getResponse(org.osid.id.Id itemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all submitted responses. 
     *
     *  @return the list of responses 
     *  @throws org.osid.IllegalStateException <code> 
     *          hasAssessmentSectionBegun() </code> is <code> false or 
     *          isAssessmentSectionOver() </code> is <code> true </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.ResponseList getResponses()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Clears the response to an item The item appears as unanswered. If no 
     *  response exists, the method simply returns. 
     *
     *  @param  itemId <code> Id </code> of the <code> Item </code> 
     *  @throws org.osid.IllegalStateException <code> 
     *          hasAssessmentSectionBegun() is false or 
     *          isAssessmentSectionOver() is true </code> 
     *  @throws org.osid.NotFoundException <code> itemId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> itemId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearResponse(org.osid.id.Id itemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Indicates the assessment section is complete. 
     *
     *  @throws org.osid.IllegalStateException <code> 
     *          hasAssessmentSectionBegun() is false or 
     *          isAssessmentSectionOver() is true </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void finish()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if an answer is available for the given item. 
     *
     *  @param  itemId <code> Id </code> of the <code> Item </code> 
     *  @return <code> true </code> if an answer are available, <code> false 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> itemId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isAnswerAvailable(org.osid.id.Id itemId);


    /**
     *  Gets the acceptable answers to the associated item. 
     *
     *  @param  itemId <code> Id </code> of the <code> Item </code> 
     *  @return the answers 
     *  @throws org.osid.IllegalStateException <code> isAnswerAvailable() 
     *          </code> is <code> false </code> 
     *  @throws org.osid.NotFoundException <code> itemId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> itemId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentList getAnswers(org.osid.id.Id itemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
