//
// org.osid.assessment.AssessmentTakenSearch
//
//     The OSID Java specification for org.osid.assessment.AssessmentTakenSearch.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment;


/**
 *  <p><code> AssessmentTakenSearch </code> defines the interface for 
 *  specifying assessment search options. </p>
 */

public interface AssessmentTakenSearch
    extends org.osid.OsidSearch {


    /**
     *  Execute this search among the given list of assessments. 
     *
     *  @param  assessmentTakenIds list of assessments taken 
     *  @throws org.osid.NullArgumentException <code> assessmentTakenIds 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void searchAmongAssessmentsTaken(org.osid.id.IdList assessmentTakenIds);


    /**
     *  Specify an ordering to the search results. 
     *
     *  @param  assessmentTakenSearchOrder assessment offered search order 
     *  @throws org.osid.NullArgumentException <code> 
     *          assessmentTakenSearchOrder </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          assessmentTakenSearchOrder </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderAssessmentTakenResults(org.osid.assessment.AssessmentTakenSearchOrder assessmentTakenSearchOrder);


    /**
     *  Gets the assessment taken search record corresponding to the given 
     *  assessment taken search record <code> Type. </code> This method is 
     *  used to retrieve an object implementing the requested record. 
     *
     *  @param  assessmentTakenSearchRecordType an assessment taken search 
     *          record type 
     *  @return the assessment taken search record 
     *  @throws org.osid.NullArgumentException <code> 
     *          assessmentTakenSearchRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(assessmentTakenSearchRecordType) </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.records.AssessmentTakenSearchRecord getAssessmentTakenSearchRecord(org.osid.type.Type assessmentTakenSearchRecordType)
        throws org.osid.OperationFailedException;
}
