//
// org.osid.assessment.AssessmentTakenSearchSession
//
//     The OSID Java specification for org.osid.assessment.AssessmentTakenSearchSession.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment;


/**
 *  <p>This session provides methods for searching among <code> 
 *  AssessmentTaken </code> objects. The search query is constructed using the 
 *  <code> AssessmentTakenQuery. </code> </p> 
 *  
 *  <p> <code> getAssessmentsTakenByQuery() </code> is the basic search method 
 *  and returns a list of <code> AssessmentTaken </code> elements. A more 
 *  advanced search may be performed with <code> 
 *  getAssessmentsTakenBySearch(). </code> It accepts an <code> 
 *  AssessmentTakenSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getAssessmentsTakenBySearch() </code> returns an <code> 
 *  AssessmentTakenSearchResults </code> that can be used to access the 
 *  resulting <code> AssessmenTakenList </code> or be used to perform a search 
 *  within the result set through <code> AssessmentTakenSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated bank view: searches include assessments taken in banks 
 *      of which this bank is an ancestor in the bank hierarchy </li> 
 *      <li> isolated bank view: searches are restricted to assessments taken 
 *      in this bank </li> 
 *  </ul>
 *  
 *  
 *  <p> Assessments taken may have query records indicated by their respective 
 *  record types. The query record is accessed via the <code> 
 *  AssessmentTakenQuery. </code> </p>
 */

public interface AssessmentTakenSearchSession
    extends org.osid.assessment.AssessmentTakenQuerySession {


    /**
     *  Gets an assessment taken search. 
     *
     *  @return the assessment taken search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentTakenSearch getAssessmentTakenSearch();


    /**
     *  Gets an assessment taken search order. The <code> 
     *  AssessmentTakenSearchOrder </code> is supplied to an <code> 
     *  AssessmentTakenSearch </code> to specify the ordering of results. 
     *
     *  @return the assessment taken search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentTakenSearchOrder getAssessmentTakenSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given assessment taken query. 
     *
     *  @param  assessmentTakenQuery the assessment taken query 
     *  @param  assessmentTakenSearch the assessment taken search 
     *  @return the assessment taken search results 
     *  @throws org.osid.NullArgumentException <code> assessmentTakenQuery 
     *          </code> or <code> assessmentTakenSearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> assessmentTakenQuery 
     *          </code> or <code> assessmentTakenSearch </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentTakenSearchResults getAssessmentsTakenBySearch(org.osid.assessment.AssessmentTakenQuery assessmentTakenQuery, 
                                                                                        org.osid.assessment.AssessmentTakenSearch assessmentTakenSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an assessment taken query from an inspector. The inspector is 
     *  available from an <code> AssessmentTakenSearchResults. </code> 
     *
     *  @param  assessmentTakenQueryInspector an assessment taken query 
     *          inspector 
     *  @return the assessment taken query 
     *  @throws org.osid.NullArgumentException <code> 
     *          assessmentTakenQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          assessmentTakenQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentTakenQuery getAssessmentTakenQueryFromInspector(org.osid.assessment.AssessmentTakenQueryInspector assessmentTakenQueryInspector);
}
