//
// org.osid.assessment.BankAdminSession
//
//     The OSID Java specification for org.osid.assessment.BankAdminSession.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment;


/**
 *  <p>This session creates, updates, and deletes <code> Banks. </code> The 
 *  data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Bank, </code> a <code> BankForm </code> is requested using <code> 
 *  getBankFormForCreate() </code> specifying the desired record <code> Types 
 *  </code> or none if no record <code> Types </code> are needed. The returned 
 *  <code> BankForm </code> will indicate that it is to be used with a create 
 *  operation and can be used to examine metdata or validate data prior to 
 *  creation. Once the <code> BankForm </code> is submiited to a create 
 *  operation, it cannot be reused with another create operation unless the 
 *  first operation was unsuccessful. Each <code> BankForm </code> corresponds 
 *  to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> BankForms </code> are requested to the <code> Bank 
 *  </code> <code> Id </code> that is to be updated using <code> 
 *  getBankFormForUpdate(). </code> Similarly, the <code> BankForm </code> has 
 *  metadata about the data that can be updated and it can perform validation 
 *  before submitting the update. The <code> BankForm </code> can only be used 
 *  once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Banks. </code> </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface BankAdminSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can create <code> Banks. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> Bank </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may not wish to offer create operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Bank </code> creation is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateBanks();


    /**
     *  Tests if this user can create a single <code> Bank </code> using the 
     *  desired record types. While <code> 
     *  AssessmentManager.getBankRecordTypes() </code> can be used to examine 
     *  which records are supported, this method tests which record(s) are 
     *  required for creating a specific <code> Bank. </code> Providing an 
     *  empty array tests if a <code> Bank </code> can be created with no 
     *  records. 
     *
     *  @param  bankRecordTypes array of bank record types 
     *  @return <code> true </code> if <code> Bank </code> creation using the 
     *          specified <code> Types </code> is supported, <code> false 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> bankRecordTypes </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateBankWithRecordTypes(org.osid.type.Type[] bankRecordTypes);


    /**
     *  Gets the bank form for creating new banks. A new form should be 
     *  requested for each create transaction. 
     *
     *  @param  bankRecordTypes array of bank record types to be included in 
     *          the create operation or an empty list if none 
     *  @return the bank form 
     *  @throws org.osid.NullArgumentException <code> bankRecordTypes </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.BankForm getBankFormForCreate(org.osid.type.Type[] bankRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Bank. </code> 
     *
     *  @param  bankForm the form for this <code> Bank </code> 
     *  @return the new <code> Bank </code> 
     *  @throws org.osid.IllegalStateException <code> bankForm </code> already 
     *          used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> bankForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> bankForm </code> did not 
     *          originate from <code> getBankFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.Bank createBank(org.osid.assessment.BankForm bankForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Banks. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> Bank </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may not wish to offer update operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Bank </code> modification is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateBanks();


    /**
     *  Gets the bank form for updating an existing bank. A new bank form 
     *  should be requested for each update transaction. 
     *
     *  @param  bankId the <code> Id </code> of the <code> Bank </code> 
     *  @return the bank form 
     *  @throws org.osid.NotFoundException <code> bankId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> bankId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.BankForm getBankFormForUpdate(org.osid.id.Id bankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing bank. 
     *
     *  @param  bankForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> bankForm </code> already 
     *          used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> bankForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> bankForm </code> did not 
     *          originate from <code> getBankFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateBank(org.osid.assessment.BankForm bankForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete banks. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known deleting a <code> Bank </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer delete operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Bank </code> deletion is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteBanks();


    /**
     *  Deletes a <code> Bank. </code> 
     *
     *  @param  bankId the <code> Id </code> of the <code> Bank </code> to 
     *          remove 
     *  @throws org.osid.NotFoundException <code> bankId </code> not found 
     *  @throws org.osid.NullArgumentException <code> bankId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteBank(org.osid.id.Id bankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Banks. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Bank </code> aliasing is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageBankAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Bank </code> for the purpose of 
     *  creating compatibility. The primary <code> Id </code> of the <code> 
     *  Bank </code> is determined by the provider. The new <code> Id </code> 
     *  is an alias to the primary <code> Id. </code> If the alias is a 
     *  pointer to another bank, it is reassigned to the given bank <code> Id. 
     *  </code> 
     *
     *  @param  bankId the <code> Id </code> of a <code> Bank </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is in 
     *          use as a primary <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> bankId </code> not found 
     *  @throws org.osid.NullArgumentException <code> bankId </code> or <code> 
     *          aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasBank(org.osid.id.Id bankId, org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
