//
// org.osid.assessment.Item
//
//     The OSID Java specification for org.osid.assessment.Item.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment;


/**
 *  <p>An <code> Item </code> represents an individual assessment item such as 
 *  a question. Like all OSID objects, a <code> Item </code> is identified by 
 *  its <code> Id </code> and any persisted references should use the <code> 
 *  Id. </code> </p> 
 *  
 *  <p> <code> </code> An <code> Item </code> is composed of a <code> Question 
 *  </code> and an <code> Answer. </code> </p>
 */

public interface Item
    extends org.osid.OsidObject,
            org.osid.Aggregateable {


    /**
     *  Gets the <code> Ids </code> of any <code> Objectives </code> 
     *  corresponding to this item. 
     *
     *  @return the learning objective <code> Ids </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getLearningObjectiveIds();


    /**
     *  Gets the any <code> Objectives </code> corresponding to this item. 
     *
     *  @return the learning objectives 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveList getLearningObjectives()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of the <code> Question </code> . 
     *
     *  @return the question <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getQuestionId();


    /**
     *  Gets the question. 
     *
     *  @return the question 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.Question getQuestion()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Ids </code> of the answers. Questions may have more 
     *  than one acceptable answer. 
     *
     *  @return the answer <code> Ids </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAnswerIds();


    /**
     *  Gets the answers. 
     *
     *  @return the answers 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AnswerList getAnswers()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the item record corresponding to the given <code> Item </code> 
     *  record <code> Type </code> . This method is used to retrieve an object 
     *  implementing the requested records. The <code> itemRecordType </code> 
     *  may be the <code> Type </code> returned in <code> getRecordTypes() 
     *  </code> or any of its parents in a <code> Type </code> hierarchy where 
     *  <code> hasRecordType(itemRecordType) </code> is <code> true </code> . 
     *
     *  @param  itemRecordType the type of the record to retrieve 
     *  @return the item record 
     *  @throws org.osid.NullArgumentException <code> itemRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(itemRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.records.ItemRecord getItemRecord(org.osid.type.Type itemRecordType)
        throws org.osid.OperationFailedException;
}
