//
// org.osid.assessment.ItemLookupSession
//
//     The OSID Java specification for org.osid.assessment.ItemLookupSession.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment;


/**
 *  <p>This session provides methods for retrieving <code> Item </code> 
 *  objects. </p> 
 *  
 *  <p> This session defines two sets of views which offer differing behaviors 
 *  when retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete and ordered result set or is an 
 *      error condition </li> 
 *      <li> isolated assessment bank view: All assessment item methods in 
 *      this session operate, retrieve and pertain to assessment items defined 
 *      explicitly in the current bank. Using an isolated view is useful for 
 *      managing items with the <code> ItemAdminSession. </code> </li> 
 *      <li> federated assessment bank view: All assessment item methods in 
 *      this session operate, retrieve and pertain to all assessment items 
 *      defined in this assessment bank and any other assessment banks 
 *      implicitly available in this assessment bank through assessment bank 
 *      inheritence. </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there a particular element is 
 *  inaccessible. For example, a hierarchy output can be plugged into a lookup 
 *  method to retrieve all objects known to a hierarchy, but it may not be 
 *  necessary to break execution if a node from the hierarchy no longer 
 *  exists. However, some administrative applications may need to know whether 
 *  it had retrieved an entire set of objects and may sacrifice some 
 *  interoperability for the sake of precision. </p> 
 *  
 *  <p> Items may have an additional records indicated by their respective 
 *  record types. </p>
 */

public interface ItemLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Bank </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Bank Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBankId();


    /**
     *  Gets the <code> Bank </code> associated with this session. 
     *
     *  @return the <code> Bank </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.Bank getBank()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Item </code> lookups. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupItems();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as assessment, and not result in an error. 
     *  This view is used when greater interoperability is desired at the 
     *  expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeItemView();


    /**
     *  A complete view of the <code> Item </code> returns is desired. Methods 
     *  will return what is requested or result in an error. This view is used 
     *  when greater precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryItemView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include assessment items in assessment banks which are children of 
     *  this assessment bank in the assessment bank hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedBankView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this assessment bank only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedBankView();


    /**
     *  Gets the <code> Item </code> specified by its <code> Id. </code> In 
     *  plenary mode, the exact <code> Id </code> is found or a <code> 
     *  NOT_FOUND </code> results. Otherwise, the returned <code> Item </code> 
     *  may have a different <code> Id </code> than requested, such as the 
     *  case where a duplicate <code> Id </code> was assigned to an <code> 
     *  Item </code> and retained for compatibility. 
     *
     *  @param  itemId the <code> Id </code> of the <code> Item </code> to 
     *          retrieve 
     *  @return the returned <code> Item </code> 
     *  @throws org.osid.NotFoundException no <code> Item </code> found with 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> itemId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.Item getItem(org.osid.id.Id itemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ItemList </code> corresponding to the given <code> 
     *  IdList. </code> In plenary mode, the returned list contains all of the 
     *  items specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Items </code> may be omitted from the list and may 
     *  present the elements in any order including returning a unique set. 
     *
     *  @param  itemIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Item </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> itemIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.ItemList getItemsByIds(org.osid.id.IdList itemIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ItemList </code> corresponding to the given assessment 
     *  item genus <code> Type </code> which does not include assessment items 
     *  of genus types derived from the specified <code> Type. </code> In 
     *  plenary mode, the returned list contains all known assessment items or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  assessment items that are accessible through this session. 
     *
     *  @param  itemGenusType an assessment item genus type 
     *  @return the returned <code> Item </code> list 
     *  @throws org.osid.NullArgumentException <code> itemGenusType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.ItemList getItemsByGenusType(org.osid.type.Type itemGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ItemList </code> corresponding to the given assessment 
     *  item genus <code> Type </code> and include any additional assessment 
     *  items with genus types derived from the specified <code> Type. </code> 
     *  In plenary mode, the returned list contains all known assessment items 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those assessment items that are accessible through this session. 
     *
     *  @param  itemGenusType an assessment item genus type 
     *  @return the returned <code> Item </code> list 
     *  @throws org.osid.NullArgumentException <code> itemGenusType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.ItemList getItemsByParentGenusType(org.osid.type.Type itemGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ItemList </code> containing the given assessment item 
     *  record <code> Type. </code> In plenary mode, the returned list 
     *  contains all known items or an error results. Otherwise, the returned 
     *  list may contain only those assessment items that are accessible 
     *  through this session. 
     *
     *  @param  itemRecordType an item record type 
     *  @return the returned <code> Item </code> list 
     *  @throws org.osid.NullArgumentException <code> itemRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.ItemList getItemsByRecordType(org.osid.type.Type itemRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ItemList </code> containing the given question. <code> 
     *  </code> In plenary mode, the returned list contains all known items or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  assessment items that are accessible through this session. 
     *
     *  @param  questionId a question <code> Id </code> 
     *  @return the returned <code> Item </code> list 
     *  @throws org.osid.NullArgumentException <code> questionId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.ItemList getItemsByQuestion(org.osid.id.Id questionId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ItemList </code> containing the given answer. <code> 
     *  </code> In plenary mode, the returned list contains all known items or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  assessment items that are accessible through this session. 
     *
     *  @param  answerId an answer <code> Id </code> 
     *  @return the returned <code> Item </code> list 
     *  @throws org.osid.NullArgumentException <code> answerId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.ItemList getItemsByAnswer(org.osid.id.Id answerId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ItemList </code> containing the given learning 
     *  objective. <code> </code> In plenary mode, the returned list contains 
     *  all known items or an error results. Otherwise, the returned list may 
     *  contain only those assessment items that are accessible through this 
     *  session. 
     *
     *  @param  objectiveId a learning objective <code> Id </code> 
     *  @return the returned <code> Item </code> list 
     *  @throws org.osid.NullArgumentException <code> objectiveId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.ItemList getItemsByLearningObjective(org.osid.id.Id objectiveId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ItemList </code> containing the given learning 
     *  objectives. <code> </code> In plenary mode, the returned list contains 
     *  all known items or an error results. Otherwise, the returned list may 
     *  contain only those assessment items that are accessible through this 
     *  session. 
     *
     *  @param  objectiveIds a list of learning objective <code> Ids </code> 
     *  @return the returned <code> Item </code> list 
     *  @throws org.osid.NullArgumentException <code> objectiveIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.ItemList getItemsByLearningObjectives(org.osid.id.IdList objectiveIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Items. </code> In plenary mode, the returned list 
     *  contains all known items or an error results. Otherwise, the returned 
     *  list may contain only those items that are accessible through this 
     *  session. 
     *
     *  @return a list of <code> Items </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.ItemList getItems()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
