//
// org.osid.assessment.ItemQueryInspector
//
//     The OSID Java specification for org.osid.assessment.ItemQueryInspector.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment;


/**
 *  <p>The query inspectors provide a means of accessing the match terms of a 
 *  query. These interfaces are used to examine the actual query terms used in 
 *  a search or that may be used to create a smart catalog. Query inspectors 
 *  may be converted to <code> OsidQuery </code> interfaces for reuse or 
 *  modification in the search sessions. </p>
 */

public interface ItemQueryInspector
    extends org.osid.OsidObjectQueryInspector,
            org.osid.OsidAggregateableQueryInspector {


    /**
     *  Gets the learning objective <code> Id </code> query terms. 
     *
     *  @return the learning objective <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getLearningObjectiveIdTerms();


    /**
     *  Gets the learning objective query terms. 
     *
     *  @return the learning objective terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveQueryInspector[] getLearningObjectiveTerms();


    /**
     *  Gets the question <code> Id </code> query terms. 
     *
     *  @return the question <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getQuestionIdTerms();


    /**
     *  Gets the question query terms. 
     *
     *  @return the question terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.QuestionQueryInspector[] getQuestionTerms();


    /**
     *  Gets the answer <code> Id </code> query terms. 
     *
     *  @return the answer <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getAnswerIdTerms();


    /**
     *  Gets the answer query terms. 
     *
     *  @return the answer terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AnswerQueryInspector[] getAnswerTerms();


    /**
     *  Gets the assessment <code> Id </code> query terms. 
     *
     *  @return the assessment <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getAssessmentIdTerms();


    /**
     *  Gets the assessment query terms. 
     *
     *  @return the assessment terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentQueryInspector[] getAssessmentTerms();


    /**
     *  Gets the bank <code> Id </code> query terms. 
     *
     *  @return the bank <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getBankIdTerms();


    /**
     *  Gets the bank query terms. 
     *
     *  @return the bank terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.BankQueryInspector[] getBankTerms();


    /**
     *  Gets the record query inspector corresponding to the given <code> Item 
     *  </code> record <code> Type. </code> 
     *
     *  @param  itemRecordType an item record type 
     *  @return the item query inspector record 
     *  @throws org.osid.NullArgumentException <code> itemRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(itemRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.records.ItemQueryInspectorRecord getItemQueryInspectorRecord(org.osid.type.Type itemRecordType)
        throws org.osid.OperationFailedException;
}
