//
// org.osid.assessment.ItemQuerySession
//
//     The OSID Java specification for org.osid.assessment.ItemQuerySession.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment;


/**
 *  <p>This session provides methods for searching <code> Item </code> 
 *  objects. The search query is constructed using the <code> ItemQuery. 
 *  </code> The assessment item record <code> Type </code> also specifies the 
 *  query record for the assessment item query. </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated assessment bank view: searches include assessment items 
 *      in assessment banks of which this assessment bank is a ancestor in the 
 *      assessment bank hierarchy </li> 
 *      <li> isolated bank </li> 
 *  </ul>
 *  
 *  
 *  <p> Assessment items may have a query record indicated by their respective 
 *  record types. Thequery record is accessed via the <code> ItemQuery. 
 *  </code> </p>
 */

public interface ItemQuerySession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Bank </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Bank Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBankId();


    /**
     *  Gets the <code> Bank </code> associated with this session. 
     *
     *  @return the <code> Bank </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.Bank getBank()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Item </code> searches. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  pplication that may wish not to offer search operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if search methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSearchItems();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include assessment items in assessment banks which are children of 
     *  this assessment bank in the assessment bank hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedBankView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts searches to this assessment bank only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedBankView();


    /**
     *  Gets an assessment item query. 
     *
     *  @return the assessment item query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.ItemQuery getItemQuery();


    /**
     *  Gets a list of <code> Items </code> matching the given item query. 
     *
     *  @param  itemQuery the item query 
     *  @return the returned <code> ItemList </code> 
     *  @throws org.osid.NullArgumentException <code> itemQuery </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> itemQuery </code> is not 
     *          of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.ItemList getItemsByQuery(org.osid.assessment.ItemQuery itemQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
