//
// org.osid.assessment.authoring.AssessmentAuthoringProfile
//
//     The OSID Java specification for org.osid.assessment.authoring.AssessmentAuthoringProfile.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment.authoring;


/**
 *  <p>The <code> AssessmentAuthoringProfile </code> describes the 
 *  interoperability among assessment authoring services. </p>
 */

public interface AssessmentAuthoringProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if federation is visible. 
     *
     *  @return <code> true </code> if visible federation is supported <code> 
     *          , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if looking up assessment part is supported. 
     *
     *  @return <code> true </code> if assessment part lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentPartLookup();


    /**
     *  Tests if querying assessment part is supported. 
     *
     *  @return <code> true </code> if assessment part query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentPartQuery();


    /**
     *  Tests if searching assessment part is supported. 
     *
     *  @return <code> true </code> if assessment part search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentPartSearch();


    /**
     *  Tests if an assessment part administrative service is supported. 
     *
     *  @return <code> true </code> if assessment part administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentPartAdmin();


    /**
     *  Tests if an assessment part notification service is supported. 
     *
     *  @return <code> true </code> if assessment part notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentPartNotification();


    /**
     *  Tests if an assessment part bank lookup service is supported. 
     *
     *  @return <code> true </code> if an assessment part bank lookup service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentPartBank();


    /**
     *  Tests if an assessment part bank service is supported. 
     *
     *  @return <code> true </code> if assessment part bank assignment service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentPartBankAssignment();


    /**
     *  Tests if an assessment part bank lookup service is supported. 
     *
     *  @return <code> true </code> if an assessment part bank service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentPartSmartBank();


    /**
     *  Tests if an assessment part item service is supported for looking up 
     *  assessment part and item mappings. 
     *
     *  @return <code> true </code> if assessment part item service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentPartItem();


    /**
     *  Tests if an assessment part item design session is supported. 
     *
     *  @return <code> true </code> if an assessment part item design service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentPartItemDesign();


    /**
     *  Tests if looking up sequence rule is supported. 
     *
     *  @return <code> true </code> if sequence rule lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSequenceRuleLookup();


    /**
     *  Tests if querying sequence rule is supported. 
     *
     *  @return <code> true </code> if sequence rule query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSequenceRuleQuery();


    /**
     *  Tests if searching sequence rule is supported. 
     *
     *  @return <code> true </code> if sequence rule search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSequenceRuleSearch();


    /**
     *  Tests if a sequence rule administrative service is supported. 
     *
     *  @return <code> true </code> if sequence rule administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSequenceRuleAdmin();


    /**
     *  Tests if a sequence rule notification service is supported. 
     *
     *  @return <code> true </code> if sequence rule notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSequenceRuleNotification();


    /**
     *  Tests if a sequence rule bank lookup service is supported. 
     *
     *  @return <code> true </code> if a sequence rule bank lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSequenceRuleBank();


    /**
     *  Tests if a sequence rule bank service is supported. 
     *
     *  @return <code> true </code> if sequence rule bank assignment service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSequenceRuleBankAssignment();


    /**
     *  Tests if a sequence rule bank lookup service is supported. 
     *
     *  @return <code> true </code> if a sequence rule bank service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSequenceRuleSmartBank();


    /**
     *  Tests if looking up sequence rule enablers is supported. 
     *
     *  @return <code> true </code> if sequence rule enabler lookup is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSequenceRuleEnablerLookup();


    /**
     *  Tests if querying sequence rule enablers is supported. 
     *
     *  @return <code> true </code> if sequence rule enabler query is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSequenceRuleEnablerQuery();


    /**
     *  Tests if searching sequence rule enablers is supported. 
     *
     *  @return <code> true </code> if sequence rule enabler search is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSequenceRuleEnablerSearch();


    /**
     *  Tests if a sequence rule enabler administrative service is supported. 
     *
     *  @return <code> true </code> if sequence rule enabler administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSequenceRuleEnablerAdmin();


    /**
     *  Tests if a sequence rule enabler notification service is supported. 
     *
     *  @return <code> true </code> if sequence rule enabler notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSequenceRuleEnablerNotification();


    /**
     *  Tests if a sequence rule enabler bank lookup service is supported. 
     *
     *  @return <code> true </code> if a sequence rule enabler bank lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSequenceRuleEnablerBank();


    /**
     *  Tests if a sequence rule enabler bank service is supported. 
     *
     *  @return <code> true </code> if sequence rule enabler bank assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSequenceRuleEnablerBankAssignment();


    /**
     *  Tests if a sequence rule enabler bank lookup service is supported. 
     *
     *  @return <code> true </code> if a sequence rule enabler bank service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSequenceRuleEnablerSmartBank();


    /**
     *  Tests if a sequence rule enabler rule lookup service is supported. 
     *
     *  @return <code> true </code> if a sequence rule enabler rule lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSequenceRuleEnablerRuleLookup();


    /**
     *  Tests if a sequence rule enabler rule application service is 
     *  supported. 
     *
     *  @return <code> true </code> if sequence rule enabler rule application 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSequenceRuleEnablerRuleApplication();


    /**
     *  Gets the supported <code> AssessmentPart </code> record types. 
     *
     *  @return a list containing the supported <code> AssessmentPart </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAssessmentPartRecordTypes();


    /**
     *  Tests if the given <code> AssessmentPart </code> record type is 
     *  supported. 
     *
     *  @param  assessmentPartRecordType a <code> Type </code> indicating an 
     *          <code> AssessmentPart </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> assessmentPartRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentPartRecordType(org.osid.type.Type assessmentPartRecordType);


    /**
     *  Gets the supported <code> AssessmentPart </code> search record types. 
     *
     *  @return a list containing the supported <code> AssessmentPart </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAssessmentPartSearchRecordTypes();


    /**
     *  Tests if the given <code> AssessmentPart </code> search record type is 
     *  supported. 
     *
     *  @param  assessmentPartSearchRecordType a <code> Type </code> 
     *          indicating an <code> AssessmentPart </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          assessmentPartSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentPartSearchRecordType(org.osid.type.Type assessmentPartSearchRecordType);


    /**
     *  Gets the supported <code> SequenceRule </code> record types. 
     *
     *  @return a list containing the supported <code> SequenceRule </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSequenceRuleRecordTypes();


    /**
     *  Tests if the given <code> SequenceRule </code> record type is 
     *  supported. 
     *
     *  @param  sequenceRuleRecordType a <code> Type </code> indicating a 
     *          <code> SequenceRule </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> sequenceRuleRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSequenceRuleRecordType(org.osid.type.Type sequenceRuleRecordType);


    /**
     *  Gets the supported <code> SequenceRule </code> search record types. 
     *
     *  @return a list containing the supported <code> SequenceRule </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSequenceRuleSearchRecordTypes();


    /**
     *  Tests if the given <code> SequenceRule </code> search record type is 
     *  supported. 
     *
     *  @param  sequenceRuleSearchRecordType a <code> Type </code> indicating 
     *          a <code> SequenceRule </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          sequenceRuleSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSequenceRuleSearchRecordType(org.osid.type.Type sequenceRuleSearchRecordType);


    /**
     *  Gets the supported <code> SequenceRuleEnabler </code> record types. 
     *
     *  @return a list containing the supported <code> SequenceRuleEnabler 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSequenceRuleEnablerRecordTypes();


    /**
     *  Tests if the given <code> SequenceRuleEnabler </code> record type is 
     *  supported. 
     *
     *  @param  sequenceRuleEnablerRecordType a <code> Type </code> indicating 
     *          a <code> SequenceRuleEnabler </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          sequenceRuleEnablerRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSequenceRuleEnablerRecordType(org.osid.type.Type sequenceRuleEnablerRecordType);


    /**
     *  Gets the supported <code> SequenceRuleEnabler </code> search record 
     *  types. 
     *
     *  @return a list containing the supported <code> SequenceRuleEnabler 
     *          </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSequenceRuleEnablerSearchRecordTypes();


    /**
     *  Tests if the given <code> SequenceRuleEnabler </code> search record 
     *  type is supported. 
     *
     *  @param  sequenceRuleEnablerSearchRecordType a <code> Type </code> 
     *          indicating a <code> SequenceRuleEnabler </code> search record 
     *          type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          sequenceRuleEnablerSearchRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSequenceRuleEnablerSearchRecordType(org.osid.type.Type sequenceRuleEnablerSearchRecordType);
}
