//
// org.osid.assessment.authoring.AssessmentPart
//
//     The OSID Java specification for org.osid.assessment.authoring.AssessmentPart.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment.authoring;


/**
 *  <p>An <code> AssessmentPart </code> represents a section of an assessment. 
 *  <code> AssessmentParts </code> may be visible as sections of an assessment 
 *  or just used to clump together a set of items on which to hang sequence 
 *  rules. </p>
 */

public interface AssessmentPart
    extends org.osid.OsidObject,
            org.osid.Containable,
            org.osid.Operable {


    /**
     *  Gets the assessment <code> Id </code> to which this rule belongs. 
     *
     *  @return <code> Id </code> of an assessment 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAssessmentId();


    /**
     *  Gets the assessment to which this rule belongs. 
     *
     *  @return an assessment 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.Assessment getAssessment()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this assessment part belongs to a parent assessment part. 
     *
     *  @return <code> true </code> if this part has a parent, <code> false 
     *          </code> if a root 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasParentPart();


    /**
     *  Gets the parent assessment <code> Id. </code> 
     *
     *  @return <code> Id </code> of an assessment 
     *  @throws org.osid.IllegalStateException <code> hasParentPart() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAssessmentPartId();


    /**
     *  Gets the parent assessment. 
     *
     *  @return the parent assessment part 
     *  @throws org.osid.IllegalStateException <code> hasParentPart() </code> 
     *          is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.AssessmentPart getAssessmentPart()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this part should be visible as a section in an assessment. If 
     *  visible, this part will appear to the user as a separate section of 
     *  the assessment. Typically, a section may not be under a non-sectioned 
     *  part. 
     *
     *  @return <code> true </code> if this part is a section, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isSection();


    /**
     *  Gets an integral weight factor for this assessment part used for 
     *  scoring. The percentage weight for this part is this weight divided by 
     *  the sum total of all the weights in the assessment. 
     *
     *  @return the weight 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getWeight();


    /**
     *  Gets the allocated time for this part. The allocated time may be used 
     *  to assign fixed time limits to each item or can be used to estimate 
     *  the total assessment time. 
     *
     *  @return allocated time 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Duration getAllocatedTime();


    /**
     *  Gets any child assessment part <code> Ids. </code> 
     *
     *  @return <code> Ids </code> of the child assessment parts 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getChildAssessmentPartIds();


    /**
     *  Gets any child assessment parts. 
     *
     *  @return the child assessment parts 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.AssessmentPartList getChildAssessmentParts()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the assessment part record corresponding to the given <code> 
     *  AssessmentPart </code> record <code> Type. </code> This method is used 
     *  to retrieve an object implementing the requested record. The <code> 
     *  assessmentPartRecordType </code> may be the <code> Type </code> 
     *  returned in <code> getRecordTypes() </code> or any of its parents in a 
     *  <code> Type </code> hierarchy where <code> 
     *  hasRecordType(assessmentPartRecordType) </code> is <code> true </code> 
     *  . 
     *
     *  @param  assessmentPartRecordType the type of the record to retrieve 
     *  @return the assessment part record 
     *  @throws org.osid.NullArgumentException <code> assessmentPartRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(assessmentPartRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.records.AssessmentPartRecord getAssessmentPartRecord(org.osid.type.Type assessmentPartRecordType)
        throws org.osid.OperationFailedException;
}
