//
// org.osid.assessment.authoring.AssessmentPartAdminSession
//
//     The OSID Java specification for org.osid.assessment.authoring.AssessmentPartAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment.authoring;


/**
 *  <p>This session creates, updates, and deletes <code> AssessmentParts. 
 *  </code> The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create an 
 *  <code> AssessmentPart, </code> an <code> AssessmentPartForm </code> is 
 *  requested using <code> getAssessmentPartFormForCreate() </code> specifying 
 *  the desired record <code> Types </code> or none if no record <code> Types 
 *  </code> are needed. The returned <code> AssessmentPartForm </code> will 
 *  indicate that it is to be used with a create operation and can be used to 
 *  examine metdata or validate data prior to creation. Once the <code> 
 *  AssessmentPartForm </code> is submiited to a create operation, it cannot 
 *  be reused with another create operation unless the first operation was 
 *  unsuccessful. Each <code> AssessmentPartForm </code> corresponds to an 
 *  attempted transaction. </p> 
 *  
 *  <p> For updates, <code> AssessmentPartForms </code> are requested to the 
 *  <code> AssessmentPart </code> <code> Id </code> that is to be updated 
 *  using <code> getAssessmentPartFormForUpdate(). </code> Similarly, the 
 *  <code> AssessmentPartForm </code> has metadata about the data that can be 
 *  updated and it can perform validation before submitting the update. The 
 *  <code> AssessmentPartForm </code> can only be used once for a successful 
 *  update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> AssessmentParts. </code> </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface AssessmentPartAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Bank </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Bank Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBankId();


    /**
     *  Gets the <code> Bank </code> associated with this session. 
     *
     *  @return the <code> Bank </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.Bank getBank()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create assessment parts. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known mapping methods in this session will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer create operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> AssessmentPart </code> creation 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAssessmentParts();


    /**
     *  Tests if this user can create a single <code> AssessmentPart </code> 
     *  using the desired record types. While <code> 
     *  AssessmentAuthoringManager.getAssessmentPartRecordTypes() </code> can 
     *  be used to examine which records are supported, this method tests 
     *  which record(s) are required for creating a specific <code> 
     *  AssessmentPart. </code> Providing an empty array tests if an <code> 
     *  AssessmentPart </code> can be created with no records. 
     *
     *  @param  assessmentPartRecordTypes array of assessment part record 
     *          types 
     *  @return <code> true </code> if <code> AssessmentPart </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          assessmentPartRecordTypes </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAssessmentPartWithRecordTypes(org.osid.type.Type[] assessmentPartRecordTypes);


    /**
     *  Gets the assessment part form for creating new assessment parts for an 
     *  assessment. A new form should be requested for each create 
     *  transaction. 
     *
     *  @param  assessmentId an assessment <code> Id </code> 
     *  @param  assessmentPartRecordTypes array of assessment part record 
     *          types to be included in the create operation or an empty list 
     *          if none 
     *  @return the assessment part form 
     *  @throws org.osid.NotFoundException <code> assessmentId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> assessmentId </code> or 
     *          <code> assessmentPartRecordTypes </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.AssessmentPartForm getAssessmentPartFormForCreateForAssessment(org.osid.id.Id assessmentId, 
                                                                                                        org.osid.type.Type[] assessmentPartRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new assessment part. 
     *
     *  @param  assessmentPartForm assessment part form 
     *  @return the new part 
     *  @throws org.osid.IllegalStateException <code> assessmentPartForm 
     *          </code> already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException <code> assessmentPartForm 
     *          </code> is invalid 
     *  @throws org.osid.NullArgumentException <code> assessmentPartForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> assessmentPartForm 
     *          </code> did not originate from <code> 
     *          getAssessmentPartFormForCreateForAssessment() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.AssessmentPart createAssessmentPartForAssessment(org.osid.assessment.authoring.AssessmentPartForm assessmentPartForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the assessment part form for creating new assessment parts under 
     *  another assessment part. A new form should be requested for each 
     *  create transaction. 
     *
     *  @param  assessmentPartId an assessment part <code> Id </code> 
     *  @param  assessmentPartRecordTypes array of assessment part record 
     *          types to be included in the create operation or an empty list 
     *          if none 
     *  @return the assessment part form 
     *  @throws org.osid.NotFoundException <code> assessmentPartId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> assessmentPartId </code> 
     *          or <code> assessmentPartRecordTypes </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.AssessmentPartForm getAssessmentPartFormForCreateForAssessmentPart(org.osid.id.Id assessmentPartId, 
                                                                                                            org.osid.type.Type[] assessmentPartRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new assessment part. 
     *
     *  @param  assessmentPartForm assessment part form 
     *  @return the new part 
     *  @throws org.osid.IllegalStateException <code> assessmentPartForm 
     *          </code> already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException <code> assessmentPartForm 
     *          </code> is invalid 
     *  @throws org.osid.NullArgumentException <code> assessmentPartForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> assessmentPartForm 
     *          </code> did not originate from <code> 
     *          getAssessmentPartFormForCreateForAssessmentPart() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.AssessmentPart createAssessmentPartForAssessmentPart(org.osid.assessment.authoring.AssessmentPartForm assessmentPartForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> AssessmentParts. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating an <code> AssessmentPart </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer update operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if assessment part modification is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateAssessmentParts();


    /**
     *  Gets the assessment part form for updating an existing assessment 
     *  part. A new assessment part form should be requested for each update 
     *  transaction. 
     *
     *  @param  assessmentPartId the <code> Id </code> of the <code> 
     *          AssessmentPart </code> 
     *  @return the assessment part form 
     *  @throws org.osid.NotFoundException <code> assessmentPartId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> assessmentPartId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.AssessmentPartForm getAssessmentPartFormForUpdate(org.osid.id.Id assessmentPartId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing assessment part. 
     *
     *  @param  assessmentPartId the <code> Id </code> of the <code> 
     *          AssessmentPart </code> 
     *  @param  assessmentPartForm part form 
     *  @throws org.osid.NotFoundException <code> assessmentPartId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> assessmentPartId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> assessmentPartForm 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateAssessmentPart(org.osid.id.Id assessmentPartId, 
                                     org.osid.assessment.authoring.AssessmentPartForm assessmentPartForm)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> AssessmentParts. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting an <code> AssessmentPart </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer delete operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> AssessmentPart </code> deletion 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteAssessmentParts();


    /**
     *  Removes an asessment part and all mapped items. 
     *
     *  @param  assessmentPartId the <code> Id </code> of the <code> 
     *          AssessmentPart </code> 
     *  @throws org.osid.NotFoundException <code> assessmentPartId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> assessmentPartId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteAssessmentPart(org.osid.id.Id assessmentPartId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  AssessmentParts. </code> A return of true does not guarantee 
     *  successful authorization. A return of false indicates that it is known 
     *  changing an alias will result in a <code> PERMISSION_DENIED. </code> 
     *  This is intended as a hint to an application that may opt not to offer 
     *  alias operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> AssessmentPart </code> aliasing 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageAssessmentPartAliases();


    /**
     *  Adds an <code> Id </code> to an <code> AssessmentPart </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> AssessmentPart </code> is determined by the provider. The 
     *  new <code> Id </code> is an alias to the primary <code> Id. </code> If 
     *  the alias is a pointer to another assessment part, it is reassigned to 
     *  the given assessment part <code> Id. </code> 
     *
     *  @param  assessmentPartId the <code> Id </code> of an <code> 
     *          AssessmentPart </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is in 
     *          use as a primary <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> assessmentPartId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> assessmentPartId </code> 
     *          or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasAssessmentPart(org.osid.id.Id assessmentPartId, 
                                    org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
