//
// org.osid.assessment.authoring.AssessmentPartItemSession
//
//     The OSID Java specification for org.osid.assessment.authoring.AssessmentPartItemSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment.authoring;


/**
 *  <p>This session defines methods for looking up <code> Item </code> to 
 *  <code> AssessmentPart </code> mappings. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated assessment part view: only items in the specified 
 *      assessment part are accessible </li> 
 *      <li> federated assessment part view: includes items in assessment 
 *      parts that are descendants of the specified assessment part </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedAssessmentPartView() </code> and <code> 
 *  useIsolatedAssessmentPartView() </code> behave as a radio group and one 
 *  should be selected before invoking any lookup methods. </p>
 */

public interface AssessmentPartItemSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Bank </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Bank Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBankId();


    /**
     *  Gets the <code> Bank </code> associated with this session. 
     *
     *  @return the <code> Bank </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.Bank getBank()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform assessment part lookups. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAccessAssessmentPartItems();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeAsseessmentPartItemView();


    /**
     *  A complete view of the returns is desired. Methods will return what is 
     *  requested or result in an error. This view is used when greater 
     *  precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryAssessmentPartItemView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include assessment parts in catalogs which are children of this 
     *  catalog in the bank hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedBankView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this bank only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedBankView();


    /**
     *  Gets the list of items mapped to the given <code> AssessmentPart. 
     *  </code> In plenary mode, the returned list contains all known items or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  items that are accessible through this session. 
     *
     *  @param  assessmentPartId <code> Id </code> of the <code> 
     *          AssessmentPart </code> 
     *  @return list of items 
     *  @throws org.osid.NotFoundException <code> assessmentPartId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> assessmentPartId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.assessment.ItemList getAssessmentPartItems(org.osid.id.Id assessmentPartId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the assessment parts containing the given item. In plenary mode, 
     *  the returned list contains all known assessment parts or an error 
     *  results. Otherwise, the returned list may contain only those 
     *  assessment parts that are accessible through this session. 
     *
     *  @param  itemId <code> Id </code> of the <code> Item </code> 
     *  @return the returned <code> AssessmentPart list </code> 
     *  @throws org.osid.NotFoundException <code> itemId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> itemId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.AssessmentPartList getAssessmentPartsByItem(org.osid.id.Id itemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
