//
// org.osid.assessment.authoring.SequenceRuleAdminSession
//
//     The OSID Java specification for org.osid.assessment.authoring.SequenceRuleAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment.authoring;


/**
 *  <p>This session creates and removes sequence rules. The data for create 
 *  and update is provided via the <code> SequenceRuleForm. </code> </p>
 */

public interface SequenceRuleAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Bank </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Bank Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBankId();


    /**
     *  Gets the <code> Bank </code> associated with this session. 
     *
     *  @return the bank 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.Bank getBank()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create sequence rules. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known creating a <code> SequenceRule </code> will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer create operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> SequenceRule </code> creation 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateSequenceRule();


    /**
     *  Tests if this user can create a single <code> SequenceRule </code> 
     *  using the desired record types. While <code> 
     *  AssessmentAuthoringManager.getSequenceRuleRecordTypes() </code> can be 
     *  used to examine which records are supported, this method tests which 
     *  record(s) are required for creating a specific <code> SequenceRule. 
     *  </code> Providing an empty array tests if a <code> SequenceRule 
     *  </code> can be created with no records. 
     *
     *  @param  sequenceRuleRecordTypes array of sequence rule record types 
     *  @return <code> true </code> if <code> SequenceRule </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> sequenceRuleRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateSequenceRuleWithRecordTypes(org.osid.type.Type[] sequenceRuleRecordTypes);


    /**
     *  Gets the sequence rule form for creating new sequence rules between 
     *  two assessment parts. A new form should be requested for each create 
     *  transaction. 
     *
     *  @param  assessmentPartId the source assessment part <code> Id </code> 
     *  @param  nextAssessmentPartId the target assessment part <code> Id 
     *          </code> 
     *  @param  sequenceRuleRecordTypes array of sequence rule record types 
     *  @return the sequence rule form 
     *  @throws org.osid.InvalidArgumentException <code> assessmentPartId 
     *          </code> and <code> nextAssessmentPartId </code> not on the 
     *          same assessment 
     *  @throws org.osid.NotFoundException <code> assessmentPartId </code> or 
     *          <code> nextAssessmentPartId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> assessmentPartId, 
     *          nextAssessmentPartId </code> , or <code> 
     *          sequenceRuleRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.SequenceRuleForm getSequenceRuleFormForCreate(org.osid.id.Id assessmentPartId, 
                                                                                       org.osid.id.Id nextAssessmentPartId, 
                                                                                       org.osid.type.Type[] sequenceRuleRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> SequenceRule. </code> 
     *
     *  @param  sequenceRuleForm the form for this <code> SequenceRule </code> 
     *  @return the new <code> SequenceRule </code> 
     *  @throws org.osid.IllegalStateException <code> sequenceRuleForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> sequenceRuleForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> sequenceRuleForm </code> 
     *          did not originate from <code> getSequenceRuleFormForCreate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.SequenceRule createSequenceRule(org.osid.assessment.authoring.SequenceRuleForm sequenceRuleForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update sequence rules. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known updating a <code> SequenceRule </code> will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer update operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> SequenceRule </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateSequenceRules();


    /**
     *  Gets the sequence rule form for updating an existing sequence rule. A 
     *  new sequence rule form should be requested for each update 
     *  transaction. 
     *
     *  @param  sequenceRuleId the <code> Id </code> of the <code> 
     *          SequenceRule </code> 
     *  @return the sequence rule form 
     *  @throws org.osid.NotFoundException <code> sequenceRuleId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> sequenceRuleId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.SequenceRuleForm getSequenceRuleFormForUpdate(org.osid.id.Id sequenceRuleId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing sequence rule. 
     *
     *  @param  sequenceRuleForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> sequenceRuleForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> sequenceRuleForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> sequenceRuleForm </code> 
     *          did not originate from <code> getSequenceRuleFormForUpdate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateSequenceRule(org.osid.assessment.authoring.SequenceRuleForm sequenceRuleForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete sequence rules. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known deleting a <code> SequenceRule </code> will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer delete operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> SequenceRule </code> deletion 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteSequenceRules();


    /**
     *  Deletes a <code> SequenceRule. </code> 
     *
     *  @param  sequenceRuleId the <code> Id </code> of the <code> 
     *          SequenceRule </code> to remove 
     *  @throws org.osid.NotFoundException <code> sequenceRuleId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> sequenceRuleId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteSequenceRule(org.osid.id.Id sequenceRuleId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for sequence 
     *  rules. A return of true does not guarantee successful authorization. A 
     *  return of false indicates that it is known changing an alias will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer alias operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> SequenceRule </code> aliasing 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSequenceRuleAliases();


    /**
     *  Adds a <code> Id </code> to a <code> SequenceRule </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> SequenceRule </code> is determined by the provider. The new 
     *  <code> Id </code> performs as an alias to the primary <code> Id 
     *  </code> . If the alias is a pointer to another sequence rule. it is 
     *  reassigned to the given sequence rule <code> Id. </code> 
     *
     *  @param  sequenceRuleId the <code> Id </code> of a <code> SequenceRule 
     *          </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> sequenceRuleId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> sequenceRuleId </code> 
     *          or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasSequenceRule(org.osid.id.Id sequenceRuleId, 
                                  org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> SequenceRules. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known sequencing operations will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> SequenceRule </code> ordering 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceSequenceRules();


    /**
     *  Reorders sequence rule for a source assessment part by moving the 
     *  specified sequence rule in front of a reference sequence rule. 
     *
     *  @param  sequenceRuleId the <code> Id </code> of a <code> SequenceRule 
     *          </code> 
     *  @param  assessmentPartId the <code> Id </code> of an <code> 
     *          AssessmentPart </code> 
     *  @param  referenceId the reference sequence rule <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> sequenceRuleId, 
     *          assessmentPartId, </code> or <code> referenceId </code> not 
     *          found or, <code> sequenceRuleId </code> or <code> referenceId 
     *          </code> not related to <code> assessmentPartId </code> 
     *  @throws org.osid.NullArgumentException <code> sequenceRuleId, 
     *          assessmentPartId, </code> or <code> referenceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveSequenceRuleAhead(org.osid.id.Id sequenceRuleId, 
                                      org.osid.id.Id assessmentPartId, 
                                      org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders sequence rule for a source assessment part by moving the 
     *  specified sequence rule behind a reference sequence rule. 
     *
     *  @param  sequenceRuleId the <code> Id </code> of a <code> SequenceRule 
     *          </code> 
     *  @param  assessmentPartId the <code> Id </code> of an <code> 
     *          AssessmentPart </code> 
     *  @param  referenceId the reference sequence rule <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> sequenceRuleId, 
     *          assessmentPartId, </code> or <code> referenceId </code> not 
     *          found or, <code> sequenceRuleId </code> or <code> referenceId 
     *          </code> not related to <code> assessmentPartId </code> 
     *  @throws org.osid.NullArgumentException <code> sequenceRuleId, 
     *          assessmentPartId, </code> or <code> referenceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveSequenceRuleBehind(org.osid.id.Id sequenceRuleId, 
                                       org.osid.id.Id assessmentPartId, 
                                       org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of sequence rules for an assessment part. 
     *
     *  @param  sequenceRuleIds the <code> Ids </code> for a set of <code> 
     *          SequenceRules </code> 
     *  @param  assessmentPartId the <code> Id </code> of an <code> 
     *          AssessmentPart </code> 
     *  @throws org.osid.NotFoundException <code> assessmentPartId </code> not 
     *          found or, a <code> sequenceRuleId </code> not related to 
     *          <code> assessmentPartId </code> 
     *  @throws org.osid.NullArgumentException <code> sequenceRuleIds </code> 
     *          or <code> assessmentPartId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderSequenceRules(org.osid.id.Id[] sequenceRuleIds, 
                                   org.osid.id.Id assessmentPartId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
