//
// org.osid.assessment.authoring.SequenceRuleBankAssignmentSession
//
//     The OSID Java specification for org.osid.assessment.authoring.SequenceRuleBankAssignmentSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment.authoring;


/**
 *  <p>This session provides methods to re-assign <code> SequenceRule </code> 
 *  to <code> Bank </code> mappings. a <code> SequenceRule </code> may appear 
 *  in multiple <code> Bank </code> objects and removing the last reference to 
 *  a <code> SequenceRule </code> is the equivalent of deleting it. Each 
 *  <code> Bank </code> may have its own authorizations governing who is 
 *  allowed to operate on it. </p> 
 *  
 *  <p> Adding a reference of a <code> SequenceRule </code> to another <code> 
 *  Bank </code> is not a copy operation (eg: does not change its <code> Id 
 *  </code> ). </p>
 */

public interface SequenceRuleBankAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter sequence rule/bank mappings. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignSequenceRules();


    /**
     *  Tests if this user can alter sequence rule/bank mappings. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @param  bankId the <code> Id </code> of the <code> Bank </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> bankId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignSequenceRulesToBank(org.osid.id.Id bankId);


    /**
     *  Gets a list of bank including and under the given bank node in which 
     *  any sequence rule can be assigned. 
     *
     *  @param  bankId the <code> Id </code> of the <code> Bank </code> 
     *  @return list of assignable bank <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> bankId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableBankIds(org.osid.id.Id bankId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of bank including and under the given bank node in which a 
     *  specific sequence rule can be assigned. 
     *
     *  @param  bankId the <code> Id </code> of the <code> Bank </code> 
     *  @param  sequenceRuleId the <code> Id </code> of the <code> 
     *          SequenceRule </code> 
     *  @return list of assignable bank <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> bankId </code> or <code> 
     *          sequenceRuleId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableBankIdsForSequenceRule(org.osid.id.Id bankId, 
                                                                  org.osid.id.Id sequenceRuleId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> SequenceRule </code> to a <code> Bank. </code> 
     *
     *  @param  sequenceRuleId the <code> Id </code> of the <code> 
     *          SequenceRule </code> 
     *  @param  bankId the <code> Id </code> of the <code> Bank </code> 
     *  @throws org.osid.AlreadyExistsException <code> sequenceRuleId </code> 
     *          is already assigned to <code> bankId </code> 
     *  @throws org.osid.NotFoundException <code> sequenceRuleId </code> or 
     *          <code> bankId </code> not found 
     *  @throws org.osid.NullArgumentException <code> sequenceRuleId </code> 
     *          or <code> bankId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignSequenceRuleToBank(org.osid.id.Id sequenceRuleId, 
                                         org.osid.id.Id bankId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> SequenceRule </code> from a <code> Bank. </code> 
     *
     *  @param  sequenceRuleId the <code> Id </code> of the <code> 
     *          SequenceRule </code> 
     *  @param  bankId the <code> Id </code> of the <code> Bank </code> 
     *  @throws org.osid.NotFoundException <code> sequenceRuleId </code> or 
     *          <code> bankId </code> not found or <code> sequenceRuleId 
     *          </code> not assigned to <code> bankId </code> 
     *  @throws org.osid.NullArgumentException <code> sequenceRuleId </code> 
     *          or <code> bankId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignSequenceRuleFromBank(org.osid.id.Id sequenceRuleId, 
                                             org.osid.id.Id bankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Moves a <code> SequenceRule </code> from one <code> Bank </code> to 
     *  another. Mappings to other <code> Banks </code> are unaffected. 
     *
     *  @param  sequenceRuleId the <code> Id </code> of the <code> 
     *          SequenceRule </code> 
     *  @param  fromBankId the <code> Id </code> of the current <code> Bank 
     *          </code> 
     *  @param  toBankId the <code> Id </code> of the destination <code> Bank 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> sequenceRuleId, fromBankId, 
     *          </code> or <code> toBankId </code> not found or <code> 
     *          sequenceRuleId </code> not mapped to <code> fromBankId </code> 
     *  @throws org.osid.NullArgumentException <code> sequenceRuleId, 
     *          fromBankId, </code> or <code> toBankId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void reassignSequenceRuleToBank(org.osid.id.Id sequenceRuleId, 
                                           org.osid.id.Id fromBankId, 
                                           org.osid.id.Id toBankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
