//
// org.osid.assessment.authoring.SequenceRuleEnablerQuery
//
//     The OSID Java specification for org.osid.assessment.authoring.SequenceRuleEnablerQuery.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment.authoring;


/**
 *  <p>This is the query for searching sequence rule enablers. Each method 
 *  match specifies a <code> AND </code> term while multiple invocations of 
 *  the same method produce a nested <code> OR. </code> </p>
 */

public interface SequenceRuleEnablerQuery
    extends org.osid.OsidEnablerQuery {


    /**
     *  Matches enablers mapped to the sequence rule. 
     *
     *  @param  sequenceRuleId the sequence rule <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> sequenceRuleId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRuledSequenceRuleId(org.osid.id.Id sequenceRuleId, 
                                         boolean match);


    /**
     *  Clears the sequence rule <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRuledSequenceRuleIdTerms();


    /**
     *  Tests if a <code> SequenceRuleQuery </code> is available. 
     *
     *  @return <code> true </code> if a sequence rule query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRuledSequenceRuleQuery();


    /**
     *  Gets the query for a sequence rule. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the sequence rule query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRuledSequenceRuleQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRuledSequenceRuleQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.assessment.authoring.SequenceRuleQuery getRuledSequenceRuleQuery();


    /**
     *  Matches enablers mapped to any sequence rule. 
     *
     *  @param  match <code> true </code> for enablers mapped to any sequence 
     *          rule, <code> false </code> to match enablers mapped to no 
     *          sequence rules 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRuledSequenceRule(boolean match);


    /**
     *  Clears the sequence rule query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRuledSequenceRuleTerms();


    /**
     *  Matches enablers mapped to the bank. 
     *
     *  @param  bankId the bank <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> bankId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBankId(org.osid.id.Id bankId, boolean match);


    /**
     *  Clears the bank <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBankIdTerms();


    /**
     *  Tests if an <code> BankQuery </code> is available. 
     *
     *  @return <code> true </code> if a bank query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBankQuery();


    /**
     *  Gets the query for a bank. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the bank query 
     *  @throws org.osid.UnimplementedException <code> supportsBankQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBankQuery() </code> is <code> true. </code> 
     */

    public org.osid.assessment.BankQuery getBankQuery();


    /**
     *  Clears the bank query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBankTerms();


    /**
     *  Gets the sequence rule enabler query record corresponding to the given 
     *  <code> SequenceRuleEnabler </code> record <code> Type. </code> 
     *  Multiple record retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  sequenceRuleEnablerRecordType a sequence rule enabler record 
     *          type 
     *  @return the sequence rule enabler query record 
     *  @throws org.osid.NullArgumentException <code> 
     *          sequenceRuleEnablerRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(sequenceRuleEnablerRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.records.SequenceRuleEnablerQueryRecord getSequenceRuleEnablerQueryRecord(org.osid.type.Type sequenceRuleEnablerRecordType)
        throws org.osid.OperationFailedException;
}
