//
// org.osid.assessment.authoring.SequenceRuleEnablerRuleApplicationSession
//
//     The OSID Java specification for org.osid.assessment.authoring.SequenceRuleEnablerRuleApplicationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment.authoring;


/**
 *  <p>This session provides methods to apply <code> SequenceRuleEnablers 
 *  </code> to <code> SequenceRules. </code> a <code> SequenceRule </code> 
 *  with multiple <code> SequenceRuleEnablers </code> means any positive rule 
 *  evaluation across the enablers result in an effective <code> SequenceRule. 
 *  </code> </p>
 */

public interface SequenceRuleEnablerRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Bank </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Bank Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBankId();


    /**
     *  Gets the <code> Bank </code> associated with this session. 
     *
     *  @return the bank 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.Bank getBank()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter sequence rule enabler/sequence rule 
     *  mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known mapping 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignSequenceRuleEnablers();


    /**
     *  Adds an existing <code> SequenceRuleEnabler </code> to a <code> 
     *  SequenceRule. </code> 
     *
     *  @param  sequenceRuleEnablerId the <code> Id </code> of the <code> 
     *          SequenceRuleEnabler </code> 
     *  @param  sequenceRuleId the <code> Id </code> of the <code> 
     *          SequenceRule </code> 
     *  @throws org.osid.AlreadyExistsException <code> sequenceRuleEnablerId 
     *          </code> is already applied to <code> sequenceRuleId </code> 
     *  @throws org.osid.NotFoundException <code> sequenceRuleEnablerId 
     *          </code> or <code> sequenceRuleId </code> not found 
     *  @throws org.osid.NullArgumentException <code> sequenceRuleEnablerId 
     *          </code> or <code> sequenceRuleId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignSequenceRuleEnablerToSequenceRule(org.osid.id.Id sequenceRuleEnablerId, 
                                                        org.osid.id.Id sequenceRuleId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> SequenceRuleEnabler </code> from a <code> 
     *  SequenceRule. </code> 
     *
     *  @param  sequenceRuleEnablerId the <code> Id </code> of the <code> 
     *          SequenceRuleEnabler </code> 
     *  @param  sequenceRuleId the <code> Id </code> of the <code> 
     *          SequenceRule </code> 
     *  @throws org.osid.NotFoundException <code> sequenceRuleEnablerId 
     *          </code> or <code> sequenceRuleId </code> not found or <code> 
     *          sequenceRuleEnablerId </code> not applied to <code> 
     *          sequenceRuleId </code> 
     *  @throws org.osid.NullArgumentException <code> sequenceRuleEnablerId 
     *          </code> or <code> sequenceRuleId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignSequenceRuleEnablerFromSequenceRule(org.osid.id.Id sequenceRuleEnablerId, 
                                                            org.osid.id.Id sequenceRuleId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> SequenceRuleEnablers. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known sequencing operations will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> SequenceRuleEnabler </code> 
     *          ordering is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceSequenceRuleEnablers();


    /**
     *  Reorders sequence rule enablers for a sequence rule by moving the 
     *  specified sequence rule enabler in front of a reference sequence rule 
     *  enabler. 
     *
     *  @param  sequenceRuleEnablerId the <code> Id </code> of a <code> 
     *          SequenceRuleEnabler </code> 
     *  @param  sequenceRuleId the <code> Id </code> of a <code> SequenceRule 
     *          </code> 
     *  @param  referenceId the reference sequence rule enabler <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> sequenceRuleEnablerId, 
     *          sequenceRuleId, </code> or <code> referenceId </code> not 
     *          found or, <code> sequenceRuleEnablerId </code> or <code> 
     *          referenceId </code> not related to <code> sequenceRuleId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> sequenceRuleEnablerId, 
     *          sequenceRuleId, </code> or <code> referenceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveSequenceRuleEnablerAhead(org.osid.id.Id sequenceRuleEnablerId, 
                                             org.osid.id.Id sequenceRuleId, 
                                             org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders sequence rule enablers for a sequence rule by moving the 
     *  specified sequence rule enabler behind a reference sequence rule 
     *  enabler. 
     *
     *  @param  sequenceRuleEnablerId the <code> Id </code> of a <code> 
     *          SequenceRuleEnabler </code> 
     *  @param  sequenceRuleId the <code> Id </code> of a <code> SequenceRule 
     *          </code> 
     *  @param  referenceId the reference sequence rule enabler <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> sequenceRuleEnablerId, 
     *          sequenceRuleId, </code> or <code> referenceId </code> not 
     *          found or, <code> sequenceRuleEnablerId </code> or <code> 
     *          referenceId </code> not related to <code> sequenceRuleId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> sequenceRuleEnablerId, 
     *          sequenceRuleId, </code> or <code> referenceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveSequenceRuleEnablerBehind(org.osid.id.Id sequenceRuleEnablerId, 
                                              org.osid.id.Id sequenceRuleId, 
                                              org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of sequence rule enablers for a sequence rule. 
     *
     *  @param  sequenceRuleEnablerIds the <code> Ids </code> for a set of 
     *          <code> SequenceRuleEnablers </code> 
     *  @param  sequenceRuleId the <code> Id </code> of a <code> SequenceRule 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> sequenceRuleId </code> not 
     *          found or, an <code> sequenceRuleEnablerId </code> not related 
     *          to <code> sequenceRuleId </code> 
     *  @throws org.osid.NullArgumentException <code> sequenceRuleEnablerIds 
     *          </code> or <code> sequenceRuleId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderSequenceRuleEnablers(org.osid.id.Id[] sequenceRuleEnablerIds, 
                                          org.osid.id.Id sequenceRuleId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
