//
// org.osid.assessment.authoring.SequenceRuleEnablerRuleLookupSession
//
//     The OSID Java specification for org.osid.assessment.authoring.SequenceRuleEnablerRuleLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment.authoring;


/**
 *  <p>This session provides methods to retrieve <code> SequenceRuleEnabler 
 *  </code> to <code> SequenceRule </code> mappings. a <code> Step </code> 
 *  with multiple <code> SequenceRuleEnablers </code> means any positive rule 
 *  evaluation across the enablers result in an effective <code> SequenceRule. 
 *  </code> </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated bank view: All methods in this session operate, retrieve 
 *      and pertain sequence rule enablers defined explicitly in the current 
 *      bank </li> 
 *      <li> federated bank view: All methods in this session operate, 
 *      retrieve and pertain to all sequence rule enablers defined in this 
 *      bank and any other sequence rule enablers implicitly available in this 
 *      bank through bank inheritence. </li> 
 *  </ul>
 *  
 */

public interface SequenceRuleEnablerRuleLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Bank </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Bank Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBankId();


    /**
     *  Gets the <code> Bank </code> associated with this session. 
     *
     *  @return the bank 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.Bank getBank()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform lookups of sequence rule 
     *  enabler/sequence rule mappings. A return of true does not guarantee 
     *  successful authorization. A return of false indicates that it is known 
     *  lookup methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if looking up mappings is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupSequenceRuleEnablerRules();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeSequenceRuleEnablerRuleView();


    /**
     *  A complete view of the <code> SequenceRuleEnabler </code> and <code> 
     *  SequenceRule </code> returns is desired. Methods will return what is 
     *  requested or result in an error. This view is used when greater 
     *  precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenarySequenceRuleEnablerRuleView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include sequence rule enablers in banks which are children of this 
     *  bank in the bank hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedBankView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this bank only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedBankView();


    /**
     *  Gets the <code> SequenceRuleEnabler Id </code> associated with a 
     *  <code> SequenceRule. </code> 
     *
     *  @param   sequenceRuleId <code> Id </code> of the <code> SequenceRule 
     *          </code> 
     *  @return the sequence rule enabler <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> sequenceRuleId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> sequenceRuleId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getSequenceRuleEnablerIdsForSequenceRule(org.osid.id.Id  sequenceRuleId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> SequenceRuleEnablers </code> associated with a <code> 
     *  SequenceRule. </code> 
     *
     *  @param  sequenceRuleId <code> Id </code> of the <code> SequenceRule 
     *          </code> 
     *  @return the sequence rule enablers 
     *  @throws org.osid.NotFoundException <code> sequenceRuleId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> sequenceRuleId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.SequenceRuleEnablerList getSequenceRuleEnablersForSequenceRule(org.osid.id.Id sequenceRuleId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> SequenceRule </code> <code> Ids </code> mapped to a 
     *  <code> SequenceRuleEnabler. </code> 
     *
     *  @param  sequenceRuleEnablerId <code> Id </code> of a <code> 
     *          SequenceRuleEnabler </code> 
     *  @return list of sequence rule <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> sequenceRuleEnablerId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> sequenceRuleEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getSequenceRuleIdsForSequenceRuleEnabler(org.osid.id.Id sequenceRuleEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> SequenceRules </code> mapped to a <code> 
     *  SequenceRuleEnabler. </code> 
     *
     *  @param  sequenceRuleEnablerId <code> Id </code> of a <code> 
     *          SequenceRuleEnabler </code> 
     *  @return list of sequence rules 
     *  @throws org.osid.NotFoundException <code> sequenceRuleEnablerId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> sequenceRuleEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.SequenceRuleList getSequenceRulesForSequenceRuleEnabler(org.osid.id.Id sequenceRuleEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
