//
// org.osid.assessment.authoring.SequenceRuleNotificationSession
//
//     The OSID Java specification for org.osid.assessment.authoring.SequenceRuleNotificationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment.authoring;


/**
 *  <p>This session defines methods to receive notifications on adds/changes 
 *  to <code> SequenceRule </code> objects in this <code> Bank. </code> This 
 *  also includes existing <code> SequenceRules </code> that may appear or 
 *  disappear due to changes in the <code> Bank </code> hierarchy, This 
 *  session is intended for consumers needing to synchronize their state with 
 *  this service without the use of polling. Notifications are cancelled when 
 *  this session is closed. </p> 
 *  
 *  <p> The two views defined in this session correspond to the views in the 
 *  <code> SequenceRuleLookupSession. </code> </p>
 */

public interface SequenceRuleNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Bank </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Bank Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBankId();


    /**
     *  Gets the <code> Bank </code> associated with this session. 
     *
     *  @return the bank 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.Bank getBank()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can register for <code> SequenceRule </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForSequenceRuleNotifications();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include in banks which are children of this bank in the bank 
     *  hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedBankView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts notifications to this bank only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedBankView();


    /**
     *  Reliable notifications are desired. In reliable mode, notifications 
     *  are to be acknowledged using <code> 
     *  acknowledgeSequenceRuleNotification() </code> . 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void reliableSequenceRuleNotifications();


    /**
     *  Unreliable notifications are desired. In unreliable mode, 
     *  notifications do not need to be acknowledged. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void unreliableSequenceRuleNotifications();


    /**
     *  Acknowledge a sequence rule notification. 
     *
     *  @param  notificationId the <code> Id </code> of the notification 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void acknowledgeSequenceRuleNotification(org.osid.id.Id notificationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new sequence rules. <code> 
     *  SequenceRuleReceiver.newSequenceRules() </code> is invoked when a new 
     *  <code> SequenceRule </code> appears in this bank. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewSequenceRules()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new sequence rules for the given 
     *  assessment part. <code> SequenceRuleReceiver.newSequenceRules() 
     *  </code> is invoked when a new <code> SequenceRule </code> appears in 
     *  this bank. 
     *
     *  @param  assessmentPartId the <code> Id </code> of the <code> 
     *          AssessmentPart </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> sequenceRuleId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewSequenceRulesForAssessmentPart(org.osid.id.Id assessmentPartId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new sequence rules for the given 
     *  assessment part. <code> SequenceRuleReceiver.newSequenceRules() 
     *  </code> is invoked when a new <code> SequenceRule </code> appears in 
     *  this bank. 
     *
     *  @param  assessmentPartId the <code> Id </code> of the <code> 
     *          AssessmentPart </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> sequenceRuleId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewSequenceRulesForNextAssessmentPart(org.osid.id.Id assessmentPartId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated sequence rules. <code> 
     *  SequenceRuleReceiver.changedSequenceRules() </code> is invoked when a 
     *  sequence rule in this bank is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedSequenceRules()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of updated sequence rules for the given 
     *  assessment part. <code> SequenceRuleReceiver.changedSequenceRules() 
     *  </code> is invoked when a new <code> SequenceRule </code> in this bank 
     *  is changed. 
     *
     *  @param  assessmentPartId the <code> Id </code> of the <code> 
     *          AssessmentPart </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> sequenceRuleId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedSequenceRulesForAssessmentPart(org.osid.id.Id assessmentPartId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of updated sequence rules for the given 
     *  assessment part. <code> SequenceRuleReceiver.changedSequenceRules() 
     *  </code> is invoked when a new <code> SequenceRule </code> in this bank 
     *  is changed. 
     *
     *  @param  assessmentPartId the <code> Id </code> of the <code> 
     *          AssessmentPart </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> sequenceRuleId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedSequenceRulesForNextAssessmentPart(org.osid.id.Id assessmentPartId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated sequence rule. <code> 
     *  ProvisionableReceiver.changedSequenceRules() </code> is invoked when 
     *  the specified sequence rule in this bank is changed. 
     *
     *  @param  sequenceRuleId the <code> Id </code> of the <code> 
     *          SequenceRule </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> sequenceRuleId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedSequenceRule(org.osid.id.Id sequenceRuleId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted sequence rules. <code> 
     *  SequenceRuleReceiver.deletedSequenceRules() </code> is invoked when a 
     *  sequence rule is deleted or removed from this bank. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedSequenceRules()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted sequence rules for the given 
     *  assessment part. <code> SequenceRuleReceiver.deletedSequenceRule() 
     *  </code> is invoked when a sequence rule is deleted or removed from 
     *  this bank. 
     *
     *  @param  assessmentPartId the <code> Id </code> of the <code> 
     *          AssessmentPart </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> sequenceRuleId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedSequenceRulesForAssessmentPart(org.osid.id.Id assessmentPartId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted sequence rules for the given 
     *  assessment part. <code> SequenceRuleReceiver.deletedSequenceRule() 
     *  </code> is invoked when a sequence rule is deleted or removed from 
     *  this bank. 
     *
     *  @param  assessmentPartId the <code> Id </code> of the <code> 
     *          AssessmentPart </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> sequenceRuleId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedSequenceRulesForNextAssessmentPart(org.osid.id.Id assessmentPartId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted sequence rule. <code> 
     *  SequenceRuleReceiver.deletedSequenceRule() </code> is invoked when the 
     *  specified sequence rule is deleted or removed from this bank. 
     *
     *  @param  sequenceRuleId the <code> Id </code> of the <code> 
     *          SequenceRule </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> sequenceRuleId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedSequenceRule(org.osid.id.Id sequenceRuleId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
