//
// org.osid.assessment.authoring.SequenceRuleSearchOrder
//
//     The OSID Java specification for org.osid.assessment.authoring.SequenceRuleSearchOrder.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment.authoring;


/**
 *  <p>An interface for specifying the ordering of search results. </p>
 */

public interface SequenceRuleSearchOrder
    extends org.osid.OsidRuleSearchOrder {


    /**
     *  Specifies a preference for ordering the result set by the assessment 
     *  part. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByAssessmentPart(org.osid.SearchOrderStyle style);


    /**
     *  Tests if an assessment part search order is available. 
     *
     *  @return <code> true </code> if an assessment part search order is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentPartSearchOrder();


    /**
     *  Gets the assessment order. 
     *
     *  @return the assessment part search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentPartSearchOrder() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentPartSearchOrder() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.assessment.authoring.AssessmentPartSearchOrder getAssessmentPartSearchOrder();


    /**
     *  Specifies a preference for ordering the result set by the assessment 
     *  part. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByNextAssessmentPart(org.osid.SearchOrderStyle style);


    /**
     *  Tests if an assessment part search order is available. 
     *
     *  @return <code> true </code> if an assessment part search order is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsNextAssessmentPartSearchOrder();


    /**
     *  Gets the assessment order. 
     *
     *  @return the assessment part search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsNextAssessmentPartSearchOrder() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsNextAssessmentPartSearchOrder() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.assessment.authoring.AssessmentPartSearchOrder getNextAssessmentPartSearchOrder();


    /**
     *  Specifies a preference for ordering the result set by the minimum 
     *  score. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByMinimumScore(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the maximum 
     *  score. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByMaximumScore(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the cumulative. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByCumulative(org.osid.SearchOrderStyle style);


    /**
     *  Gets the sequence rule search order record corresponding to the given 
     *  sequence rule record <code> Type. </code> Multiple retrievals return 
     *  the same underlying object. 
     *
     *  @param  sequenceRuleRecordType a sequence rule record type 
     *  @return the sequence rule search order record 
     *  @throws org.osid.NullArgumentException <code> sequenceRuleRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(sequenceRuleRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.records.SequenceRuleSearchOrderRecord getSequenceRuleSearchOrderRecord(org.osid.type.Type sequenceRuleRecordType)
        throws org.osid.OperationFailedException;
}
