//
// org.osid.assessment.authoring.SequenceRuleSearchSession
//
//     The OSID Java specification for org.osid.assessment.authoring.SequenceRuleSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment.authoring;


/**
 *  <p>This session provides methods for searching among <code> SequenceRule 
 *  </code> objects. The search query is constructed using the <code> 
 *  SequenceRuleyQuery. </code> </p> 
 *  
 *  <p> <code> getSequenceRulesByQuery() </code> is the basic search method 
 *  and returns a list of <code> SequenceRules. </code> A more advanced search 
 *  may be performed with <code> getSequenceRulesBySearch(). </code> It 
 *  accepts a <code> SequenceRuleSearch </code> in addition to the query for 
 *  the purpose of specifying additional options affecting the entire search, 
 *  such as workflow. <code> getSequenceRulesBySearch() </code> returns a 
 *  <code> SequenceRuleSearchResults </code> that can be used to access the 
 *  resulting <code> SequenceRuleList </code> or be used to perform a search 
 *  within the result set through <code> SequenceRuleSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated bank view: searches include sequence rule in bank of 
 *      which this bank matchmaker is an ancestor in the bank hierarchy </li> 
 *      <li> isolated bank view: searches are restricted to sequence rule in 
 *      this bank </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> SequenceRules </code> may have a query record indicated by 
 *  their respective record types. The query record is accessed via the <code> 
 *  SequenceRuleQuery. </code> </p>
 */

public interface SequenceRuleSearchSession
    extends org.osid.assessment.authoring.SequenceRuleQuerySession {


    /**
     *  Gets a sequence rule search. 
     *
     *  @return the sequence rule search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.SequenceRuleSearch getSequenceRuleSearch();


    /**
     *  Gets a sequence rule search order. The <code> SequenceRuleSearchOrder 
     *  </code> is supplied to a <code> SequenceRuleSearch </code> to specify 
     *  the ordering of results. 
     *
     *  @return the sequence rule search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.SequenceRuleSearchOrder getSequenceRuleSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  sequenceRuleQuery the sequence rule query 
     *  @param  sequenceRuleSearch the sequence rule search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> sequenceRuleQuery 
     *          </code> or <code> sequenceRuleSearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> sequenceRuleQuery </code> 
     *          or <code> sequenceRuleSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.SequenceRuleSearchResults getSequenceRulesBySearch(org.osid.assessment.authoring.SequenceRuleQuery sequenceRuleQuery, 
                                                                                            org.osid.assessment.authoring.SequenceRuleSearch sequenceRuleSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a sequence rule query from an inspector. The inspector is 
     *  available from a <code> SequenceRuleSearchResults. </code> 
     *
     *  @param  sequenceRuleQueryInspector a sequence rule query inspector 
     *  @return the sequence rule query 
     *  @throws org.osid.NullArgumentException <code> 
     *          sequenceRuleQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          sequenceRuleQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.SequenceRuleQuery getSequenceRuleQueryFromInspector(org.osid.assessment.authoring.SequenceRuleQueryInspector sequenceRuleQueryInspector);
}
