//
// org.osid.assessment.batch.AssessmentOfferedBatchAdminSession
//
//     The OSID Java specification for org.osid.assessment.batch.AssessmentOfferedBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment.batch;


/**
 *  <p>This session creates, updates, and deletes <code> AssessmentsOffered 
 *  </code> in bulk. The data for create and update is provided by the 
 *  consumer via the form object. <code> OsidForms </code> are requested for 
 *  each create or update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create an 
 *  <code> AssessmentOffered, </code> an <code> AssessmentOfferedForm </code> 
 *  is requested using <code> getAssessmentOfferedFormsForCreate() </code> 
 *  specifying the desired assessment and record <code> Types </code> or none 
 *  if no record <code> Types </code> are needed. Each of the returned <code> 
 *  AssessmentOfferedForms </code> will indicate that it is to be used with a 
 *  create operation and can be used to examine metdata or validate data prior 
 *  to creation. Once an <code> AssessmentOfferedForm </code> is submiited to 
 *  a create operation, it cannot be reused with another create operation 
 *  unless the first operation was unsuccessful. Each <code> 
 *  AssessmentOfferedForm </code> corresponds to an attempted transaction. 
 *  </p> 
 *  
 *  <p> The <code> AssessmentOfferedForms </code> returned from <code> 
 *  getAssessmentOfferedFormsForCreate() </code> may be linked to the 
 *  originating request through the peer <code> Ids </code> of the <code> 
 *  AssessmentOfferedForm. </code> In the case where there may be duplicates, 
 *  any <code> AssessmentOfferedForm </code> of the same peer <code> Ids 
 *  </code> may be used for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> AssessmentOfferedForms </code> are submitted 
 *  for create, a <code> CreateResponse </code> is returned for each <code> 
 *  AssessmentOfferedForm, </code> although the ordering is not defined. Only 
 *  errors that pertain to the entire create operation are returned from 
 *  <code> createAssessmentsOffered(), </code> errors specific to an 
 *  individual <code> AssessmentOfferedForm </code> are indicated in the 
 *  corresponding <code> CreateResponse. </code> <code> CreateResponses 
 *  </code> may be linked to the originating <code> AssessmentOfferedForm 
 *  </code> through the <code> AssessmentOfferedForm </code> <code> Id </code> 
 *  . </p> 
 *  
 *  <p> For updates, <code> AssessmentOfferedForms </code> are requested to 
 *  the <code> AssessmentOffered </code> <code> Id </code> that is to be 
 *  updated using <code> getAssessmentOfferedFormsForUpdate() </code> where 
 *  the reference <code> Id </code> in the <code> AssessmentOfferedForm 
 *  </code> may be used to link the request. Similarly, the <code> 
 *  AssessmentOfferedForm </code> has metadata about the data that can be 
 *  updated and it can perform validation before submitting the update. The 
 *  <code> AssessmentOfferedForm </code> can only be used once for a 
 *  successful update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> AssessmentOfferedForms </code> are submitted 
 *  for update, an <code> UpdateResponse </code> is returned for each <code> 
 *  AssessmentOfferedForm, </code> although the ordering is not defined. Only 
 *  errors that pertain to the entire update operation are returned from 
 *  <code> updateAssessmentsOffered(), </code> errors specific to an 
 *  individual <code> AssessmentOfferedForm </code> are indicated in the 
 *  corresponding <code> UpdateResponse. </code> <code> UpdateResponses 
 *  </code> may be linked to the originating <code> AssessmentOfferedForm 
 *  </code> through the <code> AssessmentOfferedForm </code> <code> Id. 
 *  </code> </p> 
 *  
 *  <p> The delete operations delete <code> AssessmentsOffered </code> in 
 *  bulk. To unmap an <code> AssessmentOffered </code> from the current <code> 
 *  Bank, </code> the <code> AssessmentOfferedBankAssignmentSession </code> 
 *  should be used. These delete operations attempt to remove the <code> 
 *  AssessmentOffered </code> itself thus removing it from all known <code> 
 *  Bank </code> catalogs. Bulk delete operations return the results in <code> 
 *  DeleteResponses. </code> </p>
 */

public interface AssessmentOfferedBatchAdminSession
    extends org.osid.assessment.AssessmentOfferedAdminSession {


    /**
     *  Gets the assessment offered forms for creating a bunch of new 
     *  assessments offered. An AssessmentOfferedForm is returned for each 
     *  supplied assessment. 
     *
     *  @param  assessmentIds a list of assessment <code> Ids </code> 
     *  @param  assessmentOfferedRecordTypes array of assessment offered 
     *          record types to be included in each create operation or an 
     *          empty list if none 
     *  @return the assessment offered forms 
     *  @throws org.osid.NotFoundException an <code> assessmentId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> assessmentids </code> or 
     *          <code> assessmentOfferedRecordTypes </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.batch.AssessmentOfferedBatchFormList getAssessmentOfferedFormsForCreate(org.osid.id.IdList assessmentIds, 
                                                                                                       org.osid.type.Type[] assessmentOfferedRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> AssessmentsOffered. </code> This method 
     *  returns an error if the entire operation fails. Otherwise, the status 
     *  of an individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  assessmentOfferedForms the assessment offered forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> assessmentOfferedForms 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createAssessmentsOffered(org.osid.assessment.batch.AssessmentOfferedBatchFormList assessmentOfferedForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the assessment offered forms for updating an existing set of 
     *  assessments offered. A new assessment offeredform should be requested 
     *  for each update transaction. 
     *
     *  @param  assessmentOfferedIds the <code> Ids </code> of the <code> 
     *          AssessmentOffered </code> 
     *  @return the assessment offered form 
     *  @throws org.osid.NotFoundException an <code> assessmentOfferedId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> assessmentOfferedIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.batch.AssessmentOfferedBatchFormList getAssessmentOfferedFormsForUpdate(org.osid.id.IdList assessmentOfferedIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing assessments offered. This method returns an error if 
     *  the entire operation fails. Otherwise, the status of an individual 
     *  update operation is indicated in the <code> BatchCreateResponse 
     *  </code> . 
     *
     *  @param  assessmentOfferedForms the form containing the elements to be 
     *          updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> assessmentOfferedForms 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateAssessmentsOffered(org.osid.assessment.batch.AssessmentOfferedBatchFormList assessmentOfferedForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> AssessmentsOffered </code> in this <code> Bank 
     *  </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllAssessmentsOffered()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes assessments offered for the given <code> Ids. </code> 
     *
     *  @param  assessmentOfferedIds the <code> Ids </code> of the assessments 
     *          offered to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> assessmentOfferedIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAssessmentsOffered(org.osid.id.IdList assessmentOfferedIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all assessments offered for the given assessment, 
     *
     *  @param  assessmentId an <code> Id </code> of an assessment 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> assessmentId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAssessmentsOfferedForAssessment(org.osid.id.Id assessmentId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes assessments offeredexpired before the given date. 
     *
     *  @param  date a date 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteIneffectiveAssessmentsOfferedByDate(org.osid.calendaring.DateTime date)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to an <code> AssessmentOffered </code> for 
     *  the purpose of creating compatibility. The primary <code> Id </code> 
     *  of the <code> AssessmentOffered </code> is determined by the provider. 
     *  The new <code> Id </code> is an alias to the primary <code> Id. 
     *  </code> If the alias is a pointer to another assessment offered, it is 
     *  reassigned to the given assessment offered <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasAssessmentsOffered(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
