//
// org.osid.assessment.batch.AssessmentTakenBatchAdminSession
//
//     The OSID Java specification for org.osid.assessment.batch.AssessmentTakenBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment.batch;


/**
 *  <p>This session creates, updates, and deletes <code> AssessmentsTaken 
 *  </code> in bulk. The data for create and update is provided by the 
 *  consumer via the form object. <code> OsidForms </code> are requested for 
 *  each create or update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create an 
 *  <code> AssessmentTaken, </code> an <code> AssessmentTakenForm </code> is 
 *  requested using <code> getAssessmentTakenFormsForCreate() </code> 
 *  specifying the desired assessment offered, resource, and record <code> 
 *  Types </code> or none if no record <code> Types </code> are needed. Each 
 *  of the returned <code> AssessmentTakenForms </code> will indicate that it 
 *  is to be used with a create operation and can be used to examine metdata 
 *  or validate data prior to creation. Once an <code> AssessmentTakenForm 
 *  </code> is submiited to a create operation, it cannot be reused with 
 *  another create operation unless the first operation was unsuccessful. Each 
 *  <code> AssessmentTakenForm </code> corresponds to an attempted 
 *  transaction. </p> 
 *  
 *  <p> The <code> AssessmentTakenForms </code> returned from <code> 
 *  getAssessmentTakenFormsForCreate() </code> may be linked to the 
 *  originating request through the peer <code> Ids </code> of the <code> 
 *  AssessmentTakenForm. </code> In the case where there may be duplicates, 
 *  any <code> AssessmentTakenForm </code> of the same peer <code> Ids </code> 
 *  may be used for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> AssessmentTakenForms </code> are submitted for 
 *  create, a <code> CreateResponse </code> is returned for each <code> 
 *  AssessmentTakenForm, </code> although the ordering is not defined. Only 
 *  errors that pertain to the entire create operation are returned from 
 *  <code> createAssessmentsTaken(), </code> errors specific to an individual 
 *  <code> AssessmentTakenForm </code> are indicated in the corresponding 
 *  <code> CreateResponse. </code> <code> CreateResponses </code> may be 
 *  linked to the originating <code> AssessmentTakenForm </code> through the 
 *  <code> AssessmentTakenForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> AssessmentTakenForms </code> are requested to the 
 *  <code> AssessmentTaken </code> <code> Id </code> that is to be updated 
 *  using <code> getAssessmentTakenFormsForUpdate() </code> where the 
 *  reference <code> Id </code> in the <code> AssessmentTakenForm </code> may 
 *  be used to link the request. Similarly, the <code> AssessmentTakenForm 
 *  </code> has metadata about the data that can be updated and it can perform 
 *  validation before submitting the update. The <code> AssessmentTakenForm 
 *  </code> can only be used once for a successful update and cannot be 
 *  reused. </p> 
 *  
 *  <p> Once a batch of <code> AssessmentTakenForms </code> are submitted for 
 *  update, an <code> UpdateResponse </code> is returned for each <code> 
 *  AssessmentTakenForm, </code> although the ordering is not defined. Only 
 *  errors that pertain to the entire update operation are returned from 
 *  <code> updateAssessmentsTaken(), </code> errors specific to an individual 
 *  <code> AssessmentTakenForm </code> are indicated in the corresponding 
 *  <code> UpdateResponse. </code> <code> UpdateResponses </code> may be 
 *  linked to the originating <code> AssessmentTakenForm </code> through the 
 *  <code> AssessmentTakenForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> AssessmentsTaken </code> in bulk. 
 *  To unmap an <code> AssessmentTaken </code> from the current <code> Bank, 
 *  </code> the <code> AssessmentTakenBankAssignmentSession </code> should be 
 *  used. These delete operations attempt to remove the <code> AssessmentTaken 
 *  </code> itself thus removing it from all known <code> Bank </code> 
 *  catalogs. Bulk delete operations return the results in <code> 
 *  DeleteResponses. </code> </p>
 */

public interface AssessmentTakenBatchAdminSession
    extends org.osid.assessment.AssessmentTakenAdminSession {


    /**
     *  Gets the assessment taken forms for creating a bunch of new 
     *  assessments taken. A form is returned for each supplied assessment 
     *  offered and resource pair. 
     *
     *  @param  peers a list of assessment taken <code> peers </code> 
     *  @param  assessmentTakenRecordTypes array ofassessment taken record 
     *          types to be included in each create operation or an empty list 
     *          if none 
     *  @return the assessment taken forms 
     *  @throws org.osid.NotFoundException an <code> assessmentOfferedId 
     *          </code> or <code> resourceId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> peers </code> or <code> 
     *          assessmentTakenRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.batch.AssessmentTakenBatchFormList getAssessmentTakenFormsForCreate(org.osid.assessment.batch.AssessmentTakenPeerList peers, 
                                                                                                   org.osid.type.Type[] assessmentTakenRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> AssessmentsTaken. </code> This method 
     *  returns an error if the entire operation fails. Otherwise, the status 
     *  of an individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  assessmentTakenForms the assessment taken forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> assessmentTakenForms 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createAssessmentsTaken(org.osid.assessment.batch.AssessmentTakenBatchFormList assessmentTakenForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the assessment taken forms for updating an existing set of 
     *  assessments taken. A newassessment taken form should be requested for 
     *  each update transaction. 
     *
     *  @param  assessmentTakenIds the <code> Ids </code> of the <code> 
     *          AssessmentTaken </code> 
     *  @return the assessment taken forms 
     *  @throws org.osid.NotFoundException an <code> assessmentTakenId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> assessmentTakenIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.batch.AssessmentTakenBatchFormList getAssessmentTakenFormsForUpdate(org.osid.id.IdList assessmentTakenIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing assessments taken. This method returns an error if 
     *  the entire operation fails. Otherwise, the status of an individual 
     *  update operation is indicated in the <code> BatchCreateResponse 
     *  </code> . 
     *
     *  @param  assessmentTakenForms the form containing the elements to be 
     *          updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> assessmentTakenForms 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateAssessmentsTaken(org.osid.assessment.batch.AssessmentTakenBatchFormList assessmentTakenForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> AssessmentsTaken </code> in this <code> Bank 
     *  </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllAssessmentsTaken()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes assessments taken for the given <code> Ids. </code> 
     *
     *  @param  assessmentTakenIds the <code> Ids </code> of the assessments 
     *          taken to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> assessmentTakenIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAssessmentsTaken(org.osid.id.IdList assessmentTakenIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes assessments taken for the given taker. 
     *
     *  @param  resourceId an <code> Id </code> of a resource 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAssessmentsTakenForTaker(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes assessments taken for the given assessment offered. 
     *
     *  @param  assessmentOfferedId an <code> Id </code> of an assessment 
     *          offered 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> assessmentOfferedId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAssessmentsTakenForAssessmentOffered(org.osid.id.Id assessmentOfferedId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to an <code> AssessmentTaken </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> AssessmentTaken </code> is determined by the provider. The 
     *  new <code> Id </code> is an alias to the primary <code> Id. </code> If 
     *  the alias is a pointer to another assessment taken, it is reassigned 
     *  to the given assessment taken <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasAssessmentsTaken(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
