/**
 * <p>The Open Service Interface Definitions for the org.osid.assessment
 * service.</p>
 * 
 * <p>The Assessment OSID provides the means to create, access, and take 
 * assessments. An <code> Assessment </code> may represent a quiz, survey, or 
 * other evaluation that includes assessment <code> Items. </code> The OSID 
 * defines methods to describe the flow of control and the relationships among 
 * the objects. Assessment <code> Items </code> are extensible objects to 
 * capture various types of questions, such as a multiple choice or an asset 
 * submission. </p> 
 * 
 * <p> The Assessment service can br broken down into several distinct 
 * services: </p> 
 * 
 * <ul>
 *     <li> Assessment Taking </li> 
 *     <li> Assessment and Item authoring </li> 
 *     <li> Accessing and managing banks of assessments and items </li> 
 * </ul>
 * 
 * 
 * <p> Each of these service areas are covered by different session and object 
 * interfaces. The object interfaces describe both the structure of the 
 * assessment and follow an assessment management workflow of first defining 
 * assessment items and then authoring assessments based on those items. They 
 * are: </p> 
 * 
 * <ul>
 *     <li> <code> Item </code> : a question and answer pair </li> 
 *     <li> <code> Response: </code> a response to an <code> Item </code> 
 *     question </li> 
 *     <li> <code> Assessment </code> : a set of <code> Items </code> </li> 
 *     <li> <code> AssessmentSection: </code> A grouped set of <code> Items 
 *     </code> </li> 
 *     <li> <code> AssessmentOffering: </code> An <code> Assessment </code> 
 *     available for taking </li> 
 *     <li> <code> AssessmentTaken: </code> An <code> AssessmentOffering 
 *     </code> that has been completed or in progress </li> 
 * </ul>
 * 
 * <h4> Taking Assessments </h4> 
 * 
 * <p> The <code> AssessmentSession </code> is used to take an assessment. It 
 * captures various ways an assessment can be taken which may include time 
 * constraints, the ability to suspend and resume, and the availability of an 
 * answer. </p> 
 * 
 * <p> Taking an <code> Assessment </code> involves first navigating through 
 * <code> AssessmentSections. </code> An <code> AssessmentSection </code> is 
 * an advanced authoring construct used to both visually divide an <code> 
 * Assessment </code> and impose additional constraints. Basic assessments are 
 * assumed to always have one <code> AssessmentSection </code> even if not 
 * explicitly created. </p> 
 * <h4> Authoring </h4> 
 * 
 * <p> A basic authoring session is available in this package to map <code> 
 * Items </code> to <code> Assessments. </code> More sophisticated authoring 
 * using <code> AssessmentParts </code> and sequencing is available in the 
 * Assessment Authoring OSID. </p> 
 * <h4> Bank Cataloging </h4> 
 * 
 * <p> <code> Assessments, </code> <code> AssessmentsOffered, </code> <code> 
 * AssessmentsTaken, </code> and <code> Items </code> may be organized into 
 * federateable catalogs called <code> Banks </code> . </p> 
 * <h4> Sub Packages </h4> 
 * 
 * <p> The Assessment OSID includes an Assessment Authoring OSID for more 
 * advanced authoring and sequencing options. </p>
 * 
 * <br/><hr/><br/>
 * 
 * <p>Copyright &copy; 2002-2004 Massachusetts Institute of Technology. </p> 
 * 
 * <p> Copyright &copy; 2008-2010 Ingenescus. All Rights Reserved. </p>
 * 
 * <p>This Work is being provided by the copyright holder(s) subject to the 
 * following license. By obtaining, using and/or copying this Work, you agree 
 * that you have read, understand, and will comply with the following terms 
 * and conditions. </p> 
 * 
 * <p> Permission to use, copy and distribute unmodified versions of this 
 * Work, for any purpose, without fee or royalty is hereby granted, provided 
 * that you include the above copyright notices and the terms of this license 
 * on ALL copies of the Work or portions thereof. </p> 
 * 
 * <p> You may nodify or create Derivatives of this Work only for your 
 * internal purposes. You shall not distribute or transfer any such Derivative 
 * of this Work to any location or to any third party. For the purposes of 
 * this license, "Derivative" shall mean any derivative of the Work as defined 
 * in the United States Copyright Act of 1976, such as a translation or 
 * modification. </p> 
 * 
 * <p> This Work and the information contained herein is provided on an "AS 
 * IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT 
 * NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR 
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT 
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN 
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN 
 * CONNECTION WITH THE WORK OR THE USE OR OTHER DEALINGS IN THE WORK. </p> 
 * 
 * <p> The export of software employing encryption technology may require a 
 * specific license from the United States Government. It is the 
 * responsibility of any person or organization contemplating export to obtain 
 * such a license before exporting this Work. </p>
 */

package org.osid.assessment;
