//
// org.osid.authentication.AgencyQuery
//
//     The OSID Java specification for org.osid.authentication.AgencyQuery.
//
// Copyright (C) 2002-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authentication;


/**
 *  <p>This is the query for searching agencies. Each method specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface AgencyQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Sets the agent <code> Id </code> for this query. 
     *
     *  @param  agentId an agent <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for negative match 
     *  @throws org.osid.NullArgumentException <code> agentId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAgentId(org.osid.id.Id agentId, boolean match);


    /**
     *  Clears the agent <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAgentIdTerms();


    /**
     *  Tests if an <code> AgentQuery </code> is available. 
     *
     *  @return <code> true </code> if an agent query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAgentQuery();


    /**
     *  Gets the query for an agent. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the agent query 
     *  @throws org.osid.UnimplementedException <code> supportsAgentQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAgentQuery() </code> is <code> true. </code> 
     */

    public org.osid.authentication.AgentQuery getAgentQuery();


    /**
     *  Matches agencies with any agent. 
     *
     *  @param  match <code> true </code> to match agencies with any agent. 
     *          <code> false </code> to match agencies with no agents 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAgent(boolean match);


    /**
     *  Clears the agent terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAgentTerms();


    /**
     *  Sets the agency <code> Id </code> for this query to match agencies 
     *  that have the specified agency as an ancestor. 
     *
     *  @param  agencyId an agency <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for negative match 
     *  @throws org.osid.NullArgumentException <code> agencyId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorAgencyId(org.osid.id.Id agencyId, boolean match);


    /**
     *  Clears the ancestor agency <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorAgencyIdTerms();


    /**
     *  Tests if an <code> AgencyQuery </code> is available. 
     *
     *  @return <code> true </code> if an agency query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorAgencyQuery();


    /**
     *  Gets the query for an agency. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the agency query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorAgencyQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorAgencyQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.authentication.AgentQuery getAncestorAgencyQuery();


    /**
     *  Matches agencies with any ancestor. 
     *
     *  @param  match <code> true </code> to match agencies with any ancestor, 
     *          <code> false </code> to match root agencies 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorAgency(boolean match);


    /**
     *  Clears the ancestor agency terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorAgencyTerms();


    /**
     *  Sets the agency <code> Id </code> for this query to match agencies 
     *  that have the specified agency as an descendant. 
     *
     *  @param  agencyId an agency <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for negative match 
     *  @throws org.osid.NullArgumentException <code> agencyId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantAgencyId(org.osid.id.Id agencyId, boolean match);


    /**
     *  Clears the descendant agency <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantAgencyIdTerms();


    /**
     *  Tests if an <code> AgencyQuery </code> is available. 
     *
     *  @return <code> true </code> if an agency query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantAgencyQuery();


    /**
     *  Gets the query for an agency. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the agency query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantAgencyQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantAgencyQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.authentication.AgentQuery getDescendantAgencyQuery();


    /**
     *  Matches agencies with any descendant. 
     *
     *  @param  match <code> true </code> to match agencies with any 
     *          descendant, <code> false </code> to match leaf agencies 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantAgency(boolean match);


    /**
     *  Clears the descendant agency terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantAgencyTerms();


    /**
     *  Gets the agency query record corresponding to the given <code> Agency 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @param  agencyRecordType an agency record type 
     *  @return the agency query record 
     *  @throws org.osid.NullArgumentException <code> agencyRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(agencyRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.records.AgencyQueryRecord getAgencyQueryRecord(org.osid.type.Type agencyRecordType)
        throws org.osid.OperationFailedException;
}
