//
// org.osid.authentication.AgencySearch
//
//     The OSID Java specification for org.osid.authentication.AgencySearch.
//
// Copyright (C) 2002-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authentication;


/**
 *  <p>The interface for governing agency searches. </p>
 */

public interface AgencySearch
    extends org.osid.OsidSearch {


    /**
     *  Execute this search among the given list of agencies. 
     *
     *  @param  agencyIds list of agencies 
     *  @throws org.osid.NullArgumentException <code> agencyIds </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void searchAmongAgencies(org.osid.id.IdList agencyIds);


    /**
     *  Specify an ordering to the search results. 
     *
     *  @param  agencySearchOrder agency search order 
     *  @throws org.osid.NullArgumentException <code> agencySearchOrder 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> agencySearchOrder </code> 
     *          is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderAgencyResults(org.osid.authentication.AgencySearchOrder agencySearchOrder);


    /**
     *  Gets the record corresponding to the given agency search record <code> 
     *  Type. </code> This method is used to retrieve an object implementing 
     *  the requested record. 
     *
     *  @param  agencySearchRecordType an agency search record type 
     *  @return the agency search record 
     *  @throws org.osid.NullArgumentException <code> agencySearchRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(agencySearchRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.records.AgencySearchRecord getAgencySearchRecord(org.osid.type.Type agencySearchRecordType)
        throws org.osid.OperationFailedException;
}
