//
// org.osid.authentication.AgentAdminSession
//
//     The OSID Java specification for org.osid.authentication.AgentAdminSession.
//
// Copyright (C) 2002-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authentication;


/**
 *  <p>This session creates, updates, and deletes <code> Agents. </code> The 
 *  data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create an 
 *  <code> Agent, </code> an <code> AgentForm </code> is requested using 
 *  <code> getAgentFormForCreate() </code> specifying the desired record 
 *  <code> Types </code> or none if no record <code> Types </code> are needed. 
 *  The returned <code> AgentForm </code> will indicate that it is to be used 
 *  with a create operation and can be used to examine metdata or validate 
 *  data prior to creation. Once the <code> AgentForm </code> is submiited to 
 *  a create operation, it cannot be reused with another create operation 
 *  unless the first operation was unsuccessful. Each <code> AgentForm </code> 
 *  corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> AgentForms </code> are requested to the <code> 
 *  Agent </code> <code> Id </code> that is to be updated using <code> 
 *  getAgentFormForUpdate(). </code> Similarly, the <code> AgentForm </code> 
 *  has metadata about the data that can be updated and it can perform 
 *  validation before submitting the update. The <code> AgentForm </code> can 
 *  only be used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Agents. </code> To unmap an <code> 
 *  Agent </code> from the current <code> Agency, </code> the <code> 
 *  AgentAgencyAssignmentSession </code> should be used. These delete 
 *  operations attempt to remove the <code> Agent </code> itself thus removing 
 *  it from all known <code> Agency </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface AgentAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Agency </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Agency Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAgencyId();


    /**
     *  Gets the <code> Agency </code> associated with this session. 
     *
     *  @return the <code> Agency </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.Agency getAgency()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> Agents. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating an <code> Agent </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer create operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Agent </code> creation is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAgents();


    /**
     *  Tests if this user can create a single <code> Agent </code> using the 
     *  desired record types. While <code> 
     *  AuthenticationManager.getAgentRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> Agent. </code> Providing 
     *  an empty array tests if an <code> Agent </code> can be created with no 
     *  records. 
     *
     *  @param  agentRecordTypes array of agent record types 
     *  @return <code> true </code> if <code> Agent </code> creation using the 
     *          specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> agentRecordTypes </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAgentWithRecordTypes(org.osid.type.Type[] agentRecordTypes);


    /**
     *  Gets the agent form for creating new agents. A new form should be 
     *  requested for each create transaction. 
     *
     *  @param  agentRecordTypes array of agent record types 
     *  @return the agent form 
     *  @throws org.osid.NullArgumentException <code> agentRecordTypes </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.AgentForm getAgentFormForCreate(org.osid.type.Type[] agentRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Agent. </code> 
     *
     *  @param  agentForm the form for this <code> Agent </code> 
     *  @return the new <code> Agent </code> 
     *  @throws org.osid.IllegalStateException <code> agentForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> agentForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> agentForm </code> did not 
     *          originate from <code> getAgentFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.Agent createAgent(org.osid.authentication.AgentForm agentForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Agents. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating an <code> Agent </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer update operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if agent modification is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateAgents();


    /**
     *  Tests if this user can update a specified agent. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known updating the agent will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer an update operation to an 
     *  unauthorized user for this agent. 
     *
     *  @param  agentId the <code> Id </code> of the <code> Agent </code> 
     *  @return <code> false </code> if agent modification is not authorized, 
     *          <code> true </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> agentId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If the <code> agentId </code> is not found, then it is 
     *          acceptable to return false to indicate the lack of an update 
     *          available. 
     */

    public boolean canUpdateAgent(org.osid.id.Id agentId);


    /**
     *  Gets the agent form for updating an existing agent. A new agent form 
     *  should be requested for each update transaction. 
     *
     *  @param  agentId the <code> Id </code> of the <code> Agent </code> 
     *  @return the agent form 
     *  @throws org.osid.NotFoundException <code> agentId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> agentId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.AgentForm getAgentFormForUpdate(org.osid.id.Id agentId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing agent. 
     *
     *  @param  agentForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> agentForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> agentId </code> or 
     *          <code> agentForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> agentForm </code> did not 
     *          originate from <code> getAgentFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateAgent(org.osid.authentication.AgentForm agentForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> Agents. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting an <code> Agent </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer delete operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Agent </code> deletion is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteAgents();


    /**
     *  Tests if this user can delete a specified <code> Agent. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known deleting the <code> Agent </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer a delete operation 
     *  to an unauthorized user for this agent. 
     *
     *  @param  agentId the <code> Id </code> of the <code> Agent </code> 
     *  @return <code> false </code> if <code> Agent </code> deletion is not 
     *          authorized, <code> true </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> agentId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If the <code> agentId </code> is not found, then it is 
     *          acceptable to return false to indicate the lack of a delete 
     *          available. 
     */

    public boolean canDeleteAgent(org.osid.id.Id agentId);


    /**
     *  Deletes the <code> Agent </code> identified by the given <code> Id 
     *  </code> removing it from all other <code> Agencies </code> to which 
     *  this <code> Agent </code> is associated. 
     *
     *  @param  agentId the <code> Id </code> of the <code> Agent </code> to 
     *          delete 
     *  @throws org.osid.NotFoundException an <code> Agent </code> was not 
     *          found identified by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> agentId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteAgent(org.osid.id.Id agentId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Agents. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Agent </code> aliasing is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageAgentAliases();


    /**
     *  Adds an <code> Id </code> to an <code> Agent </code> for the purpose 
     *  of creating compatibility. The primary <code> Id </code> of the <code> 
     *  Agent </code> is determined by the provider. The new <code> Id </code> 
     *  performs as an alias to the primary <code> Id. </code> If the alias is 
     *  a pointer to another engine, it is reassigned to the given engine 
     *  <code> Id. </code> 
     *
     *  @param  agentId the <code> Id </code> of an <code> Agent </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> agentId </code> not found 
     *  @throws org.osid.NullArgumentException <code> agentId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasAgent(org.osid.id.Id agentId, org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
