//
// org.osid.authentication.AgentQueryInspector
//
//     The OSID Java specification for org.osid.authentication.AgentQueryInspector.
//
// Copyright (C) 2002-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authentication;


/**
 *  <p>This is the query inspector for examining agent queries. </p>
 */

public interface AgentQueryInspector
    extends org.osid.OsidObjectQueryInspector {


    /**
     *  Gets the resource <code> Id </code> terms. 
     *
     *  @return the resource <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getResourceIdTerms();


    /**
     *  Gets the resource terms. 
     *
     *  @return the resource terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceQueryInspector[] getResourceTerms();


    /**
     *  Gets the agency <code> Id </code> terms. 
     *
     *  @return the agency <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getAgencyIdTerms();


    /**
     *  Gets the agency terms. 
     *
     *  @return the agency terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.AgencyQueryInspector[] getAgencyTerms();


    /**
     *  Gets the query inspector record corresponding to the given <code> 
     *  Agent </code> record <code> Type. </code> 
     *
     *  @param  agentRecordType an agent record type 
     *  @return the agent query inspector record 
     *  @throws org.osid.NullArgumentException <code> agentRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(agentRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.records.AgentQueryInspectorRecord getAgentQueryInspectorRecord(org.osid.type.Type agentRecordType)
        throws org.osid.OperationFailedException;
}
