//
// org.osid.authentication.AuthenticationProfile
//
//     The OSID Java specification for org.osid.authentication.AuthenticationProfile.
//
// Copyright (C) 2002-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authentication;


/**
 *  <p>The <code> AuthenticationProfile </code> describes the interoperability 
 *  among authentication services. </p>
 */

public interface AuthenticationProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if federation is visible. 
     *
     *  @return <code> true </code> if visible federation is supported <code> 
     *          , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests is authentication acquisition is supported. Authentication 
     *  acquisition is responsible for acquiring client side authentication 
     *  credentials. 
     *
     *  @return <code> true </code> if authentication acquisiiton is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuthenticationAcquisition();


    /**
     *  Tests if authentication validation is supported. Authentication 
     *  validation verifies given authentication credentials and maps to an 
     *  agent identity. 
     *
     *  @return <code> true </code> if authentication validation is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuthenticationValidation();


    /**
     *  Tests if an agent lookup service is supported. An agent lookup service 
     *  defines methods to access agents. 
     *
     *  @return <code> true </code> if agent lookup is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAgentLookup();


    /**
     *  Tests if an agent query service is supported. 
     *
     *  @return <code> true </code> if agent query is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAgentQuery();


    /**
     *  Tests if an agent search service is supported. 
     *
     *  @return <code> true </code> if agent search is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAgentSearch();


    /**
     *  Tests if an agent administrative service is supported. 
     *
     *  @return <code> true </code> if agent admin is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAgentAdmin();


    /**
     *  Tests if agent notification is supported. Messages may be sent when 
     *  agents are created, modified, or deleted. 
     *
     *  @return <code> true </code> if agent notification is supported <code> 
     *          , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAgentNotification();


    /**
     *  Tests if retrieving mappings of agents and agencies is supported. 
     *
     *  @return <code> true </code> if agent agency mapping retrieval is 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAgentAgency();


    /**
     *  Tests if managing mappings of agents and agencies is supported. 
     *
     *  @return <code> true </code> if agent agency assignment is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAgentAgencyAssignment();


    /**
     *  Tests if agent smart agency is available. 
     *
     *  @return <code> true </code> if agent smart agency is supported <code> 
     *          , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAgentSmartAgency();


    /**
     *  Tests if an agency lookup service is supported. An agency lookup 
     *  service defines methods to access agencies. 
     *
     *  @return <code> true </code> if agency lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAgencyLookup();


    /**
     *  Tests if an agency query service is supported. 
     *
     *  @return <code> true </code> if agency query is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAgencyQuery();


    /**
     *  Tests if an agency search service is supported. 
     *
     *  @return <code> true </code> if agency search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAgencySearch();


    /**
     *  Tests if an agency administrative service is supported. 
     *
     *  @return <code> true </code> if agency admin is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAgencyAdmin();


    /**
     *  Tests if agency notification is supported. Messages may be sent when 
     *  agencies are created, modified, or deleted. 
     *
     *  @return <code> true </code> if agency notification is supported <code> 
     *          , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAgencyNotification();


    /**
     *  Tests if an agency hierarchy traversal is supported. 
     *
     *  @return <code> true </code> if an agency hierarchy traversal is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAgencyHierarchy();


    /**
     *  Tests if an agency hierarchy design is supported. 
     *
     *  @return <code> true </code> if an agency hierarchy design is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAgencyHierarchyDesign();


    /**
     *  Tests if an authentication key service is available. 
     *
     *  @return <code> true </code> if an authentication key service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuthenticationKeys();


    /**
     *  Tests if an authentication process service is available. 
     *
     *  @return <code> true </code> if an authentication process service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuthenticationProcess();


    /**
     *  Gets the supported <code> Agent </code> record types. 
     *
     *  @return a list containing the supported <code> Agent </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAgentRecordTypes();


    /**
     *  Tests if the given <code> Agent </code> record type is supported. 
     *
     *  @param  agentRecordType a <code> Type </code> indicating an <code> 
     *          Agent </code> record type 
     *  @return <code> true </code> if the given record Type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> agentRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAgentRecordType(org.osid.type.Type agentRecordType);


    /**
     *  Gets the supported <code> Agent </code> search record types. 
     *
     *  @return a list containing the supported <code> Agent </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAgentSearchRecordTypes();


    /**
     *  Tests if the given <code> Agent </code> search record type is 
     *  supported. 
     *
     *  @param  agentSearchRecordType a <code> Type </code> indicating an 
     *          <code> Agent </code> search record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> agentSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAgentSearchRecordType(org.osid.type.Type agentSearchRecordType);


    /**
     *  Gets the supported <code> Agency </code> record types. 
     *
     *  @return a list containing the supported <code> Agency </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAgencyRecordTypes();


    /**
     *  Tests if the given <code> Agency </code> record type is supported. 
     *
     *  @param  agencyRecordType a <code> Type </code> indicating an <code> 
     *          Agency </code> record type 
     *  @return <code> true </code> if the given record Type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> agencyRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAgencyRecordType(org.osid.type.Type agencyRecordType);


    /**
     *  Gets the supported <code> Agency </code> search record types. 
     *
     *  @return a list containing the supported <code> Agency </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAgencySearchRecordTypes();


    /**
     *  Tests if the given <code> Agency </code> search record type is 
     *  supported. 
     *
     *  @param  agencySearchRecordType a <code> Type </code> indicating an 
     *          <code> Agency </code> search record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> agencySearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAgencySearchRecordType(org.osid.type.Type agencySearchRecordType);
}
