//
// org.osid.authentication.batch.AuthenticationBatchManager
//
//     The OSID Java specification for org.osid.authentication.batch.AuthenticationBatchManager.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authentication.batch;


/**
 *  <p>The authentication batch manager provides access to authentication 
 *  batch sessions and provides interoperability tests for various aspects of 
 *  this service. The sessions included in this manager are: </p> 
 *  
 *  <p> <code> </code> 
 *  <ul>
 *      <li> <code> AgentBatchAdminSession: </code> a session to create, 
 *      modify and delete <code> Agents </code> in bulk </li> 
 *      <li> <code> AgencyBatchAdminSession: </code> a session to create, 
 *      modify and delete <code> Agencies </code> in bulk </li> 
 *  </ul>
 *  </p>
 */

public interface AuthenticationBatchManager
    extends org.osid.OsidManager,
            org.osid.authentication.batch.AuthenticationBatchProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the bulk agent 
     *  administration service. 
     *
     *  @return an <code> AgentBatchAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAgentBatchAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAgentBatchAdmin() </code> is <code> true. </code> 
     */

    public org.osid.authentication.batch.AgentBatchAdminSession getAgentBatchAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the bulk agent 
     *  administration service for the given agency. 
     *
     *  @param  agencyId the <code> Id </code> of the <code> Agency </code> 
     *  @return an <code> AgentBatchAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Agency </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> agencyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAgentBatchAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAgentBatchAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.authentication.batch.AgentBatchAdminSession getAgentBatchAdminSessionForAgency(org.osid.id.Id agencyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the bulk agency 
     *  administration service. 
     *
     *  @return an <code> AgencyBatchAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAgencyBatchAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAgencyBatchAdmin() </code> is <code> true. </code> 
     */

    public org.osid.authentication.batch.AgencyBatchAdminSession getAgencyBatchAdminSession()
        throws org.osid.OperationFailedException;
}
