//
// org.osid.authentication.keys.KeyAdminSession
//
//     The OSID Java specification for org.osid.authentication.keys.KeyAdminSession.
//
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authentication.keys;


/**
 *  <p>This session provides methods to creating, updating and deleting <code> 
 *  Key </code> objects. Keys are managed separately from the <code> Agent. 
 *  </code> Each <code> Agent </code> maps to a zero or one <code> Key </code> 
 *  and every <code> Key </code> maps to one <code> Agent. </code> </p>
 */

public interface KeyAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Agency </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Agency Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAgencyId();


    /**
     *  Gets the <code> Agency </code> associated with this session. 
     *
     *  @return the <code> Agency </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.Agency getAgency()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> Keys. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> Key </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer create operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Key </code> creation is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateKeys();


    /**
     *  Tests if this user can create a single <code> Key </code> using the 
     *  desired record interface types. While <code> 
     *  AuthenticationKeysManager.getKeyRecordTypes() </code> can be used to 
     *  examine which record interfaces are supported, this method tests which 
     *  record(s) are required for creating a specific <code> Key. </code> 
     *  Providing an empty array tests if a <code> Key </code> can be created 
     *  with no records. 
     *
     *  @param  keyRecordTypes array of key record types 
     *  @return <code> true </code> if <code> Key </code> creation using the 
     *          specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> keyRecordTypes </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateKeyWithRecordTypes(org.osid.type.Type[] keyRecordTypes);


    /**
     *  Gets the key form for creating and updating new keys. A new form 
     *  should be requested for each create transaction. 
     *
     *  @param  agentId the <code> Id </code> of the <code> Agent </code> 
     *  @param  keyRecordTypes array of key record types 
     *  @return the key form 
     *  @throws org.osid.NotFoundException <code> agentId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> agentId </code> or 
     *          <code> keyRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.keys.KeyForm getKeyFormForCreate(org.osid.id.Id agentId, 
                                                                    org.osid.type.Type[] keyRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Key. </code> 
     *
     *  @param  keyForm the form for this <code> Key </code> 
     *  @return <code> keyForm </code> already used in a create transaction 
     *  @throws org.osid.IllegalStateException agent already has a key 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> keyForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> keyForm </code> did not 
     *          originate from <code> getKeyFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.keys.Key createKey(org.osid.authentication.keys.KeyForm keyForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Keys. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a Key will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer update operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if key modification is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateKeys();


    /**
     *  Gets the key form for updating an existing key. 
     *
     *  @param  keyId the <code> Id </code> of the <code> Key </code> 
     *  @return the key form 
     *  @throws org.osid.NotFoundException <code> keyId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> keyId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.keys.KeyForm getKeyFormForUpdate(org.osid.id.Id keyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates a key for an agent. 
     *
     *  @param  keyForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> keyForm </code> already 
     *          used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> keyForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> keyForm </code> did not 
     *          originate from <code> getKeyFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateKey(org.osid.authentication.keys.KeyForm keyForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> Keys. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> Key </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer delete operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Key </code> deletion is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteKeys();


    /**
     *  Deletes a <code> Key. </code> 
     *
     *  @param  keyId the <code> Id </code> of the <code> Key </code> 
     *  @throws org.osid.NotFoundException a <code> Key </code> was not found 
     *          identified by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> keyId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteKey(org.osid.id.Id keyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
