//
// org.osid.authentication.keys.KeyAgencyAssignmentSession
//
//     The OSID Java specification for org.osid.authentication.keys.KeyAgencyAssignmentSession.
//
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authentication.keys;


/**
 *  <p>This session provides methods to re-assign <code> Keys </code> to 
 *  <code> Agencies </code> An <code> Key </code> may map to multiple <code> 
 *  Agency </code> objects and removing the last reference to an <code> Key 
 *  </code> is the equivalent of deleting it. Each <code> Agency </code> may 
 *  have its own authorizations governing who is allowed to operate on it. 
 *  </p> 
 *  
 *  <p> Moving or adding a reference of an <code> Ageny </code> to another 
 *  <code> Agency </code> is not a copy operation (eg: does not change its 
 *  <code> Id </code> ). </p>
 */

public interface KeyAgencyAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter key/agency mappings. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignKeys();


    /**
     *  Tests if this user can alter key/agency mappings. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @param  agencyId the <code> Id </code> of the <code> Agency </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> agencyId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignKeysToAgency(org.osid.id.Id agencyId);


    /**
     *  Gets a list of agencies including and under the given agency node in 
     *  which any key can be assigned. 
     *
     *  @param  agencyId the <code> Id </code> of the <code> Agency </code> 
     *  @return list of assignable agency <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> agencyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableAgencyIds(org.osid.id.Id agencyId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of agencies including and under the given agency node in 
     *  which a specific key can be assigned. 
     *
     *  @param  agencyId the <code> Id </code> of the <code> Agency </code> 
     *  @param  keyId the <code> Id </code> of the <code> Key </code> 
     *  @return list of assignable bin <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> agencyId </code> or 
     *          <code> keyId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableAgencyIdsForKey(org.osid.id.Id agencyId, 
                                                           org.osid.id.Id keyId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> Key </code> to an <code> Agency. </code> 
     *
     *  @param  keyId the <code> Id </code> of the <code> Key </code> 
     *  @param  agencyId the <code> Id </code> of the <code> Agency </code> 
     *  @throws org.osid.AlreadyExistsException <code> keyId </code> is 
     *          already assigned to <code> agencyId </code> 
     *  @throws org.osid.NotFoundException <code> keyId </code> or <code> 
     *          agencyId </code> not found 
     *  @throws org.osid.NullArgumentException <code> keyId </code> or <code> 
     *          agencyId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignKeyToAgency(org.osid.id.Id keyId, 
                                  org.osid.id.Id agencyId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes an <code> Key </code> from an <code> Agency. </code> 
     *
     *  @param  keyId the <code> Id </code> of the <code> Key </code> 
     *  @param  agencyId the <code> Id </code> of the <code> Agency </code> 
     *  @throws org.osid.NotFoundException <code> keyId </code> or <code> 
     *          agencyId </code> not found or <code> keyId </code> not 
     *          assigned to <code> agencyId </code> 
     *  @throws org.osid.NullArgumentException <code> keyId </code> or <code> 
     *          agencyId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignKeyFromAgency(org.osid.id.Id keyId, 
                                      org.osid.id.Id agencyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Moves a <code> Key </code> from one <code> Agency </code> to another. 
     *  Mappings to other <code> Agencies </code> are unaffected. 
     *
     *  @param  keyId the <code> Id </code> of the <code> Key </code> 
     *  @param  fromAgencyId the <code> Id </code> of the current <code> 
     *          Agency </code> 
     *  @param  toAgencyId the <code> Id </code> of the destination <code> 
     *          Agency </code> 
     *  @throws org.osid.NotFoundException <code> keyId, fromAgencyId, </code> 
     *          or <code> toAgencyId </code> not found or <code> keyId </code> 
     *          not mapped to <code> fromAgencyId </code> 
     *  @throws org.osid.NullArgumentException <code> keyId, fromAgencyId, 
     *          </code> or <code> toAgencyId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void reassignKeyToAgency(org.osid.id.Id keyId, 
                                    org.osid.id.Id fromAgencyId, 
                                    org.osid.id.Id toAgencyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
