//
// org.osid.authentication.keys.KeySearch
//
//     The OSID Java specification for org.osid.authentication.keys.KeySearch.
//
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authentication.keys;


/**
 *  <p><code> KeySearch </code> defines options for governing key searches. 
 *  </p>
 */

public interface KeySearch
    extends org.osid.OsidSearch {


    /**
     *  Execute this search among the given list of keys. 
     *
     *  @param  agentIds list of agents 
     *  @throws org.osid.NullArgumentException <code> agentIds </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void searchAmongKeys(org.osid.id.IdList agentIds);


    /**
     *  Specify an ordering to the search results. 
     *
     *  @param  keySearchOrder key search order 
     *  @throws org.osid.NullArgumentException <code> keySearchOrder </code> 
     *          is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> keySearchOrder </code> is 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderKeyResults(org.osid.authentication.keys.KeySearchOrder keySearchOrder);


    /**
     *  Gets the record corresponding to the given key search record <code> 
     *  Type. </code> This method is used to retrieve an object implementing 
     *  the requested record. 
     *
     *  @param  keySearchRecordType a key search record type 
     *  @return the key search record 
     *  @throws org.osid.NullArgumentException <code> keySearchRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(keySearchRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.keys.records.KeySearchRecord getKeySearchRecord(org.osid.type.Type keySearchRecordType)
        throws org.osid.OperationFailedException;
}
