//
// org.osid.authentication.keys.KeySearchSession
//
//     The OSID Java specification for org.osid.authentication.keys.KeySearchSession.
//
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authentication.keys;


/**
 *  <p>This session provides methods for searching <code> Keys. </code> The 
 *  search query is constructed using the <code> KeyQuery. </code> The key 
 *  record <code> Type </code> also specifies the record for the key query. 
 *  </p> 
 *  
 *  <p> <code> getKeysByQuery() </code> is the basic search method and returns 
 *  a list of <code> Keys. </code> A more advanced search may be performed 
 *  with <code> getKeysBySearch(). </code> It accepts an <code> KeySearch 
 *  </code> in addition to the query for the purpose of specifying additional 
 *  options affecting the entire search, such as ordering. <code> 
 *  getKeysBySearch() </code> returns a <code> KeySearchResult </code> that 
 *  can be used to access the resulting <code> KeyList </code> or be used to 
 *  perform a search within the result set through <code> KeySearch. </code> 
 *  </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated agency view: searches include keys in agencies of which 
 *      this agency is a ancestor in the agency hierarchy </li> 
 *      <li> isolated agency view: searches are restricted to agents in this 
 *      agency </li> 
 *  </ul>
 *  
 *  
 *  <p> Keys may have a query record indicated by their respective record 
 *  types. The query record is accessed via the KeyQuery. </p>
 */

public interface KeySearchSession
    extends org.osid.authentication.keys.KeyQuerySession {


    /**
     *  Gets a key query. 
     *
     *  @return the key search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.keys.KeySearch getKeySearch();


    /**
     *  Gets a key search order. The <code> KeySearchOrder </code> is supplied 
     *  to a <code> KeySearch </code> to specify the ordering of results. 
     *
     *  @return the key search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.keys.KeySearchOrder getKeySearchOrder();


    /**
     *  Gets a list of <code> Keys </code> matching the given search. 
     *
     *  @param  keyQuery the key query 
     *  @param  keySearch the key search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> keyQuery </code> or 
     *          <code> keySearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> keySearch </code> or a 
     *          <code> keyQuery </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.keys.KeySearchResults getKeysBySearch(org.osid.authentication.keys.KeyQuery keyQuery, 
                                                                         org.osid.authentication.keys.KeySearch keySearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a key query from an inspector. The inspector is available from an 
     *  <code> KeySearchResults. </code> 
     *
     *  @param  keyQueryInspector a query inspector 
     *  @return the key query 
     *  @throws org.osid.NullArgumentException <code> keyQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> keyQueryInspector </code> 
     *          is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.keys.KeyQuery getKeyQueryFromInspector(org.osid.authentication.keys.KeyQueryInspector keyQueryInspector);
}
