//
// org.osid.authentication.process.Authentication
//
//     The OSID Java specification for org.osid.authentication.process.Authentication.
//
// Copyright (C) 2002-2004, 2007-2009 Massachusetts Institute of Technology. 
// All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authentication.process;


/**
 *  <p><code> Authentication </code> represents an authentication credential 
 *  which contains set of <code> bytes </code> and a format Type. Once an 
 *  <code> Authentication </code> is created from the <code> 
 *  AuthenticationValidationSession, </code> the credential data can be 
 *  extracted and sent to the remote peer for validation. The remote peer gets 
 *  another <code> Authentication </code> object as a result of validating the 
 *  serialized credential data. </p> 
 *  
 *  <p> An <code> Authentication </code> may or may not be valid. <code> 
 *  isValid() </code> should be checked before acting upon the <code> Agent 
 *  </code> identity to which the credential is mapped. </p>
 */

public interface Authentication
    extends org.osid.OsidObject {


    /**
     *  Gets the <code> Id </code> of the <code> Agent </code> identified in 
     *  this authentication credential. 
     *
     *  @return the <code> Agent Id </code> 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  The Agent should be determined at the time this credential is 
     *          created. 
     */

    public org.osid.id.Id getAgentId();


    /**
     *  Gets the <code> Agent </code> identified in this authentication 
     *  credential. 
     *
     *  @return the <code> Agent </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.Agent getAgent()
        throws org.osid.OperationFailedException;


    /**
     *  Tests whether or not the credential represented by this <code> 
     *  Authentication </code> is currently valid. A credential may be invalid 
     *  because it has been destroyed, expired, or is somehow no longer able 
     *  to be used. 
     *
     *  @return <code> true </code> if this authentication credential is 
     *          valid, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  Any problem in determining the validity of this credential 
     *          should result in <code> false. </code> 
     */

    public boolean isValid();


    /**
     *  Tests if this authentication has an expiration. 
     *
     *  @return <code> true </code> if this authentication has an expiration, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasExpiration();


    /**
     *  Gets the expiration date associated with this authentication 
     *  credential. Consumers should check for the existence of a an 
     *  expiration mechanism via <code> hasExpiration(). </code> 
     *
     *  @return the expiration date of this authentication credential 
     *  @throws org.osid.IllegalStateException <code> hasExpiration() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.util.Date getExpiration();


    /**
     *  Tests if this authentication has a credential for export. 
     *
     *  @return <code> true </code> if this authentication has a credential, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasCredential();


    /**
     *  Gets the credential represented by the given <code> Type </code> for 
     *  transport to a remote service. 
     *
     *  @param  credentialType the credential format <code> Type </code> 
     *  @return the credential 
     *  @throws org.osid.IllegalStateException <code> hasCredential() </code> 
     *          is <code> false </code> 
     *  @throws org.osid.NullArgumentException <code> credentialType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.UnsupportedException the given <code> credentialType 
     *          </code> is not supported 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  A provider may support multiple credential formats for a 
     *          variety of applications. 
     */

    public java.lang.Object getCredential(org.osid.type.Type credentialType);


    /**
     *  Gets the authentication record corresponding to the given 
     *  authentication record <code> Type. </code> This method is used to 
     *  retrieve an object implementing the requested record. The <code> 
     *  authenticationRecordType </code> may be the <code> Type </code> 
     *  returned in <code> getRecordTypes() </code> or any of its parents in a 
     *  <code> Type </code> hierarchy where <code> 
     *  hasRecordType(authenticationRecordType) </code> is <code> true </code> 
     *  . 
     *
     *  @param  authenticationRecordType the type of authentication record to 
     *          retrieve 
     *  @return the authentication record 
     *  @throws org.osid.NullArgumentException <code> authenticationRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(authenticatonRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.process.records.AuthenticationRecord getAuthenticationRecord(org.osid.type.Type authenticationRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
