//
// org.osid.authentication.process.AuthenticationValidationSession
//
//     The OSID Java specification for org.osid.authentication.process.AuthenticationValidationSession.
//
// Copyright (C) 2002-2004, 2007-2009 Massachusetts Institute of Technology. 
// All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authentication.process;


/**
 *  <p>This session is the remote end of a transport link from the acquisition 
 *  session and validates authentication credentials sent to it. The basic 
 *  method, <code> authenticate() </code> accepts a credential, validates it 
 *  and returns an <code> Authentication </code> containing the identity of 
 *  the authenticated user. </p> 
 *  
 *  <p> This OSID does not define any root interface for credentials and 
 *  challenge data. The object representing these are completely defined 
 *  within their <code> Type, </code> providing flexibility in adapting to a 
 *  variety of application environments. </p>
 */

public interface AuthenticationValidationSession
    extends org.osid.OsidSession {


    /**
     *  Gets an interface for authentication input. 
     *
     *  @return authentication input 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.authentication.process.AuthenticationInput getAuthenticationInput();


    /**
     *  Validates and returns the authentication credential from the given 
     *  data. 
     *
     *  @param  input the authentication input to be validated 
     *  @return the resulting authentication 
     *  @throws org.osid.NullArgumentException <code> input </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> input </code> is not of 
     *          this service 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.authentication.process.Authentication authenticate(org.osid.authentication.process.AuthenticationInput input)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets data that can be used for a challenge to the peer attempting 
     *  authentication. 
     *
     *  @param  input authentication input 
     *  @return the acquired challenge data 
     *  @throws org.osid.NullArgumentException <code> input </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnimplementedException challenge response not 
     *          available 
     *  @throws org.osid.UnsupportedException <code> input </code> is not of 
     *          this service 
     *  @compliance optional This method must be implemented if <code> 
     *              AuthenticationProcessManager.supportsChallenge() </code> 
     *              is <code> true. </code> 
     */

    public org.osid.authentication.process.Challenge getChallengeData(org.osid.authentication.process.AuthenticationInput input)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
