//
// org.osid.authorization.AuthorizationAdminSession
//
//     The OSID Java specification for org.osid.authorization.AuthorizationAdminSession.
//
// Copyright (C) 2002-2004, 2007-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authorization;


/**
 *  <p>This session creates, updates, and deletes <code> Authorizations. 
 *  </code> The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create an 
 *  <code> Authorization, </code> an <code> AuthorizationForm </code> is 
 *  requested using <code> getAuthorizationFormForCreate() </code> specifying 
 *  the desired relationship peers and record <code> Types </code> or none if 
 *  no record <code> Types </code> are needed. The returned <code> 
 *  AuthorizationForm </code> will indicate that it is to be used with a 
 *  create operation and can be used to examine metdata or validate data prior 
 *  to creation. Once the <code> AuthorizationForm </code> is submiited to a 
 *  create operation, it cannot be reused with another create operation unless 
 *  the first operation was unsuccessful. Each <code> AuthorizationForm 
 *  </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> AuthorizationForms </code> are requested to the 
 *  <code> Authorization </code> <code> Id </code> that is to be updated using 
 *  <code> getAuthorizationFormForUpdate(). </code> Similarly, the <code> 
 *  AuthorizationForm </code> has metadata about the data that can be updated 
 *  and it can perform validation before submitting the update. The <code> 
 *  AuthorizationForm </code> can only be used once for a successful update 
 *  and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Authorizations. </code> To unmap 
 *  an <code> Authorization </code> from the current <code> Vault, </code> the 
 *  <code> AuthorizationVaultAssignmentSession </code> should be used. These 
 *  delete operations attempt to remove the <code> Authorization </code> 
 *  itself thus removing it from all known <code> Vault </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface AuthorizationAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Vault </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Vault Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getVaultId();


    /**
     *  Gets the <code> Vault </code> associated with this session. 
     *
     *  @return the <code> Vault </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.Vault getVault()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> Authorizations. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer create operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Authorization </code> creation 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAuthorizations();


    /**
     *  Tests if this user can create a single <code> Authorization </code> 
     *  using the desired record types. While <code> 
     *  AuthorizationManager.getAuthorizationRecordTypes() </code> can be used 
     *  to examine which records are supported, this method tests which 
     *  record(s) are required for creating a specific <code> Authorization. 
     *  </code> Providing an empty array tests if an <code> Authorization 
     *  </code> can be created with no records. 
     *
     *  @param  authorizationRecordTypes array of authorization record types 
     *  @return <code> true </code> if <code> Authorization </code> creation 
     *          using the specified <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> authorizationRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAuthorizationWithRecordTypes(org.osid.type.Type[] authorizationRecordTypes);


    /**
     *  Gets the authorization form for creating new authorizations. A new 
     *  form should be requested for each create transaction. 
     *
     *  @param  agentId the agent <code> Id </code> 
     *  @param  functionId the function <code> Id </code> 
     *  @param  qualifierId the qualifier <code> Id </code> 
     *  @param  authorizationRecordTypes array of authorization record types 
     *  @return the authorization form 
     *  @throws org.osid.NotFoundException <code> agentId, functionId </code> 
     *          or <code> qualifierId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> agentId, functionId, 
     *          qualifierId </code> or <code> authorizationRecordTypes </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form with 
     *          requested record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.AuthorizationForm getAuthorizationFormForCreateForAgent(org.osid.id.Id agentId, 
                                                                                          org.osid.id.Id functionId, 
                                                                                          org.osid.id.Id qualifierId, 
                                                                                          org.osid.type.Type[] authorizationRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the authorization form for creating new authorizations. A new 
     *  form should be requested for each create transaction. 
     *
     *  @param  resourceId the resource <code> Id </code> 
     *  @param  functionId the function <code> Id </code> 
     *  @param  qualifierId the qualifier <code> Id </code> 
     *  @param  authorizationRecordTypes array of authorization record types 
     *  @return the authorization form 
     *  @throws org.osid.NotFoundException <code> resourceId, functionId 
     *          </code> or <code> qualifierId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> resourceId, functionId, 
     *          qualifierId, </code> or <code> authorizationRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form with 
     *          requested record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.AuthorizationForm getAuthorizationFormForCreateForResource(org.osid.id.Id resourceId, 
                                                                                             org.osid.id.Id functionId, 
                                                                                             org.osid.id.Id qualifierId, 
                                                                                             org.osid.type.Type[] authorizationRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the authorization form for creating new authorizations. A new 
     *  form should be requested for each create transaction. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  trustId an <code> Id </code> for a circle of trust 
     *  @param  functionId a function <code> Id </code> 
     *  @param  qualifierId the qualifier <code> Id </code> 
     *  @param  authorizationRecordTypes array of authorization record types 
     *  @return the authorization form 
     *  @throws org.osid.NotFoundException <code> resourceId, trustId, 
     *          functionId </code> , or <code> qualifierid </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> resourceId, trustId 
     *          </code> , <code> resourceId, qualifierId </code> or <code> 
     *          authorizationRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form with 
     *          requested record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.AuthorizationForm getAuthorizationFormForCreateForResourceAndTrust(org.osid.id.Id resourceId, 
                                                                                                     org.osid.id.Id trustId, 
                                                                                                     org.osid.id.Id functionId, 
                                                                                                     org.osid.id.Id qualifierId, 
                                                                                                     org.osid.type.Type[] authorizationRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new explicit <code> Authorization. </code> 
     *
     *  @param  authorizationForm the authorization form 
     *  @return <code> t </code> he new <code> Authorization </code> 
     *  @throws org.osid.IllegalStateException <code> authorizationForm 
     *          </code> already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> authorizationForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> authorizationForm </code> 
     *          did not originate from this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.Authorization createAuthorization(org.osid.authorization.AuthorizationForm authorizationForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Authorizations. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating an <code> Authorization </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer update operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if authorization modification is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateAuthorizations();


    /**
     *  Gets the authorization form for updating an existing authorization. A 
     *  new authorization form should be requested for each update 
     *  transaction. 
     *
     *  @param  authorizationId the <code> Id </code> of the <code> 
     *          Authorization </code> 
     *  @return the authorization form 
     *  @throws org.osid.NotFoundException <code> authorizationId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> authorizationId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.AuthorizationForm getAuthorizationFormForUpdate(org.osid.id.Id authorizationId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing authorization 
     *
     *  @param  authorizationForm the authorization <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> authorizationForm 
     *          </code> already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> authorizationForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> authorizationForm </code> 
     *          did not originate from <code> getAuthorizationFormForUpdate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateAuthorization(org.osid.authorization.AuthorizationForm authorizationForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> Authorizations. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting an <code> Authorization </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer delete operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Authorization </code> deletion 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteAuthorizations();


    /**
     *  Deletes the <code> Authorization </code> identified by the given 
     *  <code> Id. </code> 
     *
     *  @param  authorizationId the <code> Id </code> of the <code> 
     *          Authorization </code> to delete 
     *  @throws org.osid.NotFoundException an <code> Authorization </code> was 
     *          not found identified by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> authorizationId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteAuthorization(org.osid.id.Id authorizationId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Authorizations. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Authorization </code> aliasing 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageAuthorizationAliases();


    /**
     *  Adds an <code> Id </code> to an <code> Authorization </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Authorization </code> is determined by the provider. The 
     *  new <code> Id </code> performs as an alias to the primary <code> Id. 
     *  </code> If the alias is a pointer to another authorization. it is 
     *  reassigned to the given authorization <code> Id. </code> 
     *
     *  @param  authorizationId the <code> Id </code> of an <code> 
     *          Authorization </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> authorizationId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> authorizationId </code> 
     *          or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasAuthorization(org.osid.id.Id authorizationId, 
                                   org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
