//
// org.osid.authorization.AuthorizationProfile
//
//     The OSID Java specification for org.osid.authorization.AuthorizationProfile.
//
// Copyright (C) 2002-2004, 2007-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authorization;


/**
 *  <p>The <code> AuthorizationProfile </code> describes the interoperability 
 *  among authorization services. </p>
 */

public interface AuthorizationProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if federation is visible. 
     *
     *  @return <code> true </code> if visible federation is supported <code> 
     *          , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests for the availability of an authorization service which is the 
     *  basic service for checking authorizations. 
     *
     *  @return <code> true </code> if authorization is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuthorization();


    /**
     *  Tests if an authorization lookup service is supported. An 
     *  authorization lookup service defines methods to access authorizations. 
     *
     *  @return true if authorization lookup is supported, false otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuthorizationLookup();


    /**
     *  Tests if an authorization query service is supported. 
     *
     *  @return <code> true </code> if authorization query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuthorizationQuery();


    /**
     *  Tests if an authorization search service is supported. 
     *
     *  @return <code> true </code> if authorization search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuthorizationSearch();


    /**
     *  Tests if an authorization administrative service is supported. 
     *
     *  @return <code> true </code> if authorization admin is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuthorizationAdmin();


    /**
     *  Tests if authorization notification is supported. Messages may be sent 
     *  when authorizations are created, modified, or deleted. 
     *
     *  @return <code> true </code> if authorization notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuthorizationNotification();


    /**
     *  Tests if an authorization to vault lookup session is available. 
     *
     *  @return <code> true </code> if authorization vault lookup session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuthorizationVault();


    /**
     *  Tests if an authorization to vault assignment session is available. 
     *
     *  @return <code> true </code> if authorization vault assignment is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuthorizationVaultAssignment();


    /**
     *  Tests if an authorization smart vaulting session is available. 
     *
     *  @return <code> true </code> if authorization smart vaulting is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuthorizationSmartVault();


    /**
     *  Tests if a function lookup service is supported. A function lookup 
     *  service defines methods to access authorization functions. 
     *
     *  @return <code> true </code> if function lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFunctionLookup();


    /**
     *  Tests if a function query service is supported. 
     *
     *  @return <code> true </code> if function query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFunctionQuery();


    /**
     *  Tests if a function search service is supported. 
     *
     *  @return <code> true </code> if function search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFunctionSearch();


    /**
     *  Tests if a function administrative service is supported. 
     *
     *  @return <code> true </code> if function admin is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFunctionAdmin();


    /**
     *  Tests if function notification is supported. Messages may be sent when 
     *  functions are created, modified, or deleted. 
     *
     *  @return <code> true </code> if function notification is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFunctionNotification();


    /**
     *  Tests if a function to vault lookup session is available. 
     *
     *  @return <code> true </code> if function vault lookup session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFunctionVault();


    /**
     *  Tests if a function to vault assignment session is available. 
     *
     *  @return <code> true </code> if function vault assignment is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFunctionVaultAssignment();


    /**
     *  Tests if a function smart vaulting session is available. 
     *
     *  @return <code> true </code> if function smart vaulting is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFunctionSmartVault();


    /**
     *  Tests if a qualifier lookup service is supported. A function lookup 
     *  service defines methods to access authorization qualifiers. 
     *
     *  @return <code> true </code> if qualifier lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQualifierLookup();


    /**
     *  Tests if a qualifier query service is supported. 
     *
     *  @return <code> true </code> if qualifier query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQualifierQuery();


    /**
     *  Tests if a qualifier search service is supported. 
     *
     *  @return <code> true </code> if qualifier search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQualifierSearch();


    /**
     *  Tests if a qualifier administrative service is supported. 
     *
     *  @return <code> true </code> if qualifier admin is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQualifierAdmin();


    /**
     *  Tests if qualifier notification is supported. Messages may be sent 
     *  when qualifiers are created, modified, or deleted. 
     *
     *  @return <code> true </code> if qualifier notification is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQualifierNotification();


    /**
     *  Tests if a qualifier hierarchy traversal is supported. 
     *
     *  @return <code> true </code> if a qualifier hierarchy traversal is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQualifierHierarchy();


    /**
     *  Tests if qualifier hierarchy design is supported. 
     *
     *  @return <code> true </code> if a qualifier hierarchy design is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQualifierHierarchyDesign();


    /**
     *  Tests if a qualifier to vault lookup session is available. 
     *
     *  @return <code> true </code> if qualifier vault lookup session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQualifierVault();


    /**
     *  Tests if a qualifier to vault assignment session is available. 
     *
     *  @return <code> true </code> if qualifier vault assignment is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQualifierVaultAssignment();


    /**
     *  Tests if a qualifier smart vaulting session is available. 
     *
     *  @return <code> true </code> if qualifier smart vault session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQualifierSmartVault();


    /**
     *  Tests if a vault lookup service is supported. A vault lookup service 
     *  defines methods to access authorization vaults. 
     *
     *  @return <code> true </code> if function lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVaultLookup();


    /**
     *  Tests if a vault query service is supported. 
     *
     *  @return <code> true </code> if vault query is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVaultQuery();


    /**
     *  Tests if a vault search service is supported. 
     *
     *  @return <code> true </code> if vault search is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVaultSearch();


    /**
     *  Tests if a vault administrative service is supported. 
     *
     *  @return <code> true </code> if vault admin is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVaultAdmin();


    /**
     *  Tests if vault notification is supported. Messages may be sent when 
     *  vaults are created, modified, or deleted. 
     *
     *  @return <code> true </code> if vault notification is supported <code> 
     *          , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVaultNotification();


    /**
     *  Tests if a vault hierarchy traversal is supported. 
     *
     *  @return <code> true </code> if a vault hierarchy traversal is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVaultHierarchy();


    /**
     *  Tests if vault hierarchy design is supported. 
     *
     *  @return <code> true </code> if a function hierarchy design is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVaultHierarchyDesign();


    /**
     *  Tests if an authorization batch service is supported. 
     *
     *  @return <code> true </code> if an authorization batch service design 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuthorizatinBatch();


    /**
     *  Tests if an authorization rules service is supported. 
     *
     *  @return <code> true </code> if an authorization rules service design 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuthorizatinRules();


    /**
     *  Gets the supported <code> Authorization </code> record types. 
     *
     *  @return a list containing the supported authorization record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAuthorizationRecordTypes();


    /**
     *  Tests if the given authorization record type is supported. 
     *
     *  @param  authorizationRecordType a <code> Type </code> indicating an 
     *          authorization record type 
     *  @return <code> true </code> if the given record Type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> authorizationRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuthorizationRecordType(org.osid.type.Type authorizationRecordType);


    /**
     *  Gets the supported <code> Authorization </code> search record types. 
     *
     *  @return a list containing the supported authorization search record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAuthorizationSearchRecordTypes();


    /**
     *  Tests if the given authorization search record type is supported. 
     *
     *  @param  authorizationSearchRecordType a <code> Type </code> indicating 
     *          an authorization search record type 
     *  @return <code> true </code> if the given search record Type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          authorizationSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuthorizationSearchRecordType(org.osid.type.Type authorizationSearchRecordType);


    /**
     *  Gets the supported <code> Function </code> record types. 
     *
     *  @return a list containing the supported <code> Function </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getFunctionRecordTypes();


    /**
     *  Tests if the given <code> Function </code> record type is supported. 
     *
     *  @param  functionRecordType a <code> Type </code> indicating a <code> 
     *          Function </code> record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> functionRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFunctionRecordType(org.osid.type.Type functionRecordType);


    /**
     *  Gets the supported <code> Function </code> search record types. 
     *
     *  @return a list containing the supported <code> Function </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getFunctionSearchRecordTypes();


    /**
     *  Tests if the given <code> Function </code> search record type is 
     *  supported. 
     *
     *  @param  functionSearchRecordType a <code> Type </code> indicating a 
     *          <code> Function </code> search record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> functionSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFunctionSearchRecordType(org.osid.type.Type functionSearchRecordType);


    /**
     *  Gets the supported <code> Qualifier </code> record types. 
     *
     *  @return a list containing the supported <code> Qualifier </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getQualifierRecordTypes();


    /**
     *  Tests if the given <code> Qualifier </code> record type is supported. 
     *
     *  @param  qualifierRecordType a <code> Type </code> indicating a <code> 
     *          Qualifier </code> record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> qualifierRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQualifierRecordType(org.osid.type.Type qualifierRecordType);


    /**
     *  Gets the supported <code> Qualifier </code> search record types. 
     *
     *  @return a list containing the supported <code> Qualifier </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getQualifierSearchRecordTypes();


    /**
     *  Tests if the given <code> Qualifier </code> search record type is 
     *  supported. 
     *
     *  @param  qualifierSearchRecordType a <code> Type </code> indicating a 
     *          <code> Qualifier </code> search record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          qualifierSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQualifierSearchRecordType(org.osid.type.Type qualifierSearchRecordType);


    /**
     *  Gets the supported <code> Vault </code> record types. 
     *
     *  @return a list containing the supported <code> Vault </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getVaultRecordTypes();


    /**
     *  Tests if the given <code> Vault </code> record type is supported. 
     *
     *  @param  vaultRecordType a <code> Type </code> indicating a <code> 
     *          Vault </code> type 
     *  @return <code> true </code> if the given vault record <code> Type 
     *          </code> is supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> vaultRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVaultRecordType(org.osid.type.Type vaultRecordType);


    /**
     *  Gets the supported vault search record types. 
     *
     *  @return a list containing the supported <code> Vault </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getVaultSearchRecordTypes();


    /**
     *  Tests if the given vault search record type is supported. 
     *
     *  @param  vaultSearchRecordType a <code> Type </code> indicating a 
     *          <code> Vault </code> search record type 
     *  @return <code> true </code> if the given search record <code> Type 
     *          </code> is supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> vaultSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVaultSearchRecordType(org.osid.type.Type vaultSearchRecordType);


    /**
     *  Gets the supported <code> AuthorizationCondition </code> record types. 
     *
     *  @return a list containing the supported <code> AuthorizationCondition 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAuthorizationConditionRecordTypes();


    /**
     *  Tests if the given <code> AuthorizationCondition </code> record type 
     *  is supported. 
     *
     *  @param  authorizationConditionRecordType a <code> Type </code> 
     *          indicating an <code> AuthorizationCondition </code> record 
     *          type 
     *  @return <code> true </code> if the given authorization condition 
     *          record <code> Type </code> is supported, <code> false </code> 
     *          otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          authorizationConditionRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuthorizationConditionRecordType(org.osid.type.Type authorizationConditionRecordType);
}
