//
// org.osid.authorization.AuthorizationQuerySession
//
//     The OSID Java specification for org.osid.authorization.AuthorizationQuerySession.
//
// Copyright (C) 2002-2004, 2007-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authorization;


/**
 *  <p>This session provides methods for searching <code> Authorization 
 *  </code> objects. The search query is constructed using the <code> 
 *  AuthorizationQuery. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated view: searches include authorizations in <code> Vaults 
 *      </code> of which this vault is a ancestor in the vault hierarchy </li> 
 *      <li> isolated view: searches are restricted to authorizations in this 
 *      <code> Vault </code> </li> 
 *      <li> implicit authorization view: authorizations include implicit 
 *      authorizations </li> 
 *      <li> explicit authorization view: only explicit authorizations are 
 *      returned </li> 
 *  </ul>
 *  
 */

public interface AuthorizationQuerySession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Vault </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Vault Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getVaultId();


    /**
     *  Gets the <code> Vault </code> associated with this session. 
     *
     *  @return the <code> Vault </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.Vault getVault()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform authorization searches. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer search operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if search methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSearchAuthorizations();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include authorizations in vaults which are children of this vault in 
     *  the vault hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedVaultView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts searches to this vault only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedVaultView();


    /**
     *  Sets the view for methods in this session to implicit authorizations. 
     *  An implicit view will include authorizations derived from other 
     *  authorizations as a result of the <code> Qualifier, </code> <code> 
     *  Function </code> or <code> Resource </code> hierarchies. This method 
     *  is the opposite of <code> explicitAut </code> 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useImplicitAuthorizationView();


    /**
     *  Sets the view for methods in this session to explicit authorizations. 
     *  An explicit view includes only those authorizations that were 
     *  explicitly defined and not implied. This method is the opposite of 
     *  <code> implicitAuthorizationView(). </code> 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useExplicitAuthorizationView();


    /**
     *  Gets an authorization query. 
     *
     *  @return the authorization query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.AuthorizationQuery getAuthorizationQuery();


    /**
     *  Gets a list of <code> Authorizations </code> matching the given query. 
     *
     *  @param  authorizationQuery the authorization query 
     *  @return the returned <code> AuthorizationList </code> 
     *  @throws org.osid.NullArgumentException <code> authorizationQuery 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> authorizationQuery 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.AuthorizationList getAuthorizationsByQuery(org.osid.authorization.AuthorizationQuery authorizationQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
