//
// org.osid.authorization.AuthorizationSearchSession
//
//     The OSID Java specification for org.osid.authorization.AuthorizationSearchSession.
//
// Copyright (C) 2002-2004, 2007-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authorization;


/**
 *  <p>This session provides methods for searching <code> Authorization 
 *  </code> objects. The search query is constructed using the <code> 
 *  AuthorizationQuery. </code> </p> 
 *  
 *  <p> <code> getAuthorizationsByQuery() </code> is the basic search method 
 *  and returns a list of <code> Authorizations. </code> A more advanced 
 *  search may be performed with <code> getAuthorizationsBySearch(). </code> 
 *  It accepts an <code> AgentSearch </code> in addition to the query for the 
 *  purpose of specifying additional options affecting the entire search, such 
 *  as ordering. <code> getAuthorizationssBySearch() </code> returns an <code> 
 *  AuthorizationSearchResults </code> that can be used to access the 
 *  resulting <code> AuthorizationList </code> or be used to perform a search 
 *  within the result set through <code> AuthorizationSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated view: searches include authorizations in <code> Vaults 
 *      </code> of which this vault is a ancestor in the vault hierarchy </li> 
 *      <li> isolated view: searches are restricted to authorizations in this 
 *      <code> Vault </code> </li> 
 *      <li> implicit authorization view: authorizations include implicit 
 *      authorizations </li> 
 *      <li> explicit authorization view: only explicit authorizations are 
 *      returned </li> 
 *  </ul>
 *  
 */

public interface AuthorizationSearchSession
    extends org.osid.authorization.AuthorizationQuerySession {


    /**
     *  Gets an authorization search. 
     *
     *  @return the authorization search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.AuthorizationSearch getAuthorizationSearch();


    /**
     *  Gets an authorization search order. The <code> 
     *  AuthorizationSearchOrder </code> is supplied to an <code> 
     *  AuthorizationSearch </code> to specify the ordering of results. 
     *
     *  @return the authorization search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.AuthorizationSearchOrder getAuthorizationSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  authorizationQuery the authorization query 
     *  @param  authorizationSearch the authorization search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> authorizationQuery 
     *          </code> or <code> authorizationSearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> authorizationSearch 
     *          </code> or <code> authorizationQuery </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.AuthorizationSearchResults getAuthorizationsBySearch(org.osid.authorization.AuthorizationQuery authorizationQuery, 
                                                                                       org.osid.authorization.AuthorizationSearch authorizationSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an authorization query from an inspector. The inspector is 
     *  available from an <code> AuthorizationSearchResults. </code> 
     *
     *  @param  authorizationQueryInspector an authorization query inspector 
     *  @return the authorization query 
     *  @throws org.osid.NullArgumentException <code> 
     *          authorizationQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          authorizationQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.AuthorizationQuery getAuthorizationQueryFromInspector(org.osid.authorization.AuthorizationQueryInspector authorizationQueryInspector);
}
