//
// org.osid.authorization.AuthorizationSession
//
//     The OSID Java specification for org.osid.authorization.AuthorizationSession.
//
// Copyright (C) 2002-2004, 2007-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authorization;


/**
 *  <p>This is the basic session for verifying authorizations. </p>
 */

public interface AuthorizationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Vault </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Vault Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getVaultId();


    /**
     *  Gets the <code> Vault </code> associated with this session. 
     *
     *  @return the <code> Vault </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.Vault getVault()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform authorization checks. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if authorization methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAccessAuthorizations();


    /**
     *  Determines if the given agent is authorized. An agent is authorized if 
     *  an active authorization exists whose <code> Agent, </code> <code> 
     *  Function </code> and <code> Qualifier </code> matches the supplied 
     *  parameters. Authorizations may be defined using groupings or 
     *  hieratchical structures for both the <code> Agent </code> and the 
     *  <code> Qualifier </code> but are queried in the de-nornmalized form. 
     *  
     *  The <code> Agent </code> is generally determined through the use of an 
     *  Authentication OSID. The <code> Function </code> and <code> Qualifier 
     *  </code> are already known as they map to the desired authorization to 
     *  validate. 
     *
     *  @param  agentId the <code> Id </code> of an <code> Agent </code> 
     *  @param  functionId the <code> Id </code> of a <code> Function </code> 
     *  @param  qualifierId the <code> Id </code> of a <code> Qualifier 
     *          </code> 
     *  @return <code> true </code> if the user is authorized, <code> false 
     *          </code> othersise 
     *  @throws org.osid.NotFoundException <code> functionId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> agentId </code> , <code> 
     *          functionId </code> or <code> qualifierId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          making request 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  Authorizations may be stored in a normalized form with respect 
     *          to various Resources and created using specific nodes in a 
     *          <code> Function </code> or <code> Qualifer </code> hierarchy. 
     *          The provider needs to maintain a de-normalized implicit 
     *          authorization store or expand the applicable hierarchies on 
     *          the fly to honor this query. 
     *          
     *          Querying the authorization service may in itself require a 
     *          separate authorization. A <code> PERMISSION_DENIED </code> is 
     *          a result of this authorization failure. If no explicit or 
     *          implicit authorization exists for the queried tuple, this 
     *          method should return <code> false. </code> 
     */

    public boolean isAuthorized(org.osid.id.Id agentId, 
                                org.osid.id.Id functionId, 
                                org.osid.id.Id qualifierId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> AuthorizationCondition </code> for making conditional 
     *  authorization checks. 
     *
     *  @param  functionId the <code> Id </code> of a <code> Function </code> 
     *  @return an authorization condition 
     *  @throws org.osid.NotFoundException <code> functionId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> functionId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          making request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.AuthorizationCondition getAuthorizationCondition(org.osid.id.Id functionId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Determines if the given agent is authorized. An agent is authorized if 
     *  an active authorization exists whose <code> Agent, </code> <code> 
     *  Function </code> and <code> Qualifier </code> matches the supplied 
     *  parameters. Authorizations may be defined using groupings or 
     *  hieratchical structures for both the <code> Agent </code> and the 
     *  <code> Qualifier </code> but are queried in the de-nornmalized form. 
     *  
     *  The <code> Agent </code> is generally determined through the use of an 
     *  Authentication OSID. The <code> Function </code> and <code> Qualifier 
     *  </code> are already known as they map to the desired authorization to 
     *  validate. 
     *
     *  @param  agentId the <code> Id </code> of an <code> Agent </code> 
     *  @param  functionId the <code> Id </code> of a <code> Function </code> 
     *  @param  qualifierId the <code> Id </code> of a <code> Qualifier 
     *          </code> 
     *  @param  condition an authorization condition 
     *  @return <code> true </code> if the user is authorized, <code> false 
     *          </code> othersise 
     *  @throws org.osid.NotFoundException <code> functionId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> agentId </code> , <code> 
     *          functionId, qualifierId </code> , or <code> condition </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          making request 
     *  @throws org.osid.UnsupportedException <code> condition </code> is not 
     *          of this service 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  Authorizations may be stored in a normalized form with respect 
     *          to various Resources and created using specific nodes in a 
     *          <code> Function </code> or <code> Qualifer </code> hierarchy. 
     *          The provider needs to maintain a de-normalized implicit 
     *          authorization store or expand the applicable hierarchies on 
     *          the fly to honor this query. 
     *          
     *          Querying the authorization service may in itself require a 
     *          separate authorization. A <code> PERMISSION_DENIED </code> is 
     *          a result of this authorization failure. If no explicit or 
     *          implicit authorization exists for the queried tuple, this 
     *          method should return <code> false. </code> 
     */

    public boolean isAuthorizedOnCondition(org.osid.id.Id agentId, 
                                           org.osid.id.Id functionId, 
                                           org.osid.id.Id qualifierId, 
                                           org.osid.authorization.AuthorizationCondition condition)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
