//
// org.osid.authorization.FunctionSearchSession
//
//     The OSID Java specification for org.osid.authorization.FunctionSearchSession.
//
// Copyright (C) 2002-2004, 2007-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authorization;


/**
 *  <p>This session provides methods for searching <code> Function </code> 
 *  objects. The search query is constructed using the <code> FunctionQuery. 
 *  </code> The function record <code> Type </code> also specifies the record 
 *  for the function query. </p> 
 *  
 *  <p> <code> getFunctionsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Functions. </code> A more advanced search may be 
 *  performed with <code> getFunctionsBySearch(). </code> It accepts a <code> 
 *  FunctionSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getFunctionsBySearch() </code> returns an <code> 
 *  FunctionSearchResults </code> that can be used to access the resulting 
 *  <code> FunctionList </code> or be used to perform a search within the 
 *  result set through <code> FunctionSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated vault view: searches include functions in vaults of 
 *      which this vault is a ancestor in the vault hierarchy </li> 
 *      <li> isolated vault view: searches are restricted to functions in this 
 *      vault </li> 
 *  </ul>
 *  
 *  
 *  <p> Functions may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> FunctionQuery. </code> 
 *  </p>
 */

public interface FunctionSearchSession
    extends org.osid.authorization.FunctionQuerySession {


    /**
     *  Gets a function search. 
     *
     *  @return the function search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.FunctionSearch getFunctionSearch();


    /**
     *  Gets a function search order. The <code> FunctionSearchOrder </code> 
     *  is supplied to a <code> FunctionSearch </code> to specify the ordering 
     *  of results. 
     *
     *  @return the function search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.FunctionSearchOrder getFunctionSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  functionQuery the function query 
     *  @param  functionSearch the function search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> functionQuery </code> or 
     *          <code> functionSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> functionSearch </code> or 
     *          <code> functionQuery </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.FunctionSearchResults getFunctionsBySearch(org.osid.authorization.FunctionQuery functionQuery, 
                                                                             org.osid.authorization.FunctionSearch functionSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a function query from an inspector. The inspector is available 
     *  from a <code> FunctionSearchResults. </code> 
     *
     *  @param  functionQueryInspector a function query inspector 
     *  @return the function query 
     *  @throws org.osid.NullArgumentException <code> functionQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> functionQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.FunctionQuery getFunctionQueryFromInspector(org.osid.authorization.FunctionQueryInspector functionQueryInspector);
}
