//
// org.osid.authorization.QualifierAdminSession
//
//     The OSID Java specification for org.osid.authorization.QualifierAdminSession.
//
// Copyright (C) 2002-2004, 2007-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authorization;


/**
 *  <p>This session creates, updates, and deletes <code> Qualifiers. </code> 
 *  The data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Qualifier, </code> a <code> QualifierForm </code> is requested using 
 *  <code> getQualifierFormForCreate() </code> specifying the desired 
 *  relationship peers and record <code> Types </code> or none if no record 
 *  <code> Types </code> are needed. The returned <code> QualifierForm </code> 
 *  will indicate that it is to be used with a create operation and can be 
 *  used to examine metdata or validate data prior to creation. Once the 
 *  <code> QualifierForm </code> is submiited to a create operation, it cannot 
 *  be reused with another create operation unless the first operation was 
 *  unsuccessful. Each <code> QualifierForm </code> corresponds to an 
 *  attempted transaction. </p> 
 *  
 *  <p> For updates, <code> QualifierForms </code> are requested to the <code> 
 *  Qualifier </code> <code> Id </code> that is to be updated using <code> 
 *  getQualifierFormForUpdate(). </code> Similarly, the <code> QualifierForm 
 *  </code> has metadata about the data that can be updated and it can perform 
 *  validation before submitting the update. The <code> QualifierForm </code> 
 *  can only be used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Qualifiers. </code> To unmap a 
 *  <code> Qualifier </code> from the current <code> Vault, </code> the <code> 
 *  QualifierVaultAssignmentSession </code> should be used. These delete 
 *  operations attempt to remove the <code> Qualifier </code> itself thus 
 *  removing it from all known <code> Vault </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface QualifierAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Vault </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Vault Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getVaultId();


    /**
     *  Gets the <code> Vault </code> associated with this session. 
     *
     *  @return the <code> Vault </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.Vault getVault()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> Qualifiers. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> Qualifier </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer create operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Qualifier </code> creation is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateQualifiers();


    /**
     *  Tests if this user can create a single <code> Qualifier </code> using 
     *  the desired record types. While <code> 
     *  AuthorizationManager.getQualifierRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> Qualifier. </code> 
     *  Providing an empty array tests if a <code> Qualifier </code> can be 
     *  created with no records. 
     *
     *  @param  qualifierRecordTypes array of qualifier record types 
     *  @return <code> true </code> if <code> Qualifier </code> creation using 
     *          the specified <code> Types </code> is supported, <code> false 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> qualifierRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateQualifierWithRecordTypes(org.osid.type.Type[] qualifierRecordTypes);


    /**
     *  Gets the qualifier form for creating new qualifiers. A new form should 
     *  be requested for each create transaction. 
     *
     *  @param  qualifierRecordTypes array of qualifier record types 
     *  @return the qualifier form 
     *  @throws org.osid.NullArgumentException <code> qualifierRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form with 
     *          requested record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.QualifierForm getQualifierFormForCreate(org.osid.type.Type[] qualifierRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Qualifier. </code> 
     *
     *  @param  qualifierForm the form for this <code> Qualifier </code> 
     *  @return the new <code> Qualifier </code> 
     *  @throws org.osid.IllegalStateException <code> qualifierForm </code> 
     *          already used for a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> qualifierForms </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> qualifierForm </code> did 
     *          not originate from <code> getQualifierFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.Qualifier createQualifier(org.osid.authorization.QualifierForm qualifierForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Qualifiers. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> Qualifier </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer update operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Qualifier </code> modification 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateQualifiers();


    /**
     *  Gets the qualifier form for updating an existing qualifier. A new 
     *  qualifier form should be requested for each update transaction. 
     *
     *  @param  qualifierId the <code> Id </code> of the <code> Qualifier 
     *          </code> 
     *  @return the qualifier form 
     *  @throws org.osid.NotFoundException <code> qualifierId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> qualifierId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.QualifierForm getQualifierFormForUpdate(org.osid.id.Id qualifierId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing qualifier. 
     *
     *  @param  qualifierForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> qualifierForm </code> 
     *          already used for an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> qualifierForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> qualifierForm </code> did 
     *          not originate from <code> getQualifierFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateQualifier(org.osid.authorization.QualifierForm qualifierForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> Qualifiers. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> Qualifier </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer delete operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Qualifier </code> deletion is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteQualifiers();


    /**
     *  Deletes a <code> Qualifier. </code> 
     *
     *  @param  qualifierId the <code> Id </code> of the <code> Qualifier 
     *          </code> to remove 
     *  @throws org.osid.NotFoundException <code> qualifierId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> qualifierId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteQualifier(org.osid.id.Id qualifierId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Qualifiers. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Qualifier </code> aliasing is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageQualifierAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Qualifier </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Qualifier </code> is determined by the provider. The new 
     *  <code> Id </code> performs as an alias to the primary <code> Id. 
     *  </code> If the alias is a pointer to another qualifier, it is 
     *  reassigned to the given qualifier <code> Id. </code> 
     *
     *  @param  qualifierId the <code> Id </code> of a <code> Qualifier 
     *          </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> qualifierId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> qualifierId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasQualifier(org.osid.id.Id qualifierId, 
                               org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
