//
// org.osid.authorization.QualifierQueryInspector
//
//     The OSID Java specification for org.osid.authorization.QualifierQueryInspector.
//
// Copyright (C) 2002-2004, 2007-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authorization;


/**
 *  <p>This is the query inspector for examining qualifiers queries. </p>
 */

public interface QualifierQueryInspector
    extends org.osid.OsidObjectQueryInspector,
            org.osid.OsidFederateableQueryInspector {


    /**
     *  Gets the qualifier hierarchy <code> Id </code> query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getQualifierHierarchyIdTerms();


    /**
     *  Gets the qualifier hierarchy query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hierarchy.HierarchyQueryInspector[] getQualifierHierarchyTerms();


    /**
     *  Gets the authorization <code> Id </code> query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getAuthorizationIdTerms();


    /**
     *  Gets the authorization query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.AuthorizationQueryInspector[] getAuthorizationTerms();


    /**
     *  Gets the ancestor qualifier <code> Id </code> query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getAncestorQualifierIdTerms();


    /**
     *  Gets the ancestor qualifier query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.FunctionQueryInspector[] getAncestorQualifierTerms();


    /**
     *  Gets the descendant qualifier <code> Id </code> query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getDescendantQualifierIdTerms();


    /**
     *  Gets the descendant qualifier query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.FunctionQueryInspector[] getDescendantQualifierTerms();


    /**
     *  Gets the vault <code> Id </code> query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getVaultIdTerms();


    /**
     *  Gets the vault query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.VaultQueryInspector[] getVaultTerms();


    /**
     *  Gets the qualifier query inspector record corresponding to the given 
     *  <code> Qualifier </code> record <code> Type. </code> 
     *
     *  @param  qualifierRecordType a qualifier query inspector record type 
     *  @return the qualifier query inspector record 
     *  @throws org.osid.NullArgumentException <code> qualifierRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(qualifierRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.records.QualifierQueryInspectorRecord getQualifierQueryInspectorRecord(org.osid.type.Type qualifierRecordType)
        throws org.osid.OperationFailedException;
}
