//
// org.osid.authorization.VaultSearchSession
//
//     The OSID Java specification for org.osid.authorization.VaultSearchSession.
//
// Copyright (C) 2002-2004, 2007-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authorization;


/**
 *  <p>This session provides methods for searching among <code> Vault </code> 
 *  objects. The search query is constructed using the <code> VaultQuery. 
 *  </code> </p> 
 *  
 *  <p> <code> getVaultsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Vault </code> objects.A more advanced search may 
 *  be performed with <code> getVaultsBySearch(). </code> It accepts a <code> 
 *  VaultSearch </code> in addition to the query for the purpose of specifying 
 *  additional options affecting the entire search, such as ordering. <code> 
 *  getVaultsBySearch() </code> returns a <code> VaultSearchResults </code> 
 *  that can be used to access the resulting <code> VaultList </code> or be 
 *  used to perform a search within the result set through <code> VaultSearch. 
 *  </code> </p> 
 *  
 *  <p> Vaults may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> VaultQuery. </code> 
 *  </p>
 */

public interface VaultSearchSession
    extends org.osid.authorization.VaultQuerySession {


    /**
     *  Gets a vault search. 
     *
     *  @return a vault search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.VaultSearch getVaultSearch();


    /**
     *  Gets a vault search order. The <code> VaultSearchOrder </code> is 
     *  supplied to a <code> VaultSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the vault search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.VaultSearchOrder getVaultSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  vaultQuery the vault query 
     *  @param  vaultSearch the vault search 
     *  @return the search results 
     *  @throws org.osid.NullArgumentException <code> vaultQuery </code> or 
     *          <code> vaultSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> vaultQuery </code> or 
     *          <code> vaultSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.VaultSearchResults getVaultsBySearch(org.osid.authorization.VaultQuery vaultQuery, 
                                                                       org.osid.authorization.VaultSearch vaultSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a vault query from an inspector. The inspector is available from 
     *  a <code> VaultSearchResults. </code> 
     *
     *  @param  vaultQueryInspector a vault query inspector 
     *  @return the vault query 
     *  @throws org.osid.NullArgumentException <code> vaultQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> vaultQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.VaultQuery getVaultQueryFromInspector(org.osid.authorization.VaultQueryInspector vaultQueryInspector);
}
