//
// org.osid.authorization.batch.AuthorizationBatchAdminSession
//
//     The OSID Java specification for org.osid.authorization.batch.AuthorizationBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authorization.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Authorizations 
 *  </code> in bulk. The data for create and update is provided by the 
 *  consumer via the form object. <code> OsidForms </code> are requested for 
 *  each create or update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create an 
 *  <code> Authorization, </code> an <code> AuthorizationForm </code> is 
 *  requested using <code> getAuthorizationFormsForCreate() </code> specifying 
 *  the desired qualifier, resource, and record <code> Types </code> or none 
 *  if no record <code> Types </code> are needed. Each of the returned <code> 
 *  AuthorizationForms </code> will indicate that it is to be used with a 
 *  create operation and can be used to examine metdata or validate data prior 
 *  to creation. Once an <code> AuthorizationForm </code> is submiited to a 
 *  create operation, it cannot be reused with another create operation unless 
 *  the first operation was unsuccessful. Each <code> AuthorizationForm 
 *  </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> AuthorizationForms </code> returned from <code> 
 *  getAuthorizationFormsForCreate() </code> may be linked to the originating 
 *  request through the peer <code> Ids </code> of the <code> 
 *  AuthorizationForm. </code> In the case where there may be duplicates, any 
 *  <code> AuthorizationForm </code> of the same peer <code> Ids </code> may 
 *  be used for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> AuthorizationForms </code> are submitted for 
 *  create, a <code> CreateResponse </code> is returned for each <code> 
 *  AuthorizationForm, </code> although the ordering is not defined. Only 
 *  errors that pertain to the entire create operation are returned from 
 *  <code> createAuthorizations(), </code> errors specific to an individual 
 *  <code> AuthorizationForm </code> are indicated in the corresponding <code> 
 *  CreateResponse. </code> <code> CreateResponses </code> may be linked to 
 *  the originating <code> AuthorizationForm </code> through the <code> 
 *  AuthorizationForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> AuthorizationForms </code> are requested to the 
 *  <code> Authorization </code> <code> Id </code> that is to be updated using 
 *  <code> getAuthorizationFormsForUpdate() </code> where the reference <code> 
 *  Id </code> in the <code> AuthorizationForm </code> may be used to link the 
 *  request. Similarly, the <code> AuthorizationForm </code> has metadata 
 *  about the data that can be updated and it can perform validation before 
 *  submitting the update. The <code> AuthorizationForm </code> can only be 
 *  used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> AuthorizationForms </code> are submitted for 
 *  update, an <code> UpdateResponse </code> is returned for each <code> 
 *  AuthorizationForm, </code> although the ordering is not defined. Only 
 *  errors that pertain to the entire update operation are returned from 
 *  <code> updateAuthorizations(), </code> errors specific to an individual 
 *  <code> AuthorizationForm </code> are indicated in the corresponding <code> 
 *  UpdateResponse. </code> <code> UpdateResponses </code> may be linked to 
 *  the originating <code> AuthorizationForm </code> through the <code> 
 *  AuthorizationForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> Authorizations </code> in bulk. To 
 *  unmap an <code> Authorization </code> from the current <code> Vault, 
 *  </code> the <code> AuthorizationVaultAssignmentSession </code> should be 
 *  used. These delete operations attempt to remove the <code> Authorization 
 *  </code> itself thus removing it from all known <code> Vault </code> 
 *  catalogs. Bulk delete operations return the results in <code> 
 *  DeleteResponses. </code> </p>
 */

public interface AuthorizationBatchAdminSession
    extends org.osid.authorization.AuthorizationAdminSession {


    /**
     *  Gets the authorization forms for creating a bunch of new 
     *  authorizations using agents. An AuthorizationForm is returned for each 
     *  qualifier and agent pair. 
     *
     *  @param  peers the authorization peers 
     *  @param  authorizationRecordTypes array of authorization record types 
     *          to be included in each create operation or an empty list if 
     *          none 
     *  @return the authorization forms 
     *  @throws org.osid.NotFoundException an <code> agentId, functionId, 
     *          </code> or <code> qualifierId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> peers </code> or <code> 
     *          authorizationRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.batch.AuthorizationBatchFormList getAuthorizationFormsForCreateForAgents(org.osid.authorization.batch.AuthorizationAgentPeerList peers, 
                                                                                                           org.osid.type.Type[] authorizationRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the authorization forms for creating a bunch of new 
     *  authorizations using resources. An AuthorizationForm is returned for 
     *  each qualifier and agent pair. 
     *
     *  @param  peers the authorization peers 
     *  @param  authorizationRecordTypes array of authorization record types 
     *          to be included in each create operation or an empty list if 
     *          none 
     *  @return the authorization forms 
     *  @throws org.osid.NotFoundException a <code> resourceId, functionId, 
     *          </code> or <code> qualifierId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> peers </code> or <code> 
     *          authorizationRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.batch.AuthorizationBatchFormList getAuthorizationFormsForCreateForResources(org.osid.authorization.batch.AuthorizationResourcePeerList peers, 
                                                                                                              org.osid.type.Type[] authorizationRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the authorization forms for creating a bunch of new 
     *  authorizations using resources and trusts. An AuthorizationForm is 
     *  returned for each qualifier and agent pair. 
     *
     *  @param  peers the authorization peers 
     *  @param  authorizationRecordTypes array of authorization record types 
     *          to be included in each create operation or an empty list if 
     *          none 
     *  @return the authorization forms 
     *  @throws org.osid.NotFoundException a <code> resourceId, trustId, 
     *          functionId, </code> or <code> qualifierId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> peers </code> or <code> 
     *          authorizationRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.batch.AuthorizationBatchFormList getAuthorizationFormsForCreateForResourcesAndTrusts(org.osid.authorization.batch.AuthorizationTrustPeerList peers, 
                                                                                                                       org.osid.type.Type[] authorizationRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Authorizations. </code> This method 
     *  returns an error if the entire operation fails. Otherwise, the status 
     *  of an individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  authorizationForms the authorization forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> authorizationForms 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createAuthorizations(org.osid.authorization.batch.AuthorizationBatchFormList authorizationForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the authorization forms for updating an existing set of 
     *  authorizations. A new authorization form should be requested for each 
     *  update transaction. 
     *
     *  @param  authorizationIds the <code> Ids </code> of the <code> 
     *          Authorization </code> 
     *  @return the authorization form 
     *  @throws org.osid.NotFoundException an <code> authorizationId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> authorizationIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.batch.AuthorizationBatchFormList getAuthorizationFormsForUpdate(org.osid.id.IdList authorizationIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing authorizations. This method returns an error if the 
     *  entire operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  authorizationForms the form containing the elements to be 
     *          updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> authorizationForms 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateAuthorizations(org.osid.authorization.batch.AuthorizationBatchFormList authorizationForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Authorizations </code> in this <code> Vault </code> 
     *  . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllAuthorizations()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes authorizations for the given <code> Ids. </code> 
     *
     *  @param  authorizationIds the <code> Ids </code> of the authorizations 
     *          to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> authorizationIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAuthorizations(org.osid.id.IdList authorizationIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all authorizations for the given resource. 
     *
     *  @param  resourceId an <code> Id </code> of a resource 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAuthorizationsForResource(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all authorizations for the given qualifier. 
     *
     *  @param  qualifierId an <code> Id </code> of a qualifier 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> qualifierId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAuthorizationsForQualifier(org.osid.id.Id qualifierId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes authorizations expired before the given date. 
     *
     *  @param  date a date 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteIneffectiveAuthorizationsByDate(org.osid.calendaring.DateTime date)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to an <code> Authorization </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Authorization </code> is determined by the provider. The 
     *  new <code> Id </code> is an alias to the primary <code> Id. </code> If 
     *  the alias is a pointer to another authorization, it is reassigned to 
     *  the given entry <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasAuthorizations(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
