//
// org.osid.authorization.batch.QualifierBatchAdminSession
//
//     The OSID Java specification for org.osid.authorization.batch.QualifierBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authorization.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Qualifiers </code> in 
 *  bulk. The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Qualifier, </code> a <code> QualifierForm </code> is requested using 
 *  <code> getQualifierFormsForCreate() </code> specifying the desired record 
 *  <code> Types </code> or none if no record <code> Types </code> are needed. 
 *  Each of the returned <code> QualifierForms </code> will indicate that it 
 *  is to be used with a create operation and can be used to examine metdata 
 *  or validate data prior to creation. Once a <code> QualifierForm </code> is 
 *  submiited to a create operation, it cannot be reused with another create 
 *  operation unless the first operation was unsuccessful. Each <code> 
 *  QualifierForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> QualifierForms </code> returned from <code> 
 *  getQualifierFormsForCreate() </code> may be linked to the originating 
 *  request through the peer <code> Ids </code> of the <code> QualifierForm. 
 *  </code> In the case where there may be duplicates, any <code> 
 *  QualifierForm </code> of the same peer <code> Ids </code> may be used for 
 *  a create operation. </p> 
 *  
 *  <p> Once a batch of <code> QualifierForms </code> are submitted for 
 *  create, a <code> CreateResponse </code> is returned for each <code> 
 *  QualifierForm, </code> although the ordering is not defined. Only errors 
 *  that pertain to the entire create operation are returned from <code> 
 *  createQualifiers(), </code> errors specific to an individual <code> 
 *  QualifierForm </code> are indicated in the corresponding <code> 
 *  CreateResponse. </code> <code> CreateResponses </code> may be linked to 
 *  the originating <code> QualifierForm </code> through the <code> 
 *  QualifierForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> QualifierForms </code> are requested to the <code> 
 *  Qualifier </code> <code> Id </code> that is to be updated using <code> 
 *  getQualifierFormsForUpdate() </code> where the reference <code> Id </code> 
 *  in the <code> QualifierForm </code> may be used to link the request. 
 *  Similarly, the <code> QualifierForm </code> has metadata about the data 
 *  that can be updated and it can perform validation before submitting the 
 *  update. The <code> QualifierForm </code> can only be used once for a 
 *  successful update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> QualifierForms </code> are submitted for 
 *  update, an <code> UpdateResponse </code> is returned for each <code> 
 *  QualifierForm, </code> although the ordering is not defined. Only errors 
 *  that pertain to the entire update operation are returned from <code> 
 *  updateQualifiers(), </code> errors specific to an individual <code> 
 *  QualifierForm </code> are indicated in the corresponding <code> 
 *  UpdateResponse. </code> <code> UpdateResponses </code> may be linked to 
 *  the originating <code> QualifierForm </code> through the <code> 
 *  QualifierForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> Qualifiers </code> in bulk. To 
 *  unmap a <code> Qualifier </code> from the current <code> Vault, </code> 
 *  the <code> QualifierVaultAssignmentSession </code> should be used. These 
 *  delete operations attempt to remove the <code> Qualifier </code> itself 
 *  thus removing it from all known <code> Vault </code> catalogs. Bulk delete 
 *  operations return the results in <code> DeleteResponses. </code> </p>
 */

public interface QualifierBatchAdminSession
    extends org.osid.authorization.QualifierAdminSession {


    /**
     *  Gets the qualifier forms for creating a bunch of new qualifiers. A 
     *  QualifierForm is returned for each competency <code> Id. </code> 
     *
     *  @param  number the number of forms to retrieve 
     *  @param  qualifierRecordTypes array of qualifier record types to be 
     *          included in each create operation or an empty list if none 
     *  @return the qualifier forms 
     *  @throws org.osid.NullArgumentException <code> qualifierRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.batch.QualifierBatchFormList getQualifierFormsForCreate(long number, 
                                                                                          org.osid.type.Type[] qualifierRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Qualifiers. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  qualifierForms the qualifier forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> qualifierForms </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createQualifiers(org.osid.authorization.batch.QualifierBatchFormList qualifierForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the qualifier forms for updating an existing set of qualifiers. A 
     *  new qualifier form should be requested for each update transaction. 
     *
     *  @param  qualifierIds the <code> Ids </code> of the <code> Qualifier 
     *          </code> 
     *  @return the qualifier form 
     *  @throws org.osid.NotFoundException a <code> qualifierId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> qualifierIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.batch.QualifierBatchFormList getQualifierFormsForUpdate(org.osid.id.IdList qualifierIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing qualifiers. This method returns an error if the 
     *  entire operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  qualifierForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> qualifierForms </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateQualifiers(org.osid.authorization.batch.QualifierBatchFormList qualifierForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Qualifiers </code> in this <code> Vault </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllQualifiers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes qualifiers for the given <code> Ids. </code> 
     *
     *  @param  qualifierIds the <code> Ids </code> of the qualifiers to 
     *          delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> qualifierIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteQualifiers(org.osid.id.IdList qualifierIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Qualifier </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Qualifier </code> is determined by the provider. The new 
     *  <code> Id </code> is an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another qualifier, it is reassigned to the given 
     *  entry <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasQualifiers(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
