//
// org.osid.authorization.rules.AuthorizationEnablerAdminSession
//
//     The OSID Java specification for org.osid.authorization.rules.AuthorizationEnablerAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authorization.rules;


/**
 *  <p>This session creates and removes authorization enablers. The data for 
 *  create and update is provided via the <code> AuthorizationEnablerForm. 
 *  </code> </p>
 */

public interface AuthorizationEnablerAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Vault </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Vault Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getVaultId();


    /**
     *  Gets the <code> Vault </code> associated with this session. 
     *
     *  @return the vault 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.Vault getVault()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create authorization enablers. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating an <code> AuthorizationEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer create 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> AuthorizationEnabler </code> 
     *          creation is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAuthorizationEnabler();


    /**
     *  Tests if this user can create a single <code> AuthorizationEnabler 
     *  </code> using the desired record types. While <code> 
     *  AuthorizationRulesManager.getAuthorizationEnablerRecordTypes() </code> 
     *  can be used to examine which records are supported, this method tests 
     *  which record(s) are required for creating a specific <code> 
     *  AuthorizationEnabler. </code> Providing an empty array tests if an 
     *  <code> AuthorizationEnabler </code> can be created with no records. 
     *
     *  @param  authorizationEnablerRecordTypes array of authorization enabler 
     *          record types 
     *  @return <code> true </code> if <code> AuthorizationEnabler </code> 
     *          creation using the specified record <code> Types </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          authorizationEnablerRecordTypes </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAuthorizationEnablerWithRecordTypes(org.osid.type.Type[] authorizationEnablerRecordTypes);


    /**
     *  Gets the authorization enabler form for creating new authorization 
     *  enablers. A new form should be requested for each create transaction. 
     *
     *  @param  authorizationEnablerRecordTypes array of authorization enabler 
     *          record types 
     *  @return the authorization enabler form 
     *  @throws org.osid.NullArgumentException <code> 
     *          authorizationEnablerRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.rules.AuthorizationEnablerForm getAuthorizationEnablerFormForCreate(org.osid.type.Type[] authorizationEnablerRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> AuthorizationEnabler. </code> 
     *
     *  @param  authorizationEnablerForm the form for this <code> 
     *          AuthorizationEnabler </code> 
     *  @return the new <code> AuthorizationEnabler </code> 
     *  @throws org.osid.IllegalStateException <code> authorizationEnablerForm 
     *          </code> already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> authorizationEnablerForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> authorizationEnablerForm 
     *          </code> did not originate from <code> 
     *          getAuthorizationEnablerFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.rules.AuthorizationEnabler createAuthorizationEnabler(org.osid.authorization.rules.AuthorizationEnablerForm authorizationEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update authorization enablers. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating an <code> AuthorizationEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer update 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> AuthorizationEnabler </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateAuthorizationEnablers();


    /**
     *  Gets the authorization enabler form for updating an existing 
     *  authorization enabler. A new authorization enabler form should be 
     *  requested for each update transaction. 
     *
     *  @param  authorizationEnablerId the <code> Id </code> of the <code> 
     *          AuthorizationEnabler </code> 
     *  @return the authorization enabler form 
     *  @throws org.osid.NotFoundException <code> authorizationEnablerId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> authorizationEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.rules.AuthorizationEnablerForm getAuthorizationEnablerFormForUpdate(org.osid.id.Id authorizationEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing authorization enabler. 
     *
     *  @param  authorizationEnablerForm the form containing the elements to 
     *          be updated 
     *  @throws org.osid.IllegalStateException <code> authorizationEnablerForm 
     *          </code> already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> authorizationEnablerForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> authorizationEnablerForm 
     *          </code> did not originate from <code> 
     *          getAuthorizationEnablerFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateAuthorizationEnabler(org.osid.authorization.rules.AuthorizationEnablerForm authorizationEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete authorization enablers. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting an <code> AuthorizationEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer delete 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> AuthorizationEnabler </code> 
     *          deletion is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteAuthorizationEnablers();


    /**
     *  Deletes an <code> AuthorizationEnabler. </code> 
     *
     *  @param  authorizationEnablerId the <code> Id </code> of the <code> 
     *          AuthorizationEnabler </code> to remove 
     *  @throws org.osid.NotFoundException <code> authorizationEnablerId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> authorizationEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteAuthorizationEnabler(org.osid.id.Id authorizationEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for 
     *  authorization enablers. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> AuthorizationEnabler </code> 
     *          aliasing is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageAuthorizationEnablerAliases();


    /**
     *  Adds an <code> Id </code> to an <code> AuthorizationEnabler </code> 
     *  for the purpose of creating compatibility. The primary <code> Id 
     *  </code> of the <code> AuthorizationEnabler </code> is determined by 
     *  the provider. The new <code> Id </code> performs as an alias to the 
     *  primary <code> Id </code> . If the alias is a pointer to another 
     *  authorization enabler. it is reassigned to the given authorization 
     *  enabler <code> Id. </code> 
     *
     *  @param  authorizationEnablerId the <code> Id </code> of an <code> 
     *          AuthorizationEnabler </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> authorizationEnablerId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> authorizationEnablerId 
     *          </code> or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasAuthorizationEnabler(org.osid.id.Id authorizationEnablerId, 
                                          org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
