//
// org.osid.authorization.rules.AuthorizationEnablerLookupSession
//
//     The OSID Java specification for org.osid.authorization.rules.AuthorizationEnablerLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authorization.rules;


/**
 *  <p>This session provides methods for retrieving <code> 
 *  AuthorizationEnablers. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated vault view: All authorization enabler methods in this 
 *      session operate, retrieve and pertain to authorization enablers 
 *      defined explicitly in the current vault. Using an isolated view is 
 *      useful for managing <code> AuthorizationEnablers </code> with the 
 *      <code> AuthorizationEnablerAdminSession. </code> </li> 
 *      <li> federated vault view: All authorization enabler methods in this 
 *      session operate, retrieve and pertain to all authorization enablers 
 *      defined in this vault and any other authorization enablers implicitly 
 *      available in this vault through vault inheritence. </li> 
 *      <li> active authorization enabler view: All authorization enabler 
 *      lookup methods return active authorization enablers. </li> 
 *      <li> any status authorization enabler view: Authorization enablers of 
 *      any active or inactive status are returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedDistributorView() </code> and <code> 
 *  useIsolatedDistributorView() </code> behave as a radio group and one 
 *  should be selected before invoking the methods in this session. </p>
 */

public interface AuthorizationEnablerLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Vault </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Vault Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getVaultId();


    /**
     *  Gets the <code> Vault </code> associated with this session. 
     *
     *  @return the vault 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.Vault getVault()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> AuthorizationEnablers </code> 
     *  lookups. A return of true does not guarantee successful authorization. 
     *  A return of false indicates that it is known all methods in this 
     *  session will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer lookup 
     *  operations to unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupAuthorizationEnablers();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeAuthorizationEnablerView();


    /**
     *  A complete view of the <code> AuthorizationEnabler </code> returns is 
     *  desired. Methods will return what is requested or result in an error. 
     *  This view is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryAuthorizationEnablerView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include authorization enablers in vaults which are children of this 
     *  vault in the vault hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedVaultView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this vault only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedVaultView();


    /**
     *  Only active authorization enablers are returned by methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveAuthorizationEnablerView();


    /**
     *  All active and inactive authorization enablers are returned by methods 
     *  in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusAuthorizationEnablerView();


    /**
     *  Gets the <code> AuthorizationEnabler </code> specified by its <code> 
     *  Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  AuthorizationEnabler </code> may have a different <code> Id </code> 
     *  than requested, such as the case where a duplicate <code> Id </code> 
     *  was assigned to an <code> AuthorizationEnabler </code> and retained 
     *  for compatibility. 
     *  
     *  In active mode, authorization enablers are returned that are currently 
     *  active. In any status mode, active and inactive authorization enablers 
     *  are returned. 
     *
     *  @param  authorizationEnablerId <code> Id </code> of the <code> 
     *          AuthorizationEnabler </code> 
     *  @return the authorization enabler 
     *  @throws org.osid.NotFoundException <code> authorizationEnablerId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> authorizationEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.authorization.rules.AuthorizationEnabler getAuthorizationEnabler(org.osid.id.Id authorizationEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AuthorizationEnablerList </code> corresponding to the 
     *  given <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  authorization enablers specified in the <code> Id </code> list, in the 
     *  order of the list, including duplicates, or an error results if an 
     *  <code> Id </code> in the supplied list is not found or inaccessible. 
     *  Otherwise, inaccessible <code> AuthorizationEnablers </code> may be 
     *  omitted from the list and may present the elements in any order 
     *  including returning a unique set. 
     *  
     *  In active mode, authorization enablers are returned that are currently 
     *  active. In any status mode, active and inactive authorization enablers 
     *  are returned. 
     *
     *  @param  authorizationEnablerIds the list of <code> Ids </code> to 
     *          retrieve 
     *  @return the returned <code> AuthorizationEnabler </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> authorizationEnablerIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.rules.AuthorizationEnablerList getAuthorizationEnablersByIds(org.osid.id.IdList authorizationEnablerIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AuthorizationEnablerList </code> corresponding to the 
     *  given authorization enabler genus <code> Type </code> which does not 
     *  include authorization enablers of genus types derived from the 
     *  specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  authorization enablers or an error results. Otherwise, the returned 
     *  list may contain only those authorization enablers that are accessible 
     *  through this session. 
     *  
     *  In active mode, authorization enablers are returned that are currently 
     *  active. In any status mode, active and inactive authorization enablers 
     *  are returned. 
     *
     *  @param  authorizationEnablerGenusType an authorization enabler genus 
     *          type 
     *  @return the returned <code> AuthorizationEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          authorizationEnablerGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.rules.AuthorizationEnablerList getAuthorizationEnablersByGenusType(org.osid.type.Type authorizationEnablerGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AuthorizationEnablerList </code> corresponding to the 
     *  given authorization enabler genus <code> Type </code> and include any 
     *  additional authorization enablers with genus types derived from the 
     *  specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  authorization enablers or an error results. Otherwise, the returned 
     *  list may contain only those authorization enablers that are accessible 
     *  through this session. 
     *  
     *  In active mode, authorization enablers are returned that are currently 
     *  active. In any status mode, active and inactive authorization enablers 
     *  are returned. 
     *
     *  @param  authorizationEnablerGenusType an authorization enabler genus 
     *          type 
     *  @return the returned <code> AuthorizationEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          authorizationEnablerGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.rules.AuthorizationEnablerList getAuthorizationEnablersByParentGenusType(org.osid.type.Type authorizationEnablerGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AuthorizationEnablerList </code> containing the given 
     *  authorization enabler record <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  authorization enablers or an error results. Otherwise, the returned 
     *  list may contain only those authorization enablers that are accessible 
     *  through this session. 
     *  
     *  In active mode, authorization enablers are returned that are currently 
     *  active. In any status mode, active and inactive authorization enablers 
     *  are returned. 
     *
     *  @param  authorizationEnablerRecordType an authorization enabler record 
     *          type 
     *  @return the returned <code> AuthorizationEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          authorizationEnablerRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.rules.AuthorizationEnablerList getAuthorizationEnablersByRecordType(org.osid.type.Type authorizationEnablerRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AuthorizationEnablerList </code> that are effective for 
     *  the entire given date range inclusive but not confined to the date 
     *  range for any agent. 
     *  
     *  In plenary mode, the returned list contains all known authorization 
     *  enablers or an error results. Otherwise, the returned list may contain 
     *  only those authorization enablers that are accessible through this 
     *  session. 
     *  
     *  In active mode, authorization enablers are returned that are currently 
     *  active in addition to being effective during the given date range. In 
     *  any status mode, active and inactive authorization enablers are 
     *  returned. 
     *
     *  @param  from a start date 
     *  @param  to an end date 
     *  @return the returned <code> AuthorizationEnabler </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from, </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.rules.AuthorizationEnablerList getAuthorizationEnablersOnDate(org.osid.calendaring.DateTime from, 
                                                                                                org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AuthorizationEnablerList </code> that are effective for 
     *  the entire given date range and evaluated against the given agent. 
     *  
     *  In plenary mode, the returned list contains all known authorization 
     *  enablers or an error results. Otherwise, the returned list may contain 
     *  only those authorization enablers that are accessible through this 
     *  session. 
     *  
     *  In active mode, authorization enablers are returned that are currently 
     *  active in addition to being effective in the given date range for the 
     *  given agent. In any status mode, active and inactive authorization 
     *  enablers are returned. 
     *
     *  @param  agentId an agent <code> Id </code> 
     *  @param  from a start date 
     *  @param  to an end date 
     *  @return the returned <code> AuthorizationEnabler </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> agentId, from, </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.rules.AuthorizationEnablerList getAuthorizationEnablersOnDateWithAgent(org.osid.id.Id agentId, 
                                                                                                         org.osid.calendaring.DateTime from, 
                                                                                                         org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> AuthorizationEnablers. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  authorization enablers or an error results. Otherwise, the returned 
     *  list may contain only those authorization enablers that are accessible 
     *  through this session. 
     *  
     *  In active mode, authorization enablers are returned that are currently 
     *  active. In any status mode, active and inactive authorization enablers 
     *  are returned. 
     *
     *  @return the returned <code> AuthorizationEnabler </code> list 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.rules.AuthorizationEnablerList getAuthorizationEnablers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
