//
// org.osid.authorization.rules.AuthorizationEnablerRuleLookupSession
//
//     The OSID Java specification for org.osid.authorization.rules.AuthorizationEnablerRuleLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authorization.rules;


/**
 *  <p>This session provides methods to retrieve <code> AuthorizationEnabler 
 *  </code> to <code> Authorization </code> mappings. An <code> Authorization 
 *  </code> with multiple <code> AuthorizationEnablers </code> means any 
 *  positive rule evaluation across the enablers result in an effective <code> 
 *  Authorization. </code> </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated vault view: All methods in this session operate, 
 *      retrieve and pertain authorization enablers defined explicitly in the 
 *      current vault </li> 
 *      <li> federated vault view: All methods in this session operate, 
 *      retrieve and pertain to all authorization enablers defined in this 
 *      vault and any other authorization enablers implicitly available in 
 *      this vault through vault inheritence. </li> 
 *  </ul>
 *  
 */

public interface AuthorizationEnablerRuleLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Vault </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Vault Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getVaultId();


    /**
     *  Gets the <code> Vault </code> associated with this session. 
     *
     *  @return the vault 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.Vault getVault()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform lookups of authorization 
     *  enabler/authorization mappings. A return of true does not guarantee 
     *  successful authorization. A return of false indicates that it is known 
     *  lookup methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if looking up mappings is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupAuthorizationEnablerRules();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeAuthorizationEnablerRuleView();


    /**
     *  A complete view of the <code> AuthorizationEnabler </code> and <code> 
     *  Authorization </code> returns is desired. Methods will return what is 
     *  requested or result in an error. This view is used when greater 
     *  precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryAuthorizationEnablerRuleView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include authorization enablers in vaults which are children of this 
     *  vault in the vault hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedVaultView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this vault only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedVaultView();


    /**
     *  Gets the <code> AuthorizationEnabler Id </code> associated with an 
     *  <code> Authorization. </code> 
     *
     *  @param  authorizationId <code> Id </code> of the <code> Authorization 
     *          </code> 
     *  @return the authorization enabler <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> authorizationId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> authorizationId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAuthorizationEnablerIdsForAuthorization(org.osid.id.Id authorizationId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> AuthorizationEnabler </code> associated with an <code> 
     *  Authorization. </code> 
     *
     *  @param  authorizationId <code> Id </code> of the <code> Authorization 
     *          </code> 
     *  @return the authorization enablers 
     *  @throws org.osid.NotFoundException <code> authorizationId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> authorizationId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.rules.AuthorizationEnablerList getAuthorizationEnablersForAuthorization(org.osid.id.Id authorizationId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Authorization </code> <code> Ids </code> mapped to an 
     *  <code> AuthorizationEnabler. </code> 
     *
     *  @param  authorizationEnablerId <code> Id </code> of an <code> 
     *          AuthorizationEnabler </code> 
     *  @return list of authorization <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> authorizationEnablerId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> authorizationEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAuthorizationIdsForAuthorizationEnabler(org.osid.id.Id authorizationEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Authorizations </code> mapped to an <code> 
     *  AuthorizationEnabler. </code> 
     *
     *  @param  authorizationEnablerId <code> Id </code> of an <code> 
     *          AuthorizationEnabler </code> 
     *  @return list of authorizations 
     *  @throws org.osid.NotFoundException <code> authorizationEnablerId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> authorizationEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.AuthorizationList getAuthorizationsForAuthorizationEnabler(org.osid.id.Id authorizationEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
