//
// org.osid.authorization.rules.AuthorizationEnablerSearchSession
//
//     The OSID Java specification for org.osid.authorization.rules.AuthorizationEnablerSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authorization.rules;


/**
 *  <p>This session provides methods for searching among <code> 
 *  AuthorizationEnabler </code> objects. The search query is constructed 
 *  using the <code> AuthorizationEnableryQuery. </code> </p> 
 *  
 *  <p> <code> getAuthorizationEnablersByQuery() </code> is the basic search 
 *  method and returns a list of <code> AuthorizationEnablers. </code> A more 
 *  advanced search may be performed with <code> 
 *  getAuthorizationEnablersBySearch(). </code> It accepts an <code> 
 *  AuthorizationEnablerSearch </code> in addition to the query for the 
 *  purpose of specifying additional options affecting the entire search, such 
 *  as ordering. <code> getAuthorizationEnablersBySearch() </code> returns an 
 *  <code> AuthorizationEnablerSearchResults </code> that can be used to 
 *  access the resulting <code> AuthorizationEnablerList </code> or be used to 
 *  perform a search within the result set through <code> 
 *  AuthorizationEnablerSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated vault view: searches include authorization enablers in 
 *      vaults of which this vault is an ancestor in the vault hierarchy </li> 
 *      <li> isolated vault view: searches are restricted to authorization 
 *      enablers in this vault </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> AuthorizationEnablers </code> may have a query record indicated 
 *  by their respective record types. The query record is accessed via the 
 *  <code> AuthorizationEnablerQuery. </code> </p>
 */

public interface AuthorizationEnablerSearchSession
    extends org.osid.authorization.rules.AuthorizationEnablerQuerySession {


    /**
     *  Gets an authorization enabler search. 
     *
     *  @return the authorization enabler search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.rules.AuthorizationEnablerSearch getAuthorizationEnablerSearch();


    /**
     *  Gets an authorization enabler search order. The <code> 
     *  AuthorizationEnablerSearchOrder </code> is supplied to an <code> 
     *  AuthorizationEnablerSearch </code> to specify the ordering of results. 
     *
     *  @return the authorization enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.rules.AuthorizationEnablerSearchOrder getAuthorizationEnablerSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  authorizationEnablerQuery the authorization enabler query 
     *  @param  authorizationEnablerSearch the authorization enabler search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> 
     *          authorizationEnablerQuery </code> or <code> 
     *          authorizationEnablerSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> authorizationEnablerQuery 
     *          </code> or <code> authorizationEnablerSearch </code> is not of 
     *          this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.rules.AuthorizationEnablerSearchResults getAuthorizationEnablersBySearch(org.osid.authorization.rules.AuthorizationEnablerQuery authorizationEnablerQuery, 
                                                                                                           org.osid.authorization.rules.AuthorizationEnablerSearch authorizationEnablerSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an authorization enabler query from an inspector. The inspector 
     *  is available from an <code> AuthorizationEnablerSearchResults. </code> 
     *
     *  @param  authorizationEnablerQueryInspector an authorization enabler 
     *          query inspector 
     *  @return the authorization enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          authorizationEnablerQueryInspector </code> is <code> null 
     *          </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          authorizationEnablerQueryInspector </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.rules.AuthorizationEnablerQuery getAuthorizationEnablerQueryFromInspector(org.osid.authorization.rules.AuthorizationEnablerQueryInspector authorizationEnablerQueryInspector);
}
