//
// org.osid.authorization.rules.AuthorizationEnablerVaultAssignmentSession
//
//     The OSID Java specification for org.osid.authorization.rules.AuthorizationEnablerVaultAssignmentSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authorization.rules;


/**
 *  <p>This session provides methods to re-assign <code> AuthorizationEnabler 
 *  </code> to <code> Vault </code> mappings. An <code> AuthorizationEnabler 
 *  </code> may appear in multiple <code> Vault </code> objects and removing 
 *  the last reference to an <code> AuthorizationEnabler </code> is the 
 *  equivalent of deleting it. Each <code> Vault </code> may have its own 
 *  authorizations governing who is allowed to operate on it. </p> 
 *  
 *  <p> Adding a reference of an <code> AuthorizationEnabler </code> to 
 *  another <code> Vault </code> is not a copy operation (eg: does not change 
 *  its <code> Id </code> ). </p>
 */

public interface AuthorizationEnablerVaultAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter authorization enabler/vault mappings. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignAuthorizationEnablers();


    /**
     *  Tests if this user can alter authorization enabler/vault mappings. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @param  vaultId the <code> Id </code> of the <code> Vault </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> vaultId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignAuthorizationEnablersToVault(org.osid.id.Id vaultId);


    /**
     *  Gets a list of vaults including and under the given vault node in 
     *  which any authorization enabler can be assigned. 
     *
     *  @param  vaultId the <code> Id </code> of the <code> Vault </code> 
     *  @return list of assignable vault <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> vaultId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableVaultIds(org.osid.id.Id vaultId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of vaults including and under the given vault node in 
     *  which a specific authorization enabler can be assigned. 
     *
     *  @param  vaultId the <code> Id </code> of the <code> Vault </code> 
     *  @param  authorizationEnablerId the <code> Id </code> of the <code> 
     *          AuthorizationEnabler </code> 
     *  @return list of assignable vault <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> vaultId </code> or 
     *          <code> authorizationEnablerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableVaultIdsForAuthorizationEnabler(org.osid.id.Id vaultId, 
                                                                           org.osid.id.Id authorizationEnablerId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> AuthorizationEnabler </code> to a <code> 
     *  Vault. </code> 
     *
     *  @param  authorizationEnablerId the <code> Id </code> of the <code> 
     *          AuthorizationEnabler </code> 
     *  @param  vaultId the <code> Id </code> of the <code> Vault </code> 
     *  @throws org.osid.AlreadyExistsException <code> authorizationEnablerId 
     *          </code> already assigned to <code> vaultI </code> 
     *  @throws org.osid.NotFoundException <code> authorizationEnablerId 
     *          </code> or <code> vaultId </code> not found 
     *  @throws org.osid.NullArgumentException <code> authorizationEnablerId 
     *          </code> or <code> vaultId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignAuthorizationEnablerToVault(org.osid.id.Id authorizationEnablerId, 
                                                  org.osid.id.Id vaultId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes an <code> AuthorizationEnabler </code> from a <code> Vault. 
     *  </code> 
     *
     *  @param  authorizationEnablerId the <code> Id </code> of the <code> 
     *          AuthorizationEnabler </code> 
     *  @param  vaultId the <code> Id </code> of the <code> Vault </code> 
     *  @throws org.osid.NotFoundException <code> authorizationEnablerId 
     *          </code> or <code> vaultId </code> not found or <code> 
     *          authorizationEnablerId </code> not assigned to <code> vaultId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> authorizationEnablerId 
     *          </code> or <code> vaultId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignAuthorizationEnablerFromVault(org.osid.id.Id authorizationEnablerId, 
                                                      org.osid.id.Id vaultId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Moves an <code> AuthorizationEnabler </code> from one <code> Vault 
     *  </code> to another. Mappings to other <code> Vaults </code> are 
     *  unaffected. 
     *
     *  @param  authorizationEnablerId the <code> Id </code> of the <code> 
     *          AuthorizationEnabler </code> 
     *  @param  fromVaultId the <code> Id </code> of the current <code> Vault 
     *          </code> 
     *  @param  toVaultId the <code> Id </code> of the destination <code> 
     *          Vault </code> 
     *  @throws org.osid.NotFoundException <code> authorizationEnablerId, 
     *          fromVaultId, </code> or <code> toVaultId </code> not found or 
     *          <code> authorizationEnablerId </code> not mapped to <code> 
     *          fromVaultId </code> 
     *  @throws org.osid.NullArgumentException <code> authorizationEnablerId, 
     *          fromVaultId, </code> or <code> toVaultId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void reassignAuthorizationEnablerToVault(org.osid.id.Id authorizationEnablerId, 
                                                    org.osid.id.Id fromVaultId, 
                                                    org.osid.id.Id toVaultId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
