//
// org.osid.authorization.rules.AuthorizationRulesProfile
//
//     The OSID Java specification for org.osid.authorization.rules.AuthorizationRulesProfile.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authorization.rules;


/**
 *  <p>The authorization rules profile describes the interoperability among 
 *  authorization rules services. </p>
 */

public interface AuthorizationRulesProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any broker federation is exposed. Federation is exposed when 
     *  a specific broker may be identified, selected and used to create a 
     *  lookup or admin session. Federation is not exposed when a set of 
     *  brokers appears as a single broker. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if looking up authorization enablers is supported. 
     *
     *  @return <code> true </code> if authorization enabler lookup is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuthorizationEnablerLookup();


    /**
     *  Tests if querying authorization enablers is supported. 
     *
     *  @return <code> true </code> if authorization enabler query is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuthorizationEnablerQuery();


    /**
     *  Tests if searching authorization enablers is supported. 
     *
     *  @return <code> true </code> if authorization enabler search is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuthorizationEnablerSearch();


    /**
     *  Tests if an authorization enabler administrative service is supported. 
     *
     *  @return <code> true </code> if authorization enabler administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuthorizationEnablerAdmin();


    /**
     *  Tests if an authorization enabler notification service is supported. 
     *
     *  @return <code> true </code> if authorization enabler notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuthorizationEnablerNotification();


    /**
     *  Tests if an authorization enabler vault lookup service is supported. 
     *
     *  @return <code> true </code> if an authorization enabler vault lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuthorizationEnablerVault();


    /**
     *  Tests if an authorization enabler vault service is supported. 
     *
     *  @return <code> true </code> if authorization enabler vault assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuthorizationEnablerVaultAssignment();


    /**
     *  Tests if an authorization enabler vault lookup service is supported. 
     *
     *  @return <code> true </code> if an authorization enabler vault service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuthorizationEnablerSmartVault();


    /**
     *  Tests if an authorization enabler authorization rule lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if an authorization enabler authorization 
     *          rule lookup service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuthorizationEnablerRuleLookup();


    /**
     *  Tests if an authorization enabler authorization rule application 
     *  service is supported. 
     *
     *  @return <code> true </code> if authorization enabler authorization 
     *          rule application service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuthorizationEnablerRuleApplication();


    /**
     *  Gets the supported <code> AuthorizationEnabler </code> record types. 
     *
     *  @return a list containing the supported <code> AuthorizationEnabler 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAuthorizationEnablerRecordTypes();


    /**
     *  Tests if the given <code> AuthorizationEnabler </code> record type is 
     *  supported. 
     *
     *  @param  authorizationEnablerRecordType a <code> Type </code> 
     *          indicating an <code> AuthorizationEnabler </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          authorizationEnablerRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuthorizationEnablerRecordType(org.osid.type.Type authorizationEnablerRecordType);


    /**
     *  Gets the supported <code> AuthorizationEnabler </code> search record 
     *  types. 
     *
     *  @return a list containing the supported <code> AuthorizationEnabler 
     *          </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAuthorizationEnablerSearchRecordTypes();


    /**
     *  Tests if the given <code> AuthorizationEnabler </code> search record 
     *  type is supported. 
     *
     *  @param  authorizationEnablerSearchRecordType a <code> Type </code> 
     *          indicating an <code> AuthorizationEnabler </code> search 
     *          record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          authorizationEnablerSearchRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuthorizationEnablerSearchRecordType(org.osid.type.Type authorizationEnablerSearchRecordType);
}
