//
// org.osid.bidding.AuctionForm
//
//     The OSID Java specification for org.osid.bidding.AuctionForm.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.bidding;


/**
 *  <p>This is the form for creating and updating <code> Auctions. </code> 
 *  Like all <code> OsidForm </code> objects, various data elements may be set 
 *  here for use in the create and update methods in the <code> 
 *  AuctionAdminSession. </code> For each data element that may be set, 
 *  metadata may be examined to provide display hints or data constraints. 
 *  </p>
 */

public interface AuctionForm
    extends org.osid.OsidGovernatorForm,
            org.osid.OsidTemporalForm {


    /**
     *  Gets the metadata for the currency type. 
     *
     *  @return metadata for the currency type 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getCurrnecyTypeMetadata();


    /**
     *  Sets the currency type 
     *
     *  @param  currencyType the new currency type 
     *  @throws org.osid.InvalidArgumentException <code> currencyType </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> currencyType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setCurrencyType(org.osid.type.Type currencyType);


    /**
     *  Removes the currency type. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCurrencyType();


    /**
     *  Gets the metadata for the minimum bidders. 
     *
     *  @return metadata for the minimum bidders 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getMinimumBiddersMetadata();


    /**
     *  Sets the minimum bidders. 
     *
     *  @param  bidders the new minimum bidders 
     *  @throws org.osid.InvalidArgumentException <code> bidders </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setMinimumBidders(long bidders);


    /**
     *  Removes the minimum bidders. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMinimumBidders();


    /**
     *  Gets the metadata for the sealed flag. 
     *
     *  @return metadata for the sealed flag 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getSealedMetadata();


    /**
     *  Sets the sealed flag. 
     *
     *  @param  sealed the new sealed flag 
     *  @throws org.osid.InvalidArgumentException <code> sealed </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setSealed(boolean sealed);


    /**
     *  Removes the sealed flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSealed();


    /**
     *  Gets the metadata for the seller. 
     *
     *  @return metadata for the seller 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getSellerMetadata();


    /**
     *  Sets the seller. 
     *
     *  @param  resourceId the new resource <code> Id </code> 
     *  @throws org.osid.InvalidArgumentException <code> resourceId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setSeller(org.osid.id.Id resourceId);


    /**
     *  Removes the item. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSeller();


    /**
     *  Gets the metadata for the item. 
     *
     *  @return metadata for the item 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getItemMetadata();


    /**
     *  Sets the item. 
     *
     *  @param  resourceId the new resource <code> Id </code> 
     *  @throws org.osid.InvalidArgumentException <code> resourceId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setItem(org.osid.id.Id resourceId);


    /**
     *  Removes the item. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearItem();


    /**
     *  Gets the metadata for the lot size. 
     *
     *  @return metadata for the lot size 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getLotSizeMetadata();


    /**
     *  Sets the lot size. 
     *
     *  @param  size the new lot size 
     *  @throws org.osid.InvalidArgumentException <code> size </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setLotSize(long size);


    /**
     *  Removes the lot size. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLotSize();


    /**
     *  Gets the metadata for the item limit. 
     *
     *  @return metadata for the item limit 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getItemLimitMetadata();


    /**
     *  Sets the item limit. 
     *
     *  @param  limit the new item limit 
     *  @throws org.osid.InvalidArgumentException <code> limit </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setItemLimit(long limit);


    /**
     *  Removes the item limit. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearItemLimit();


    /**
     *  Gets the metadata for the starting price. 
     *
     *  @return metadata for the starting price 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getStartingPriceMetadata();


    /**
     *  Sets the starting price. 
     *
     *  @param  price the new starting price 
     *  @throws org.osid.InvalidArgumentException <code> price </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> price </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setStartingPrice(org.osid.financials.Currency price);


    /**
     *  Removes the starting price. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStartingPrice();


    /**
     *  Gets the metadata for the price increment. 
     *
     *  @return metadata for the price increment 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getPriceIncrementMetadata();


    /**
     *  Sets the price increment. 
     *
     *  @param  price the new price increment 
     *  @throws org.osid.InvalidArgumentException <code> price </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> price </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setPriceIncrement(org.osid.financials.Currency price);


    /**
     *  Removes the price increment. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPriceIncrement();


    /**
     *  Gets the metadata for the reserve price. 
     *
     *  @return metadata for the reserve price 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getReservePriceMetadata();


    /**
     *  Sets the reserve price. 
     *
     *  @param  price the new reserve price 
     *  @throws org.osid.InvalidArgumentException <code> price </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> price </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setReservePrice(org.osid.financials.Currency price);


    /**
     *  Removes the reserve price. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearReservePrice();


    /**
     *  Gets the metadata for the buyout price. 
     *
     *  @return metadata for the buyout price 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getBuyoutPriceMetadata();


    /**
     *  Sets the buyout price. 
     *
     *  @param  price the new buyout price 
     *  @throws org.osid.InvalidArgumentException <code> price </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> price </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setBuyoutPrice(org.osid.financials.Currency price);


    /**
     *  Removes the buyout price. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBuyoutPrice();


    /**
     *  Gets the <code> AuctionFormRecord </code> corresponding to the given 
     *  auction record <code> Type. </code> 
     *
     *  @param  auctionRecordType an auction record type 
     *  @return the auction form record 
     *  @throws org.osid.NullArgumentException <code> auctionRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(auctionRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.records.AuctionFormRecord getAuctionFormRecord(org.osid.type.Type auctionRecordType)
        throws org.osid.OperationFailedException;
}
