//
// org.osid.bidding.AuctionHouseAdminSession
//
//     The OSID Java specification for org.osid.bidding.AuctionHouseAdminSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.bidding;


/**
 *  <p>This session creates, updates, and deletes <code> AuctionHouses. 
 *  </code> The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create an 
 *  <code> AuctionHouse, </code> an <code> AuctionHouseForm </code> is 
 *  requested using <code> getAuctionHouseFormForCreate() </code> specifying 
 *  the desired record <code> Types </code> or none if no record <code> Types 
 *  </code> are needed. The returned <code> AuctionHouseForm </code> will 
 *  indicate that it is to be used with a create operation and can be used to 
 *  examine metdata or validate data prior to creation. Once the <code> 
 *  AuctionHouseForm </code> is submiited to a create operation, it cannot be 
 *  reused with another create operation unless the first operation was 
 *  unsuccessful. Each <code> AuctionHouseForm </code> corresponds to an 
 *  attempted transaction. </p> 
 *  
 *  <p> For updates, <code> AuctionHouseForms </code> are requested to the 
 *  <code> AuctionHouse </code> <code> Id </code> that is to be updated using 
 *  <code> getAuctionHouseFormForUpdate(). </code> Similarly, the <code> 
 *  AuctionHouseForm </code> has metadata about the data that can be updated 
 *  and it can perform validation before submitting the update. The <code> 
 *  AuctionHouseForm </code> can only be used once for a successful update and 
 *  cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> AuctionHouses. </code> This 
 *  session includes an <code> Id </code> aliasing mechanism to assign an 
 *  external <code> Id </code> to an internally assigned Id. </p>
 */

public interface AuctionHouseAdminSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can create <code> AuctionHouses. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating an <code> AuctionHouse. </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may not wish to offer create operations 
     *  to unauthorized users. 
     *
     *  @return <code> false </code> if <code> AuctionHouse </code> creation 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAuctionHouses();


    /**
     *  Tests if this user can create a single <code> AuctionHouse </code> 
     *  using the desired record types. While <code> 
     *  BiddingManager.getAuctionHouseRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> AuctionHouse. </code> 
     *  Providing an empty array tests if an <code> AuctionHouse </code> can 
     *  be created with no records. 
     *
     *  @param  auctionHouseRecordTypes array of auction house record types 
     *  @return <code> true </code> if <code> AuctionHouse </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> auctionHouseRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAuctionHouseWithRecordTypes(org.osid.type.Type[] auctionHouseRecordTypes);


    /**
     *  Gets the auction house form for creating new auction houses. A new 
     *  form should be requested for each create transaction. 
     *
     *  @param  auctionHouseRecordTypes array of auction house record types 
     *  @return the auction house form 
     *  @throws org.osid.NullArgumentException <code> auctionHouseRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.AuctionHouseForm getAuctionHouseFormForCreate(org.osid.type.Type[] auctionHouseRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> AuctionHouse. </code> 
     *
     *  @param  auctionHouseForm the form for this <code> AuctionHouse </code> 
     *  @return the new <code> AuctionHouse </code> 
     *  @throws org.osid.IllegalStateException <code> auctionHouseForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> auctionHouseForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> auctionHouseForm </code> 
     *          did not originate from <code> getAuctionHouseFormForCreate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.AuctionHouse createAuctionHouse(org.osid.bidding.AuctionHouseForm auctionHouseForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Auction Houses. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating an <code> AuctionHouse </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may not wish to offer update operations 
     *  to unauthorized users. 
     *
     *  @return <code> false </code> if <code> AuctionHouse </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateAuctionHouses();


    /**
     *  Gets the auction house form for updating an existing auction house. A 
     *  new auction house form should be requested for each update 
     *  transaction. 
     *
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @return the auction house form 
     *  @throws org.osid.NotFoundException <code> auctionHouseId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.AuctionHouseForm getAuctionHouseFormForUpdate(org.osid.id.Id auctionHouseId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing auction house 
     *
     *  @param  auctionHouseForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> auctionHouseForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> auctionHouseForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> auctionHouseForm </code> 
     *          did not originate from <code> getAuctionHouseFormForUpdate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateAuctionHouse(org.osid.bidding.AuctionHouseForm auctionHouseForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> AuctionHouses. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting an <code> AuctionHouse </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may not wish to offer delete operations 
     *  to unauthorized users. 
     *
     *  @return <code> false </code> if <code> AuctionHouse </code> deletion 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteAuctionHouses();


    /**
     *  Deletes an <code> AuctionHouse. </code> 
     *
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> to remove 
     *  @throws org.osid.NotFoundException <code> auctionHouseId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteAuctionHouse(org.osid.id.Id auctionHouseId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Auction Houses. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> AuctionHouse </code> aliasing 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageAuctionHouseAliases();


    /**
     *  Adds an <code> Id </code> to an <code> AuctionHouse </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> AuctionHouse </code> is determined by the provider. The new 
     *  <code> Id </code> performs as an alias to the primary <code> Id. 
     *  </code> 
     *
     *  @param  auctionHouseId the <code> Id </code> of an <code> AuctionHouse 
     *          </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> auctionHouseId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId </code> 
     *          or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasAuctionHouse(org.osid.id.Id auctionHouseId, 
                                  org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
