//
// org.osid.bidding.AuctionHouseQueryInspector
//
//     The OSID Java specification for org.osid.bidding.AuctionHouseQueryInspector.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.bidding;


/**
 *  <p>This is the query inspector interface for examining auction house 
 *  queries. </p>
 */

public interface AuctionHouseQueryInspector
    extends org.osid.OsidCatalogQueryInspector {


    /**
     *  Gets the auction <code> Id </code> query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getAuctionIdTerms();


    /**
     *  Gets the auction query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.AuctionQueryInspector[] getAuctionTerms();


    /**
     *  Gets the bid <code> Id </code> query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getBidIdTerms();


    /**
     *  Gets the bid query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.BidQueryInspector[] getBidTerms();


    /**
     *  Gets the ancestor auction house <code> Id </code> query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getAncestorAuctionHouseIdTerms();


    /**
     *  Gets the ancestor auction house query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.AuctionHouseQueryInspector[] getAncestorAuctionHouseTerms();


    /**
     *  Gets the descendant auction house <code> Id </code> query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getDescendantAuctionHouseIdTerms();


    /**
     *  Gets the descendant auction house query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.AuctionHouseQueryInspector[] getDescendantAuctionHouseTerms();


    /**
     *  Gets the auction house query inspector record corresponding to the 
     *  given <code> AuctionHouse </code> record <code> Type. </code> 
     *
     *  @param  auctionHouseRecordType an auction house record type 
     *  @return the auction house query inspector record 
     *  @throws org.osid.NullArgumentException <code> auctionHouseRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(auctionHouseRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.records.AuctionHouseQueryInspectorRecord getAuctionHouseQueryInspectorRecord(org.osid.type.Type auctionHouseRecordType)
        throws org.osid.OperationFailedException;
}
