//
// org.osid.bidding.AuctionLookupSession
//
//     The OSID Java specification for org.osid.bidding.AuctionLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.bidding;


/**
 *  <p>This session provides methods for retrieving <code> Auction </code> 
 *  objects. The <code> Auction </code> represents a fixed connection between 
 *  two <code> Items. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated auction house view: All auction methods in this session 
 *      operate, retrieve and pertain to auctions defined explicitly in the 
 *      current auction house. Using an isolated view is useful for managing 
 *      <code> Auctions </code> with the <code> AuctionAdminSession. </code> 
 *      </li> 
 *      <li> federated auction house view: All auction methods in this session 
 *      operate, retrieve and pertain to all auctions defined in this auction 
 *      house and any other auctions implicitly available in this auction 
 *      house through auction house inheritence. </li> 
 *      <li> active auction view: All auction lookup methods return active 
 *      auctions. </li> 
 *      <li> any status auction view: Active and inactive auctions are 
 *      returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedAuctionHouseView() </code> and <code> 
 *  useIsolatedAuctionHouseView() </code> behave as a radio group and one 
 *  should be selected before invoking any lookup methods. </p>
 */

public interface AuctionLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> AuctionHouse </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> AuctionHouse Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAuctionHouseId();


    /**
     *  Gets the <code> AuctionHouse </code> associated with this session. 
     *
     *  @return the auction house 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.AuctionHouse getAuctionHouse()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Auction </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupAuctions();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeAuctionView();


    /**
     *  A complete view of the <code> Auction </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryAuctionView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include auctions in auction houses which are children of this auction 
     *  house in the auction house hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedAuctionHouseView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this auction house only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedAuctionHouseView();


    /**
     *  Only active auctions are returned by methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveAuctionView();


    /**
     *  Active and inactive auctions are returned by methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusAuctionView();


    /**
     *  Gets the <code> Auction </code> specified by its <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Auction </code> may have a different <code> Id </code> than requested, 
     *  such as the case where a duplicate <code> Id </code> was assigned to 
     *  an <code> Auction </code> and retained for compatibility. 
     *  
     *  In active mode, auctions are returned that are currently active. In 
     *  any status mode, active and inactive auctions are returned. 
     *
     *  @param  auctionId <code> Id </code> of the <code> Auction </code> 
     *  @return the auction 
     *  @throws org.osid.NotFoundException <code> auctionId </code> not found 
     *  @throws org.osid.NullArgumentException <code> auctionId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.bidding.Auction getAuction(org.osid.id.Id auctionId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AuctionList </code> corresponding to the given <code> 
     *  IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  auctions specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Auctions </code> may be omitted from the list and 
     *  may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In active mode, auctions are returned that are currently active. In 
     *  any status mode, active and inactive auctions are returned. 
     *
     *  @param  auctionIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Auction </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> auctionIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.AuctionList getAuctionsByIds(org.osid.id.IdList auctionIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AuctionList </code> corresponding to the given auction 
     *  genus <code> Type </code> which does not include auctions of genus 
     *  types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  auctions or an error results. Otherwise, the returned list may contain 
     *  only those auctions that are accessible through this session. 
     *  
     *  In active mode, auctions are returned that are currently active. In 
     *  any status mode, active and inactive auctions are returned. 
     *
     *  @param  auctionGenusType an auction genus type 
     *  @return the returned <code> Auction </code> list 
     *  @throws org.osid.NullArgumentException <code> auctionGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.AuctionList getAuctionsByGenusType(org.osid.type.Type auctionGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AuctionList </code> corresponding to the given auction 
     *  genus <code> Type </code> and include any additional auctions with 
     *  genus types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  auctions or an error results. Otherwise, the returned list may contain 
     *  only those auctions that are accessible through this session. 
     *  
     *  In active mode, auctions are returned that are currently active. In 
     *  any status mode, active and inactive auctions are returned. 
     *
     *  @param  auctionGenusType an auction genus type 
     *  @return the returned <code> Auction </code> list 
     *  @throws org.osid.NullArgumentException <code> auctionGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.AuctionList getAuctionsByParentGenusType(org.osid.type.Type auctionGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AuctionList </code> containing the given auction record 
     *  <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  auctions or an error results. Otherwise, the returned list may contain 
     *  only those auctions that are accessible through this session. 
     *  
     *  In active mode, auctions are returned that are currently active. In 
     *  any status mode, active and inactive auctions are returned. 
     *
     *  @param  auctionRecordType an auction record type 
     *  @return the returned <code> Auction </code> list 
     *  @throws org.osid.NullArgumentException <code> auctionRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.AuctionList getAuctionsByRecordType(org.osid.type.Type auctionRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AuctionList </code> from the given provider. 
     *  
     *  In plenary mode, the returned list contains all known auctions or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  auctions that are accessible through this session. 
     *  
     *  In active mode, auctions are returned that are currently active. In 
     *  any status mode, active and inactive auctions are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @return the returned <code> Auction </code> list 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.AuctionList getAuctionsByProvider(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AuctionList </code> effective during the entire given 
     *  date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known auctions or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  auctions that are accessible through this session. 
     *  
     *  In active mode, auctions are returned that are currently active. In 
     *  any status mode, active and inactive auctions are returned. 
     *
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Auction </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.AuctionList getAuctionsOnDate(org.osid.calendaring.DateTime from, 
                                                          org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of auctions for an item. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  auctions or an error results. Otherwise, the returned list may contain 
     *  only those auctions that are accessible through this session. 
     *  
     *  In active mode, auctions are returned that are currently active. In 
     *  any status mode, active and inactive auctions are returned. 
     *
     *  @param  itemId a resource <code> Id </code> 
     *  @return the returned <code> Auction </code> list 
     *  @throws org.osid.NullArgumentException <code> itemId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.AuctionList getAuctionsByItem(org.osid.id.Id itemId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of auctions for an item genus type. 
     *  
     *  In plenary mode, the returned list contains all known auctions or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  auctions that are accessible through this session. 
     *  
     *  In active mode, auctions are returned that are currently active. In 
     *  any status mode, active and inactive auctions are returned. 
     *
     *  @param  itemGenusType an item genus type 
     *  @return the returned <code> Auction </code> list 
     *  @throws org.osid.NullArgumentException <code> itemGenusType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.AuctionList getAuctionsByItemGenusType(org.osid.type.Type itemGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AuctionList </code> for an item genus type and 
     *  effective during the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known auctions or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  auctions that are accessible through this session. 
     *  
     *  In active mode, auctions are returned that are currently active. In 
     *  any status mode, active and inactive auctions are returned. 
     *
     *  @param  itemGenusType an item genus type 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Auction </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> itemGenusType, from, 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.AuctionList getAuctionsByItemGenusTypeOnDate(org.osid.type.Type itemGenusType, 
                                                                         org.osid.calendaring.DateTime from, 
                                                                         org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Auctions. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  auctions or an error results. Otherwise, the returned list may contain 
     *  only those auctions that are accessible through this session. 
     *  
     *  In active mode, auctions are returned that are currently active. In 
     *  any status mode, active and inactive auctions are returned. 
     *
     *  @return a list of <code> Auctions </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.AuctionList getAuctions()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
