//
// org.osid.bidding.AuctionSearchSession
//
//     The OSID Java specification for org.osid.bidding.AuctionSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.bidding;


/**
 *  <p>This session provides methods for searching among <code> Auction 
 *  </code> objects. The search query is constructed using the <code> 
 *  AuctionQuery. </code> </p> 
 *  
 *  <p> <code> getAuctionsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Auctions. </code> A more advanced search may be 
 *  performed with <code> getAuctionsBySearch(). </code> It accepts an <code> 
 *  AuctionSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getAuctionsBySearch() </code> returns an <code> 
 *  AuctionSearchResults </code> that can be used to access the resulting 
 *  <code> AuctionList </code> or be used to perform a search within the 
 *  result set through <code> AuctionSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated auction house view: searches include auctions in 
 *      auction houses of which this auction house is an ancestor in the 
 *      auction house hierarchy </li> 
 *      <li> isolated auction house view: searches are restricted to auctions 
 *      in this auction house </li> 
 *  </ul>
 *  
 *  
 *  <p> Auctions may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> AuctionQuery. </code> 
 *  </p>
 */

public interface AuctionSearchSession
    extends org.osid.bidding.AuctionQuerySession {


    /**
     *  Gets an auction search. 
     *
     *  @return the auction search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.AuctionSearch getAuctionSearch();


    /**
     *  Gets an auction search order. The <code> AuctionSearchOrder </code> is 
     *  supplied to an <code> AuctionSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the auction search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.AuctionSearchOrder getAuctionSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  auctionQuery the auction query 
     *  @param  auctionSearch the auction search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> auctionQuery </code> or 
     *          <code> auctionSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> auctionQuery </code> or 
     *          <code> auctionSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.AuctionSearchResults getAuctionsBySearch(org.osid.bidding.AuctionQuery auctionQuery, 
                                                                     org.osid.bidding.AuctionSearch auctionSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an auction query from an inspector. The inspector is available 
     *  from an <code> AuctionSearchResults. </code> 
     *
     *  @param  auctionQueryInspector an auction query inspector 
     *  @return the auction query 
     *  @throws org.osid.NullArgumentException <code> auctionQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> auctionQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.AuctionQuery getAuctionQueryFromInspector(org.osid.bidding.AuctionQueryInspector auctionQueryInspector);
}
