//
// org.osid.bidding.Bid
//
//     The OSID Java specification for org.osid.bidding.Bid.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.bidding;


/**
 *  <p>A <code> Bid </code> represents a bid for an item at an auction. </p>
 */

public interface Bid
    extends org.osid.OsidRelationship {


    /**
     *  Gets the <code> Id </code> of the auction. 
     *
     *  @return the auction <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAuctionId();


    /**
     *  Gets the auction. 
     *
     *  @return the auction 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.Auction getAuction()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of the bidder. 
     *
     *  @return the resource <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBidderId();


    /**
     *  Gets the bidder. 
     *
     *  @return the resource 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getBidder()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of the bidding agent. 
     *
     *  @return the agent <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBiddingAgentId();


    /**
     *  Gets the bidding agent. 
     *
     *  @return the agent 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.Agent getBiddingAgent()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the quantity of items in this bid. 
     *
     *  @return the quantity of items 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getQuantity();


    /**
     *  Gets the current bid amount. 
     *
     *  @return the current bid 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.Currency getCurrentBid();


    /**
     *  Gets the maximum bid. For some auctions, the current bid is the 
     *  maximum bid. For others, the current bid may be less then the maximum 
     *  bid and automatically increment when greater bids are made up to the 
     *  maximum bid. 
     *
     *  @return the maximum bid 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.Currency getMaximumBid();


    /**
     *  Tests if this was a winning bid. 
     *
     *  @return <code> true </code> if this was a winnign bid, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isWinner();


    /**
     *  Gets the settlement amount owed from the bidder. 
     *
     *  @return the settlement amount 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.Currency getSettlementAmount();


    /**
     *  Gets the bid record corresponding to the given <code> Bid </code> 
     *  record <code> Type. </code> This method is used to retrieve an object 
     *  implementing the requested record. The <code> bidRecordType </code> 
     *  may be the <code> Type </code> returned in <code> getRecordTypes() 
     *  </code> or any of its parents in a <code> Type </code> hierarchy where 
     *  <code> hasRecordType(bidRecordType) </code> is <code> true </code> . 
     *
     *  @param  bidRecordType the type of bid record to retrieve 
     *  @return the bid record 
     *  @throws org.osid.NullArgumentException <code> bidRecordType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(bidRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.records.BidRecord getBidRecord(org.osid.type.Type bidRecordType)
        throws org.osid.OperationFailedException;
}
