//
// org.osid.bidding.BidAuctionHouseAssignmentSession
//
//     The OSID Java specification for org.osid.bidding.BidAuctionHouseAssignmentSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.bidding;


/**
 *  <p>This session provides methods to re-assign <code> Bids </code> to 
 *  <code> AuctionHouse </code> mappings. A <code> Bid </code> may appear in 
 *  multiple <code> AuctionHouse </code> objects and removing the last 
 *  reference to a <code> Bid </code> is the equivalent of deleting it. Each 
 *  <code> AuctionHouse </code> may have its own authorizations governing who 
 *  is allowed to operate on it. </p> 
 *  
 *  <p> Adding a reference of a <code> Bid </code> to another <code> 
 *  AuctionHouse </code> is not a copy operation (eg: does not change its 
 *  <code> Id </code> ). </p>
 */

public interface BidAuctionHouseAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter bid/auction house mappings. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known item methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignBids();


    /**
     *  Tests if this user can alter bid/auction house mappings. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known item methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignBidsToAuctionHouse(org.osid.id.Id auctionHouseId);


    /**
     *  Gets a list of auction houses including and under the given auction 
     *  house node in which any bid can be assigned. 
     *
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @return list of assignable auction house <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableAuctionHouseIds(org.osid.id.Id auctionHouseId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of auction houses including and under the given auction 
     *  house node in which a specific bid can be assigned. 
     *
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @param  bidId the <code> Id </code> of the <code> Bid </code> 
     *  @return list of assignable auction house <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId </code> 
     *          or <code> bidId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableAuctionHouseIdsForBid(org.osid.id.Id auctionHouseId, 
                                                                 org.osid.id.Id bidId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> Bid </code> to an <code> AuctionHouse. </code> 
     *
     *  @param  bidId the <code> Id </code> of the <code> Bid </code> 
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @throws org.osid.AlreadyExistsException <code> bidId </code> is 
     *          already assigned tio <code> auctionHouseId </code> 
     *  @throws org.osid.NotFoundException <code> bidId </code> or <code> 
     *          auctionHouseId </code> not found 
     *  @throws org.osid.NullArgumentException <code> bidId </code> or <code> 
     *          auctionHouseId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignBidToAuctionHouse(org.osid.id.Id bidId, 
                                        org.osid.id.Id auctionHouseId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> Bid </code> from an <code> AuctionHouse. </code> 
     *
     *  @param  bidId the <code> Id </code> of the <code> Bid </code> 
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @throws org.osid.NotFoundException <code> bidId </code> or <code> 
     *          auctionHouseId </code> not found or <code> bidId </code> not 
     *          assigned to <code> auctionHouseId </code> 
     *  @throws org.osid.NullArgumentException <code> bidId </code> or <code> 
     *          auctionHouseId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignBidFromAuctionHouse(org.osid.id.Id bidId, 
                                            org.osid.id.Id auctionHouseId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Moves a <code> Bid </code> from one <code> AuctionHouse </code> to 
     *  another. Mappings to other <code> AuctionHouses </code> are 
     *  unaffected. 
     *
     *  @param  bidId the <code> Id </code> of the <code> Bid </code> 
     *  @param  fromAuctionHouseId the <code> Id </code> of the current <code> 
     *          AuctionHouse </code> 
     *  @param  toAuctionHouseId the <code> Id </code> of the destination 
     *          <code> AuctionHouse </code> 
     *  @throws org.osid.NotFoundException <code> bidId, fromAuctionHouseId, 
     *          </code> or <code> toAuctionHouseId </code> not found or <code> 
     *          bidId </code> not mapped to <code> fromAuctionHouseId </code> 
     *  @throws org.osid.NullArgumentException <code> bidId, 
     *          fromAuctionHouseId, </code> or <code> toAuctionHouseId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void reassignBidToAuctionHouse(org.osid.id.Id bidId, 
                                          org.osid.id.Id fromAuctionHouseId, 
                                          org.osid.id.Id toAuctionHouseId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
