//
// org.osid.bidding.BidLookupSession
//
//     The OSID Java specification for org.osid.bidding.BidLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.bidding;


/**
 *  <p>This session provides methods for retrieving <code> Bid </code> 
 *  relationships. </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated auction house view: All bid methods in this session 
 *      operate, retrieve and pertain to bids defined explicitly in the 
 *      current auction house. Using an isolated view is useful for managing 
 *      <code> Bids </code> with the <code> BidAdminSession. </code> </li> 
 *      <li> federated auction house view: All bid methods in this session 
 *      operate, retrieve and pertain to all bids defined in this auction 
 *      house and any other bids implicitly available in this auction house 
 *      through auction house inheritence. </li> 
 *      <li> effective bid view: All bid lookup methods return bids where the 
 *      current date falls in between the effective dates inclusive. </li> 
 *      <li> any effective bid view: Bids of any effective date are returned 
 *      from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedAuctionHouseView() </code> and <code> 
 *  useIsolatedAuctionHouseView() </code> behave as a radio group and one 
 *  should be selected before invoking any lookup methods. </p>
 */

public interface BidLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> AuctionHouse </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> AuctionHouse Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAuctionHouseId();


    /**
     *  Gets the <code> AuctionHouse </code> associated with this session. 
     *
     *  @return the auction house 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.AuctionHouse getAuctionHouse()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Bid </code> lookups. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupBids();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeBidView();


    /**
     *  A complete view of the <code> Bid </code> returns is desired. Methods 
     *  will return what is requested or result in an error. This view is used 
     *  when greater precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryBidView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include bids in auction houses which are children of this auction 
     *  house in the auction house hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedAuctionHouseView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this auction house only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedAuctionHouseView();


    /**
     *  Only bids whose effective dates are current are returned by methods in 
     *  this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useEffectiveBidView();


    /**
     *  All bids of any effective dates are returned by methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyEffectiveBidView();


    /**
     *  Gets the <code> Bid </code> specified by its <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Bid </code> may have a different <code> Id </code> than requested, 
     *  such as the case where a duplicate <code> Id </code> was assigned to a 
     *  <code> Bid </code> and retained for compatibility. 
     *  
     *  In effective mode, bids are returned that are currently effective. In 
     *  any effective mode, effective bids and those currently expired are 
     *  returned. 
     *
     *  @param  bidId <code> Id </code> of the <code> Bid </code> 
     *  @return the bid 
     *  @throws org.osid.NotFoundException <code> bidId </code> not found 
     *  @throws org.osid.NullArgumentException <code> bidId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.bidding.Bid getBid(org.osid.id.Id bidId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BidList </code> corresponding to the given <code> 
     *  IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  bids specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Bids </code> may be omitted from the list and may 
     *  present the elements in any order including returning a unique set. 
     *  
     *  In effective mode, bids are returned that are currently effective. In 
     *  any effective mode, effective bids and those currently expired are 
     *  returned. 
     *
     *  @param  bidIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Bid </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> bidIds </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.BidList getBidsByIds(org.osid.id.IdList bidIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BidList </code> corresponding to the given bid genus 
     *  <code> Type </code> which does not include bids of genus types derived 
     *  from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  bids or an error results. Otherwise, the returned list may contain 
     *  only those bids that are accessible through this session. 
     *  
     *  In effective mode, bids are returned that are currently effective. In 
     *  any effective mode, effective bids and those currently expired are 
     *  returned. 
     *
     *  @param  bidGenusType a bid genus type 
     *  @return the returned <code> Bid </code> list 
     *  @throws org.osid.NullArgumentException <code> bidGenusType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.BidList getBidsByGenusType(org.osid.type.Type bidGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BidList </code> corresponding to the given bid genus 
     *  <code> Type </code> and include any additional bids with genus types 
     *  derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  bids or an error results. Otherwise, the returned list may contain 
     *  only those bids that are accessible through this session. 
     *  
     *  In effective mode, bids are returned that are currently effective. In 
     *  any effective mode, effective bids and those currently expired are 
     *  returned. 
     *
     *  @param  bidGenusType a bid genus type 
     *  @return the returned <code> Bid </code> list 
     *  @throws org.osid.NullArgumentException <code> bidGenusType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.BidList getBidsByParentGenusType(org.osid.type.Type bidGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BidList </code> containing the given bid record <code> 
     *  Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  bids or an error results. Otherwise, the returned list may contain 
     *  only those bids that are accessible through this session. 
     *  
     *  In effective mode, bids are returned that are currently effective. In 
     *  any effective mode, effective bids and those currently expired are 
     *  returned. 
     *
     *  @param  bidRecordType a bid record type 
     *  @return the returned <code> Bid </code> list 
     *  @throws org.osid.NullArgumentException <code> bidRecordType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.BidList getBidsByRecordType(org.osid.type.Type bidRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BidList </code> effective during the entire given date 
     *  range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known bids or an error 
     *  results. Otherwise, the returned list may contain only those bids that 
     *  are accessible through this session. 
     *  
     *  In effective mode, bids are returned that are currently effective. In 
     *  any effective mode, effective bids and those currently expired are 
     *  returned. 
     *
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Bid </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.BidList getBidsOnDate(org.osid.calendaring.DateTime from, 
                                                  org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of bids for an auction. 
     *  
     *  In plenary mode, the returned list contains all known auctions or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  auctions that are accessible through this session. 
     *  
     *  In effective mode, bids are returned that are currently effective. In 
     *  any effective mode, effective bids and those currently expired are 
     *  returned. 
     *
     *  @param  auctionId an auction <code> Id </code> 
     *  @return the returned <code> Bid </code> list 
     *  @throws org.osid.NullArgumentException <code> auctionId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.BidList getBidsForAuction(org.osid.id.Id auctionId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of bids for an auction and effective during the entire 
     *  given date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known bids or an error 
     *  results. Otherwise, the returned list may contain only those bids that 
     *  are accessible through this session. 
     *  
     *  In effective mode, bids are returned that are currently effective. In 
     *  any effective mode, effective bids and those currently expired are 
     *  returned. 
     *
     *  @param  auctionId an auction <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Bid </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> auctionId, from, </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.BidList getBidsForAuctionOnDate(org.osid.id.Id auctionId, 
                                                            org.osid.calendaring.DateTime from, 
                                                            org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of bids for a bidder. 
     *  
     *  In plenary mode, the returned list contains all known bids or an error 
     *  results. Otherwise, the returned list may contain only those bids that 
     *  are accessible through this session. 
     *  
     *  In effective mode, bids are returned that are currently effective. In 
     *  any effective mode, effective bids and those currently expired are 
     *  returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @return the returned C <code> ommission </code> list 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.BidList getBidsForBidder(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of bids for a bidder and effective during the entire given 
     *  date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known bids or an error 
     *  results. Otherwise, the returned list may contain only those bids that 
     *  are accessible through this session. 
     *  
     *  In effective mode, bids are returned that are currently effective. In 
     *  any effective mode, effective bids and those currently expired are 
     *  returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned C <code> ommission </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, from, 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.BidList getBidsForBidderOnDate(org.osid.id.Id resourceId, 
                                                           org.osid.calendaring.DateTime from, 
                                                           org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of bids for an auction and bidder. 
     *  
     *  In plenary mode, the returned list contains all known bids or an error 
     *  results. Otherwise, the returned list may contain only those bids that 
     *  are accessible through this session. 
     *  
     *  In effective mode, bids are returned that are currently effective. In 
     *  any effective mode, effective bids and those currently expired are 
     *  returned. 
     *
     *  @param  auctionId an auction <code> Id </code> 
     *  @param  resourceId a resource <code> Id </code> 
     *  @return the returned C <code> ommission </code> list 
     *  @throws org.osid.NullArgumentException <code> auctionId </code> or 
     *          <code> resourceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.BidList getBidsForAuctionAndBidder(org.osid.id.Id auctionId, 
                                                               org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of bids for an auction and bidder and effective during the 
     *  entire given date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known bids or an error 
     *  results. Otherwise, the returned list may contain only those bids that 
     *  are accessible through this session. 
     *  
     *  In effective mode, bids are returned that are currently effective. In 
     *  any effective mode, effective bids and those currently expired are 
     *  returned. 
     *
     *  @param  auctionId an auction <code> Id </code> 
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned C <code> ommission </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> auctionId, resourceId, 
     *          from, </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.BidList getBidsForAuctionAndBidderOnDate(org.osid.id.Id auctionId, 
                                                                     org.osid.id.Id resourceId, 
                                                                     org.osid.calendaring.DateTime from, 
                                                                     org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all winning <code> Bids. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  bids or an error results. Otherwise, the returned list may contain 
     *  only those bids that are accessible through this session. In both 
     *  cases, the order of the set is by start effective date. 
     *  
     *  In effective mode, bids are returned that are currently effective. In 
     *  any effective mode, effective bids and those currently expired are 
     *  returned. 
     *
     *  @return a list of <code> Bids </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.BidList getWinningBids()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all winning bids effective during the entire given date 
     *  range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known bids or an error 
     *  results. Otherwise, the returned list may contain only those bids that 
     *  are accessible through this session. In both cases, the order of the 
     *  set is by the start of the effective date. 
     *  
     *  In effective mode, bids are returned that are currently effective. In 
     *  any effective mode, effective bids and those currently expired are 
     *  returned. 
     *
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Bid </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.BidList getWinningBidsOnDate(org.osid.calendaring.DateTime from, 
                                                         org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all winning bids for an auction. 
     *  
     *  In plenary mode, the returned list contains all known auctions or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  auctions that are accessible through this session. 
     *  
     *  In effective mode, bids are returned that are currently effective. In 
     *  any effective mode, effective bids and those currently expired are 
     *  returned. 
     *
     *  @param  auctionId an auction <code> Id </code> 
     *  @return the returned <code> Bid </code> list 
     *  @throws org.osid.NullArgumentException <code> auctionId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.BidList getWinningBidsForAuction(org.osid.id.Id auctionId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of winning bids for an auction and effectiveduring the 
     *  entire given date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known bids or an error 
     *  results. Otherwise, the returned list may contain only those bids that 
     *  are accessible through this session. 
     *  
     *  In effective mode, bids are returned that are currently effective. In 
     *  any effective mode, effective bids and those currently expired are 
     *  returned. 
     *
     *  @param  auctionId an auction <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Bid </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> auctionId, from, </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.BidList getWinningBidsForAuctionOnDate(org.osid.id.Id auctionId, 
                                                                   org.osid.calendaring.DateTime from, 
                                                                   org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all winning bids for a bidder. 
     *  
     *  In plenary mode, the returned list contains all known auctions or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  auctions that are accessible through this session. 
     *  
     *  In effective mode, bids are returned that are currently effective. In 
     *  any effective mode, effective bids and those currently expired are 
     *  returned. 
     *
     *  @param  resourceId a resourceId <code> Id </code> 
     *  @return the returned <code> Bid </code> list 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.BidList getWinningBidsForBidder(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of winning bids for a bidder and effective during the 
     *  entire given date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known bids or an error 
     *  results. Otherwise, the returned list may contain only those bids that 
     *  are accessible through this session. 
     *  
     *  In effective mode, bids are returned that are currently effective. In 
     *  any effective mode, effective bids and those currently expired are 
     *  returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned C <code> ommission </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, from, 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.BidList getWinningBidsForBidderOnDate(org.osid.id.Id resourceId, 
                                                                  org.osid.calendaring.DateTime from, 
                                                                  org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Bids. </code> 
     *  
     *  In plenary mode, the returned list contains all known bids or an error 
     *  results. Otherwise, the returned list may contain only those bids that 
     *  are accessible through this session. 
     *  
     *  In effective mode, bids are returned that are currently effective. In 
     *  any effective mode, effective bids and those currently expired are 
     *  returned. 
     *
     *  @return a list of <code> Bids </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.BidList getBids()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
