//
// org.osid.bidding.BiddingManager
//
//     The OSID Java specification for org.osid.bidding.BiddingManager.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.bidding;


/**
 *  <p>The bidding manager provides access to rules sessions and provides 
 *  interoperability tests for various aspects of this service. The sessions 
 *  included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> MyAuctionSession: </code> a session to look up auctions 
 *      for authenticated agent </li> 
 *      <li> <code> MyAuctionNotificationSession: </code> a session to receive 
 *      notifications about an auction in progress for the the authenticated 
 *      agent </li> 
 *      <li> <code> AuctionLookupSession: </code> a session to retrieve 
 *      auctions </li> 
 *      <li> <code> AuctionQuerySession: </code> a session to query for 
 *      auctions </li> 
 *      <li> <code> AuctionSearchSession: </code> a session to search for 
 *      auctions </li> 
 *      <li> <code> AuctionAdminSession: </code> a session to create and 
 *      delete auctions </li> 
 *      <li> <code> AuctionNotificationSession: </code> a session to receive 
 *      notifications pertaining to auction changes </li> 
 *      <li> <code> AuctionAuctionHouseSession: </code> a session to look up 
 *      auction auction house mappings </li> 
 *      <li> <code> AuctionAuctionHouseAssignmentSession: </code> a session to 
 *      manage auctions to auction house mappings </li> 
 *      <li> <code> AuctionSmartAuctionHouseSession: </code> a session to 
 *      manage dynamic auction houses of auctions </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> BidLookupSession: </code> a session to retrieve bids </li> 
 *      <li> <code> BidQuerySession: </code> a session to query for bids </li> 
 *      <li> <code> BidSearchSession: </code> a session to search for bids 
 *      </li> 
 *      <li> <code> BidAdminSession: </code> a session to create and delete 
 *      bids </li> 
 *      <li> <code> BidNotificationSession: </code> a session to receive 
 *      notifications pertaining to bid changes </li> 
 *      <li> <code> BidAuctionHouseSession: </code> a session to look up bid 
 *      auction house mappings </li> 
 *      <li> <code> BidAuctionHouseAssignmentSession: </code> a session to 
 *      manage bid to auction house mappings </li> 
 *      <li> <code> BidSmartAuctionHouseSession: </code> a session to manage 
 *      dynamic auction houses of bids </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> AuctionHouseLookupSession: </code> a session to retrieve 
 *      auction houses </li> 
 *      <li> <code> AuctionHouseQuerySession: </code> a session to search for 
 *      auction houses </li> 
 *      <li> <code> AuctionHouseSearchSession: </code> a session to search for 
 *      auction houses </li> 
 *      <li> <code> AuctionHouseAdminSession: </code> a session to create and 
 *      delete auction houses </li> 
 *      <li> <code> AuctionHouseNotificationSession: </code> a session to 
 *      receive notifications pertaining to auction house changes </li> 
 *      <li> <code> AuctionHouseHierarchySession: </code> a session to 
 *      traverse a hierarchy of auction house </li> 
 *      <li> <code> AuctionHouseHierarchyDesignSession: </code> a session to 
 *      manage a auction house hierarchy </li> 
 *  </ul>
 *  
 */

public interface BiddingManager
    extends org.osid.OsidManager,
            org.osid.bidding.BiddingProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the my auction 
     *  service. 
     *
     *  @return a <code> MyAuctionSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsMyAuction() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMyAuction() </code> is <code> true. </code> 
     */

    public org.osid.bidding.MyAuctionSession getMyAuctionSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the my auction 
     *  service for the given auction house. 
     *
     *  @param  auctionHouseId the <code> Id </code> of the auction house 
     *  @return a <code> MyAuctionSession </code> 
     *  @throws org.osid.NotFoundException no <code> AuctionHouse </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsMyAuction() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMyAuction() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.bidding.MyAuctionSession getMyAuctionSessionForAuctionHouse(org.osid.id.Id auctionHouseId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the my auction 
     *  notification service. 
     *
     *  @param  myAuctionReceiver the notification callback 
     *  @return a <code> MyAuctionNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> myAuctionReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsMyAuctionNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMyAuctionNotification() </code> is <code> true 
     *              </code> 
     */

    public org.osid.bidding.MyAuctionNotificationSession getMyAuctionNotificationSession(org.osid.bidding.MyAuctionReceiver myAuctionReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the my auction 
     *  notification service for the given auction house. 
     *
     *  @param  myAuctionReceiver the notification callback 
     *  @param  auctionHouseId the <code> Id </code> of the auction house 
     *  @return a <code> MyAuctionNotificationSession </code> 
     *  @throws org.osid.NotFoundException no <code> AuctionHouse </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> myAuctionReceiver 
     *          </code> or <code> auctionHouseId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsMyAuctionNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMyAuctionNotification() </code> is <code> true 
     *              </code> 
     */

    public org.osid.bidding.MyAuctionNotificationSession getMyAuctionNotificationSessionForAuctionHouse(org.osid.bidding.MyAuctionReceiver myAuctionReceiver, 
                                                                                                        org.osid.id.Id auctionHouseId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction lookup 
     *  service. 
     *
     *  @return an <code> AuctionLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAuctionLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionLookup() </code> is <code> true. </code> 
     */

    public org.osid.bidding.AuctionLookupSession getAuctionLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction lookup 
     *  service for the given auction house. 
     *
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @return an <code> AuctionLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> AuctionHouse </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAuctionLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.bidding.AuctionLookupSession getAuctionLookupSessionForAuctionHouse(org.osid.id.Id auctionHouseId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction query 
     *  service. 
     *
     *  @return an <code> AuctionQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAuctionQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionQuery() </code> is <code> true. </code> 
     */

    public org.osid.bidding.AuctionQuerySession getAuctionQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction query 
     *  service for the given auction house. 
     *
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @return an <code> AuctionQuerySession </code> 
     *  @throws org.osid.NotFoundException no auction house found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAuctionQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.bidding.AuctionQuerySession getAuctionQuerySessionForAuctionHouse(org.osid.id.Id auctionHouseId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction search 
     *  service. 
     *
     *  @return an <code> AuctionSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAuctionSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionSearch() </code> is <code> true. </code> 
     */

    public org.osid.bidding.AuctionSearchSession getAuctionSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction search 
     *  service for the given auction house. 
     *
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @return an <code> AuctionSearchSession </code> 
     *  @throws org.osid.NotFoundException no auction house found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAuctionSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.bidding.AuctionSearchSession getAuctionSearchSessionForAuctionHouse(org.osid.id.Id auctionHouseId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  administration service. 
     *
     *  @return an <code> AuctionAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAuctionAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionAdmin() </code> is <code> true. </code> 
     */

    public org.osid.bidding.AuctionAdminSession getAuctionAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  administration service for the given auction house. 
     *
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @return an <code> AuctionAdminSession </code> 
     *  @throws org.osid.NotFoundException no auction house found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAuctionAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.bidding.AuctionAdminSession getAuctionAdminSessionForAuctionHouse(org.osid.id.Id auctionHouseId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  notification service. 
     *
     *  @param  auctionReceiver the notification callback 
     *  @return an <code> AuctionNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> auctionReceiver </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.bidding.AuctionNotificationSession getAuctionNotificationSession(org.osid.bidding.AuctionReceiver auctionReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  notification service for the given auction house. 
     *
     *  @param  auctionReceiver the notification callback 
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @return an <code> AuctionNotificationSession </code> 
     *  @throws org.osid.NotFoundException no auction house found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> auctionReceiver </code> 
     *          or <code> auctionHouseId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.bidding.AuctionNotificationSession getAuctionNotificationSessionForAuctionHouse(org.osid.bidding.AuctionReceiver auctionReceiver, 
                                                                                                    org.osid.id.Id auctionHouseId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup auction/auctionHouse 
     *  mappings. 
     *
     *  @return an <code> AuctionAuctionHouseSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionAuctionHouse() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionAuctionHouse() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.bidding.AuctionAuctionHouseSession getAuctionAuctionHouseSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning auctions 
     *  to auction houses. 
     *
     *  @return an <code> AuctionAuctionHouseAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionAuctionHouseAssignment() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionAuctionHouseAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.bidding.AuctionAuctionHouseAssignmentSession getAuctionAuctionHouseAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage auction smart auction 
     *  houses. 
     *
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @return an <code> AuctionSmartAuctionHouseSession </code> 
     *  @throws org.osid.NotFoundException no auction house found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionSmartAuctionHouse() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionSmartAuctionHouse() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.bidding.AuctionAuctionHouseSession getAuctionSmartAuctionHouseSession(org.osid.id.Id auctionHouseId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the bid lookup 
     *  service. 
     *
     *  @return a <code> BidLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBidLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBidLookup() </code> is <code> true. </code> 
     */

    public org.osid.bidding.BidLookupSession getBidLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the bid lookup 
     *  service for the given auction house. 
     *
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @return a <code> BidLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> AuctionHouse </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBidLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBidLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.bidding.BidLookupSession getBidLookupSessionForAuctionHouse(org.osid.id.Id auctionHouseId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the bid query 
     *  service. 
     *
     *  @return a <code> BidQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBidQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBidQuery() </code> is <code> true. </code> 
     */

    public org.osid.bidding.BidQuerySession getBidQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the bid query 
     *  service for the given auction house. 
     *
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @return a <code> CBidQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> AuctionHouse </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBidQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBidQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.bidding.BidQuerySession getBidQuerySessionForAuctionHouse(org.osid.id.Id auctionHouseId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the bid search 
     *  service. 
     *
     *  @return a <code> BidSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBidSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBidSearch() </code> is <code> true. </code> 
     */

    public org.osid.bidding.BidSearchSession getBidSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the bid search 
     *  service for the given auction house. 
     *
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @return a <code> BidSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> AuctionHouse </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBidSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBidSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.bidding.BidSearchSession getBidSearchSessionForAuctionHouse(org.osid.id.Id auctionHouseId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the bid 
     *  administrative service. 
     *
     *  @return a <code> BidAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBidAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBidAdmin() </code> is <code> true. </code> 
     */

    public org.osid.bidding.BidAdminSession getBidAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the bid 
     *  administrative service for the given auction house. 
     *
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @return a <code> BidAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> AuctionHouse </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBidAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBidAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.bidding.BidAdminSession getBidAdminSessionForAuction(org.osid.id.Id auctionHouseId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the bid 
     *  notification service. 
     *
     *  @param  bidReceiver the notification callback 
     *  @return a <code> BidNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> bidReceiver </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBidNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBidNotification() </code> is <code> true. </code> 
     */

    public org.osid.bidding.BidNotificationSession getBidNotificationSession(org.osid.bidding.BidReceiver bidReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the bid 
     *  notification service for the given auction house. 
     *
     *  @param  bidReceiver the notification callback 
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @return a <code> BidNotificationSession </code> 
     *  @throws org.osid.NotFoundException no auction house found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> bidReceiver </code> or 
     *          <code> auctionHouseId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBidNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBidNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.bidding.BidNotificationSession getBidNotificationSessionForAuctionHouse(org.osid.bidding.BidReceiver bidReceiver, 
                                                                                            org.osid.id.Id auctionHouseId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup bid/auctionHouse 
     *  mappings. 
     *
     *  @return a <code> BidAuctionHouseSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBidAuctionHouse() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBidyAuctionHouse() </code> is <code> true. </code> 
     */

    public org.osid.bidding.BidAuctionHouseSession getBidAuctionHouseSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning 
     *  competencies to auction houses. 
     *
     *  @return a <code> BidyAuctionHouseAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBidAuctionHouseAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBidAuctionHouseAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.bidding.BidAuctionHouseAssignmentSession getBidAuctionHouseAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage bid smart auction 
     *  houses. 
     *
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @return a <code> BidSmartAuctionHouseSession </code> 
     *  @throws org.osid.NotFoundException no <code> AuctionHouse </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBidSmartAuctionHouse() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBidSmartAuctionHouse() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.bidding.BidSmartAuctionHouseSession getBidSmartAuctionHouseSession(org.osid.id.Id auctionHouseId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction house 
     *  lookup service. 
     *
     *  @return a <code> AuctionHouseLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionHouseLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionHouseLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.bidding.AuctionHouseLookupSession getAuctionHouseLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction house 
     *  query service. 
     *
     *  @return a <code> AuctionHouseQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionHouseQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionHouseQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.bidding.AuctionHouseQuerySession getAuctionHouseQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction house 
     *  search service. 
     *
     *  @return a <code> AuctionHouseSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionHouseSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionHouseSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.bidding.AuctionHouseSearchSession getAuctionHouseSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction house 
     *  administrative service. 
     *
     *  @return a <code> AuctionHouseAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionHouseAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionHouseAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.bidding.AuctionHouseAdminSession getAuctionHouseAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction house 
     *  notification service. 
     *
     *  @param  auctionHouseReceiver the notification callback 
     *  @return a <code> AuctionHouseNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> auctionHouseReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionHouseNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionHouseNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.bidding.AuctionHouseNotificationSession getAuctionHouseNotificationSession(org.osid.bidding.AuctionHouseReceiver auctionHouseReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction house 
     *  hierarchy service. 
     *
     *  @return a <code> AuctionHouseHierarchySession </code> for auction 
     *          houses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionHouseHierarchy() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionHouseHierarchy() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.bidding.AuctionHouseHierarchySession getAuctionHouseHierarchySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction house 
     *  hierarchy design service. 
     *
     *  @return a <code> HierarchyDesignSession </code> for auction houses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionHouseHierarchyDesign() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionHouseHierarchyDesign() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.bidding.AuctionHouseHierarchyDesignSession getAuctionHouseHierarchyDesignSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a <code> BiddingBatchManager. </code> 
     *
     *  @return a <code> BiddingBatchManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBiddingBatch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBiddingBatch() </code> is <code> true. </code> 
     */

    public org.osid.bidding.batch.BiddingBatchManager getBiddingBatchManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a <code> BiddingRulesManager. </code> 
     *
     *  @return a <code> BiddingRulesManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBiddingRules() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBiddingRules() </code> is <code> true. </code> 
     */

    public org.osid.bidding.rules.BiddingRulesManager getBiddingRulesManager()
        throws org.osid.OperationFailedException;
}
