//
// org.osid.bidding.batch.AuctionBatchAdminSession
//
//     The OSID Java specification for org.osid.bidding.batch.AuctionBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.bidding.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Auctions </code> in 
 *  bulk. The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create an 
 *  <code> Auction, </code> an <code> AuctionForm </code> is requested using 
 *  <code> getAuctionFormsForCreate() </code> specifying the desired record 
 *  <code> Types </code> or none if no record <code> Types </code> are needed. 
 *  Each of the returned <code> AuctionForms </code> will indicate that it is 
 *  to be used with a create operation and can be used to examine metdata or 
 *  validate data prior to creation. Once an <code> AuctionForm </code> is 
 *  submiited to a create operation, it cannot be reused with another create 
 *  operation unless the first operation was unsuccessful. Each <code> 
 *  AuctionForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> AuctionForms </code> returned from <code> 
 *  getAuctionFormsForCreate() </code> may be linked to the originating 
 *  request through the peer <code> Ids </code> of the <code> AuctionForm. 
 *  </code> In the case where there may be duplicates, any <code> AuctionForm 
 *  </code> of the same peer <code> Ids </code> may be used for a create 
 *  operation. </p> 
 *  
 *  <p> Once a batch of <code> AuctionForms </code> are submitted for create, 
 *  a <code> CreateResponse </code> is returned for each <code> AuctionForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire create operation are returned from <code> createAuctions(), 
 *  </code> errors specific to an individual <code> AuctionForm </code> are 
 *  indicated in the corresponding <code> CreateResponse. </code> <code> 
 *  CreateResponses </code> may be linked to the originating <code> 
 *  AuctionForm </code> through the <code> AuctionForm </code> <code> Id 
 *  </code> . </p> 
 *  
 *  <p> For updates, <code> AuctionForms </code> are requested to the <code> 
 *  Auction </code> <code> Id </code> that is to be updated using <code> 
 *  getAuctionFormsForUpdate() </code> where the reference <code> Id </code> 
 *  in the <code> AuctionForm </code> may be used to link the request. 
 *  Similarly, the <code> AuctionForm </code> has metadata about the data that 
 *  can be updated and it can perform validation before submitting the update. 
 *  The <code> AuctionForm </code> can only be used once for a successful 
 *  update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> AuctionForms </code> are submitted for update, 
 *  an <code> UpdateResponse </code> is returned for each <code> AuctionForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire update operation are returned from <code> updateAuctions(), 
 *  </code> errors specific to an individual <code> AuctionForm </code> are 
 *  indicated in the corresponding <code> UpdateResponse. </code> <code> 
 *  UpdateResponses </code> may be linked to the originating <code> 
 *  AuctionForm </code> through the <code> AuctionForm </code> <code> Id. 
 *  </code> </p> 
 *  
 *  <p> The delete operations delete <code> Auctions </code> in bulk. To unmap 
 *  an <code> Auction </code> from the current <code> AuctionHouse, </code> 
 *  the <code> AuctionAuctionHouseAssignmentSession </code> should be used. 
 *  These delete operations attempt to remove the <code> Auction </code> 
 *  itself thus removing it from all known <code> AuctionHouse </code> 
 *  catalogs. Bulk delete operations return the results in <code> 
 *  DeleteResponses. </code> </p>
 */

public interface AuctionBatchAdminSession
    extends org.osid.bidding.AuctionAdminSession {


    /**
     *  Gets the auction forms for creating a bunch of new auctions. 
     *
     *  @param  number the number of foms to retrieve 
     *  @param  auctionRecordTypes array of auction record types to be 
     *          included in each create operation or an empty list if none 
     *  @return the auction forms 
     *  @throws org.osid.NullArgumentException <code> auctionRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.batch.AuctionBatchFormList getAuctionFormsForCreate(long number, 
                                                                                org.osid.type.Type[] auctionRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Auctions. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  auctionForms the auction forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> auctionForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createAuctions(org.osid.bidding.batch.AuctionBatchFormList auctionForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the auction forms for updating an existing set of auctions. A new 
     *  auction form should be requested for each update transaction. 
     *
     *  @param  auctionIds the <code> Ids </code> of the <code> Auction 
     *          </code> 
     *  @return the auction form 
     *  @throws org.osid.NotFoundException an <code> auctionId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> auctionIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.batch.AuctionBatchFormList getAuctionFormsForUpdate(org.osid.id.IdList auctionIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing auctions. This method returns an error if the entire 
     *  operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  auctionForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> auctionForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateAuctions(org.osid.bidding.batch.AuctionBatchFormList auctionForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Auctions </code> in this <code> AuctionHouse 
     *  </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllAuctions()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes auctions for the given <code> Ids. </code> 
     *
     *  @param  auctionIds the <code> Ids </code> of the auctions to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> auctionIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAuctions(org.osid.id.IdList auctionIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to an <code> Auction </code> for the purpose 
     *  of creating compatibility. The primary <code> Id </code> of the <code> 
     *  Auction </code> is determined by the provider. The new <code> Id 
     *  </code> is an alias to the primary <code> Id. </code> If the alias is 
     *  a pointer to another auction, it is reassigned to the given entry 
     *  <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasAuctions(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
