//
// org.osid.bidding.batch.BidBatchAdminSession
//
//     The OSID Java specification for org.osid.bidding.batch.BidBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.bidding.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Bids </code> in bulk. 
 *  The data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Bid, </code> a <code> BidForm </code> is requested using <code> 
 *  getBidFormsForCreate() </code> specifying the desired auction bidder, and 
 *  record <code> Types </code> or none if no record <code> Types </code> are 
 *  needed. Each of the returned <code> BidForms </code> will indicate that it 
 *  is to be used with a create operation and can be used to examine metdata 
 *  or validate data prior to creation. Once a <code> BidForm </code> is 
 *  submiited to a create operation, it cannot be reused with another create 
 *  operation unless the first operation was unsuccessful. Each <code> BidForm 
 *  </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> BidForms </code> returned from <code> 
 *  getBidFormsForCreate() </code> may be linked to the originating request 
 *  through the peer <code> Ids </code> of the <code> BidForm. </code> In the 
 *  case where there may be duplicates, any <code> BidForm </code> of the same 
 *  peer <code> Ids </code> may be used for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> BidForms </code> are submitted for create, a 
 *  <code> CreateResponse </code> is returned for each <code> BidForm, </code> 
 *  although the ordering is not defined. Only errors that pertain to the 
 *  entire create operation are returned from <code> createBids(), </code> 
 *  errors specific to an individual <code> BidForm </code> are indicated in 
 *  the corresponding <code> CreateResponse. </code> <code> CreateResponses 
 *  </code> may be linked to the originating <code> BidForm </code> through 
 *  the <code> BidForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> BidForms </code> are requested to the <code> Bid 
 *  </code> <code> Id </code> that is to be updated using <code> 
 *  getBidFormsForUpdate() </code> where the reference <code> Id </code> in 
 *  the <code> BidForm </code> may be used to link the request. Similarly, the 
 *  <code> BidForm </code> has metadata about the data that can be updated and 
 *  it can perform validation before submitting the update. The <code> BidForm 
 *  </code> can only be used once for a successful update and cannot be 
 *  reused. </p> 
 *  
 *  <p> Once a batch of <code> BidForms </code> are submitted for update, an 
 *  <code> UpdateResponse </code> is returned for each <code> BidForm, </code> 
 *  although the ordering is not defined. Only errors that pertain to the 
 *  entire update operation are returned from <code> updateBids(), </code> 
 *  errors specific to an individual <code> BidForm </code> are indicated in 
 *  the corresponding <code> UpdateResponse. </code> <code> UpdateResponses 
 *  </code> may be linked to the originating <code> BidForm </code> through 
 *  the <code> BidForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> Bids </code> in bulk. To unmap a 
 *  <code> Bid </code> from the current <code> AuctionHouse, </code> the 
 *  <code> BidAuctionHouseAssignmentSession </code> should be used. These 
 *  delete operations attempt to remove the <code> Bid </code> itself thus 
 *  removing it from all known <code> AuctionHouse </code> catalogs. Bulk 
 *  delete operations return the results in <code> DeleteResponses. </code> 
 *  </p>
 */

public interface BidBatchAdminSession
    extends org.osid.bidding.BidAdminSession {


    /**
     *  Gets the bid forms for creating a bunch of new bids. A form is 
     *  returned for each auction and bidder pair. 
     *
     *  @param  peers the relationship peers 
     *  @param  bidRecordTypes array of bid record types to be included in 
     *          each create operation or an empty list if none 
     *  @return the bid forms 
     *  @throws org.osid.NotFoundException an <code> auctionId </code> or 
     *          <code> bidderId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> peers </code> or <code> 
     *          bidRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.batch.BidBatchFormList getBidFormsForCreate(org.osid.bidding.batch.BidPeerList peers, 
                                                                        org.osid.type.Type[] bidRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Bids. </code> This method returns an error 
     *  if the entire operation fails. Otherwise, the status of an individual 
     *  create operation is indicated in the <code> BatchCreateResponse 
     *  </code> . 
     *
     *  @param  bidForms the bid forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> bidForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createBids(org.osid.bidding.batch.BidBatchFormList bidForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the bid forms for updating an existing set of bids. A new bid 
     *  form should be requested for each update transaction. 
     *
     *  @param  bidIds the <code> Ids </code> of the <code> Bid </code> 
     *  @return the bid form 
     *  @throws org.osid.NotFoundException a <code> bidId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> bidIds </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.batch.BidBatchFormList getBidFormsForUpdate(org.osid.id.IdList bidIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing bids. This method returns an error if the entire 
     *  operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  bidForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> bidForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateBids(org.osid.bidding.batch.BidBatchFormList bidForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Bids </code> in this <code> AuctionHouse </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllBids()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes bids for the given <code> Ids. </code> 
     *
     *  @param  bidIds the <code> Ids </code> of the bids to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> bidIds </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteBids(org.osid.id.IdList bidIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes bids for the given auction. 
     *
     *  @param  auctionId the <code> Id </code> of an auction 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> auctionId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteBidsForAuction(org.osid.id.Id auctionId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes bids for the given bidder. 
     *
     *  @param  resourceId the <code> Id </code> of a resource 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteBidsForBidder(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes bids expired before the given date. 
     *
     *  @param  date a date 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteIneffectiveBidsByDate(org.osid.calendaring.DateTime date)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Bid </code> for the purpose of 
     *  creating compatibility. The primary <code> Id </code> of the <code> 
     *  Bid </code> is determined by the provider. The new <code> Id </code> 
     *  is an alias to the primary <code> Id. </code> If the alias is a 
     *  pointer to another bid, it is reassigned to the given entry <code> Id. 
     *  </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasBids(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
