//
// org.osid.bidding.rules.AuctionConstrainerAdminSession
//
//     The OSID Java specification for org.osid.bidding.rules.AuctionConstrainerAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.bidding.rules;


/**
 *  <p>This session creates and removes auction constrainers. The data for 
 *  create and update is provided via the <code> AuctionConstrainerForm. 
 *  </code> </p>
 */

public interface AuctionConstrainerAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> AuctionHouse </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> AuctionHouse Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAuctionHouseId();


    /**
     *  Gets the <code> AuctionHouse </code> associated with this session. 
     *
     *  @return the auction house 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.AuctionHouse getAuctionHouse()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create auction constrainers. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating an <code> AuctionConstrainer 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer create 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> AuctionConstrainer </code> 
     *          creation is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAuctionConstrainer();


    /**
     *  <code> BiddingRulesManager.getAuctionConstrainerRecordTypes() </code> 
     *  can be used to examine which records are supported, this method tests 
     *  which record(s) are required for creating a specific <code> 
     *  AuctionConstrainer. </code> Providing an empty array tests if an 
     *  <code> AuctionConstrainer </code> can be created with no records. 
     *
     *  @param  auctionConstrainerRecordTypes array of auction constrainer 
     *          record types 
     *  @return <code> true </code> if <code> AuctionConstrainer </code> 
     *          creation using the specified record <code> Types </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionConstrainerRecordTypes </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAuctionConstrainerWithRecordTypes(org.osid.type.Type[] auctionConstrainerRecordTypes);


    /**
     *  Gets the auction constrainer form for creating new auction 
     *  constrainers. A new form should be requested for each create 
     *  transaction. 
     *
     *  @param  auctionConstrainerRecordTypes array of auction constrainer 
     *          record types 
     *  @return the auction constrainer form 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionConstrainerRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.rules.AuctionConstrainerForm getAuctionConstrainerFormForCreate(org.osid.type.Type[] auctionConstrainerRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> AuctionConstrainer. </code> 
     *
     *  @param  auctionConstrainerForm the form for this <code> 
     *          AuctionConstrainer </code> 
     *  @return the new <code> AuctionConstrainer </code> 
     *  @throws org.osid.IllegalStateException <code> auctionConstrainerForm 
     *          </code> already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> auctionConstrainerForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> auctionConstrainerForm 
     *          </code> did not originate from <code> 
     *          getAuctionConstrainerFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.rules.AuctionConstrainer createAuctionConstrainer(org.osid.bidding.rules.AuctionConstrainerForm auctionConstrainerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update auction constrainers. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating an <code> AuctionConstrainer 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer update 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> AuctionConstrainer </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateAuctionConstrainers();


    /**
     *  Gets the auction constrainer form for updating an existing auction 
     *  constrainer. A new auction constrainer form should be requested for 
     *  each update transaction. 
     *
     *  @param  auctionConstrainerId the <code> Id </code> of the <code> 
     *          AuctionConstrainer </code> 
     *  @return the auction constrainer form 
     *  @throws org.osid.NotFoundException <code> auctionConstrainerId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> auctionConstrainerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.rules.AuctionConstrainerForm getAuctionConstrainerFormForUpdate(org.osid.id.Id auctionConstrainerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing auction constrainer. 
     *
     *  @param  auctionConstrainerForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> auctionConstrainerForm 
     *          </code> already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> auctionConstrainerForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> auctionConstrainerForm 
     *          </code> did not originate from <code> 
     *          getAuctionConstrainerFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateAuctionConstrainer(org.osid.bidding.rules.AuctionConstrainerForm auctionConstrainerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete auction constrainers. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting an <code> AuctionConstrainer 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer delete 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> AuctionConstrainer </code> 
     *          deletion is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteAuctionConstrainers();


    /**
     *  Deletes an <code> AuctionConstrainer. </code> 
     *
     *  @param  auctionConstrainerId the <code> Id </code> of the <code> 
     *          AuctionConstrainer </code> to remove 
     *  @throws org.osid.NotFoundException <code> auctionConstrainerId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> auctionConstrainerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteAuctionConstrainer(org.osid.id.Id auctionConstrainerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for auction 
     *  constrainers. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> AuctionConstrainer </code> 
     *          aliasing is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageAuctionConstrainerAliases();


    /**
     *  Adds an <code> Id </code> to an <code> AuctionConstrainer </code> for 
     *  the purpose of creating compatibility. The primary <code> Id </code> 
     *  of the <code> AuctionConstrainer </code> is determined by the 
     *  provider. The new <code> Id </code> performs as an alias to the 
     *  primary <code> Id </code> . If the alias is a pointer to another 
     *  auction constrainer. it is reassigned to the given auction constrainer 
     *  <code> Id. </code> 
     *
     *  @param  auctionConstrainerId the <code> Id </code> of an <code> 
     *          AuctionConstrainer </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> auctionConstrainerId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> auctionConstrainerId 
     *          </code> or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasAuctionConstrainer(org.osid.id.Id auctionConstrainerId, 
                                        org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
