//
// org.osid.bidding.rules.AuctionConstrainerEnablerRuleApplicationSession
//
//     The OSID Java specification for org.osid.bidding.rules.AuctionConstrainerEnablerRuleApplicationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.bidding.rules;


/**
 *  <p>This session provides methods to apply <code> 
 *  AuctionConstrainerEnablers </code> to <code> AuctionConstrainers. </code> 
 *  An <code> AuctionConstrainer </code> with multiple <code> 
 *  AuctionConstrainerEnablers </code> means any positive rule evaluation 
 *  across the enablers result in an effective <code> AuctionConstrainer. 
 *  </code> </p>
 */

public interface AuctionConstrainerEnablerRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> AuctionHouse </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> AuctionHouse Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAuctionHouseId();


    /**
     *  Gets the <code> AuctionHouse </code> associated with this session. 
     *
     *  @return the auction house 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.AuctionHouse getAuctionHouse()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter auction constrainer enabler/auction 
     *  constrainer mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known mapping 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignAuctionConstrainerEnablers();


    /**
     *  Adds an existing <code> AuctionConstrainerEnabler </code> to an <code> 
     *  AuctionConstrainer. </code> 
     *
     *  @param  auctionConstrainerEnablerId the <code> Id </code> of the 
     *          <code> AuctionConstrainerEnabler </code> 
     *  @param  auctionConstrainerId the <code> Id </code> of the <code> 
     *          AuctionConstrainer </code> 
     *  @throws org.osid.AlreadyExistsException <code> 
     *          auctionConstrainerEnablerId </code> already applied to <code> 
     *          auctionConstrainerId </code> 
     *  @throws org.osid.NotFoundException <code> auctionConstrainerEnablerId 
     *          </code> or <code> auctionConstrainerId </code> not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionConstrainerEnablerId </code> or <code> 
     *          auctionConstrainerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignAuctionConstrainerEnablerToAuctionConstrainer(org.osid.id.Id auctionConstrainerEnablerId, 
                                                                    org.osid.id.Id auctionConstrainerId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes an <code> AuctionConstrainerEnabler </code> from an <code> 
     *  AuctionConstrainer. </code> 
     *
     *  @param  auctionConstrainerEnablerId the <code> Id </code> of the 
     *          <code> AuctionConstrainerEnabler </code> 
     *  @param  auctionConstrainerId the <code> Id </code> of the <code> 
     *          AuctionConstrainer </code> 
     *  @throws org.osid.NotFoundException <code> auctionConstrainerEnablerId 
     *          </code> or <code> auctionConstrainerId </code> not found or 
     *          <code> auctionConstrainerEnablerId </code> not applied to 
     *          <code> auctionConstrainerId </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionConstrainerEnablerId </code> or <code> 
     *          auctionConstrainerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignAuctionConstrainerEnablerFromAuctionConstrainer(org.osid.id.Id auctionConstrainerEnablerId, 
                                                                        org.osid.id.Id auctionConstrainerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> AuctionConstrainerEnablers. 
     *  </code> A return of true does not guarantee successful authorization. 
     *  A return of false indicates that it is known sequencing operations 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer sequencing 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> AuctionConstrainerEnabler 
     *          </code> ordering is not authorized, <code> true </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceAuctionConstrainerEnablers();


    /**
     *  Reorders auction constrainer enablers for an auction constrainer by 
     *  moving the specified auction constrainer enabler in front of a 
     *  reference auction constrainer enabler. 
     *
     *  @param  auctionConstrainerEnablerId the <code> Id </code> of an <code> 
     *          AuctionConstrainerEnabler </code> 
     *  @param  auctionConstrainerId the <code> Id </code> of an <code> 
     *          AuctionConstrainer </code> 
     *  @param  referenceId the reference auction constrainer enabler <code> 
     *          Id </code> 
     *  @throws org.osid.NotFoundException <code> auctionConstrainerEnablerId, 
     *          auctionConstrainerId, </code> or <code> referenceId </code> 
     *          not found or, <code> auctionConstrainerEnablerId </code> or 
     *          <code> referenceId </code> not related to <code> 
     *          auctionConstrainerId </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionConstrainerEnablerId, auctionConstrainerId, </code> or 
     *          <code> referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveAuctionConstrainerEnablerAhead(org.osid.id.Id auctionConstrainerEnablerId, 
                                                   org.osid.id.Id auctionConstrainerId, 
                                                   org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders auction constrainer enablers for an auction by moving the 
     *  specified auction constrainer enabler behind a reference auction 
     *  constrainer enabler. 
     *
     *  @param  auctionConstrainerEnablerId the <code> Id </code> of an <code> 
     *          AuctionConstrainerEnabler </code> 
     *  @param  auctionConstrainerId the <code> Id </code> of an <code> 
     *          AuctionConstrainer </code> 
     *  @param  referenceId the reference auction constrainer enabler <code> 
     *          Id </code> 
     *  @throws org.osid.NotFoundException <code> auctionConstrainerEnablerId, 
     *          auctionConstrainerId, </code> or <code> referenceId </code> 
     *          not found or, <code> auctionConstrainerEnablerId </code> or 
     *          <code> referenceId </code> not related to <code> 
     *          auctionConstrainerId </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionConstrainerEnablerId, auctionConstrainerId, </code> or 
     *          <code> referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveAuctionConstrainerEnablerBehind(org.osid.id.Id auctionConstrainerEnablerId, 
                                                    org.osid.id.Id auctionConstrainerId, 
                                                    org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of auction constrainer enablers for an auction 
     *  constrainer. 
     *
     *  @param  auctionConstrainerEnablerIds the <code> Ids </code> for a set 
     *          of <code> AuctionConstrainerEnablers </code> 
     *  @param  auctionConstrainerId the <code> Id </code> of an <code> 
     *          AuctionConstrainer </code> 
     *  @throws org.osid.NotFoundException <code> auctionConstraienrId </code> 
     *          not found or, an <code> auctionConstrainerEnablerId </code> 
     *          not related to <code> auctionConstrainerId </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionConstrainerEnablerIds </code> or <code> 
     *          auctionConstrainerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderAuctionConstrainerEnablers(org.osid.id.Id[] auctionConstrainerEnablerIds, 
                                                org.osid.id.Id auctionConstrainerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
