//
// org.osid.bidding.rules.AuctionConstrainerEnablerRuleLookupSession
//
//     The OSID Java specification for org.osid.bidding.rules.AuctionConstrainerEnablerRuleLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.bidding.rules;


/**
 *  <p>This session provides methods to retrieve <code> 
 *  AuctionConstrainerEnabler </code> to <code> AuctionConstrainer </code> 
 *  mappings. An <code> Auction </code> with multiple <code> 
 *  AuctionConstrainerEnablers </code> means any positive rule evaluation 
 *  across the enablers result in an effective <code> Auction. </code> </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated auction house view: All methods in this session operate, 
 *      retrieve and pertain auction constrainer enablers defined explicitly 
 *      in the current auction house </li> 
 *      <li> federated auction house view: All methods in this session 
 *      operate, retrieve and pertain to all auction constrainer enablers 
 *      defined in this auction house and any other auction constrainer 
 *      enablers implicitly available in this auction house through auction 
 *      house inheritence. </li> 
 *  </ul>
 *  
 */

public interface AuctionConstrainerEnablerRuleLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> AuctionHouse </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> AuctionHouse Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAuctionHouseId();


    /**
     *  Gets the <code> AuctionHouse </code> associated with this session. 
     *
     *  @return the auction house 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.AuctionHouse getAuctionHouse()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform lookups of auction constrainer 
     *  enabler/auction constrainer mappings. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known lookup methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if looking up mappings is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupAuctionConstrainerEnablerRules();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeAuctionConstrainerEnablerRuleView();


    /**
     *  A complete view of the <code> AuctionConstrainerEnabler </code> and 
     *  <code> AuctionConstrainer </code> returns is desired. Methods will 
     *  return what is requested or result in an error. This view is used when 
     *  greater precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryAuctionConstrainerEnablerRuleView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include auction constrainer enablers in auction houses which are 
     *  children of this auction house in the auction house hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedAuctionHouseView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this auction house only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedAuctionHouseView();


    /**
     *  Gets the <code> AuctionConstrainerEnabler Id </code> associated with 
     *  an <code> AuctionConstrainer. </code> 
     *
     *  @param  auctionConstrainerId <code> Id </code> of the <code> 
     *          AuctionConstrainer </code> 
     *  @return the auction constrainer enabler <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> auctionConstrainerId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> auctionConstrainerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAuctionConstrainerEnablerIdsForAuctionConstrainer(org.osid.id.Id auctionConstrainerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> AuctionConstrainerEnablers </code> associated with an 
     *  <code> AuctionConstrainer. </code> 
     *
     *  @param  auctionConstrainerId <code> Id </code> of the <code> 
     *          AuctionConstrainer </code> 
     *  @return the auction constrainer enablers 
     *  @throws org.osid.NotFoundException <code> auctionConstrainerId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> auctionConstrainerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.rules.AuctionConstrainerEnablerList getAuctionConstrainerEnablersForAuctionConstrainer(org.osid.id.Id auctionConstrainerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> AuctionConstrainer </code> <code> Ids </code> mapped 
     *  to an <code> AuctionConstrainerEnabler. </code> 
     *
     *  @param  auctionConstrainerEnablerId <code> Id </code> of an <code> 
     *          AuctionConstrainerEnabler </code> 
     *  @return list of auction constrainer <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> auctionConstrainerEnablerId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionConstrainerEnablerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAuctionConstrainerIdsForAuctionConstrainerEnabler(org.osid.id.Id auctionConstrainerEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> AuctionConstrainers </code> mapped to an <code> 
     *  AuctionConstrainerEnabler. </code> 
     *
     *  @param  auctionConstrainerEnablerId <code> Id </code> of an <code> 
     *          AuctionConstrainerEnabler </code> 
     *  @return list of auction constrainers 
     *  @throws org.osid.NotFoundException <code> auctionConstrainerEnablerId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionConstrainerEnablerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.rules.AuctionConstrainerList getAuctionConstrainersForAuctionConstrainerEnabler(org.osid.id.Id auctionConstrainerEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
