//
// org.osid.bidding.rules.AuctionConstrainerSmartAuctionHouseSession
//
//     The OSID Java specification for org.osid.bidding.rules.AuctionConstrainerSmartAuctionHouseSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.bidding.rules;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  auction houses. An <code> AuctionConstrainerQuery </code> can be retrieved 
 *  from this session and mapped to this <code> AuctionHouse </code> to create 
 *  a virtual collection of auction constrainers. The auction constrainer may 
 *  be sequenced using the <code> AuctionConstrainerSearchOrder </code> from 
 *  this session. </p> 
 *  
 *  <p> This <code> AuctionHouse </code> has a default query that matches any 
 *  auction constrainer and a default search order that specifies no 
 *  sequencing. The queries may be examined using an <code> 
 *  AuctionConstrainerQueryInspector. </code> The query may be modified by 
 *  converting the inspector back to an <code> AuctionConstrainerQuery. 
 *  </code> </p>
 */

public interface AuctionConstrainerSmartAuctionHouseSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> AuctionHouse </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> AuctionHouse Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAuctionHouseId();


    /**
     *  Gets the <code> AuctionHouse </code> associated with this session. 
     *
     *  @return the auction house 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.AuctionHouse getAuctionHouse()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart auction houses. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known methods in this session will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart auction house management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartAuctionHouses();


    /**
     *  Gets an auction constrainer query. 
     *
     *  @return the auction constrainer query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.rules.AuctionConstrainerQuery getAuctionConstrainerQuery();


    /**
     *  Gets an auction constrainer search order. 
     *
     *  @return the auction constrainer search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.rules.AuctionConstrainerSearchOrder getAuctionConstrainerSearchOrder();


    /**
     *  Applies an auction constrainer query to this auction house. 
     *
     *  @param  auctionConstrainerQuery the auction constrainer query 
     *  @throws org.osid.NullArgumentException <code> auctionConstrainerQuery 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> auctionConstrainerQuery 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyAuctionConstrainerQuery(org.osid.bidding.rules.AuctionConstrainerQuery auctionConstrainerQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an auction constrainer query inspector for this auction house. 
     *
     *  @return the auction constrainer query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.rules.AuctionConstrainerQueryInspector inspectAuctionConstrainerQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies an auction constrainer search order to this auction house. 
     *
     *  @param  auctionConstrainerSearchOrder the auction constrainer search 
     *          order 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionConstrainerSearchOrder </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> 
     *          auctionConstrainerSearchOrder </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyAuctionConstrainerSequencing(org.osid.bidding.rules.AuctionConstrainerSearchOrder auctionConstrainerSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an auction constrainer query from an inspector. 
     *
     *  @param  auctionConstrainerQueryInspector an auction constrainer query 
     *          inspector 
     *  @return the auction constrainer query 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionConstrainerQueryInspector </code> is <code> null 
     *          </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          auctionConstrainerQueryInspector </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.rules.AuctionConstrainerQuery getAuctionConstrainerQueryFromInspector(org.osid.bidding.rules.AuctionConstrainerQueryInspector auctionConstrainerQueryInspector);
}
