//
// org.osid.bidding.rules.AuctionProcessorAdminSession
//
//     The OSID Java specification for org.osid.bidding.rules.AuctionProcessorAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.bidding.rules;


/**
 *  <p>This session creates and removes auction processors. The data for 
 *  create and update is provided via the <code> AuctionProcessorForm. </code> 
 *  </p>
 */

public interface AuctionProcessorAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> AuctionHouse </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> AuctionHouse Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAuctionHouseId();


    /**
     *  Gets the <code> AuctionHouse </code> associated with this session. 
     *
     *  @return the auction house 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.AuctionHouse getAuctionHouse()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create auction processors. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating an <code> AuctionProcessor </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer create operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> AuctionProcessor </code> 
     *          creation is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAuctionProcessor();


    /**
     *  Tests if this user can create a single <code> AuctionProcessor </code> 
     *  using the desired record types. While <code> 
     *  BiddingRulesManager.getAuctionProcessorRecordTypes() </code> can be 
     *  used to examine which records are supported, this method tests which 
     *  record(s) are required for creating a specific <code> 
     *  AuctionProcessor. </code> Providing an empty array tests if an <code> 
     *  AuctionProcessor </code> can be created with no records. 
     *
     *  @param  auctionProcessorRecordTypes array of auction processor record 
     *          types 
     *  @return <code> true </code> if <code> AuctionProcessor </code> 
     *          creation using the specified record <code> Types </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionProcessorRecordTypes </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAuctionProcessorWithRecordTypes(org.osid.type.Type[] auctionProcessorRecordTypes);


    /**
     *  Gets the auction processor form for creating new auction processors. A 
     *  new form should be requested for each create transaction. 
     *
     *  @param  auctionProcessorRecordTypes array of auction processor record 
     *          types 
     *  @return the auction processor form 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionProcessorRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.rules.AuctionProcessorForm getAuctionProcessorFormForCreate(org.osid.type.Type[] auctionProcessorRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> AuctionProcessor. </code> 
     *
     *  @param  auctionProcessorForm the form for this <code> AuctionProcessor 
     *          </code> 
     *  @return the new <code> AuctionProcessor </code> 
     *  @throws org.osid.IllegalStateException <code> auctionProcessorForm 
     *          </code> already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> auctionProcessorForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> auctionProcessorForm did 
     *          not originate from getAuctionProcessorFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.rules.AuctionProcessor createAuctionProcessor(org.osid.bidding.rules.AuctionProcessorForm auctionProcessorForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update auction processors. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating an <code> AuctionProcessor </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer update operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> AuctionProcessor </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateAuctionProcessors();


    /**
     *  Gets the auction processor form for updating an existing auction 
     *  processor. A new auction processor form should be requested for each 
     *  update transaction. 
     *
     *  @param  auctionProcessorId the <code> Id </code> of the <code> 
     *          AuctionProcessor </code> 
     *  @return the auction processor form 
     *  @throws org.osid.NotFoundException <code> auctionProcessorId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> auctionProcessorId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.rules.AuctionProcessorForm getAuctionProcessorFormForUpdate(org.osid.id.Id auctionProcessorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing auction processor. 
     *
     *  @param  auctionProcessorForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> auctionProcessorForm 
     *          </code> already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> auctionProcessorForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> auctionProcessorForm did 
     *          not originate from getAuctionProcessorFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateAuctionProcessor(org.osid.bidding.rules.AuctionProcessorForm auctionProcessorForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete auction processors. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting an <code> AuctionProcessor </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer delete operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> AuctionProcessor </code> 
     *          deletion is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteAuctionProcessors();


    /**
     *  Deletes an <code> AuctionProcessor. </code> 
     *
     *  @param  auctionProcessorId the <code> Id </code> of the <code> 
     *          AuctionProcessor </code> to remove 
     *  @throws org.osid.NotFoundException <code> auctionProcessorId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> auctionProcessorId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteAuctionProcessor(org.osid.id.Id auctionProcessorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for auction 
     *  processors. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> AuctionProcessor </code> 
     *          aliasing is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageAuctionProcessorAliases();


    /**
     *  Adds an <code> Id </code> to an <code> AuctionProcessor </code> for 
     *  the purpose of creating compatibility. The primary <code> Id </code> 
     *  of the <code> AuctionProcessor </code> is determined by the provider. 
     *  The new <code> Id </code> performs as an alias to the primary <code> 
     *  Id </code> . If the alias is a pointer to another auction processor. 
     *  it is reassigned to the given auction processor <code> Id. </code> 
     *
     *  @param  auctionProcessorId the <code> Id </code> of an <code> 
     *          AuctionProcessor </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> auctionProcessorId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> auctionProcessorId 
     *          </code> or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasAuctionProcessor(org.osid.id.Id auctionProcessorId, 
                                      org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
