//
// org.osid.bidding.rules.AuctionProcessorEnablerRuleApplicationSession
//
//     The OSID Java specification for org.osid.bidding.rules.AuctionProcessorEnablerRuleApplicationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.bidding.rules;


/**
 *  <p>This session provides methods to apply <code> AuctionProcessorEnablers 
 *  </code> to <code> AuctionProcessors. </code> An <code> AuctionProcessor 
 *  </code> with multiple <code> AuctionProcessorEnablers </code> means any 
 *  positive rule evaluation across the enablers result in an effective <code> 
 *  AuctionProcessor. </code> </p>
 */

public interface AuctionProcessorEnablerRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> AuctionHouse </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> AuctionHouse Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAuctionHouseId();


    /**
     *  Gets the <code> AuctionHouse </code> associated with this session. 
     *
     *  @return the auction house 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.AuctionHouse getAuctionHouse()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter auction processor enabler/auction 
     *  processor mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known mapping 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignAuctionProcessorEnablers();


    /**
     *  Adds an existing <code> AuctionProcessorEnabler </code> to an <code> 
     *  AuctionProcessor. </code> 
     *
     *  @param  auctionProcessorEnablerId the <code> Id </code> of the <code> 
     *          AuctionProcessorEnabler </code> 
     *  @param  auctionProcessorId the <code> Id </code> of the <code> 
     *          AuctionProcessor </code> 
     *  @throws org.osid.AlreadyExistsException <code> 
     *          auctionProcessorEnablerId </code> already applied to <code> 
     *          auctionProcessorId </code> 
     *  @throws org.osid.NotFoundException <code> auctionProcessorEnablerId 
     *          </code> or <code> auctionProcessorId </code> not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionProcessorEnablerId </code> or <code> auctionProcessorId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignAuctionProcessorEnablerToAuctionProcessor(org.osid.id.Id auctionProcessorEnablerId, 
                                                                org.osid.id.Id auctionProcessorId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes an <code> AuctionProcessorEnabler </code> from an <code> 
     *  AuctionProcessor. </code> 
     *
     *  @param  auctionProcessorEnablerId the <code> Id </code> of the <code> 
     *          AuctionProcessorEnabler </code> 
     *  @param  auctionProcessorId the <code> Id </code> of the <code> 
     *          AuctionProcessor </code> 
     *  @throws org.osid.NotFoundException <code> auctionProcessorEnablerId 
     *          </code> or <code> auctionProcessorId </code> not found or not 
     *          mapped 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionProcessorEnablerId </code> or <code> auctionProcessorId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignAuctionProcessorEnablerFromAuctionProcessor(org.osid.id.Id auctionProcessorEnablerId, 
                                                                    org.osid.id.Id auctionProcessorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> AuctionProcessors. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known sequencing operations will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> AuctionProcessorEnabler </code> 
     *          ordering is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceAuctionProcessorEnablers();


    /**
     *  Reorders auction processor enablers for an auction processor by moving 
     *  the specified auction processor enabler in front of a reference 
     *  auction processor enabler. 
     *
     *  @param  auctionProcessorEnablerId the <code> Id </code> of an <code> 
     *          AuctionProcessorEnabler </code> 
     *  @param  auctionProcessorId the <code> Id </code> of an <code> 
     *          AuctionProcessor </code> 
     *  @param  referenceId the reference auction processor <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> auctionProcessorEnablerId, 
     *          auctionProcesorId, </code> or <code> referenceId </code> not 
     *          found or, <code> auctionProcessorEnablerId </code> or <code> 
     *          referenceId </code> not related to <code> auctionProcessorId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionProcessorEnablerId, auctionProcessorId, </code> or 
     *          <code> referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveAuctionProcessorEnablerAhead(org.osid.id.Id auctionProcessorEnablerId, 
                                                 org.osid.id.Id auctionProcessorId, 
                                                 org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders auction processor enablers for an auction processor by moving 
     *  the specified auction processor enabler behind a reference auction 
     *  processor enabler. 
     *
     *  @param  auctionProcessorEnablerId the <code> Id </code> of an <code> 
     *          AuctionProcessorEnabler </code> 
     *  @param  auctionProcessorId the <code> Id </code> of an <code> 
     *          AuctionProcessor </code> 
     *  @param  referenceId the reference auction processor <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> auctionProcessorEnablerId, 
     *          auctionProcesorId, </code> or <code> referenceId </code> not 
     *          found or, <code> auctionProcessorEnablerId </code> or <code> 
     *          referenceId </code> not related to <code> auctionProcessorId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionProcessorEnablerId, auctionProcessorId, </code> or 
     *          <code> referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveAuctionProcessorEnablerBehind(org.osid.id.Id auctionProcessorEnablerId, 
                                                  org.osid.id.Id auctionProcessorId, 
                                                  org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of auction processor enablers for an auction processor. 
     *
     *  @param  auctionProcessorEnablerIds the <code> Ids </code> for a set of 
     *          <code> AuctionProcessorEnablers </code> 
     *  @param  auctionProcessorId the <code> Id </code> of an <code> 
     *          AuctionProcessor </code> 
     *  @throws org.osid.NotFoundException <code> auctionProcessorId </code> 
     *          not found or, an <code> auctionProcessorEnablerId </code> not 
     *          related to <code> auctionProcessorId </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionProcessorEnablerIds </code> or <code> 
     *          auctionProcessorId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderAuctionProcessorEnablers(org.osid.id.Id[] auctionProcessorEnablerIds, 
                                              org.osid.id.Id auctionProcessorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
