//
// org.osid.bidding.rules.AuctionProcessorEnablerSearchSession
//
//     The OSID Java specification for org.osid.bidding.rules.AuctionProcessorEnablerSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.bidding.rules;


/**
 *  <p>This session provides methods for searching among <code> 
 *  AuctionProcessorEnabler </code> objects. The search query is constructed 
 *  using the <code> AuctionProcessorEnableryQuery. </code> </p> 
 *  
 *  <p> <code> getAuctionProcessorEnablersByQuery() </code> is the basic 
 *  search method and returns a list of <code> AuctionProcessorEnablers. 
 *  </code> A more advanced search may be performed with <code> 
 *  getAuctionProcessorEnablersBySearch(). </code> It accepts an <code> 
 *  AuctionProcessorEnablerSearch </code> in addition to the query for the 
 *  purpose of specifying additional options affecting the entire search, such 
 *  as bidding. <code> getAuctionProcessorEnablersBySearch() </code> returns 
 *  an <code> AuctionProcessorEnablerSearchResults </code> that can be used to 
 *  access the resulting <code> AuctionProcessorEnablerList </code> or be used 
 *  to perform a search within the result set through <code> 
 *  AuctionProcessorEnablerSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated auction house view: searches include auction processor 
 *      enablers in auction houses of which this auction house is an ancestor 
 *      in the auction house hierarchy </li> 
 *      <li> isolated auction house view: searches are restricted to auction 
 *      processor enablers in this auction house </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> AuctionProcessorEnablers </code> may have a query record 
 *  indicated by their respective record types. The query record is accessed 
 *  via the <code> AuctionProcessorEnablerQuery. </code> </p>
 */

public interface AuctionProcessorEnablerSearchSession
    extends org.osid.bidding.rules.AuctionProcessorEnablerQuerySession {


    /**
     *  Gets an auction processor enabler search. 
     *
     *  @return the auction processor enabler search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.rules.AuctionProcessorEnablerSearch getAuctionProcessorEnablerSearch();


    /**
     *  Gets an auction processor enabler search order. The <code> 
     *  AuctionProcessorEnablerSearchOrder </code> is supplied to an <code> 
     *  AuctionProcessorEnablerSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the auction processor enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.rules.AuctionProcessorEnablerSearchOrder getAuctionProcessorEnablerSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  auctionProcessorEnablerQuery the auction processor enabler 
     *          query 
     *  @param  auctionProcessorEnablerSearch the auction processor enabler 
     *          search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionProcessorEnablerQuery </code> or <code> 
     *          auctionProcessorEnablerSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> 
     *          auctionProcessorEnablerQuery </code> or <code> 
     *          auctionProcessorEnablerSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.rules.AuctionProcessorEnablerSearchResults getAuctionProcessorEnablersBySearch(org.osid.bidding.rules.AuctionProcessorEnablerQuery auctionProcessorEnablerQuery, 
                                                                                                           org.osid.bidding.rules.AuctionProcessorEnablerSearch auctionProcessorEnablerSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an auction processor enabler query from an inspector. The 
     *  inspector is available from an <code> 
     *  AuctionProcessorEnablerSearchResults. </code> 
     *
     *  @param  auctionProcessorEnablerQueryInspector an auction processor 
     *          enabler query inspector 
     *  @return the auction processor enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionProcessorEnablerQueryInspector </code> is <code> null 
     *          </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          auctionProcessorEnablerQueryInspector </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.rules.AuctionProcessorEnablerQuery getAuctionProcessorEnablerQueryFromInspector(org.osid.bidding.rules.AuctionProcessorEnablerQueryInspector auctionProcessorEnablerQueryInspector);
}
