//
// org.osid.bidding.rules.AuctionProcessorSearchSession
//
//     The OSID Java specification for org.osid.bidding.rules.AuctionProcessorSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.bidding.rules;


/**
 *  <p>This session provides methods for searching among <code> 
 *  AuctionProcessor </code> objects. The search query is constructed using 
 *  the <code> AuctionProcessoryQuery. </code> </p> 
 *  
 *  <p> <code> getAuctionProcessorsByQuery() </code> is the basic search 
 *  method and returns a list of <code> AuctionProcessors. </code> A more 
 *  advanced search may be performed with <code> 
 *  getAuctionProcessorsBySearch(). </code> It accepts an <code> 
 *  AuctionProcessorSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  bidding. <code> getAuctionProcessorsBySearch() </code> returns an <code> 
 *  AuctionProcessorSearchResults </code> that can be used to access the 
 *  resulting <code> AuctionProcessorList </code> or be used to perform a 
 *  search within the result set through <code> AuctionProcessorSearch. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated auction house view: searches include auction processor 
 *      in auction houses of which this auction house is an ancestor in the 
 *      auction house hierarchy </li> 
 *      <li> isolated auction house view: searches are restricted to auction 
 *      processor in this auction house </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> AuctionProcessors </code> may have a query record indicated by 
 *  their respective record types. The query record is accessed via the <code> 
 *  AuctionProcessorQuery. </code> </p>
 */

public interface AuctionProcessorSearchSession
    extends org.osid.bidding.rules.AuctionProcessorQuerySession {


    /**
     *  Gets an auction processor search. 
     *
     *  @return the auction processor search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.rules.AuctionProcessorSearch getAuctionProcessorSearch();


    /**
     *  Gets an auction processor search order. The <code> 
     *  AuctionProcessorSearchOrder </code> is supplied to an <code> 
     *  AuctionProcessorSearch </code> to specify the ordering of results. 
     *
     *  @return the auction processor search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.rules.AuctionProcessorSearchOrder getAuctionProcessorSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  auctionProcessorQuery the auction processor query 
     *  @param  auctionProcessorSearch the auction processor search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> auctionProcessorQuery 
     *          </code> or <code> auctionProcessorSearch </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> auctionProcessorQuery 
     *          </code> or <code> auctionProcessorSearch </code> is not of 
     *          this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.rules.AuctionProcessorSearchResults getAuctionProcessorsBySearch(org.osid.bidding.rules.AuctionProcessorQuery auctionProcessorQuery, 
                                                                                             org.osid.bidding.rules.AuctionProcessorSearch auctionProcessorSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an auction processor query from an inspector. The inspector is 
     *  available from an <code> AuctionProcessorSearchResults. </code> 
     *
     *  @param  auctionProcessorQueryInspector an auction processor query 
     *          inspector 
     *  @return the auction processor query 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionProcessorQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          auctionProcessorQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.rules.AuctionProcessorQuery getAuctionProcessorQueryFromInspector(org.osid.bidding.rules.AuctionProcessorQueryInspector auctionProcessorQueryInspector);
}
