//
// org.osid.billing.BusinessSearch
//
//     The OSID Java specification for org.osid.billing.BusinessSearch.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.billing;


/**
 *  <p>The search interface for governing business searches. </p>
 */

public interface BusinessSearch
    extends org.osid.OsidSearch {


    /**
     *  Execute this search among the given list of businesses. 
     *
     *  @param  businessIds list of businesses 
     *  @throws org.osid.NullArgumentException <code> businessIds </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void searchAmongBusinesses(org.osid.id.IdList businessIds);


    /**
     *  Specify an ordering to the search results. 
     *
     *  @param  businessSearchOrder business search order 
     *  @throws org.osid.NullArgumentException <code> businessSearchOrder 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> businessSearchOrder 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderBusinessResults(org.osid.billing.BusinessSearchOrder businessSearchOrder);


    /**
     *  Gets the business search record corresponding to the given business 
     *  search record <code> Type. </code> This method is used to retrieve an 
     *  object implementing the requested record. 
     *
     *  @param  businessSearchRecordType a business search record type 
     *  @return the business search record 
     *  @throws org.osid.NullArgumentException <code> businessSearchRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(businessSearchRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.records.BusinessSearchRecord getBusinessSearchRecord(org.osid.type.Type businessSearchRecordType)
        throws org.osid.OperationFailedException;
}
