//
// org.osid.billing.CategorySearchSession
//
//     The OSID Java specification for org.osid.billing.CategorySearchSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.billing;


/**
 *  <p>This session provides methods for searching among <code> Category 
 *  </code> objects. The search query is constructed using the <code> 
 *  CategoryQuery. </code> </p> 
 *  
 *  <p> <code> getCategoriesByQuery() </code> is the basic search method and 
 *  returns a list of <code> Categories. </code> A more advanced search may be 
 *  performed with <code> getCategoriesBySearch(). </code> It accepts a <code> 
 *  CategorySearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getCategoriesBySearch() </code> returns a <code> 
 *  CategorySearchResults </code> that can be used to access the resulting 
 *  <code> CategoryList </code> or be used to perform a search within the 
 *  result set through <code> CategorySearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated business view: searches include categories in 
 *      businesses of which this business is an ancestor in the business 
 *      hierarchy </li> 
 *      <li> isolated business view: searches are restricted to categories in 
 *      this business </li> 
 *  </ul>
 *  
 *  
 *  <p> Categories may have a query record indicated by their respective 
 *  record types. The queryrecord is accessed via the <code> CategoryQuery. 
 *  </code> </p>
 */

public interface CategorySearchSession
    extends org.osid.billing.CategoryQuerySession {


    /**
     *  Gets a category search. 
     *
     *  @return the category search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.CategorySearch getCategorySearch();


    /**
     *  Gets a category search order. The <code> CategorySearchOrder </code> 
     *  is supplied to a <code> CategorySearch </code> to specify the ordering 
     *  of results. 
     *
     *  @return the category search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.CategorySearchOrder getCategorySearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  categoryQuery the category query 
     *  @param  categorySearch the category search 
     *  @return the category search results 
     *  @throws org.osid.NullArgumentException <code> categoryQuery </code> or 
     *          <code> categorySearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> categoryQuery </code> or 
     *          <code> categorySearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.CategorySearchResults getCategoriesBySearch(org.osid.billing.CategoryQuery categoryQuery, 
                                                                        org.osid.billing.CategorySearch categorySearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a category query from an inspector. The inspector is available 
     *  from a <code> CategorySearchResults. </code> 
     *
     *  @param  categoryQueryInspector a category query inspector 
     *  @return the category query 
     *  @throws org.osid.NullArgumentException <code> categoryQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> categoryQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.CategoryQuery getCategoryQueryFromInspector(org.osid.assessment.ItemQueryInspector categoryQueryInspector);
}
