//
// org.osid.billing.Customer
//
//     The OSID Java specification for org.osid.billing.Customer.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.billing;


/**
 *  <p>A <code> Customer </code> represents data associated to a resource 
 *  representing a customer. Contact information for this object can be 
 *  managed in the Contact OSID. </p>
 */

public interface Customer
    extends org.osid.OsidObject,
            org.osid.Temporal {


    /**
     *  Gets the resource <code> Id </code> representing the customer. 
     *
     *  @return the resource <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getResourceId();


    /**
     *  Gets the resource. 
     *
     *  @return the resource 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getResource()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the customer account number. 
     *
     *  @return the customer number 
     *  @compliance mandatory This method must be implemented. 
     */

    public String getCustomerNumber();


    /**
     *  Tests if this customer is linked to a financial activity, 
     *
     *  @return <code> true </code> if this customer has an activity, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasActivity();


    /**
     *  Gets the activity <code> Id. </code> 
     *
     *  @return the activity <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> hasActivity() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getActivityId();


    /**
     *  Gets the activity. 
     *
     *  @return the activity 
     *  @throws org.osid.IllegalStateException <code> hasActivity() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.Activity getActivity()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the customer record corresponding to the given <code> Customer 
     *  </code> record <code> Type. </code> This method is used to retrieve an 
     *  object implementing the requested record. The <code> 
     *  customerRecordType </code> may be the <code> Type </code> returned in 
     *  <code> getRecordTypes() </code> or any of its parents in a <code> Type 
     *  </code> hierarchy where <code> hasRecordType(customerRecordType) 
     *  </code> is <code> true </code> . 
     *
     *  @param  customerRecordType the type of customer record to retrieve 
     *  @return the customer record 
     *  @throws org.osid.NullArgumentException <code> customerRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(customerRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.records.CustomerRecord getCustomerRecord(org.osid.type.Type customerRecordType)
        throws org.osid.OperationFailedException;
}
