//
// org.osid.billing.CustomerQuery
//
//     The OSID Java specification for org.osid.billing.CustomerQuery.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.billing;


/**
 *  <p>This is the query for searching customers. Each method match specifies 
 *  an <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface CustomerQuery
    extends org.osid.OsidObjectQuery,
            org.osid.OsidTemporalQuery {


    /**
     *  Sets the resource <code> Id </code> for this query. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchResourceId(org.osid.id.Id resourceId, boolean match);


    /**
     *  Clears the resource <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearResourceIdTerms();


    /**
     *  Tests if a <code> ResourceQuery </code> is available. 
     *
     *  @return <code> true </code> if a resource query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceQuery();


    /**
     *  Gets the query for a resource. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return a resource query 
     *  @throws org.osid.UnimplementedException <code> supportsResourceQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceQuery getResourceQuery();


    /**
     *  Clears the resource terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearResourceTerms();


    /**
     *  Matches customer numbers. 
     *
     *  @param  number a customer number 
     *  @param  stringMatchType a string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> number </code> not of 
     *          <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> number </code> or <code> 
     *          stringMatchType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCustomerNumber(String number, 
                                    org.osid.type.Type stringMatchType, 
                                    boolean match);


    /**
     *  Matches customers with any number. 
     *
     *  @param  match <code> true </code> to match customers with any number, 
     *          <code> false </code> to match customers with no number 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCustomerNumber(boolean match);


    /**
     *  Clears the customer number. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCustomerNumberTerms();


    /**
     *  Sets the activity <code> Id </code> for this query to match customers 
     *  that have a financial activity. 
     *
     *  @param  activityId an activity <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> activityId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchActivityId(org.osid.id.Id activityId, boolean match);


    /**
     *  Clears the activity <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearActivityIdTerms();


    /**
     *  Tests if an <code> ActivityQuery </code> is available. 
     *
     *  @return <code> true </code> if an activity query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityQuery();


    /**
     *  Gets the query for an activity. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return an activity query 
     *  @throws org.osid.UnimplementedException <code> supportsActivityQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityQuery() </code> is <code> true. </code> 
     */

    public org.osid.financials.ActivityQuery getActivityQuery();


    /**
     *  Matches customers that have any financial activity. 
     *
     *  @param  match <code> true </code> to match customers with any 
     *          activity, <code> false </code> to match customers with no 
     *          activity 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyActivity(boolean match);


    /**
     *  Clears the activity terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearActivityTerms();


    /**
     *  Sets the business <code> Id </code> for this query to match customers 
     *  assigned to businesses. 
     *
     *  @param  businessId the business <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> businessId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBusinessId(org.osid.id.Id businessId, boolean match);


    /**
     *  Clears the business <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBusinessIdTerms();


    /**
     *  Tests if a <code> BusinessQuery </code> is available. 
     *
     *  @return <code> true </code> if a business query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBusinessQuery();


    /**
     *  Gets the query for a business. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the business query 
     *  @throws org.osid.UnimplementedException <code> supportsBusinessQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBusinessQuery() </code> is <code> true. </code> 
     */

    public org.osid.billing.BusinessQuery getBusinessQuery();


    /**
     *  Clears the business terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBusinessTerms();


    /**
     *  Gets the customer query record corresponding to the given <code> 
     *  Customer </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  customerRecordType a customer record type 
     *  @return the customer query record 
     *  @throws org.osid.NullArgumentException <code> customerRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(customerRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.records.CustomerQueryRecord getCustomerQueryRecord(org.osid.type.Type customerRecordType)
        throws org.osid.OperationFailedException;
}
