//
// org.osid.billing.CustomerSearchSession
//
//     The OSID Java specification for org.osid.billing.CustomerSearchSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.billing;


/**
 *  <p>This session provides methods for searching among <code> Customer 
 *  </code> objects. The search query is constructed using the <code> 
 *  CustomerQuery. </code> </p> 
 *  
 *  <p> <code> getCustomersByQuery() </code> is the basic search method and 
 *  returns a list of <code> Customers. </code> A more advanced search may be 
 *  performed with <code> getCustomersBySearch(). </code> It accepts a <code> 
 *  CustomerSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getCustomersBySearch() </code> returns a <code> 
 *  CustomerSearchResults </code> that can be used to access the resulting 
 *  <code> CustomerList </code> or be used to perform a search within the 
 *  result set through <code> CustomerSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated business view: searches include customers in businesses 
 *      of which this business is an ancestor in the business hierarchy </li> 
 *      <li> isolated business view: searches are restricted to customers in 
 *      this business </li> 
 *  </ul>
 *  
 *  
 *  <p> Customers may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> CustomerQuery. </code> 
 *  </p>
 */

public interface CustomerSearchSession
    extends org.osid.billing.CustomerQuerySession {


    /**
     *  Gets a customer search. 
     *
     *  @return the customer search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.CustomerSearch getCustomerSearch();


    /**
     *  Gets a customer search order. The <code> CustomerSearchOrder </code> 
     *  is supplied to a <code> CustomerSearch </code> to specify the ordering 
     *  of results. 
     *
     *  @return the customer search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.CustomerSearchOrder getCustomerSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  customerQuery the customer query 
     *  @param  customerSearch the customer search 
     *  @return the customer search results 
     *  @throws org.osid.NullArgumentException <code> customerQuery </code> or 
     *          <code> customerSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> customerQuery </code> or 
     *          <code> customerSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.CustomerSearchResults getCustomersBySearch(org.osid.billing.CustomerQuery customerQuery, 
                                                                       org.osid.billing.CustomerSearch customerSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a customer query from an inspector. The inspector is available 
     *  from a <code> CustomerSearchResults. </code> 
     *
     *  @param  customerQueryInspector a customer query inspector 
     *  @return the customer query 
     *  @throws org.osid.NullArgumentException <code> customerQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> customerQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.CustomerQuery getCustomerQueryFromInspector(org.osid.billing.CustomerQueryInspector customerQueryInspector);
}
