//
// org.osid.billing.EntrySearchSession
//
//     The OSID Java specification for org.osid.billing.EntrySearchSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.billing;


/**
 *  <p>This session provides methods for searching among <code> Entry </code> 
 *  objects. The search query is constructed using the <code> EntryQuery. 
 *  </code> </p> 
 *  
 *  <p> <code> getEntriesByQuery() </code> is the basic search method and 
 *  returns a list of <code> Entrys. </code> A more advanced search may be 
 *  performed with <code> getEntrysBySearch(). </code> It accepts an <code> 
 *  EntrySearch </code> in addition to the query for the purpose of specifying 
 *  additional options affecting the entire search, such as ordering. <code> 
 *  getEntriesBySearch() </code> returns an <code> EntrySearchResults </code> 
 *  that can be used to access the resulting <code> EntryList </code> or be 
 *  used to perform a search within the result set through <code> EntrySearch. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated business view: searches include entries in businesses 
 *      of which this business is an ancestor in the business hierarchy </li> 
 *      <li> isolated business view: searches are restricted to entries in 
 *      this business </li> 
 *  </ul>
 *  
 *  
 *  <p> Entries may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> EntryQuery. </code> 
 *  </p>
 */

public interface EntrySearchSession
    extends org.osid.billing.EntryQuerySession {


    /**
     *  Gets an entry search. 
     *
     *  @return the entry search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.EntrySearch getEntrySearch();


    /**
     *  Gets an entry search order. The <code> EntrySearchOrder </code> is 
     *  supplied to an <code> EntrySearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the entry search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.EntrySearchOrder getEntrySearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  entryQuery the entry query 
     *  @param  entrySearch the entry search 
     *  @return the entry search results 
     *  @throws org.osid.NullArgumentException <code> entryQuery </code> or 
     *          <code> entrySearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> entryQuery </code> or 
     *          <code> entrySearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.EntrySearchResults getEntriesBySearch(org.osid.billing.EntryQuery entryQuery, 
                                                                  org.osid.billing.EntrySearch entrySearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an entry query from an inspector. The inspector is available from 
     *  an <code> EntrySearchResults. </code> 
     *
     *  @param  entryQueryInspector an entry query inspector 
     *  @return the entry query 
     *  @throws org.osid.NullArgumentException <code> entryQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> entryQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.EntryQuery getEntryQueryFromInspector(org.osid.billing.EntryQueryInspector entryQueryInspector);
}
