//
// org.osid.billing.Item
//
//     The OSID Java specification for org.osid.billing.Item.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.billing;


/**
 *  <p>An <code> Item </code> is a product or service. </p>
 */

public interface Item
    extends org.osid.OsidObject {


    /**
     *  Gets the category <code> Id. </code> 
     *
     *  @return the category <code> Id </code> 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.id.Id getCategoryId();


    /**
     *  Gets the item category. 
     *
     *  @return the category 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.Category getCategory()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this item relates to s specific general ledger account. 
     *
     *  @return <code> true </code> if this item has an account, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasAccount();


    /**
     *  Gets the account <code> Id. </code> 
     *
     *  @return the account <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> hasAccount() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.id.Id getAccountId();


    /**
     *  Gets the item account. 
     *
     *  @return the account 
     *  @throws org.osid.IllegalStateException <code> hasAccount() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.Account getAccount()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this item relates to s specific product. 
     *
     *  @return <code> true </code> if this item has a product, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasProduct();


    /**
     *  Gets the product <code> Id. </code> 
     *
     *  @return the product <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> hasProduct() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.id.Id getProductId();


    /**
     *  Gets the product. 
     *
     *  @return the product 
     *  @throws org.osid.IllegalStateException <code> hasProduct() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.Product getProduct()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the amount of this item. 
     *
     *  @return the amount 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.Currency getAmount();


    /**
     *  Tests if the amount is a debit or a credit. 
     *
     *  @return <code> true </code> if this item amount is a debit, <code> 
     *          false </code> if it is a credit 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isDebit();


    /**
     *  Tests if this item is a recurring charge. 
     *
     *  @return <code> true </code> if this item is recurring, <code> false 
     *          </code> if one-time 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isRecurring();


    /**
     *  Gets the recurring interval. 
     *
     *  @return the interval 
     *  @throws org.osid.IllegalStateException <code> isRecurring() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Duration getRecurringInterval();


    /**
     *  Gets the item record corresponding to the given <code> Item </code> 
     *  record <code> Type. </code> This method is used to retrieve an object 
     *  implementing the requested record. The <code> itemRecordType </code> 
     *  may be the <code> Type </code> returned in <code> getRecordTypes() 
     *  </code> or any of its parents in a <code> Type </code> hierarchy where 
     *  <code> hasRecordType(itemRecordType) </code> is <code> true </code> . 
     *
     *  @param  itemRecordType the type of item record to retrieve 
     *  @return the item record 
     *  @throws org.osid.NullArgumentException <code> itemRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(itemRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.records.ItemRecord getItemRecord(org.osid.type.Type itemRecordType)
        throws org.osid.OperationFailedException;
}
