//
// org.osid.billing.Period
//
//     The OSID Java specification for org.osid.billing.Period.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.billing;


/**
 *  <p>A <code> Period </code> represents a billing period. </p>
 */

public interface Period
    extends org.osid.OsidObject {


    /**
     *  Gets a display label for this period which may be less formal than the 
     *  display name. 
     *
     *  @return the period label 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getDisplayLabel();


    /**
     *  Tests if this period has an open date. 
     *
     *  @return <code> true </code> if there is an open date associated with 
     *          this period, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasOpenDate();


    /**
     *  Gets the open date. 
     *
     *  @return the open date 
     *  @throws org.osid.IllegalStateException <code> hasOpenDate() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getOpenDate();


    /**
     *  Tests if this period has a close date. 
     *
     *  @return <code> true </code> if there is a close date associated with 
     *          this period, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasCloseDate();


    /**
     *  Gets the close date. 
     *
     *  @return the close date 
     *  @throws org.osid.IllegalStateException <code> hasCloseDate() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getCloseDate();


    /**
     *  Tests if this period has a billing date. 
     *
     *  @return <code> true </code> if there is a billing date associated with 
     *          this period, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasBillingDate();


    /**
     *  Gets the billing date. 
     *
     *  @return the billing date 
     *  @throws org.osid.IllegalStateException <code> hasBillingDate() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getBillingDate();


    /**
     *  Tests if this period has a due date. 
     *
     *  @return <code> true </code> if there is a due date associated with 
     *          this period, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasDueDate();


    /**
     *  Gets the due date. 
     *
     *  @return the due date 
     *  @throws org.osid.IllegalStateException <code> hasDueDate() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getDueDate();


    /**
     *  Gets the period record corresponding to the given <code> Period 
     *  </code> record <code> Type. </code> This method is used to retrieve an 
     *  object implementing the requested record. The <code> periodRecordType 
     *  </code> may be the <code> Type </code> returned in <code> 
     *  getRecordTypes() </code> or any of its parents in a <code> Type 
     *  </code> hierarchy where <code> hasRecordType(periodRecordType) </code> 
     *  is <code> true </code> . 
     *
     *  @param  periodRecordType the type of period record to retrieve 
     *  @return the period record 
     *  @throws org.osid.NullArgumentException <code> periodRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(periodRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.records.PeriodRecord getPeriodRecord(org.osid.type.Type periodRecordType)
        throws org.osid.OperationFailedException;
}
