//
// org.osid.billing.PeriodNotificationSession
//
//     The OSID Java specification for org.osid.billing.PeriodNotificationSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.billing;


/**
 *  <p>This session defines methods to receive notifications on adds/changes 
 *  to <code> Period </code> objects in this <code> Business. </code> This 
 *  also includes existing periods that may appear or disappear due to changes 
 *  in the <code> Business </code> hierarchy, This session is intended for 
 *  consumers needing to synchronize their state with this service without the 
 *  use of polling. Notifications are cancelled when this session is closed. 
 *  </p> 
 *  
 *  <p> The two views defined in this session correspond to the views in the 
 *  <code> PeriodLookupSession. </code> </p>
 */

public interface PeriodNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Business </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Business Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBusinessId();


    /**
     *  Gets the <code> Business </code> associated with this session. 
     *
     *  @return the business 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.Business getBusiness()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can register for <code> Period </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForPeriodNotifications();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include periods in catalogs which are children of this catalog in the 
     *  business hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedBusinessView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts notifications to this business only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedBusinessView();


    /**
     *  Reliable notifications are desired. In reliable mode, notifications 
     *  are to be acknowledged using <code> acknowledgePeriodNotification() 
     *  </code> . 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void reliablePeriodNotifications();


    /**
     *  Unreliable notifications are desired. In unreliable mode, 
     *  notifications do not need to be acknowledged. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void unreliablePeriodNotifications();


    /**
     *  Acknowledge a period notification. 
     *
     *  @param  notificationId the <code> Id </code> of the notification 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void acknowledgePeriodNotification(org.osid.id.Id notificationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new periods. <code> 
     *  PeriodReceiver.newPeriods() </code> is invoked when a new <code> 
     *  Period </code> appears in this business. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewPeriods()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated customers. <code> 
     *  PeriodReceiver.changedPeriods() </code> is invoked when a period in 
     *  this business is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedPeriods()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated period. <code> 
     *  PeriodReceiver.changedPeriods() </code> is invoked when the specified 
     *  period in this business is changed. 
     *
     *  @param  periodId the <code> Id </code> of the <code> Period </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> periodId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedPeriod(org.osid.id.Id periodId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted periods. <code> 
     *  PeriodReceiver.deletedPeriods() </code> is invoked when a period is 
     *  deleted or removed from this business. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedPeriods()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted period. <code> 
     *  PeriodReceiver.deletedPeriods() </code> is invoked when the specified 
     *  period is deleted or removed from this business. 
     *
     *  @param  periodId the <code> Id </code> of the <code> Period </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> periodId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedPeriod(org.osid.id.Id periodId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
