//
// org.osid.billing.batch.EntryBatchFormList
//
//     The OSID Java specification for org.osid.billing.batch.EntryBatchFormList.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO CUSTOMER SHALL THE 
//     AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.billing.batch;


/**
 *  <p>Like all <code> OsidLists, </code> <code> EntryBatchFormList </code> 
 *  provides a means for accessing <code> EntryBatchForm </code> elements 
 *  sequentially either one at a time or many at a time. Examples: </p> 
 *  
 *  <pre>
 *       
 *       
 *       while (ebfl.hasNext()) {
 *            EntryBatchForm form = ebfl.getNextEntryBatchForm();
 *       }
 *       
 *                   
 *       
 *  </pre>
 *  or 
 *  <pre>
 *       
 *       
 *       while (ebfl.hasNext()) {
 *            EntryBatchForm[] forms = ebfl.getNextEntryBatchForms(ebfl.available());
 *       }
 *       
 *                   
 *       
 *  </pre>
 *  
 */

public interface EntryBatchFormList
    extends org.osid.OsidList {


    /**
     *  Gets the next <code> EntryBatchForm </code> in this list. 
     *
     *  @return the next <code> EntryBatchForm </code> in this list. The 
     *          <code> hasNext() </code> method should be used to test that a 
     *          next <code> EntryBatchForm </code> is available before calling 
     *          this method. 
     *  @throws org.osid.IllegalStateException no more elements available in 
     *          this list 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.batch.EntryBatchForm getNextEntryBatchForm()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the next set of <code> EntryBatchForm </code> elements in this 
     *  list. The specified amount must be less than or equal to the return 
     *  from <code> available(). </code> 
     *
     *  @param  n the number of <code> EntryBatchForm </code> elements 
     *          requested which must be less than or equal to <code> 
     *          available() </code> 
     *  @return an array of <code> EntryBatchForm </code> elements. <code> 
     *          </code> The length of the array is less than or equal to the 
     *          number specified. 
     *  @throws org.osid.IllegalStateException no more elements available in 
     *          this list 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.batch.EntryBatchForm[] getNextEntryBatchForms(long n)
        throws org.osid.OperationFailedException;
}
