//
// org.osid.billing.payment.BillingPaymentProfile
//
//     The OSID Java specification for org.osid.billing.payment.BillingPaymentProfile.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.billing.payment;


/**
 *  <p>The billing profile describes the interoperability among billing 
 *  management services. </p>
 */

public interface BillingPaymentProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any business federation is exposed. Federation is exposed 
     *  when a specific business may be identified, selected and used to 
     *  create a lookup or admin session. Federation is not exposed when a set 
     *  of catalogs appears as a single catalog. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if looking up payers is supported. 
     *
     *  @return <code> true </code> if payer lookup is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPayerLookup();


    /**
     *  Tests if querying payers is supported. 
     *
     *  @return <code> true </code> if payer query is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPayerQuery();


    /**
     *  Tests if searching payers is supported. 
     *
     *  @return <code> true </code> if payer search is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPayerSearch();


    /**
     *  Tests if payer <code> </code> administrative service is supported. 
     *
     *  @return <code> true </code> if payer administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPayerAdmin();


    /**
     *  Tests if a payer <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if payer notification is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPayerNotification();


    /**
     *  Tests if a businessing service is supported. 
     *
     *  @return <code> true </code> if businessing is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPayerBusiness();


    /**
     *  Tests if a businessing service is supported. A businessing service 
     *  maps payers to catalogs. 
     *
     *  @return <code> true </code> if businessing is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPayerBusinessAssignment();


    /**
     *  Tests if a payer smart business session is available. 
     *
     *  @return <code> true </code> if a payer smart business session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPayerSmartBusiness();


    /**
     *  Tests if looking up payments is supported. 
     *
     *  @return <code> true </code> if payment lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPaymentLookup();


    /**
     *  Tests if querying payments is supported. 
     *
     *  @return <code> true </code> if payment query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPaymentQuery();


    /**
     *  Tests if searching payments is supported. 
     *
     *  @return <code> true </code> if payment search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPaymentSearch();


    /**
     *  Tests if payment <code> </code> administrative service is supported. 
     *
     *  @return <code> true </code> if payment administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPaymentAdmin();


    /**
     *  Tests if a payment <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if payment notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPaymentNotification();


    /**
     *  Tests if a payment cataloging service is supported. 
     *
     *  @return <code> true </code> if payment catalog is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPaymentBusiness();


    /**
     *  Tests if a payment cataloging service is supported. A cataloging 
     *  service maps payments to catalogs. 
     *
     *  @return <code> true </code> if payment cataloging is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPaymentBusinessAssignment();


    /**
     *  Tests if a payment smart business session is available. 
     *
     *  @return <code> true </code> if a payment smart business session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPaymentSmartBusiness();


    /**
     *  Tests if a payment summary session is available. 
     *
     *  @return <code> true </code> if a summary session is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSummary();


    /**
     *  Tests if a payment batch service is available. 
     *
     *  @return <code> true </code> if a payment batch service is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBillingPaymentBatch();


    /**
     *  Gets the supported <code> Payer </code> record types. 
     *
     *  @return a list containing the supported <code> Payer </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getPayerRecordTypes();


    /**
     *  Tests if the given <code> Payer </code> record type is supported. 
     *
     *  @param  payerRecordType a <code> Type </code> indicating a <code> 
     *          Payer </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> payerRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPayerRecordType(org.osid.type.Type payerRecordType);


    /**
     *  Gets the supported <code> Payer </code> search record types. 
     *
     *  @return a list containing the supported <code> Payer </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getPayerSearchRecordTypes();


    /**
     *  Tests if the given <code> Payer </code> search record type is 
     *  supported. 
     *
     *  @param  payerSearchRecordType a <code> Type </code> indicating a 
     *          <code> Payer </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> payerSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPayerSearchRecordType(org.osid.type.Type payerSearchRecordType);


    /**
     *  Gets the supported <code> Payment </code> record types. 
     *
     *  @return a list containing the supported <code> Payment </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getPaymentRecordTypes();


    /**
     *  Tests if the given <code> Payment </code> record type is supported. 
     *
     *  @param  paymentRecordType a <code> Type </code> indicating a <code> 
     *          Payment </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> paymentRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPaymentRecordType(org.osid.type.Type paymentRecordType);


    /**
     *  Gets the supported <code> Payment </code> search record types. 
     *
     *  @return a list containing the supported <code> Payment </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getPaymentSearchRecordTypes();


    /**
     *  Tests if the given <code> Payment </code> search record type is 
     *  supported. 
     *
     *  @param  paymentSearchRecordType a <code> Type </code> indicating a 
     *          <code> Payment </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> paymentSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPaymentSearchRecordType(org.osid.type.Type paymentSearchRecordType);


    /**
     *  Gets the supported <code> Summary </code> record types. 
     *
     *  @return a list containing the supported <code> Summary </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSummaryRecordTypes();


    /**
     *  Tests if the given <code> Summary </code> record type is supported. 
     *
     *  @param  summaryRecordType a <code> Type </code> indicating a <code> 
     *          Summary </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> summaryRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSummaryRecordType(org.osid.type.Type summaryRecordType);
}
