//
// org.osid.billing.payment.PayerSearchSession
//
//     The OSID Java specification for org.osid.billing.payment.PayerSearchSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.billing.payment;


/**
 *  <p>This session provides methods for searching among <code> Payer </code> 
 *  objects. The search query is constructed using the <code> PayerQuery. 
 *  </code> </p> 
 *  
 *  <p> <code> getPayersByQuery() </code> is the basic search method and 
 *  returns a list of <code> Payers. </code> A more advanced search may be 
 *  performed with <code> getPayersBySearch(). </code> It accepts a <code> 
 *  PayerSearch </code> in addition to the query for the purpose of specifying 
 *  additional options affecting the entire search, such as ordering. <code> 
 *  getPayersBySearch() </code> returns a <code> PayerSearchResults </code> 
 *  that can be used to access the resulting <code> PayerList </code> or be 
 *  used to perform a search within the result set through <code> PayerSearch. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated business view: searches include payers in businesses of 
 *      which this business is an ancestor in the business hierarchy </li> 
 *      <li> isolated business view: searches are restricted to payers in this 
 *      business </li> 
 *  </ul>
 *  
 *  
 *  <p> Payers may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> PayerQuery. </code> 
 *  </p>
 */

public interface PayerSearchSession
    extends org.osid.billing.payment.PayerQuerySession {


    /**
     *  Gets a payer search. 
     *
     *  @return the payer search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.payment.PayerSearch getPayerSearch();


    /**
     *  Gets a payer search order. The <code> PayerSearchOrder </code> is 
     *  supplied to a <code> PayerSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the payer search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.payment.PayerSearchOrder getPayerSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  payerQuery the payer query 
     *  @param  payerSearch the payer search 
     *  @return the payer search results 
     *  @throws org.osid.NullArgumentException <code> payerQuery </code> or 
     *          <code> payerSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> payerQuery </code> or 
     *          <code> payerSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.payment.PayerSearchResults getPayersBySearch(org.osid.billing.payment.PayerQuery payerQuery, 
                                                                         org.osid.billing.payment.PayerSearch payerSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a payer query from an inspector. The inspector is available from 
     *  a <code> PayerSearchResults. </code> 
     *
     *  @param  payerQueryInspector a payer query inspector 
     *  @return the payer query 
     *  @throws org.osid.NullArgumentException <code> payerQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> payerQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.payment.PayerQuery getPayerQueryFromInspector(org.osid.billing.payment.PayerQueryInspector payerQueryInspector);
}
