//
// org.osid.billing.payment.Payment
//
//     The OSID Java specification for org.osid.billing.payment.Payment.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.billing.payment;


/**
 *  <p>A <code> Payment. </code> </p>
 */

public interface Payment
    extends org.osid.OsidObject {


    /**
     *  Gets the payer <code> Id. </code> 
     *
     *  @return the payer <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPayerId();


    /**
     *  Gets the payer. 
     *
     *  @return the payer 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.payment.Payer getPayer()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the customer <code> Id </code> for which this payment applies. 
     *
     *  @return the customer <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCustomerId();


    /**
     *  Gets the customer for which this payment applies. 
     *
     *  @return the customer 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.Customer getCustomer()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the billing period <code> Id </code> to which this payment 
     *  applies. 
     *
     *  @return the period <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPeriodId();


    /**
     *  Gets the billing period to which this payment applied. 
     *
     *  @return the period 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.Period getPeriod()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the date the payment was made. 
     *
     *  @return the payment date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getPaymentDate();


    /**
     *  Gets the date the payment was or will be processed. 
     *
     *  @return the process date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getProcessDate();


    /**
     *  Gets the amount of this payment. 
     *
     *  @return the amount 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.Currency getAmount();


    /**
     *  Gets the payment record corresponding to the given <code> Payment 
     *  </code> record <code> Type. </code> This method is used to retrieve an 
     *  object implementing the requested record. The <code> paymentRecordType 
     *  </code> may be the <code> Type </code> returned in <code> 
     *  getRecordTypes() </code> or any of its parents in a <code> Type 
     *  </code> hierarchy where <code> hasRecordType(paymentRecordType) 
     *  </code> is <code> true </code> . 
     *
     *  @param  paymentRecordType the type of payment record to retrieve 
     *  @return the payment record 
     *  @throws org.osid.NullArgumentException <code> paymentRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(paymentRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.payment.records.PaymentRecord getPaymentRecord(org.osid.type.Type paymentRecordType)
        throws org.osid.OperationFailedException;
}
