//
// org.osid.billing.payment.PaymentLookupSession
//
//     The OSID Java specification for org.osid.billing.payment.PaymentLookupSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.billing.payment;


/**
 *  <p>This session defines methods for retrieving payments. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated business view: All payment methods in this session 
 *      operate, retrieve and pertain to payments defined explicitly in the 
 *      current business. Using an isolated view is useful for managing <code> 
 *      Payments </code> with the <code> PaymentAdminSession. </code> </li> 
 *      <li> federated business view: All payment lookup methods in this 
 *      session operate, retrieve and pertain to all payments defined in this 
 *      business and any other payments implicitly available in this business 
 *      through business inheritence. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedBusinessView() </code> and <code> 
 *  useIsolatedBusinessView() </code> behave as a radio group and one should 
 *  be selected before invoking any lookup methods. </p> 
 *  
 *  <p> Payments may have an additional records indicated by their respective 
 *  record types. The record may not be accessed through a cast of the <code> 
 *  Payment. </code> </p>
 */

public interface PaymentLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Business </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Business Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBusinessId();


    /**
     *  Gets the <code> Business </code> associated with this session. 
     *
     *  @return the business 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.Business getBusiness()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Payment </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupPayments();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativePaymentView();


    /**
     *  A complete view of the <code> Payment </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryPaymentView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include payments in catalogs which are children of this catalog in the 
     *  business hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedBusinessView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this business only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedBusinessView();


    /**
     *  Gets the <code> Payment </code> specified by its <code> Id. </code> In 
     *  plenary mode, the exact <code> Id </code> is found or a <code> 
     *  NOT_FOUND </code> results. Otherwise, the returned <code> Payment 
     *  </code> may have a different <code> Id </code> than requested, such as 
     *  the case where a duplicate <code> Id </code> was assigned to a <code> 
     *  Payment </code> and retained for compatibility. 
     *
     *  @param  paymentId the <code> Id </code> of the <code> Payment </code> 
     *          to retrieve 
     *  @return the returned <code> Payment </code> 
     *  @throws org.osid.NotFoundException no <code> Payment </code> found 
     *          with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> paymentId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.payment.Payment getPayment(org.osid.id.Id paymentId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PaymentList </code> corresponding to the given <code> 
     *  IdList. </code> In plenary mode, the returned list contains all of the 
     *  payments specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Payments </code> may be omitted from the list and 
     *  may present the elements in any order including returning a unique 
     *  set. 
     *
     *  @param  paymentIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Payment </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> paymentIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.payment.PaymentList getPaymentsByIds(org.osid.id.IdList paymentIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PaymentList </code> corresponding to the given payment 
     *  genus <code> Type </code> which does not include payments of types 
     *  derived from the specified <code> Type. </code> In plenary mode, the 
     *  returned list contains all known payments or an error results. 
     *  Otherwise, the returned list may contain only those payments that are 
     *  accessible through this session. 
     *
     *  @param  paymentGenusType a payment genus type 
     *  @return the returned <code> Payment </code> list 
     *  @throws org.osid.NullArgumentException <code> paymentGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.payment.PaymentList getPaymentsByGenusType(org.osid.type.Type paymentGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PaymentList </code> corresponding to the given payment 
     *  genus <code> Type </code> and include any additional payments with 
     *  genus types derived from the specified <code> Type. </code> In plenary 
     *  mode, the returned list contains all known payments or an error 
     *  results. Otherwise, the returned list may contain only those payments 
     *  that are accessible through this session. 
     *
     *  @param  paymentGenusType a payment genus type 
     *  @return the returned <code> Payment </code> list 
     *  @throws org.osid.NullArgumentException <code> paymentGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.payment.PaymentList getPaymentsByParentGenusType(org.osid.type.Type paymentGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PaymentList </code> containing the given payment record 
     *  <code> Type. </code> In plenary mode, the returned list contains all 
     *  known payments or an error results. Otherwise, the returned list may 
     *  contain only those payments that are accessible through this session. 
     *
     *  @param  paymentRecordType a payment record type 
     *  @return the returned <code> Payment </code> list 
     *  @throws org.osid.NullArgumentException <code> paymentRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.payment.PaymentList getPaymentsByRecordType(org.osid.type.Type paymentRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PaymentList </code> in the given period. In plenary 
     *  mode, the returned list contains all known payments or an error 
     *  results. Otherwise, the returned list may contain only those payments 
     *  that are accessible through this session. 
     *
     *  @param  periodId a period <code> Id </code> 
     *  @return the returned <code> Payment </code> list 
     *  @throws org.osid.NullArgumentException <code> periodId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.payment.PaymentList getPaymentsByPeriod(org.osid.id.Id periodId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PaymentList </code> for the given payer. In plenary 
     *  mode, the returned list contains all known payments or an error 
     *  results. Otherwise, the returned list may contain only those payments 
     *  that are accessible through this session. 
     *
     *  @param  payerId a payer <code> Id </code> 
     *  @return the returned <code> Payment </code> list 
     *  @throws org.osid.NullArgumentException <code> payerId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.payment.PaymentList getPaymentsForPayer(org.osid.id.Id payerId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PaymentList </code> for the given payer in a billing 
     *  period. In plenary mode, the returned list contains all known payments 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those payments that are accessible through this session. 
     *
     *  @param  payerId a payer <code> Id </code> 
     *  @param  periodId a period <code> Id </code> 
     *  @return the returned <code> Payment </code> list 
     *  @throws org.osid.NullArgumentException <code> payerId </code> or 
     *          <code> periodId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.payment.PaymentList getPaymentsByPeriodForPayer(org.osid.id.Id payerId, 
                                                                            org.osid.id.Id periodId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PaymentList </code> for the given payer made within the 
     *  given date range inclusive. In plenary mode, the returned list 
     *  contains all known payments or an error results. Otherwise, the 
     *  returned list may contain only those payments that are accessible 
     *  through this session. 
     *
     *  @param  payerId a payer <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Payment </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> payerId </code> or 
     *          <code> periodId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.payment.PaymentList getPaymentsForPayerOnDate(org.osid.id.Id payerId, 
                                                                          org.osid.calendaring.DateTime from, 
                                                                          org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PaymentList </code> for the given customer. In plenary 
     *  mode, the returned list contains all known payments or an error 
     *  results. Otherwise, the returned list may contain only those payments 
     *  that are accessible through this session. 
     *
     *  @param  customerId a customer <code> Id </code> 
     *  @return the returned <code> Payment </code> list 
     *  @throws org.osid.NullArgumentException <code> customerId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.payment.PaymentList getPaymentsForCustomer(org.osid.id.Id customerId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PaymentList </code> for the given customer and billing 
     *  period. In plenary mode, the returned list contains all known payments 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those payments that are accessible through this session. 
     *
     *  @param  customerId a customer <code> Id </code> 
     *  @param  periodId a period <code> Id </code> 
     *  @return the returned <code> Payment </code> list 
     *  @throws org.osid.NullArgumentException <code> customerId </code> or 
     *          <code> periodId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.payment.PaymentList getPaymentsByPeriodForCustomer(org.osid.id.Id customerId, 
                                                                               org.osid.id.Id periodId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PaymentList </code> for the given customer made within 
     *  the given date range inclusive. In plenary mode, the returned list 
     *  contains all known payments or an error results. Otherwise, the 
     *  returned list may contain only those payments that are accessible 
     *  through this session. 
     *
     *  @param  customerId a customer <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Payment </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> customerId </code> or 
     *          <code> periodId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.payment.PaymentList getPaymentsForCustomerOnDate(org.osid.id.Id customerId, 
                                                                             org.osid.calendaring.DateTime from, 
                                                                             org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PaymentList </code> for the given payer and customer. In 
     *  plenary mode, the returned list contains all known payments or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  payments that are accessible through this session. 
     *
     *  @param  payerId a payer <code> Id </code> 
     *  @param  customerId a customerId <code> Id </code> 
     *  @return the returned <code> Payment </code> list 
     *  @throws org.osid.NullArgumentException <code> payerId </code> or 
     *          <code> customerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.payment.PaymentList getPaymentsForPayerAndCustomer(org.osid.id.Id payerId, 
                                                                               org.osid.id.Id customerId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PaymentList </code> for the given payer and customer in 
     *  a billing period. In plenary mode, the returned list contains all 
     *  known payments or an error results. Otherwise, the returned list may 
     *  contain only those payments that are accessible through this session. 
     *
     *  @param  payerId a payer <code> Id </code> 
     *  @param  customerId a customerId <code> Id </code> 
     *  @param  periodId a period <code> Id </code> 
     *  @return the returned <code> Payment </code> list 
     *  @throws org.osid.NullArgumentException <code> payerId, customerId, 
     *          </code> or <code> periodId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.payment.PaymentList getPaymentsByPeriodForPayerAndCustomer(org.osid.id.Id payerId, 
                                                                                       org.osid.id.Id customerId, 
                                                                                       org.osid.id.Id periodId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PaymentList </code> for the given customer and payer 
     *  made within the given date range inclusive. In plenary mode, the 
     *  returned list contains all known payments or an error results. 
     *  Otherwise, the returned list may contain only those payments that are 
     *  accessible through this session. 
     *
     *  @param  payerId a payer <code> Id </code> 
     *  @param  customerId a customerId <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Payment </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> payerId, customerId, 
     *          </code> or <code> periodId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.payment.PaymentList getPaymentsForPayerAndCustomerOnDate(org.osid.id.Id payerId, 
                                                                                     org.osid.id.Id customerId, 
                                                                                     org.osid.calendaring.DateTime from, 
                                                                                     org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Payments. </code> In plenary mode, the returned list 
     *  contains all known payments or an error results. Otherwise, the 
     *  returned list may contain only those payments that are accessible 
     *  through this session. 
     *
     *  @return a list of <code> Payments </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.payment.PaymentList getPayments()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
