//
// org.osid.billing.payment.PaymentQuery
//
//     The OSID Java specification for org.osid.billing.payment.PaymentQuery.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.billing.payment;


/**
 *  <p>This is the query for searching payments. Each method match specifies 
 *  an <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface PaymentQuery
    extends org.osid.OsidObjectQuery {


    /**
     *  Sets the payer <code> Id </code> for this query. 
     *
     *  @param  payerId a payer <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> payerId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchPayerId(org.osid.id.Id payerId, boolean match);


    /**
     *  Clears the payer <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPayerIdTerms();


    /**
     *  Tests if a <code> PayerQuery </code> is available. 
     *
     *  @return <code> true </code> if a payer query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPayerQuery();


    /**
     *  Gets the query for a payer. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the payer query 
     *  @throws org.osid.UnimplementedException <code> supportsPayerQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPayerQuery() </code> is <code> true. </code> 
     */

    public org.osid.billing.payment.PayerQuery getPayerQuery();


    /**
     *  Clears the payer terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPayerTerms();


    /**
     *  Sets the customer <code> Id </code> for this query. 
     *
     *  @param  customerId a customer <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> customerId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCustomerId(org.osid.id.Id customerId, boolean match);


    /**
     *  Clears the customer <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCustomerIdTerms();


    /**
     *  Tests if a <code> CustomereQuery </code> is available. 
     *
     *  @return <code> true </code> if a customer query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCustomerQuery();


    /**
     *  Gets the query for a customer. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return a customer query 
     *  @throws org.osid.UnimplementedException <code> supportsCustomerQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCustomerQuery() </code> is <code> true. </code> 
     */

    public org.osid.billing.CustomerQuery getCustomerQuery();


    /**
     *  Clears the customer terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCustomerTerms();


    /**
     *  Sets the biliing period <code> Id </code> for this query. 
     *
     *  @param  periodId a period <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> periodId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchPeriodId(org.osid.id.Id periodId, boolean match);


    /**
     *  Clears the billing period <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPeriodIdTerms();


    /**
     *  Tests if a <code> PeriodQuery </code> is available. 
     *
     *  @return <code> true </code> if a period query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPeriodQuery();


    /**
     *  Gets the query for a billing period. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the period query 
     *  @throws org.osid.UnimplementedException <code> supportsPeriodQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPeriodQuery() </code> is <code> true. </code> 
     */

    public org.osid.billing.PeriodQuery getPeriodQuery();


    /**
     *  Matches payments with any billing period. 
     *
     *  @param  match <code> true </code> to match payments with any period, 
     *          <code> false </code> to match peyments with no period 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyPeriod(boolean match);


    /**
     *  Clears the billing period terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPeriodTerms();


    /**
     *  Matches payment dates between the given date range inclusive. 
     *
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchPaymentDate(org.osid.calendaring.DateTime from, 
                                 org.osid.calendaring.DateTime to, 
                                 boolean match);


    /**
     *  Clears the payment date terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPaymentDateTerms();


    /**
     *  Matches process dates between the given date range inclusive. 
     *
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchProcessDate(org.osid.calendaring.DateTime from, 
                                 org.osid.calendaring.DateTime to, 
                                 boolean match);


    /**
     *  Matches payments with any process date. 
     *
     *  @param  match <code> true </code> to match payments with any process 
     *          date, <code> false </code> to match peyments with no process 
     *          date 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyProcessDate(boolean match);


    /**
     *  Clears the process date terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProcessDateTerms();


    /**
     *  Matches amounts between the given range inclusive. 
     *
     *  @param  from start of range 
     *  @param  to end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAmount(org.osid.financials.Currency from, 
                            org.osid.financials.Currency to, boolean match);


    /**
     *  Matches payments with any amount. 
     *
     *  @param  match <code> true </code> to match payments with any amount, 
     *          <code> false </code> to match peyments with no amount 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAmount(boolean match);


    /**
     *  Clears the amount. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAmountTerms();


    /**
     *  Sets the business <code> Id </code> for this query to match payments 
     *  assigned to businesses. 
     *
     *  @param  businessId the business <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> businessId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBusinessId(org.osid.id.Id businessId, boolean match);


    /**
     *  Clears the business <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBusinessIdTerms();


    /**
     *  Tests if a <code> BusinessQuery </code> is available. 
     *
     *  @return <code> true </code> if a business query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBusinessQuery();


    /**
     *  Gets the query for a business. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the business query 
     *  @throws org.osid.UnimplementedException <code> supportsBusinessQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBusinessQuery() </code> is <code> true. </code> 
     */

    public org.osid.billing.BusinessQuery getBusinessQuery();


    /**
     *  Clears the business terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBusinessTerms();


    /**
     *  Gets the payment query record corresponding to the given <code> 
     *  Payment </code> record <code> Type. </code> Multiple record retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @param  paymentRecordType a payment record type 
     *  @return the payment query record 
     *  @throws org.osid.NullArgumentException <code> paymentRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(paymentRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.payment.records.PaymentQueryRecord getPaymentQueryRecord(org.osid.type.Type paymentRecordType)
        throws org.osid.OperationFailedException;
}
