//
// org.osid.billing.payment.PaymentSearchSession
//
//     The OSID Java specification for org.osid.billing.payment.PaymentSearchSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.billing.payment;


/**
 *  <p>This session provides methods for searching among <code> Payment 
 *  </code> objects. The search query is constructed using the <code> 
 *  PaymentQuery. </code> </p> 
 *  
 *  <p> <code> getPaymentsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Payments. </code> A more advanced search may be 
 *  performed with <code> getPaymentsBySearch(). </code> It accepts a <code> 
 *  PaymentSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getPaymentsBySearch() </code> returns a <code> 
 *  PaymentSearchResults </code> that can be used to access the resulting 
 *  <code> PaymentList </code> or be used to perform a search within the 
 *  result set through <code> PaymentSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated business view: searches include payments in businesses 
 *      of which this business is an ancestor in the business hierarchy </li> 
 *      <li> isolated business view: searches are restricted to payments in 
 *      this business </li> 
 *  </ul>
 *  
 *  
 *  <p> Payments may have a query record indicated by their respective record 
 *  types. The queryrecord is accessed via the <code> PaymentQuery. </code> 
 *  </p>
 */

public interface PaymentSearchSession
    extends org.osid.billing.payment.PaymentQuerySession {


    /**
     *  Gets a payment search. 
     *
     *  @return the payment search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.payment.PaymentSearch getPaymentSearch();


    /**
     *  Gets a payment search order. The <code> PaymentSearchOrder </code> is 
     *  supplied to a <code> PaymentSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the payment search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.payment.PaymentSearchOrder getPaymentSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  paymentQuery the payment query 
     *  @param  paymentSearch the payment search 
     *  @return the payment search results 
     *  @throws org.osid.NullArgumentException <code> paymentQuery </code> or 
     *          <code> paymentSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> paymentQuery </code> or 
     *          <code> paymentSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.payment.PaymentSearchResults getPaymentsBySearch(org.osid.billing.payment.PaymentQuery paymentQuery, 
                                                                             org.osid.billing.payment.PaymentSearch paymentSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a payment query from an inspector. The inspector is available 
     *  from a <code> PaymentSearchResults. </code> 
     *
     *  @param  paymentQueryInspector a payment query inspector 
     *  @return the payment query 
     *  @throws org.osid.NullArgumentException <code> paymentQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> paymentQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.payment.PaymentQuery getPaymentQueryFromInspector(org.osid.assessment.ItemQueryInspector paymentQueryInspector);
}
