//
// org.osid.billing.payment.Summary
//
//     The OSID Java specification for org.osid.billing.payment.Summary.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.billing.payment;


/**
 *  <p>A <code> Payment. </code> </p>
 */

public interface Summary
    extends org.osid.OsidCompendium {


    /**
     *  Gets the customer <code> Id. </code> 
     *
     *  @return the customer <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCustomerId();


    /**
     *  Gets the customer. 
     *
     *  @return the customer 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.Customer getCustomer()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the billing period <code> Id </code> To which this summary 
     *  pertains. 
     *
     *  @return the period <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPeriodId();


    /**
     *  Gets the billing period to which this summary pertains. 
     *
     *  @return the period 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.Period getPeriod()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if the balance is a credit or customer owes money. 
     *
     *  @return <code> true </code> if a credit, <code> false </code> if a 
     *          debit 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isCreditBalance();


    /**
     *  Gets the balance for this customer. 
     *
     *  @return the balance 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.Currency getBalance();


    /**
     *  Tests if the customer has paid before. 
     *
     *  @return <code> true </code> if there is a last payment, <code> false 
     *          </code> otehrwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasLastPayment();


    /**
     *  Gets the date the last payment was made. 
     *
     *  @return the last payment date 
     *  @throws org.osid.IllegalStateException <code> hasLastPayment() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getLastPaymentDate();


    /**
     *  Gets the last payment for this customer. 
     *
     *  @return the payment 
     *  @throws org.osid.IllegalStateException <code> hasLastPayment() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.Currency getLastPayment();


    /**
     *  Gets the date the next payment is due. 
     *
     *  @return the payment due date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getPaymentDueDate();


    /**
     *  Gets the payment record corresponding to the given <code> Summary 
     *  </code> record <code> Type. </code> This method is used to retrieve an 
     *  object implementing the requested record. The <code> summaryRecordType 
     *  </code> may be the <code> Type </code> returned in <code> 
     *  getRecordTypes() </code> or any of its parents in a <code> Type 
     *  </code> hierarchy where <code> hasRecordType(summarytRecordType) 
     *  </code> is <code> true </code> . 
     *
     *  @param  summaryRecordType the type of summary record to retrieve 
     *  @return the summary record 
     *  @throws org.osid.NullArgumentException <code> summaryRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(summaryRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.payment.records.SummaryRecord getSummaryRecord(org.osid.type.Type summaryRecordType)
        throws org.osid.OperationFailedException;
}
