//
// Coordinate
//
//    Supplements the OSID Coordinate interface for Java.
//
//
// Tom Coppeto
// OnTapSolutions
// 21 October 2009
//
// Copyright (c) 2009 Ingenescus. All Rights Reserved.
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//

package org.osid.binding.java;


/**
 *  Supplements the OSID Coordinate interface for Java.
 */

public interface Coordinate
    extends OsidPrimitive,
	    Comparable<org.osid.mapping.Coordinate> {


    /**
     *	Tests if this <code>Coordinate</code> is greater in area than
     *	the given <code>Coordinate</code>. A greater
     *	<code>Coordinate</code> is one whose values minus uncertainty
     *	is greater than another plus its uncertainty. An uncertainty
     *	of infinity is undefined and returns false.
     *
     *  It is possible for <code>isLarger()</code>,
     *  <code>isSmaller()</code>, and equals() to be all
     *  <code>false</code> among two <code>Coordinates</code> due to
     *  uncertainties in the values. In this case,
     *  <code>compareTo()</code> may elect to return a value to
     *  provide a natural ordering but should not be used to determine
     *  equality. <code>equals()</code> tends to have a stricter
     *  definition of equality.
     *
     *	@param	coordinate the coordinate to compare
     *	@return <code>true</code> if this coordinate is larger,
     *		<code>false</code> otherwise
     *	@throws org.osid.NullArgumentException <code>coordinate</code>
     *		is <code>null</code>
     *	@throws org.osid.UnsupportedException cannot compare coordinate
     */

    public boolean isLarger(org.osid.mapping.Coordinate coordinate);


    /**
     *	Tests if this <code>Coordinate</code> is less in area than the
     *	given <code>Coordinate</code>. A lesser
     *	<code>Coordinate</code> is one whose values plus uncertainty
     *	is less than another minus its uncertainty. An uncertainty of
     *	infinity is undefined and returns false.
     *
     *  It is possible for <code>isLarger()</code>,
     *  <code>isSmaller()</code>, and equals() to be all
     *  <code>false</code> among two <code>Coordinates</code> due to
     *  uncertainties in the values. In this case,
     *  <code>compareTo()</code> may elect to return a value to
     *  provide a natural ordering but should not be used to determine
     *  equality. <code>equals()</code> tends to have a stricter
     *  definition of equality.
     *
     *	@param	coordinate the coordinate to compare
     *	@return <code>true</code> if this coordinate is less,
     *		<code>false</code> otherwise
     *	@throws org.osid.NullArgumentException <code>coordinate</code>
     *		is <code>null</code>
     *	@throws org.osid.UnsupportedException cannot compare coordinate
     */

    public boolean isSmaller(org.osid.mapping.Coordinate coordinate);


    /**
     *	Tests if one <code>Coordinate</code> is closer to origin than
     *	another to this <code>Coordinate</code>. A greater
     *	<code>Coordinate</code> is one whose values minus uncertainty
     *	is greater than another plus its uncertainty. An uncertainty
     *	of infinity is undefined and returns false.
     *
     *  It is possible for <code>isCloser()</code> and
     *  <code>isFarther()</code> to be both <code>false</code> among
     *  two <code>Coordinates</code> due to uncertainties in the
     *  values.
     *
     *	@param	one the coordinate to compare
     *	@param	another the coordinate to compare
     *	@return <code>true</code> if this <code>one</code> is closer
     *		than <code>another</code>, <code>false</code>
     *		otherwise
     *	@throws org.osid.NullArgumentException <code>one</code> or
     *		<code>another</code> is <code>null</code>
     *	@throws org.osid.UnsupportedException cannot compare coordinate
     */

    public boolean isCloser(org.osid.mapping.Coordinate one, 
			    org.osid.mapping.Coordinate another);


    /**
     *	Tests if one <code>Coordinate</code> is farther from origin
     *	than another from this <code>Coordinate</code>. A greater
     *	<code>Coordinate</code> is one whose values minus uncertainty
     *	is greater than another plus its uncertainty. An uncertainty
     *	of infinity is undefined and returns false.
     *
     *  It is possible for <code>isCloser()</code> and
     *  <code>isFarther()</code> to be both <code>false</code> among
     *  two <code>Coordinates</code> due to uncertainties in the
     *  values.
     *
     *	@param	one the coordinate to compare
     *	@param	another the coordinate to compare
     *	@return <code>true</code> if this <code>one</code> is closer
     *		than <code>another</code>, <code>false</code>
     *		otherwise
     *	@throws org.osid.NullArgumentException <code>one</code> or
     *		<code>another</code> is <code>null</code>
     *	@throws org.osid.UnsupportedException cannot compare coordinate
     */

    public boolean isFarther(org.osid.mapping.Coordinate one, 
			     org.osid.mapping.Coordinate another);


    /**
     *	Tests if this <code>Coordinate</code>, as specified by its
     *	uncertainty, completely includes the given
     *	<code>Coordinate</code> ranged by its uncertainty.
     *
     *	If either coordinate has an uncertainty of infinity this
     *	method returns false.
     *
     *  It is possible for <code>isInclusive()</code> and
     *  <code>isExclsuive()</code> to be both <code>false</code> among
     *  two <code>Coordinates</code> due to uncertainties in the
     *  values.
     *
     *	@param	coordinate the coordinate to compare
     *	@return <code>true</code> if this coordinate includes the given
     *		coordinate, <code>false</code> otherwise
     *	@throws org.osid.NullArgumentException <code>coordinate</code>
     *		is <code>null</code>
     *	@throws org.osid.UnsupportedException cannot compare coordinate
     */

    public boolean isInclusive(org.osid.mapping.Coordinate coordinate);


    /**
     *	Tests if this <code>Coordinate</code>, as specified by its
     *	uncertainty, does not overlap the given
     *	<code>Coordinate</code>.
     *
     *	If either coordinate has an uncertainty of infinity this
     *	method returns false.
     *
     *  It is possible for <code>isInclusive()</code> and
     *  <code>isExclsuive()</code> to be both <code>false</code> among
     *  two <code>Coordinates</code> due to uncertainties in the
     *  values.
     *     
     *	@param	coordinate the coordinate to compare
     *	@return <code>true</code> if this coordinate is excluded,
     *		<code>false</code> otherwise
     *	@throws org.osid.NullArgumentException <code>coordinate</code>
     *		is <code>null</code>
     *	@throws org.osid.UnsupportedException cannot compare coordinate
     */

    public boolean isExclusive(org.osid.mapping.Coordinate coordinate);


    /**
     *	Gets the outer bound of the coordinate. The outer bound is the
     *	coordinate plus the uncertainty. This method returns the area
     *	around the Coordinate with the largest radius allowed by its
     *	uncertainty.
     *
     *	@return the coordinate upper bound
     */

    public org.osid.mapping.SpatialUnit getOuterBound();


    /**
     *	Gets the closest bound of the coordinate. The closest bound is
     *	the coordinate of the same granularity in the uncertainty
     *	range closest to the origin.
     *
     *	@return the coordinate lower bound
     */

    public org.osid.mapping.Coordinate getClosestBound();


    /**
     *	Gets the farthest bound of the coordinate. The farthest bound
     *	is the coordinate of the same granularity in the uncertainty
     *	range farthest from the origin.
     *
     *	@return the coordinate upper bound
     */

    public org.osid.mapping.Coordinate getFarthestBound();


    /**
     *  Compares this coordinate with the specified
     *  <code>Coordinate</code> to determine the natural
     *  order. Returns a negative integer, zero, or a positive integer
     *  as this coordinate is less than, equal to, or greater than the
     *  specified coordinate.
     *
     *  The natural ordering is determined first by the natural
     *  ordering of the coordinate type, then by its values. This
     *  method is not useful for numeric comparisons. The ranges
     *  implied by their granularities and uncertainties may overlap
     *  in such a way that two unequal Coordinates may be neither less
     *  than or greater than the other.
     *
     *  If <code>compareTo</code> a coordinate is zero, then
     *  <code>equals()</code> must be <code>true</code> and their hash
     *  codes must also be equal for consistent behavior. For
     *  orderings that may yield inconsistent behavior, an external
     *  <code>Comparator</code> should be used.
     *
     *  @param coordinate the coordinate to be compared
     *  @return a negative integer, zero, or a positive integer as
     *          this coordinate is less than, equal to, or greater
     *          than the specified coordinate
     *  @throws ClassCastException if the specified coordinate's type
     *          prevents it from being compared to this coordinate
     */

    @Override
    public int compareTo(org.osid.mapping.Coordinate coordinate);


    /**
     *  Determines if the given <code> Coordinate </code> is equal to
     *  this one. Two <code>Coordinates</code> are equal if their
     *  coordinate types, values, and uncertainties are equal.
     *
     *  If <code>equals()</code> is <code>true</code>, then
     *  <code>compareTo()</code> must be zero and their hash codes
     *  must also be equal for consistent behavior. For orderings that
     *  may yield inconsistent behavior, an external
     *  <code>Comparator</code> should be used.
     *
     *  If <code>obj</code> is null or if a different interface, this
     *  method returns <code>false</code>.
     *
     *  @param  obj an object to compare
     *  @return <code> true </code> if the given object is equal to
     *          this <code>Coordinate</code>, <code> false </code>
     *          otherwise
     */

    @Override
    public boolean equals(Object obj);


    /**
     *  Returns a hash code value for this <code>Coordinate</code>.
     *  The hash code is determined by the coordinate type, values,
     *  and uncertainty.
     *
     *  @return a hash code value for this object
     */

    @Override
    public int hashCode();
}
