//
// Currency
//
//    Supplements the OSID Currency interface for Java.
//
//
// Tom Coppeto
// OnTapSolutions
// 21 October 2009
//
// Copyright (c) 2009 Ingenescus. All Rights Reserved.
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//

package org.osid.binding.java;


/**
 *  Supplements the OSID Currency interface for Java.
 */

public interface Currency
    extends OsidPrimitive,
	    Comparable<org.osid.financials.Currency> {


    /**
     *	Tests if this Currency is greater than the given Currency. A
     *	greater Currency is one whose values minus uncertainty is
     *	greater than another plus its uncertainty. An uncertainty of
     *	infinity is undefined and returns false.
     *
     *	@param	currency the currency to compare
     *	@return <code>true</code> if this currency is larger,
     *		<code>false</code> otherwise
     *	@throws org.osid.NullArgumentException <code>currency</code>
     *		is <code>null</code>
     *	@throws org.osid.UnsupportedException cannot compare currency types
     */

    public boolean isLarger(org.osid.financials.Currency currency);


    /**
     *	Tests if this Currency is less than the given Currency. A
     *	lesser Currency is one whose values plus uncertainty is less
     *	than another minus its uncertainty. An uncertainty of infinity
     *	is undefined and returns false.
     *
     *	@param	currency the currency to compare
     *	@return <code>true</code> if this currency is less,
     *		<code>false</code> otherwise
     *	@throws org.osid.NullArgumentException <code>currency</code>
     *		is <code>null</code>
     *	@throws org.osid.UnsupportedException cannot compare currency types
     */

    public boolean isSmaller(org.osid.financials.Currency currency);

    /**
     *  Compares this currency with the specified Currency for
     *  order. Returns a negative integer, zero, or a positive integer
     *  as this currency is less than, equal to, or greater than the
     *  specified currency.
     *
     *  This implementation assumes the types are equal to provide a
     *  natural ordering based on the amounts. For more accurrate
     *  comparisons, use <code>isLarger()</code> or
     *  <code>isSmaller()</code> instead.
     *
     *  @param currency the currency to be compared
     *  @return a negative integer, zero, or a positive integer as
     *          this cuurency is less than, equal to, or greater than
     *          the specified currency
     *  @throws ClassCastException if the specified cuurency's type
     *          prevents it from being compared to this currency
     */

    @Override
    public int compareTo(org.osid.financials.Currency currency);


    /**
     *  Determines if the given <code> Currency </code> is equal to
     *  this one. 
     *
     *  Two Currency objects are equal if their Currency Types and
     *  Currency amounts, and the precision in the currency amounts
     *  are equal.
     *
     *  @param  obj an object to compare
     *  @return <code> true </code> if the given object is equal to
     *          this <code>Currency</code>, <code> false </code>
     *          otherwise
     */

    @Override
    public boolean equals(Object obj);


    /**
     *  Returns a hash code value for this <code>Currency</code>. The
     *  hash code is determined from the currency type and currency
     *  amount.
     *
     *  @return a hash code value for this object
     */

    @Override
    public int hashCode();
}
