//
// DateTime
//
//    Supplements the OSID DateTime interface for Java.
//     
//
// Tom Coppeto
// OnTapSolutions
// 21 October 2009
//
// Copyright (c) 2009 Ingenescus All Rights Reserved.
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//

package org.osid.binding.java;


/**
 *  Supplements the OSID DateTime interface for Java.
 */

public interface DateTime
    extends OsidPrimitive,
	    Comparable<org.osid.calendaring.DateTime> {


    /**
     *	Tests if this DateTime is greater than the given DateTime. A
     *	greater DateTime is one whose values minus uncertainty is
     *	greater than another plus its uncertainty and graularity. An
     *	uncertainty of infinity is undefined and returns false.
     *
     *	@param	datetime the datetime to compare
     *	@return <code>true</code> if this datetime is larger,
     *		<code>false</code> otherwise
     *	@throws org.osid.NullArgumentException <code>datetime</code>
     *		is <code>null</code>
     *	@throws org.osid.UnsupportedException cannot compare calendar
     */

    public boolean isGreater(org.osid.calendaring.DateTime datetime);


    /**
     *	Tests if this DateTime is less than the given DateTime. A
     *	lesser DateTime is one whose values plus granularity and
     *	uncertainty is less than another minus its uncertainty. An
     *	uncertainty of infinity is undefined and returns false.
     *
     *	@param	datetime the datetime to compare
     *	@return <code>true</code> if this datetime is less,
     *		<code>false</code> otherwise
     *	@throws org.osid.NullArgumentException <code>datetime</code>
     *		is <code>null</code>
     *	@throws org.osid.UnsupportedException cannot compare calendar
     */

    public boolean isLess(org.osid.calendaring.DateTime datetime);


    /**
     *	Tests if the range of this DateTime, as specified by its
     *	granularity and uncertainty, includes the given DateTime
     *	ranged by its grabularity and uncertainty.
     *
     *	If either datetime has an uncertainty of infinity this method
     *	returns false.
     *
     *	@param	datetime the datetime to compare
     *	@return <code>true</code> if this datetime includes the given
     *		datetime, <code>false</code> otherwise
     *	@throws org.osid.NullArgumentException <code>datetime</code>
     *		is <code>null</code>
     *	@throws org.osid.UnsupportedException cannot compare calendar
     */

    public boolean isInclusive(org.osid.calendaring.DateTime datetime);


    /**
     *	Tests if the range of this DateTime, as specified by its
     *	granularity and uncertainty, does not overlap the given
     *	DateTime.
     *
     *	If either datetime has an uncertainty of infinity this method
     *	returns false.
     *
     *	@param	datetime the datetime to compare
     *	@return <code>true</code> if this datetime is excluded,
     *		<code>false</code> otherwise
     *	@throws org.osid.NullArgumentException <code>datetime</code>
     *		is <code>null</code>
     *	@throws org.osid.UnsupportedException cannot compare calendar
     */

    public boolean isExclusive(org.osid.calendaring.DateTime datetime);


    /**
     *	Returns an interval based on this DateTime derived by its
     *	granularity and uncertainty.
     *
     *	@return <code>true</code> if this datetime is excluded,
     *		<code>false</code> otherwise
     */

    public org.osid.calendaring.DateTimeInterval denormalize();


    /**
     *  Compares this datetime with the specified <code>DateTime</code>
     *  to determine the natural order. Returns a negative integer,
     *  zero, or a positive integer as this datetime is less than, equal
     *  to, or greater than the specified datetime.
     *
     *  The natural ordering is determined first by the natural
     *  ordering of the calendar and time types, then by its
     *  values. This method is not useful for numeric comparisons. The
     *  ranges implied by their granularities and uncertainties may
     *  overlap in such a way that two unequal DateTimes may be
     *  neither less than or greater than the other.
     *
     *  If <code>compareTo</code> a datetime is zero, then
     *  <code>equals()</code> must be <code>true</code> and their hash
     *  codes must also be equal for consistent behavior. For
     *  orderings that may yield inconsistent behavior, an external
     *  <code>Comparator</code> should be used.
     *
     *  @param datetime the datetime to be compared
     *  @return a negative integer, zero, or a positive integer as
     *          this datetime is less than, equal to, or greater than
     *          the specified datetime
     *  @throws ClassCastException if the specified datetime's type
     *          prevents it from being compared to this datetime
     */

    @Override
    public int compareTo(org.osid.calendaring.DateTime datetime);


    /**
     *  Determines if the given <code> DateTime </code> is equal to
     *  this one. Two DateTimes are equal if their Types, values,
     *  granularity, and uncertainties are equal.
     *
     *  @param  obj an object to compare
     *  @return <code> true </code> if the given object is equal to
     *          this <code>DateTime</code>, <code> false </code>
     *          otherwise
     */

    @Override
    public boolean equals(Object obj);


    /**
     *  Returns a hash code value for this <code>DateTime</code> based
     *  on the types, values, granularity and uncertainties.
     *
     *  @return a hash code value for this object
     */

    @Override
    public int hashCode();
}


