//
// DisplayTet
//
//    Supplements the OSID DisplayText interface for Java.
//
//
// Tom Coppeto
// OnTapSolutions
// 21 October 2010
//
// Copyright (c) 2010 Ingenescus. All Rights Reserved.
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//

package org.osid.binding.java;


/**
 *  Supplements the OSID DisplayText interface for Java.
 */

public interface DisplayText
    extends OsidPrimitive,
            Comparable<org.osid.locale.DisplayText> {


    /**
     *  Compares this DisplayText with the specified
     *  <code>DisplayText</code> to determine the natural
     *  order. Returns a negative integer, zero, or a positive integer
     *  as this DisplayText is less than, equal to, or greater than
     *  the specified text.
     *
     *  The natural ordering is determined first by the natural
     *  ordering of the language type, script type, then ts
     *  values.
     *
     *  If <code>compareTo</code> a DisplayText is zero, then
     *  <code>equals()</code> must be <code>true</code> and their hash
     *  codes must also be equal for consistent behavior. For
     *  orderings that may yield inconsistent behavior, an external
     *  <code>Comparator</code> should be used.
     *
     *  @param text the DisplayText to be compared
     *  @return a negative integer, zero, or a positive integer as
     *          this DisplayText is less than, equal to, or greater
     *          than the specified DisplayText
     *  @throws ClassCastException if the specified DisplayText's type
     *          prevents it from being compared to this DisplayText
     */

    @Override
    public int compareTo(org.osid.locale.DisplayText text);


    /**
     *  Determines if the given <code> DisplayText </code> is equal to
     *  this one. Two <code>DisplayTexts</code> are equal if their
     *  language types, script types, and strings are equal.
     *
     *  If <code>equals()</code> is <code>true</code>, then
     *  <code>compareTo()</code> must be zero and their hash codes
     *  must also be equal for consistent behavior. For orderings that
     *  may yield inconsistent behavior, an external
     *  <code>Comparator</code> should be used.
     *
     *  If <code>obj</code> is null or if a different interface, this
     *  method returns <code>false</code>.
     *
     *  @param  obj an object to compare
     *  @return <code> true </code> if the given object is equal to
     *          this <code>DisplayText</code>, <code> false </code>
     *          otherwise
     */

    @Override
    public boolean equals(Object obj);


    /**
     *  Returns a hash code value for this <code>DisplayText</code>
     *  based on the langauge type, script type, and string.
     *
     *  @return a hash code value for this object
     */

    @Override
    public int hashCode();
}
