//
// Duration
//
//    Supplements the OSID Duration interface for Java.
//     
//
// Tom Coppeto
// OnTapSolutions
// 21 October 2009
//
// Copyright (c) 2009 Ingenescus. All Rights Reserved.
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//

package org.osid.binding.java;


/**
 *  Supplements the OSID Duration interface for Java.
 */

public interface Duration
    extends OsidPrimitive,
	    Comparable<org.osid.calendaring.Duration> {


    /**
     *	Tests if this Duration is greater than the given Duration. A
     *	greater Duration is one whose values minus uncertainty is
     *	greater than another plus its uncertainty and graularity. An
     *	uncertainty of infinity is undefined and returns false.
     *
     *	@param	duration the duration to compare
     *	@return <code>true</code> if this duration is larger,
     *		<code>false</code> otherwise
     *	@throws org.osid.NullArgumentException <code>duration</code>
     *		is <code>null</code>
     *	@throws org.osid.UnsupportedException cannot compare calendar
     */

    public boolean isGreater(org.osid.calendaring.Duration duration);


    /**
     *	Tests if this Duration is less than the given Duration. A
     *	lesser Duration is one whose values plus granularity and
     *	uncertainty is less than another minus its d uncertainty. An
     *	uncertainty of infinity is undefined and returns false.
     *
     *	@param	duration the duration to compare
     *	@return <code>true</code> if this duration is less,
     *		<code>false</code> otherwise
     *	@throws org.osid.NullArgumentException <code>duration</code>
     *		is <code>null</code>
     *	@throws org.osid.UnsupportedException cannot compare calendar
     */

    public boolean isLess(org.osid.calendaring.Duration duration);


    /**
     *	Tests if the range of this Duration, as specified by its
     *	granularity and uncertainty, includes the given Duration
     *	ranged by its grabularity and uncertainty.
     *
     *	If either duration has an uncertainty of infinity this method
     *	returns false.
     *
     *	@param	duration the duration to compare
     *	@return <code>true</code> if this duration includes the given
     *		duration, <code>false</code> otherwise
     *	@throws org.osid.NullArgumentException <code>duration</code>
     *		is <code>null</code>
     *	@throws org.osid.UnsupportedException cannot compare calendar
     */

    public boolean isInclusive(org.osid.calendaring.Duration duration);


    /**
     *	Tests if the range of this Duration, as specified by its
     *	granularity and uncertainty, does not overlap the given
     *	Duration.
     *
     *	If either duration has an uncertainty of infinity this method
     *	returns false.
     *
     *	@param	duration the duration to compare
     *	@return <code>true</code> if this duration is excluded,
     *		<code>false</code> otherwise
     *	@throws org.osid.NullArgumentException <code>duration</code>
     *		is <code>null</code>
     *	@throws org.osid.UnsupportedException cannot compare calendar
     */

    public boolean isExclusive(org.osid.calendaring.Duration duration);


    /**
     *  Gets the lower bound of the duration. The lower bound is the
     *  duration minus the uncertainty.
     *
     *  @return the duration lower bound
     */

    public org.osid.calendaring.Duration getLowerBound();


    /**
     *  Gets the upper bound of the duration. The lower bound is the
     *  duration plus the uncertainty.
     *
     *  @return the duration upper bound
     */

    public org.osid.calendaring.Duration getUpperBound();


    /**
     *  Compares this duration with the specified <code>Duration</code>
     *  to determine the natural order. Returns a negative integer,
     *  zero, or a positive integer as this duration is less than,
     *  equal to, or greater than the specified Duration.
     *
     *  The natural ordering is determined first by the natural
     *  ordering of the type, then by its values. This method is not
     *  useful for numeric comparisons. The ranges implied by their
     *  granularities and uncertainties may overlap in such a way that
     *  two unequal Durations may be neither less than or greater than
     *  the other.
     *
     *  If <code>compareTo</code> a duration is zero, then
     *  <code>equals()</code> must be <code>true</code> and their hash
     *  codes must also be equal for consistent behavior. For
     *  orderings that may yield inconsistent behavior, an external
     *  <code>Comparator</code> should be used.
     *
     *  @param duration the duration to be compared
     *  @return a negative integer, zero, or a positive integer as
     *          this duration is less than, equal to, or greater than
     *          the specified duration
     *  @throws ClassCastException if the specified duration's type
     *          prevents it from being compared to this duration
     */

    @Override
    public int compareTo(org.osid.calendaring.Duration duration);


    /**
     *  Determines if the given <code> Duration </code> is equal to
     *  this one. Two Durations are equal if their Types,
     *  granularities, values, and uncertainties are equal.
     *
     *  @param  obj an object to compare
     *  @return <code> true </code> if the given object is equal to
     *          this <code>Duration</code>, <code> false </code>
     *          otherwise
     */

    @Override
    public boolean equals(Object obj);

    /**
     *  Returns a hash code value for this <code>Duration</code> based
     *  on the types, values, granularity, and uncertainties.
     *
     *  @return a hash code value for this object
     */

    @Override
    public int hashCode();
}


