//
// Primitive
//
//    Some OSID interfaces are designated as "primitives" in that
//    they may be constructed by either the OSID Consumer or OSID
//    Provider. They do not encapsulate provider-specific details but
//    are used as a shuttle of information both ways across the
//    OSIDs.
//     
//
// Tom Coppeto
// OnTapSolutions
// 21 October 2009
//
// Copyright (c) 2009 Ingenescus. All Rights Reserved.
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//

package org.osid.binding.java;


/**
 *  Some OSID interfaces are designated as "primitives" in that
 *  they may be constructed by either the OSID Consumer or OSID
 *  Provider. They do not encapsulate provider-specific details but
 *  are used as a shuttle of information both ways across the
 *  OSIDs.
 *
 *  The design of an OsidPrimitive implementation should take care not
 *  to include logic, such as introducing Type compatibility, where
 *  comparison methods exhibit different behavior. All comparison
 *  methods such as <code>equals()</code> should be commutative such
 *  that <code>object1.equals(object2)</code> has the same result as
 *  <code>object2.equals(object1)</code>. 
 *
 *  Primitives support Java Serialization. Java serialization and
 *  deserialization is used for persisting and retrieving the state of
 *  the internal object.  <code>toString()</code> can be used for
 *  outputting a standard format, as for example a date or a Type,
 *  using the exposed interfaces that can be used for reconstructing
 *  the underlying object from scratch. In this case, offering a
 *  <code>valueOf()</code> method to that is compatible with the
 *  object's output format can be handy.
 *
 *  Output display and serialization will vary depending on the
 *  implementation of this interface. Consumers needing a consistent
 *  behavior across all OSID Providers should wrap this primitive in
 *  another of known behavior. Implementations of OsidPrimitives are
 *  also encouraged to permit easy construction given another object
 *  of the same interface.
 */

public interface OsidPrimitive
    extends java.io.Serializable {


    /**
     *  Returns a string representation of this OsidPrimitive.
     *
     *  All implementations are encouraged to supply this method to
     *  provide a readable display. Some objects may pretty print the
     *  primitive while others may serialize for convenient
     *  persistence. 
     *
     *  @return a string
     */

    @Override
    public String toString();
}
