//
// SpatialUnit
//
//    Supplements the OSID SpatialUnit interface for Java.
//
//
// Tom Coppeto
// OnTapSolutions
// 21 October 2009
//
// Copyright (c) 2009 Ingenescus. All Rights Reserved.
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//

package org.osid.binding.java;


/**
 *  Supplements the OSID SpatialUnit interface for Java.
 */

public interface SpatialUnit
    extends OsidPrimitive,
	    Comparable<org.osid.mapping.SpatialUnit> {


    /**
     *  Tests if this SpatialUnit is greater than the given SpatialUnit. A
     *  greater SpatialUnit is one whose values minus uncertainty is
     *  greater than another plus its uncertainty. An uncertainty of
     *  infinity is undefined and returns false.
     *
     *  @param  unit the spatial unit to compare
     *  @return <code>true</code> if this spatial unit is larger,
     *          <code>false</code> otherwise
     *  @throws org.osid.NullArgumentException <code>unit</code>
     *          is <code>null</code>
     *  @throws org.osid.UnsupportedException cannot compare spatial unit
     */

    public boolean isLarger(org.osid.mapping.SpatialUnit unit);


    /**
     *  Tests if this SpatialUnit is less than the given SpatialUnit. A
     *  lesser SpatialUnit is one whose values plus uncertainty is less
     *  than another minus its uncertainty. An uncertainty of infinity
     *  is undefined and returns false.
     *
     *  @param  unit the spatial unit to compare
     *  @return <code>true</code> if this spatial unit is less,
     *          <code>false</code> otherwise
     *  @throws org.osid.NullArgumentException <code>unit</code>
     *          is <code>null</code>
     *  @throws org.osid.UnsupportedException cannot compare spatial unit
     */

    public boolean isSmaller(org.osid.mapping.SpatialUnit unit);


    /**
     *  Tests if one SpatialUnit is closer than another to this
     *  SpatialUnit. A greater SpatialUnit is one whose values minus
     *  uncertainty is greater than another plus its uncertainty. An
     *  uncertainty of infinity is undefined and returns false.
     *
     *  @param  one the spatial unit to compare
     *  @param  another the spatial unit to compare
     *  @return <code>true</code> if this <code>one</code> is closer
     *          than <code>another</code>, <code>false</code>
     *          otherwise
     *  @throws org.osid.NullArgumentException <code>one</code>
     *          or <code>another</code> is <code>null</code>
     *  @throws org.osid.UnsupportedException cannot compare spatial unit
     */

    public boolean isCloser(org.osid.mapping.SpatialUnit one, 
			    org.osid.mapping.SpatialUnit another);


    /**
     *  Tests if one SpatialUnit is farther than another from this
     *  SpatialUnit. A greater SpatialUnit is one whose values minus
     *  uncertainty is greater than another plus its uncertainty. An
     *  uncertainty of infinity is undefined and returns false.
     *
     *  @param  one the spatial unit to compare
     *  @param  another the spatial unit to compare
     *  @return <code>true</code> if this <code>one</code> is closer
     *          than <code>another</code>, <code>false</code>
     *          otherwise
     *  @throws org.osid.NullArgumentException <code>one</code>
     *          or <code>another</code> is <code>null</code>
     *  @throws org.osid.UnsupportedException cannot compare spatial unit
     */

    public boolean isFarther(org.osid.mapping.SpatialUnit one, 
			     org.osid.mapping.SpatialUnit another);


    /**
     *  Tests if the SpatialUnit, as specified by its uncertainty,
     *  completely includes the given SpatialUnit ranged by its
     *  uncertainty.
     *
     *  If either spatial unit has an uncertainty of infinity this
     *  method returns false.
     *
     *  @param  unit the spatial unit to compare
     *  @return <code>true</code> if this spatial unit includes the given
     *          spatial unit, <code>false</code> otherwise
     *  @throws org.osid.NullArgumentException <code>unit</code>
     *          is <code>null</code>
     *  @throws org.osid.UnsupportedException cannot compare spatial unit
     */

    public boolean isInclusive(org.osid.mapping.SpatialUnit unit);


    /**
     *  Tests if this SpatialUnit, as specified by its uncertainty,
     *  does not overlap the given SpatialUnit.
     *
     *  If either spatial unit has an uncertainty of infinity this method
     *  returns false.
     *
     *  @param  unit the spatial unit to compare
     *  @return <code>true</code> if this spatial unit is excluded,
     *          <code>false</code> otherwise
     *  @throws org.osid.NullArgumentException <code>unit</code>
     *          is <code>null</code>
     *  @throws org.osid.UnsupportedException cannot compare spatial unit
     */

    public boolean isExclusive(org.osid.mapping.SpatialUnit unit);


    /**
     *  Gets the lower bound of the spatial unit. The lower bound is
     *  the unit minus the uncertainty.
     *
     *  @return the unit lower bound
     */

    public org.osid.mapping.SpatialUnit getInnerBound();


    /**
     *  Gets the upper bound of the spatial unit. The lower bound is
     *  the unit plus the uncertainty.
     *
     *  @return the unit upper bound
     */

    public org.osid.mapping.SpatialUnit getOuterBound();


    /**
     *  Compares this spatial unit with the specified
     *  <code>SpatialUnit</code> to determine the natural order. Returns
     *  a negative integer, zero, or a positive integer as this
     *  spatial unit is less than, equal to, or greater than the specified
     *  SpatialUnit.
     *
     *  The natural ordering is determined first by the natural
     *  ordering of the type, then by its values. This method is not
     *  useful for numeric comparisons. The ranges implied by their
     *  granularities and uncertainties may overlap in such a way that
     *  two unequal SpatialUnits may be neither less than or greater than
     *  the other.
     *
     *  If <code>compareTo</code> a spatial unit is zero, then
     *  <code>equals()</code> must be <code>true</code> and their hash
     *  codes must also be equal for consistent behavior. For
     *  orderings that may yield inconsistent behavior, an external
     *  <code>Comparator</code> should be used.
     *
     *  @param unit the spatial unit to be compared
     *  @return a negative integer, zero, or a positive integer as
     *          this spatial unit is less than, equal to, or greater than
     *          the specified spatial unit
     *  @throws ClassCastException if the specified spatial unit's
     *          type prevents it from being compared to this spatial
     *          unit
     */

    @Override
    public int compareTo(org.osid.mapping.SpatialUnit unit);


    /**
     *  Determines if the given <code> SpatialUnit </code> is equal to
     *  this one.
     *
     *  @param  obj an object to compare
     *  @return <code> true </code> if the given object is equal to
     *          this <code>Spatial Unit</code>, <code> false </code>
     *          otherwise
     */

    @Override
    public boolean equals(Object obj);

    /**
     *  Returns a hash code value for this <code>SpatialUnit</code>
     *  based on the types, values, granularity, and uncertainties.
     *
     *  @return a hash code value for this object
     */

    @Override
    public int hashCode();
}
