//
// Time
//
//    Supplements the OSID Time interface for Java.
//     
//
// Tom Coppeto
// OnTapSolutions
// 21 October 2009
//
// Copyright (c) 2009 Ingenescus. All Rights Reserved.
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//

package org.osid.binding.java;


/**
 *  Supplements the OSID Time interface for Java.
 */

public interface Time
    extends OsidPrimitive,
	    Comparable<org.osid.calendaring.Time> {


    /**
     *  Tests if this Time is greater than the given Time. A greater
     *  Time is one whose values is greater than another plus its
     *  granularity. 
     *
     *  @param  t the time to compare
     *  @return <code>true</code> if this time is larger,
     *          <code>false</code> otherwise
     *  @throws org.osid.NullArgumentException <code>t</code>
     *          is <code>null</code>
     *  @throws org.osid.UnsupportedException cannot compare calendar
     */

    public boolean isGreater(org.osid.calendaring.Time t);


    /**
     *  Tests if this Time is less than the given Time. A lesser Time
     *  is one whose values plus granularity is less than another
     *  minus its granularity.
     *
     *  @param  t the time to compare
     *  @return <code>true</code> if this time is less,
     *          <code>false</code> otherwise
     *  @throws org.osid.NullArgumentException <code>t</code>
     *          is <code>null</code>
     *  @throws org.osid.UnsupportedException cannot compare calendar
     */

    public boolean isLess(org.osid.calendaring.Time t);


    /**
     *  Tests if the range of this Time, as specified by its
     *  granularity, includes the given Time ranged by its
     *  grabularity.
     *
     *  @param  t the time to compare
     *  @return <code>true</code> if this time includes the given
     *          time, <code>false</code> otherwise
     *  @throws org.osid.NullArgumentException <code>t</code>
     *          is <code>null</code>
     *  @throws org.osid.UnsupportedException cannot compare calendar
     */

    public boolean isInclusive(org.osid.calendaring.Time t);


    /**
     *  Tests if the range of this Time, as specified by its
     *  granularity, does not overlap the given
     *  Time.
     *
     *  If either time has an uncertainty of infinity this method
     *  returns false.
     *
     *  @param  t the time to compare
     *  @return <code>true</code> if this time is excluded,
     *          <code>false</code> otherwise
     *  @throws org.osid.NullArgumentException <code>t</code>
     *          is <code>null</code>
     *  @throws org.osid.UnsupportedException cannot compare calendar
     */

    public boolean isExclusive(org.osid.calendaring.Time t);


    /**
     *  Returns an interval based on this Time derived by its
     *  granularity.
     *
     *  @return <code>true</code> if this time is excluded,
     *          <code>false</code> otherwise
     */

    public org.osid.calendaring.Time[] denormalizeTime();


    /**
     *  Compares this Time with the specified Time to determine the
     *  natural order. Returns a negative integer, zero, or a positive
     *  integer as this time is less than, equal to, or greater than
     *  the specified time.
     *
     *  The natural ordering is determined first by the natural
     *  ordering of the time scheme, then by its components. This
     *  method is not useful for numeric comparisons. The ranges
     *  implied by the granularities may overlap in such a way that
     *  two unequal Times may be neither less than or greater than the
     *  other.
     *
     *  If <code>compareTo</code> an time is zero, then
     *  <code>equals()</code> must be <code>true</code> and their hash
     *  codes must also be equal for consistent behavior. For
     *  orderings that may yield inconsistent behavior, an external
     *  <code>Comparator</code> should be used.
     *
     *  @param time the time to be compared
     *  @return a negative integer, zero, or a positive integer as
     *          this time is less than, equal to, or greater than
     *          the specified time
     *  @throws org.osid.UnsupportedException cannot compare calendar
     */

    @Override
    public int compareTo(org.osid.calendaring.Time time);


    /**
     *  Determines if the given <code> Time </code> is equal to
     *  this one. 
     *
     *  @param  obj an object to compare
     *  @return <code> true </code> if the given object is equal to
     *          this <code>Time</code>, <code> false </code>
     *          otherwise
     */

    @Override
    public boolean equals(Object obj);


    /**
     *  Returns a hash code value for this <code>Time</code> based on
     *  the types, values, and granularity.
     *
     *  @return a hash code value for this object
     */

    @Override
    public int hashCode();
}
