//
// Type
//
//    Supplements the OSID Type interface for Java.
//
//
// Tom Coppeto
// OnTapSolutions
// 21 October 2010
//
// Copyright (c) 2010 Ingenescus. All Rights Reserved.
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//

package org.osid.binding.java;


/**
 *  Supplements the OSID Type interface for Java.
 */

public interface Type
    extends OsidPrimitive,
            Comparable<org.osid.type.Type> {

    /**
     *  Compares this type with the specified <code>Type</code> to
     *  determine the natural order. Returns a negative integer, zero,
     *  or a positive integer as this type is less than, equal to,
     *  or greater than the specified type.
     *
     *  The natural ordering is determined first by the natural
     *  ordering of the authority, namespace, and identifier.
     *
     *  If <code>compareTo</code> an type is zero, then
     *  <code>equals()</code> must be <code>true</code> and their hash
     *  codes must also be equal for consistent behavior. For
     *  orderings that may yield inconsistent behavior, an external
     *  <code>Comparator</code> should be used.
     *
     *  @param type the type to be compared
     *  @return a negative integer, zero, or a positive integer as
     *          this type is less than, equal to, or greater than
     *          the specified type
     *  @throws ClassCastException if the specified type's type
     *          prevents it from being compared to this type
     */

    @Override
    public int compareTo(org.osid.type.Type type);


    /**
     *  Determines if the given <code> Type </code> is equal to this
     *  one. Two <code>Types</code> are equal if their authority,
     *  namespace, and identifiers are equal.
     *
     *  If <code>equals()</code> is <code>true</code>, then
     *  <code>compareTo()</code> must be zero and their hash codes
     *  must also be equal for consistent behavior. For orderings that
     *  may yield inconsistent behavior, an external
     *  <code>Comparator</code> should be used.
     *
     *  If <code>obj</code> is null or if a different interface, this
     *  method returns <code>false</code>.
     *
     *  @param  obj an object to compare
     *  @return <code> true </code> if the given object is equal to
     *          this <code>Type</code>, <code> false </code>
     *          otherwise
     */

    @Override
    public boolean equals(Object obj);


    /**
     *  Returns a hash code value for this <code>Type</code> based on
     *  the authority, namespace, and identifier.
     *
     *  @return a hash code value for this object
     */

    @Override
    public int hashCode();
}
