//
// org.osid.blogging.BlogLookupSession
//
//     The OSID Java specification for org.osid.blogging.BlogLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.blogging;


/**
 *  <p>This session provides methods for retrieving <code> Blog </code> 
 *  objects. The <code> Blog </code> represents a collection entries. </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. For 
 *  example, a browsing application may only need to examine the <code> Blogs 
 *  </code> it can access, without breaking execution. However, an 
 *  administrative application may require all <code> Blog </code> elements to 
 *  be available. </p> 
 *  
 *  <p> Blogs may have an additional records indicated by their respective 
 *  record types. The record may not be accessed through a cast of the <code> 
 *  Blog. </code> </p>
 */

public interface BlogLookupSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can perform <code> Blog </code> lookups. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupBlogs();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeBlogView();


    /**
     *  A complete view of the <code> Blog </code> returns is desired. Methods 
     *  will return what is requested or result in an error. This view is used 
     *  when greater precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryBlogView();


    /**
     *  Gets the <code> Blog </code> specified by its <code> Id. </code> In 
     *  plenary mode, the exact <code> Id </code> is found or a <code> 
     *  NOT_FOUND </code> results. Otherwise, the returned <code> Blog </code> 
     *  may have a different <code> Id </code> than requested, such as the 
     *  case where a duplicate <code> Id </code> was assigned to a <code> Blog 
     *  </code> and retained for compatibility. 
     *
     *  @param  blogId <code> Id </code> of the <code> Blog </code> 
     *  @return the blog 
     *  @throws org.osid.NotFoundException <code> blogId </code> not found 
     *  @throws org.osid.NullArgumentException <code> blogId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.blogging.Blog getBlog(org.osid.id.Id blogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BlogList </code> corresponding to the given <code> 
     *  IdList. </code> In plenary mode, the returned list contains all of the 
     *  blogs specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible blogs may be omitted from the list and may present the 
     *  elements in any order including returning a unique set. 
     *
     *  @param  blogIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Blog list </code> 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> blogIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.blogging.BlogList getBlogsByIds(org.osid.id.IdList blogIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> Blog </code> corresponding to the given blog genus 
     *  <code> Type </code> which does not include blogs of types derived from 
     *  the specified <code> Type. </code> In plenary mode, the returned list 
     *  contains all known blogs or an error results. Otherwise, the returned 
     *  list may contain only those blogs that are accessible through this 
     *  session. 
     *
     *  @param  blogGenusType a blog genus type 
     *  @return the returned <code> Blog </code> list 
     *  @throws org.osid.NullArgumentException <code> blogGenusType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.blogging.BlogList getBlogsByGenusType(org.osid.type.Type blogGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BlogList </code> corresponding to the given psocess 
     *  genus <code> Type </code> and include any additional blogs with genus 
     *  types derived from the specified <code> Type. </code> In plenary mode, 
     *  the returned list contains all known blogs or an error results. 
     *  Otherwise, the returned list may contain only those blogs that are 
     *  accessible through this session. 
     *
     *  @param  blogGenusType a blog genus type 
     *  @return the returned <code> Blog </code> list 
     *  @throws org.osid.NullArgumentException <code> blogGenusType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.blogging.BlogList getBlogsByParentGenusType(org.osid.type.Type blogGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BlogList </code> containing the given blog record <code> 
     *  Type. </code> In plenary mode, the returned list contains all known 
     *  blogs or an error results. Otherwise, the returned list may contain 
     *  only those blogs that are accessible through this session. 
     *
     *  @param  blogRecordType a blog record type 
     *  @return the returned <code> Blog </code> list 
     *  @throws org.osid.NullArgumentException <code> blogRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.blogging.BlogList getBlogsByRecordType(org.osid.type.Type blogRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BlogList </code> for the given provider. In plenary 
     *  mode, the returned list contains all known blogs or an error results. 
     *  Otherwise, the returned list may contain only those blogs that are 
     *  accessible through this session. 
     *
     *  @param  resourceId a resourceId <code> Id </code> 
     *  @return the returned <code> Blog </code> list 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.blogging.BlogList getBlogsByProvider(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Blogs. </code> In plenary mode, the returned list 
     *  contains all known blogs or an error results. Otherwise, the returned 
     *  list may contain only those blogs that are accessible through this 
     *  session. 
     *
     *  @return a list of blogs 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.blogging.BlogList getBlogs()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
