//
// org.osid.blogging.BlogReceiver
//
//     The OSID Java specification for org.osid.blogging.BlogReceiver.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.blogging;


/**
 *  <p>The blog receiver is the consumer supplied interface for receiving 
 *  notifications pertaining to new, updated or deleted <code> Blog </code> 
 *  objects. </p>
 */

public interface BlogReceiver
    extends org.osid.OsidReceiver {


    /**
     *  The callback for notifications of new blogs. 
     *
     *  @param  notificationId the notification <code> Id </code> 
     *  @param  blogIds the <code> Id </code> of the new <code> Blogs </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newBlogs(org.osid.id.Id notificationId, 
                         org.osid.id.IdList blogIds);


    /**
     *  The callback for notification of updated blogs. 
     *
     *  @param  notificationId the notification <code> Id </code> 
     *  @param  blogIds the <code> Id </code> of the updated <code> Blogs 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void changedBlogs(org.osid.id.Id notificationId, 
                             org.osid.id.IdList blogIds);


    /**
     *  The callback for notification of deleted blogs. 
     *
     *  @param  notificationId the notification <code> Id </code> 
     *  @param  blogIds the <code> Id </code> of the deleted <code> Blogs 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedBlogs(org.osid.id.Id notificationId, 
                             org.osid.id.IdList blogIds);


    /**
     *  The callback for notifications of changes to children of blog 
     *  hierarchy nodes. 
     *
     *  @param  notificationId the notification <code> Id </code> 
     *  @param  blogIds the <code> Ids </code> of the <code> Blogs </code> 
     *          whose children have changed 
     *  @compliance mandatory This method must be implemented. 
     */

    public void changedChildOfBlogs(org.osid.id.Id notificationId, 
                                    org.osid.id.IdList blogIds);
}
