//
// org.osid.blogging.BloggingProfile
//
//     The OSID Java specification for org.osid.blogging.BloggingProfile.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.blogging;


/**
 *  <p>The entry profile describes interoperability among entry services. </p>
 */

public interface BloggingProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if federation is visible. 
     *
     *  @return <code> true </code> if visible federation is supported <code> 
     *          , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if sending entries is supported. 
     *
     *  @return <code> true </code> if entry sending is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBlogging();


    /**
     *  Tests if entry lookup is supported. 
     *
     *  @return <code> true </code> if entry lookup is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEntryLookup();


    /**
     *  Tests if entry query is supported. 
     *
     *  @return <code> true </code> if entry query is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEntryQuery();


    /**
     *  Tests if entry search is supported. 
     *
     *  @return <code> true </code> if entry search is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEntrySearch();


    /**
     *  Tests if creating, updating and deleting entries is supported. 
     *
     *  @return <code> true </code> if entry administration is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEntryAdmin();


    /**
     *  Tests if entry notification is supported. Entries may be sent when 
     *  entries are created, modified, or deleted. 
     *
     *  @return <code> true </code> if entry notification is supported <code> 
     *          , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEntryNotification();


    /**
     *  Tests if retrieving mappings of entry and blogs is supported. 
     *
     *  @return <code> true </code> if entry blog mapping retrieval is 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEntryBlog();


    /**
     *  Tests if managing mappings of entries and blogs is supported. 
     *
     *  @return <code> true </code> if entry blog assignment is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEntryBlogAssignment();


    /**
     *  Tests if entry smart blogging is available. 
     *
     *  @return <code> true </code> if entry smart blog is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEntrySmartBlog();


    /**
     *  Tests if blog lookup is supported. 
     *
     *  @return <code> true </code> if blog lookup is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBlogLookup();


    /**
     *  Tests if blog query is supported. 
     *
     *  @return <code> true </code> if blog query is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBlogQuery();


    /**
     *  Tests if blog search is supported. 
     *
     *  @return <code> true </code> if blog search is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBlogSearch();


    /**
     *  Tests if blog administration is supported. 
     *
     *  @return <code> true </code> if blog administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBlogAdmin();


    /**
     *  Tests if blog notification is supported. Entries may be sent when 
     *  <code> Blog </code> objects are created, deleted or updated. 
     *  Notifications for entries within blogs are sent via the entry 
     *  notification session. 
     *
     *  @return <code> true </code> if blog notification is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBlogNotification();


    /**
     *  Tests if a blog hierarchy traversal is supported. 
     *
     *  @return <code> true </code> if a blog hierarchy traversal is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBlogHierarchy();


    /**
     *  Tests if a blog hierarchy design is supported. 
     *
     *  @return <code> true </code> if a blog hierarchy design is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBlogHierarchyDesign();


    /**
     *  Tests if a blogging batch service is supported. 
     *
     *  @return <code> true </code> if a blogging batch service is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBloggingBatch();


    /**
     *  Gets all the entry record types supported. 
     *
     *  @return the list of supported entry record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getEntryRecordTypes();


    /**
     *  Tests if a given entry record type is supported. 
     *
     *  @param  entryRecordType the entry type 
     *  @return <code> true </code> if the entry record type is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> entryRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEntryRecordType(org.osid.type.Type entryRecordType);


    /**
     *  Gets all the entry search record types supported. 
     *
     *  @return the list of supported entry search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getEntrySearchRecordTypes();


    /**
     *  Tests if a given entry search type is supported. 
     *
     *  @param  entrySearchRecordType the entry search type 
     *  @return <code> true </code> if the entry search record type is 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> entrySearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEntrySearchRecordType(org.osid.type.Type entrySearchRecordType);


    /**
     *  Gets all the blog record types supported. 
     *
     *  @return the list of supported blog record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getBlogRecordTypes();


    /**
     *  Tests if a given blog record type is supported. 
     *
     *  @param  blogRecordType the blog record type 
     *  @return <code> true </code> if the blog record type is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> blogRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBlogRecordType(org.osid.type.Type blogRecordType);


    /**
     *  Gets all the blog search record types supported. 
     *
     *  @return the list of supported blog search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getBlogSearchRecordTypes();


    /**
     *  Tests if a given blog search record type is supported. 
     *
     *  @param  blogSearchRecordType the blog search record type 
     *  @return <code> true </code> if the blog search record type is 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> blogSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBlogSearchRecordType(org.osid.type.Type blogSearchRecordType);
}
