//
// org.osid.blogging.EntryQuerySession
//
//     The OSID Java specification for org.osid.blogging.EntryQuerySession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.blogging;


/**
 *  <p>This session provides methods for querying <code> Entry </code> 
 *  objects. The search query is constructed using the <code> EntryQuery. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated blog view: searches include entries in blogs of which 
 *      this blog is a ancestor in the blog hierarchy </li> 
 *      <li> isolated blog view: searches are restricted to entries in this 
 *      blog </li> 
 *  </ul>
 *  
 *  
 *  <p> Entries may have a query record indicated by their respective types. 
 *  The query record is accessed via the <code> EntryQuery. </code> </p>
 */

public interface EntryQuerySession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Blog </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Blog Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBlogId();


    /**
     *  Gets the <code> Blog </code> associated with this session. 
     *
     *  @return the <code> Blog </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.blogging.Blog getBlog()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Entry </code> queries. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer search operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if search methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSearchEntries();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include entries in blogs which are children of this blog in the blog 
     *  hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedBlogView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this blog only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedBlogView();


    /**
     *  Gets an entry query. 
     *
     *  @return the entry query interface 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.blogging.EntryQuery getEntryQuery();


    /**
     *  Gets a list of <code> Entries </code> matching the given search. 
     *
     *  @param  entryQuery the entry query 
     *  @return the returned <code> EntryList </code> 
     *  @throws org.osid.NullArgumentException <code> entryQuery </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> entryQuery </code> is not 
     *          of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.blogging.EntryList getEntriesByQuery(org.osid.blogging.EntryQuery entryQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
