//
// org.osid.calendaring.CalendarQueryInspector
//
//     The OSID Java specification for org.osid.calendaring.CalendarQueryInspector.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>This is the query inspector for examining calendar queries. </p>
 */

public interface CalendarQueryInspector
    extends org.osid.OsidCatalogQueryInspector {


    /**
     *  Gets the event <code> Id </code> terms. 
     *
     *  @return the event <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getEventIdTerms();


    /**
     *  Gets the event terms. 
     *
     *  @return the event terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.EventQueryInspector[] getEventTerms();


    /**
     *  Gets the time period <code> Id </code> terms. 
     *
     *  @return the time period <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getTimePeriodIdTerms();


    /**
     *  Gets the time period terms. 
     *
     *  @return the time period terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.TimePeriodQueryInspector[] getTimePeriodTerms();


    /**
     *  Gets the commitment <code> Id </code> terms. 
     *
     *  @return the commitment <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getCommitmentIdTerms();


    /**
     *  Gets the commitment terms. 
     *
     *  @return the commitment terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.CommitmentQueryInspector[] getCommitmentTerms();


    /**
     *  Gets the ancestor calendar <code> Id </code> terms. 
     *
     *  @return the ancestor calendar <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getAncestorCalendarIdTerms();


    /**
     *  Gets the ancestor calendar terms. 
     *
     *  @return the ancestor calendar terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.CalendarQueryInspector[] getAncestorCalendarTerms();


    /**
     *  Gets the descendant calendar <code> Id </code> terms. 
     *
     *  @return the descendant calendar <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getDescendantCalendarIdTerms();


    /**
     *  Gets the descendant calendar terms. 
     *
     *  @return the descendant calendar terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.CalendarQueryInspector[] getDescendantCalendarTerms();


    /**
     *  Gets the calendar query inspector record corresponding to the given 
     *  <code> Calendar </code> record <code> Type. </code> 
     *
     *  @param  calendarRecordType a calendar record type 
     *  @return the calendar query inspector record 
     *  @throws org.osid.NullArgumentException <code> calendarRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(calendarRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.records.CalendarQueryInspectorRecord getCalendarQueryInspectorRecord(org.osid.type.Type calendarRecordType)
        throws org.osid.OperationFailedException;
}
