//
// org.osid.calendaring.CommitmentLookupSession
//
//     The OSID Java specification for org.osid.calendaring.CommitmentLookupSession.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>This session provides methods for examining event commitments. </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated calendar view: All event methods in this session 
 *      operate, retrieve and pertain to commitments defined explicitly in the 
 *      current calendar. Using an isolated view is useful for managing events 
 *      with the <code> CommitmentAdminSession. </code> </li> 
 *      <li> federated calendar view: All commitment methods in this session 
 *      operate, retrieve and pertain to all commitments defined in this 
 *      calendar and any other calendars implicitly available in this calendar 
 *      through calendar inheritence. </li> 
 *      <li> effective commitment view: Commitment methods return only 
 *      effective commitments </li> 
 *      <li> any effective commitment view: Commitment methods return all 
 *      commitments </li> 
 *  </ul>
 *  
 */

public interface CommitmentLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Calendar </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Calendar Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCalendarId();


    /**
     *  Gets the <code> Calendar </code> associated with this session. 
     *
     *  @return the <code> Calendar </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Calendar getCalendar()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can lookup event commitments. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupCommitments();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeCommitmentView();


    /**
     *  A complete view of the <code> Commitment </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryCommitmentView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include commitments in calendars which are children of this calendar 
     *  in the calendar hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCalendarView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this calendar only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCalendarView();


    /**
     *  The commitments in this lookup session return only commitments 
     *  currently in effect. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useEffectiveCommitmentView();


    /**
     *  The commitments in this lookup session return both effective and 
     *  ineffective commitments. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyEffectiveCommitmentView();


    /**
     *  Gets the <code> Commitment </code> specified by its <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Commitment </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> Commitment </code> and retained for 
     *  compatibility. 
     *  
     *  In effective mode, commitments are returned that are currently 
     *  effective. In any effective mode, effective commitments and those 
     *  currently expired are returned. 
     *
     *  @param  commitmentId <code> Id </code> of the <code> Commitment 
     *          </code> 
     *  @return the commitment 
     *  @throws org.osid.NotFoundException <code> commitmentId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> commitmentId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.calendaring.Commitment getCommitment(org.osid.id.Id commitmentId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CommitmentList </code> corresponding to the given <code> 
     *  IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  commitments specified in the <code> Id </code> list, in the order of 
     *  the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Commitments </code> may be omitted from the list 
     *  and may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In effective mode, commitments are returned that are currently 
     *  effective. In any effective mode, effective commitments and those 
     *  currently expired are returned. 
     *
     *  @param  commitmentIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Commitment </code> list 
     *  @throws org.osid.NotFoundException an <code> Id </code> was not found 
     *  @throws org.osid.NullArgumentException <code> commitmentIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.CommitmentList getCommitmentsByIds(org.osid.id.IdList commitmentIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the commitments for the given event genus type. 
     *  
     *  In plenary mode, the returned list contains all known commitments or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  commitments that are accessible through this session. 
     *  
     *  In effective mode, commitments are returned that are currently 
     *  effective. In any effective mode, effective commitments and those 
     *  currently expired are returned. 
     *
     *  @param  commitmentGenusType commitment genus type 
     *  @return list of commitments 
     *  @throws org.osid.NullArgumentException <code> commitmentGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.calendaring.CommitmentList getCommitmentsByGenusType(org.osid.type.Type commitmentGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the commitments for the given event genus type and include any 
     *  commitments with a genus type derived from the specified genus type. 
     *  
     *  In plenary mode, the returned list contains all known commitments or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  commitments that are accessible through this session. 
     *  
     *  In effective mode, commitments are returned that are currently 
     *  effective. In any effective mode, effective commitments and those 
     *  currently expired are returned. 
     *
     *  @param  commitmentGenusType commitment genus type 
     *  @return list of commitments 
     *  @throws org.osid.NullArgumentException <code> commitmentGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.calendaring.CommitmentList getCommitmentsByParentGenusType(org.osid.type.Type commitmentGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CommitmentList </code> containing the given event 
     *  commitment record <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  commitments or an error results. Otherwise, the returned list may 
     *  contain only those commitments that are accessible through this 
     *  session. 
     *  
     *  In effective mode, commitments are returned that are currently 
     *  effective. In any effective mode, effective commitments and those 
     *  currently expired are returned. 
     *
     *  @param  commitmentRecordType a commitment record type 
     *  @return list of commitments 
     *  @throws org.osid.NullArgumentException <code> eventRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.CommitmentList getCommitmentsByRecordType(org.osid.type.Type commitmentRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CommitmentList </code> effective during the entire given 
     *  date range inclusive but not confined to the date range. <code> 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  commitments or an error results. Otherwise, the returned list may 
     *  contain only those commitments that are accessible through this 
     *  session. 
     *  
     *  In effective mode, commitments are returned that are currently 
     *  effective. In any effective mode, effective commitments and those 
     *  currently expired are returned. 
     *
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return list of commitments 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.CommitmentList getCommitmentsOnDate(org.osid.calendaring.DateTime from, 
                                                                    org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CommitmentList </code> of the given genus type and 
     *  effective during the entire given date range inclusive but not 
     *  confined to the date range. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  commitments or an error results. Otherwise, the returned list may 
     *  contain only those commitments that are accessible through this 
     *  session. 
     *  
     *  In effective mode, commitments are returned that are currently 
     *  effective. In any effective mode, effective commitments and those 
     *  currently expired are returned. 
     *
     *  @param  commitmentGenusType a commitment genus type 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return list of commitments 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> commitmentGenusType, 
     *          from, </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.CommitmentList getCommitmentsByGenusTypeOnDate(org.osid.type.Type commitmentGenusType, 
                                                                               org.osid.calendaring.DateTime from, 
                                                                               org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the commitments for the given event. If the event is a recurring 
     *  event, the commitments are returned for the recurring event only. 
     *  
     *  In plenary mode, the returned list contains all of the commitments 
     *  mapped to the event <code> Id </code> or an error results if an Id in 
     *  the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Commitments </code> may be omitted from the list 
     *  and may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In effective mode, commitments are returned that are currently 
     *  effective. In any effective mode, effective commitments and those 
     *  currently expired are returned. 
     *
     *  @param  eventId <code> Id </code> of the <code> Event </code> 
     *  @return list of commitments 
     *  @throws org.osid.NullArgumentException <code> eventId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.calendaring.CommitmentList getCommitmentsForEvent(org.osid.id.Id eventId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CommitmentList </code> for the given event and effective 
     *  during the entire given date range inclusive but not confined to the 
     *  date range. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  commitments or an error results. Otherwise, the returned list may 
     *  contain only those commitments that are accessible through this 
     *  session. 
     *  
     *  In effective mode, commitments are returned that are currently 
     *  effective. In any effective mode, effective commitments and those 
     *  currently expired are returned. 
     *
     *  @param  eventId <code> Id </code> of the <code> Event </code> 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return list of commitments 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> eventId, from </code> or 
     *          <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.CommitmentList getCommitmentsForEventOnDate(org.osid.id.Id eventId, 
                                                                            org.osid.calendaring.DateTime from, 
                                                                            org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the commitments for the given event and commitment genus type 
     *  including any genus types derived from the given genus type. 
     *  
     *  If the event is a recurring event, the commitments are returned for 
     *  the recurring event only. In plenary mode, the returned list contains 
     *  all of the commitments mapped to the event <code> Id </code> or an 
     *  error results if an Id in the supplied list is not found or 
     *  inaccessible. Otherwise, inaccessible commitments may be ommitted. 
     *  
     *  In effective mode, commitments are returned that are currently 
     *  effective. In any effective mode, effective commitments and those 
     *  currently expired are returned. 
     *
     *  @param  eventId <code> Id </code> of the <code> Event </code> 
     *  @param  commitmentGenusType commitment genus type 
     *  @return list of commitments 
     *  @throws org.osid.NullArgumentException <code> eventId </code> or 
     *          <code> commitmentGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.calendaring.CommitmentList getCommitmentsByGenusTypeForEvent(org.osid.id.Id eventId, 
                                                                                 org.osid.type.Type commitmentGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CommitmentList </code> for the given event and 
     *  commitment genus type effective during the entire given date range 
     *  inclusive but not confined to the date range. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  commitments or an error results. Otherwise, the returned list may 
     *  contain only those commitments that are accessible through this 
     *  session. 
     *  
     *  In effective mode, commitments are returned that are currently 
     *  effective. In any effective mode, effective commitments and those 
     *  currently expired are returned. 
     *
     *  @param  eventId <code> Id </code> of the <code> Event </code> 
     *  @param  commitmentGenusType commitment genus type 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return list of commitments 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> eventId, 
     *          commitmentGenusType, from </code> or <code> to </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.CommitmentList getCommitmentsByGenusTypeForEventOnDate(org.osid.id.Id eventId, 
                                                                                       org.osid.type.Type commitmentGenusType, 
                                                                                       org.osid.calendaring.DateTime from, 
                                                                                       org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the commitments for the given resource. 
     *  
     *  In plenary mode, the returned list contains all of the commitments 
     *  mapped to the resource <code> Id </code> or an error results if an Id 
     *  in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Commitments </code> may be omitted from the list 
     *  and may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In effective mode, commitments are returned that are currently 
     *  effective. In any effective mode, effective commitments and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId <code> Id </code> of a <code> Resource </code> 
     *  @return list of commitments 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.calendaring.CommitmentList getCommitmentsForResource(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CommitmentList </code> for the given resource and 
     *  effective during the entire given date range inclusive but not 
     *  confined to the date range. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  commitments or an error results. Otherwise, the returned list may 
     *  contain only those commitments that are accessible through this 
     *  session. 
     *  
     *  In effective mode, commitments are returned that are currently 
     *  effective. In any effective mode, effective commitments and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId <code> Id </code> of the <code> Event </code> 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return list of commitments 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, from </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.CommitmentList getCommitmentsForResourceOnDate(org.osid.id.Id resourceId, 
                                                                               org.osid.calendaring.DateTime from, 
                                                                               org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the commitments for the given resource and commitment genus type 
     *  including any genus types derived from the given genus type. 
     *  
     *  In plenary mode, the returned list contains all of the commitments 
     *  mapped to the resource <code> Id </code> or an error results if an Id 
     *  in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Commitments </code> may be omitted from the list 
     *  and may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In effective mode, commitments are returned that are currently 
     *  effective. In any effective mode, effective commitments and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId <code> Id </code> of a <code> Resource </code> 
     *  @param  commitmentGenusType commitment genus type 
     *  @return list of commitments 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> or 
     *          <code> commitmentGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.calendaring.CommitmentList getCommitmentsByGenusTypeForResource(org.osid.id.Id resourceId, 
                                                                                    org.osid.type.Type commitmentGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CommitmentList </code> for the given resource, 
     *  commitment genus type, and effective during the entire given date 
     *  range inclusive but not confined to the date range. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  commitments or an error results. Otherwise, the returned list may 
     *  contain only those commitments that are accessible through this 
     *  session. 
     *  
     *  In effective mode, commitments are returned that are currently 
     *  effective. In any effective mode, effective commitments and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId <code> Id </code> of the <code> Event </code> 
     *  @param  commitmentGenusType commitment genus type 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return list of commitments 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, 
     *          commitmentGenusType, from </code> or <code> to </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.CommitmentList getCommitmentsByGenusTypeForResourceOnDate(org.osid.id.Id resourceId, 
                                                                                          org.osid.type.Type commitmentGenusType, 
                                                                                          org.osid.calendaring.DateTime from, 
                                                                                          org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the commitments for the given event and resource. If the event is 
     *  a recurring event, the commitments are returned for the recurring 
     *  event only. 
     *  
     *  In plenary mode, the returned list contains all of the commitments 
     *  mapped to the event <code> Id </code> or an error results if an Id in 
     *  the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Commitments </code> may be omitted from the list 
     *  and may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In effective mode, commitments are returned that are currently 
     *  effective. In any effective mode, effective commitments and those 
     *  currently expired are returned. 
     *
     *  @param  eventId <code> Id </code> of the <code> Event </code> 
     *  @param  resourceId <code> Id </code> of a <code> Resource </code> 
     *  @return list of commitments 
     *  @throws org.osid.NullArgumentException <code> eventId </code> or 
     *          <code> resourceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.calendaring.CommitmentList getCommitmentsForEventAndResource(org.osid.id.Id eventId, 
                                                                                 org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CommitmentList </code> for the given event and resource 
     *  and effective during the entire given date range inclusive but not 
     *  confined to the date range. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  commitments or an error results. Otherwise, the returned list may 
     *  contain only those commitments that are accessible through this 
     *  session. 
     *  
     *  In effective mode, commitments are returned that are currently 
     *  effective. In any effective mode, effective commitments and those 
     *  currently expired are returned. 
     *
     *  @param  eventId <code> Id </code> of the <code> Event </code> 
     *  @param  resourceId <code> Id </code> of a <code> Resource </code> 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return list of commitments 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> eventId, resourceId, 
     *          from </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.CommitmentList getCommitmentsForEventAndResourceOnDate(org.osid.id.Id eventId, 
                                                                                       org.osid.id.Id resourceId, 
                                                                                       org.osid.calendaring.DateTime from, 
                                                                                       org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the commitments of the given genus type for the given event, 
     *  resource, and commitment genus type including any genus types derived 
     *  from the given genus type. If the event is a recurring event, the 
     *  commitments are returned for the recurring event only. 
     *  
     *  In plenary mode, the returned list contains all of the commitments 
     *  mapped to the event <code> Id </code> or an error results if an Id in 
     *  the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Commitments </code> may be omitted from the list 
     *  and may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In effective mode, commitments are returned that are currently 
     *  effective. In any effective mode, effective commitments and those 
     *  currently expired are returned. 
     *
     *  @param  eventId <code> Id </code> of the <code> Event </code> 
     *  @param  resourceId <code> Id </code> of a <code> Resource </code> 
     *  @param  commitmentGenusType commitment genus type 
     *  @return list of commitments 
     *  @throws org.osid.NullArgumentException <code> eventId, resourceId 
     *          </code> or <code> commitmentGenusType </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.calendaring.CommitmentList getCommitmentsByGenusTypeForEventAndResource(org.osid.id.Id eventId, 
                                                                                            org.osid.id.Id resourceId, 
                                                                                            org.osid.type.Type commitmentGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CommitmentList </code> of the given genus type for the 
     *  given event, resource, commitment genus type and effective during the 
     *  entire given date range inclusive but not confined to the date range. 
     *  <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  commitments or an error results. Otherwise, the returned list may 
     *  contain only those commitments that are accessible through this 
     *  session. 
     *  
     *  In effective mode, commitments are returned that are currently 
     *  effective. In any effective mode, effective commitments and those 
     *  currently expired are returned. 
     *
     *  @param  eventId <code> Id </code> of the <code> Event </code> 
     *  @param  resourceId <code> Id </code> of a <code> Resource </code> 
     *  @param  commitmentGenusType commitment genus type 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return list of commitments 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> eventId, resourceId, 
     *          commitmentGenusType, from </code> or <code> to </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.CommitmentList getCommitmentsByGenusTypeForEventAndResourceOnDate(org.osid.id.Id eventId, 
                                                                                                  org.osid.id.Id resourceId, 
                                                                                                  org.osid.type.Type commitmentGenusType, 
                                                                                                  org.osid.calendaring.DateTime from, 
                                                                                                  org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all commitments. 
     *  
     *  In plenary mode, the returned list contains all known commitments or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  commitments that are accessible through this session. 
     *  
     *  In effective mode, commitments are returned that are currently 
     *  effective. In any effective mode, effective commitments and those 
     *  currently expired are returned. 
     *
     *  @return list of commitments 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.calendaring.CommitmentList getCommitments()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
