//
// org.osid.calendaring.CommitmentSearchSession
//
//     The OSID Java specification for org.osid.calendaring.CommitmentSearchSession.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>This session provides methods for searching <code> Commitment </code> 
 *  objects. The search query is constructed using the <code> CommitmentQuery. 
 *  </code> The commitment record <code> Type </code> also specifies the 
 *  record for the commitment query. </p> 
 *  
 *  <p> <code> getCommitmentsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Commitments. </code> A more advanced search may 
 *  be performed with <code> getCommitmentsBySearch(). </code> It accepts a 
 *  <code> CommitmentSearch </code> in addition to the query for the purpose 
 *  of specifying additional options affecting the entire search, such as 
 *  ordering. <code> getCommitmentsBySearch() </code> returns an <code> 
 *  CommitmentSearchResults </code> that can be used to access the resulting 
 *  <code> CommitmentList </code> or be used to perform a search within the 
 *  result set through <code> CommitmentSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated calendar view: searches include commitments in 
 *      calendars of which this calendar is a ancestor in the calendar 
 *      hierarchy </li> 
 *      <li> isolated calendar view: searches are restricted to commitments in 
 *      this calendar only </li> 
 *  </ul>
 *  
 *  
 *  <p> Commitments may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> CommitmentQuery. 
 *  </code> </p>
 */

public interface CommitmentSearchSession
    extends org.osid.calendaring.CommitmentQuerySession {


    /**
     *  Gets a commitment search. 
     *
     *  @return the commitment search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.CommitmentSearch getCommitmentSearch();


    /**
     *  Gets a commitment search order. The <code> CommitmentSearchOrder 
     *  </code> is supplied to a <code> CommitmentSearch </code> to specify 
     *  the ordering of results. 
     *
     *  @return the commitment search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.CommitmentSearchOrder getCommitmentSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  commitmentQuery the commitment search query 
     *  @param  commitmentSearch the commitment search 
     *  @return the commitment search results 
     *  @throws org.osid.NullArgumentException <code> commitmentQuery </code> 
     *          or <code> commitmentSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> commitmentSearch </code> 
     *          or <code> commitmentQuery </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.CommitmentSearchResults getCommitmentsBySearch(org.osid.calendaring.CommitmentQuery commitmentQuery, 
                                                                               org.osid.calendaring.CommitmentSearch commitmentSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a commitment query from an inspector. The inspector is available 
     *  from an <code> CommitmentSearchResults. </code> 
     *
     *  @param  commitmentQueryInspector a commitment query inspector 
     *  @return the commitment query 
     *  @throws org.osid.NullArgumentException <code> commitmentQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> commitmentQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.CommitmentQuery getCommitmentQueryFromInspector(org.osid.calendaring.CommitmentQueryInspector commitmentQueryInspector);
}
