//
// org.osid.calendaring.DateTimeResolution
//
//     Specifies the OSID definition for org.osid.calendaring.DateTimeResolution.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  This enumeration contains the possible date/time resolutions. 
 */

public enum DateTimeResolution {

    /** ten quattuordecillionth second resolution */
    PLANCKSECOND("Plancksecond", "ten quattuordecillionth second resolution"),

    /** one unadecillionth second resolution */
    UNDASECOND("Undasecond", "one unadecillionth second resolution"),

    /** one decillionth second resolution */
    VATOSECOND("Vatosecond", "one decillionth second resolution"),

    /** one nonillionth second resolution */
    WEEBLESECOND("Weeblesecond", "one nonillionth second resolution"),

    /** one octillionth second resolution */
    XOXXOSECOND("Xoxxosecond", "one octillionth second resolution"),

    /** one septllionth second resolution */
    YOCTOSECOND("Yoctosecond", "one septllionth second resolution"),

    /** one sextillionth second resolution */
    ZEPTOSECOND("Zeptosecond", "one sextillionth second resolution"),

    /** one quintillionth second resolution */
    ATTOSECOND("Attosecond", "one quintillionth second resolution"),

    /** one quadrillionth second resolution */
    FEMTOSECOND("Femtosecond", "one quadrillionth second resolution"),

    /** one trillionth second resolution */
    PICOSECOND("Picosecond", "one trillionth second resolution"),

    /** one billionth second resolution */
    NANOSECOND("Nanosecond", "one billionth second resolution"),

    /** one millionth second resolution */
    MICROSECOND("Microsecond", "one millionth second resolution"),

    /** one thousandth second resolution */
    MILLISECOND("Millisecond", "one thousandth second resolution"),

    /** second resolution */
    SECOND("Second", "second resolution"),

    /** minute resolution */
    MINUTE("Minute", "minute resolution"),

    /** 15 minute resolution */
    QUARTER_HOUR("Quarter_hour", "15 minute resolution"),

    /** 30 minute resolution */
    HALF_HOUR("Half_hour", "30 minute resolution"),

    /** hour resolution */
    HOUR("Hour", "hour resolution"),

    /** day resolution */
    DAY("Day", "day resolution"),

    /** week resolution */
    WEEK("Week", "week resolution"),

    /** month resolution */
    MONTH("Month", "month resolution"),

    /** yearly resolution */
    YEAR("Year", "yearly resolution"),

    /** once in a blue moon */
    BLUEMOON("Bluemoon", "once in a blue moon"),

    /** decade resolution */
    DECADE("Decade", "decade resolution"),

    /** century resolution */
    CENTURY("Century", "century resolution"),

    /** millennium resolution */
    MILLENNIA("Millennia", "millennium resolution"),

    /** 100K years resolution */
    GLACIAL("Glacial", "100K years resolution"),

    /** 1M years resolution */
    EPOCH("Epoch", "1M years resolution"),

    /** 1B years resolution */
    AEON("Aeon", "1B years resolution"),

    /** clock is invalid */
    INFINITY("Infinity", "clock is invalid");


    private final String displayName;
    private final String description;

    DateTimeResolution(String displayName, String description) {
        this.displayName = displayName;
        this.description = description;
    }

    public String getDisplayName() {
        return (this.displayName);
    }

    public String getDescription() {
        return (this.description);
    }
}
