//
// org.osid.calendaring.OffsetEventLookupSession
//
//     The OSID Java specification for org.osid.calendaring.OffsetEventLookupSession.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>This session provides methods for retrieving <code> OffsetEvents. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated calendar view: All offset event methods in this session 
 *      operate, retrieve and pertain to offset events defined explicitly in 
 *      the current calendar. Using an isolated view is useful for managing 
 *      events with the <code> OffsetEventAdminSession. </code> </li> 
 *      <li> federated calendar view: All offset event methods in this session 
 *      operate, retrieve and pertain to all offset events defined in this 
 *      calendar and any other calendars implicitly available in this calendar 
 *      through calendar inheritence. </li> 
 *      <li> active offset event view: All offset event lookup methods return 
 *      active offset events. </li> 
 *      <li> any status offset event view: Offset events of any active or 
 *      inactive status are returned from methods. </li> 
 *  </ul>
 *  
 */

public interface OffsetEventLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Calendar </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Calendar Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCalendarId();


    /**
     *  Gets the <code> Calendar </code> associated with this session. 
     *
     *  @return the <code> Calendar </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Calendar getCalendar()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> OffsetEvent </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupOffsetEvents();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeOffsetEventView();


    /**
     *  A complete view of the <code> OffsetEvent </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryOffsetEventView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include offset events in calendars which are children of this calendar 
     *  in the calendar hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCalendarView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this calendar only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCalendarView();


    /**
     *  Only active offset events are returned by methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveOffsetEventView();


    /**
     *  All active and inactive offset events are returned by methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusOffsetEventView();


    /**
     *  Gets the <code> OffsetEvent </code> specified by its <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  OffsetEvent </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to an <code> OffsetEvent </code> and retained for 
     *  compatibility. 
     *  
     *  In active mode, offset events are returned that are currently active. 
     *  In any status mode, active and inactive offset events are returned. 
     *
     *  @param  offsetEventId <code> Id </code> of the <code> OffsetEvent 
     *          </code> 
     *  @return the offset event 
     *  @throws org.osid.NotFoundException <code> offsetEventId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> offsetEventId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.calendaring.OffsetEvent getOffsetEvent(org.osid.id.Id offsetEventId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> OffsetEventList </code> corresponding to the given 
     *  <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  offset events specified in the <code> Id </code> list, in the order of 
     *  the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> OffsetEvents </code> may be omitted from the list 
     *  and may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In active mode, offset events are returned that are currently active. 
     *  In any status mode, active and inactive offset events are returned. 
     *
     *  @param  offsetEventIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> OffsetEvent </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> offsetEventIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.OffsetEventList getOffsetEventsByIds(org.osid.id.IdList offsetEventIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> OffsetEventList </code> corresponding to the given 
     *  offset event genus <code> Type </code> which does not include offset 
     *  events of genus types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  offset events or an error results. Otherwise, the returned list may 
     *  contain only those offset events that are accessible through this 
     *  session. 
     *  
     *  In active mode, offset events are returned that are currently active. 
     *  In any status mode, active and inactive offset events are returned. 
     *
     *  @param  offsetEventGenusType an offset event genus type 
     *  @return the returned <code> OffsetEvent </code> list 
     *  @throws org.osid.NullArgumentException <code> offsetEventGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.OffsetEventList getOffsetEventsByGenusType(org.osid.type.Type offsetEventGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> OffsetEventList </code> corresponding to the given 
     *  offset event genus <code> Type </code> and include any additional 
     *  offset event with genus types derived from the specified <code> Type. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  offset events or an error results. Otherwise, the returned list may 
     *  contain only those offset events that are accessible through this 
     *  session. 
     *  
     *  In active mode, offset events are returned that are currently active. 
     *  In any status mode, active and inactive offset events are returned. 
     *
     *  @param  offsetEventGenusType an offset event genus type 
     *  @return the returned <code> OffsetEvent </code> list 
     *  @throws org.osid.NullArgumentException <code> offsetEventGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.OffsetEventList getOffsetEventsByParentGenusType(org.osid.type.Type offsetEventGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> OffsetEventList </code> containing the given offset 
     *  event record <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  offset events or an error results. Otherwise, the returned list may 
     *  contain only those offset events that are accessible through this 
     *  session. 
     *  
     *  In active mode, offset events are returned that are currently active. 
     *  In any status mode, active and inactive offset events are returned. 
     *
     *  @param  offsetEventrecordType an offset event record type 
     *  @return the returned <code> OffsetEvent </code> list 
     *  @throws org.osid.NullArgumentException <code> offsetEventRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.OffsetEventList getOffsetEventsByRecordType(org.osid.type.Type offsetEventrecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> OffsetEvents </code> using the given event as a start 
     *  or ending offset. 
     *  
     *  In plenary mode, the returned list contains all known offset events or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  offset events that are accessible through this session. 
     *  
     *  In active mode, offset events are returned that are currently active. 
     *  In any status mode, active and inactive offset events are returned. 
     *
     *  @param  eventId <code> Id </code> of the related event 
     *  @return the offset events 
     *  @throws org.osid.NullArgumentException <code> eventId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.calendaring.OffsetEventList getOffsetEventsByEvent(org.osid.id.Id eventId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> OffsetEvents. </code> 
     *  
     *  In plenary mode, the returned list contains all known offset events or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  offset events that are accessible through this session. 
     *  
     *  In active mode, offset events are returned that are currently active. 
     *  In any status mode, active and inactive offset events are returned. 
     *
     *  @return an <code> OffsetEventList </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.OffsetEventList getOffsetEvents()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
