//
// org.osid.calendaring.OffsetEventQuery
//
//     The OSID Java specification for org.osid.calendaring.OffsetEventQuery.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>This is the query for searching events. Each method match request 
 *  produces an <code> AND </code> term while multiple invocations of a method 
 *  produces a nested <code> OR. </code> </p>
 */

public interface OffsetEventQuery
    extends org.osid.OsidRuleQuery {


    /**
     *  Matches a fixed start time between the given range inclusive. 
     *
     *  @param  from the start of the range 
     *  @param  to the end of the range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchFixedStartTime(org.osid.calendaring.DateTime from, 
                                    org.osid.calendaring.DateTime to, 
                                    boolean match);


    /**
     *  Matches events with fixed start times. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyFixedStartTime(boolean match);


    /**
     *  Clears the fixed start time terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFixedStartTimeTerms();


    /**
     *  Sets the start reference event <code> Id </code> for this query. 
     *
     *  @param  eventId an event <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> eventId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchStartReferenceEventId(org.osid.id.Id eventId, 
                                           boolean match);


    /**
     *  Clears the start reference event <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStartReferenceEventIdTerms();


    /**
     *  Tests if an <code> EventQuery </code> is available for querying start 
     *  reference event terms. 
     *
     *  @return <code> true </code> if an event query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStartReferenceEventQuery();


    /**
     *  Gets the query for the start reference event. Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @return the event query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStartReferenceEventQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStartReferenceEventQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.EventQuery getStartReferenceEventQuery();


    /**
     *  Matches offset events with any starting reference event. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyStartReferenceEvent(boolean match);


    /**
     *  Clears the start reference event terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStartReferenceEventTerms();


    /**
     *  Matches a fixed offset amount between the given range inclusive. 
     *
     *  @param  from the start of the range 
     *  @param  to the end of the range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchFixedStartOffset(org.osid.calendaring.Duration from, 
                                      org.osid.calendaring.Duration to, 
                                      boolean match);


    /**
     *  Matches fixed offset events. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyFixedStartOffset(boolean match);


    /**
     *  Clears the fixed offset terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFixedStartOffsetTerms();


    /**
     *  Matches a relative weekday offset amount between the given range 
     *  inclusive. 
     *
     *  @param  low the start of the range 
     *  @param  high the end of the range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRelativeWeekdayStartOffset(long low, long high, 
                                                boolean match);


    /**
     *  Clears the relative weekday offset terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRelativeWeekdayStartOffsetTerms();


    /**
     *  Matches a relative weekday. 
     *
     *  @param  weekday the weekday 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRelativeStartWeekday(long weekday, boolean match);


    /**
     *  Matches relative weekday offset events. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRelativeStartWeekday(boolean match);


    /**
     *  Clears the relative weekday terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRelativeStartWeekdayTerms();


    /**
     *  Matches a fixed duration between the given range inclusive. 
     *
     *  @param  low the start of the range 
     *  @param  high the end of the range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchFixedDuration(org.osid.calendaring.Duration low, 
                                   org.osid.calendaring.Duration high, 
                                   boolean match);


    /**
     *  Clears the fixed duration offset terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFixedDurationTerms();


    /**
     *  Sets the end reference event <code> Id </code> for this query. 
     *
     *  @param  eventId an event <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> eventId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchEndReferenceEventId(org.osid.id.Id eventId, boolean match);


    /**
     *  Clears the end reference event <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEndReferenceEventIdTerms();


    /**
     *  Tests if an <code> EventQuery </code> is available for querying end 
     *  reference event terms. 
     *
     *  @return <code> true </code> if an event query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEndReferenceEventQuery();


    /**
     *  Gets the query for the end reference event. Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @return the event query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEventReferenceEventQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEndReferenceEventQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.EventQuery getEndReferenceEventQuery();


    /**
     *  Matches any end reference event events. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyEndReferenceEvent(boolean match);


    /**
     *  Clears the end reference event terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEndReferenceEventTerms();


    /**
     *  Matches a fixed offset amount between the given range inclusive. 
     *
     *  @param  from the start of the range 
     *  @param  to the end of the range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchFixedEndOffset(org.osid.calendaring.Duration from, 
                                    org.osid.calendaring.Duration to, 
                                    boolean match);


    /**
     *  Matches fixed offset events. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyFixedEndOffset(boolean match);


    /**
     *  Clears the fixed offset terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFixedEndOffsetTerms();


    /**
     *  Matches a relative weekday offset amount between the given range 
     *  inclusive. 
     *
     *  @param  low the start of the range 
     *  @param  high the end of the range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRelativeWeekdayEndOffset(long low, long high, 
                                              boolean match);


    /**
     *  Clears the relative weekday offset terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRelativeWeekdayEndOffsetTerms();


    /**
     *  Matches a relative weekday. 
     *
     *  @param  weekday the weekday 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRelativeEndWeekday(long weekday, boolean match);


    /**
     *  Matches relative weekday offset events. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRelativeEndWeekday(boolean match);


    /**
     *  Clears the relative weekday terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRelativeEndWeekdayTerms();


    /**
     *  Matches the location description string. 
     *
     *  @param  location location string 
     *  @param  stringMatchType string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> location </code> is 
     *          not of <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> location </code> or 
     *          <code> stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchLocationDescription(String location, 
                                         org.osid.type.Type stringMatchType, 
                                         boolean match);


    /**
     *  Matches an event that has any location description assigned. 
     *
     *  @param  match <code> true </code> to match events with any location 
     *          description, <code> false </code> to match events with no 
     *          location description 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyLocationDescription(boolean match);


    /**
     *  Clears the location description terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLocationDescriptionTerms();


    /**
     *  Sets the location <code> Id </code> for this query. 
     *
     *  @param  locationId a location <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> locationId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchLocationId(org.osid.id.Id locationId, boolean match);


    /**
     *  Clears the location <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLocationIdTerms();


    /**
     *  Tests if a <code> LocationQuery </code> is available for querying 
     *  locations. 
     *
     *  @return <code> true </code> if a location query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLocationQuery();


    /**
     *  Gets the query for a location. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the location query 
     *  @throws org.osid.UnimplementedException <code> supportsLocationQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLocationQuery() </code> is <code> true. </code> 
     */

    public org.osid.mapping.LocationQuery getLocationQuery();


    /**
     *  Matches an event that has any location assigned. 
     *
     *  @param  match <code> true </code> to match events with any location, 
     *          <code> false </code> to match events with no location 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyLocation(boolean match);


    /**
     *  Clears the location terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLocationTerms();


    /**
     *  Sets the sponsor <code> Id </code> for this query. 
     *
     *  @param  sponsorId a sponsor <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> sponsorId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSponsorId(org.osid.id.Id sponsorId, boolean match);


    /**
     *  Clears the sponsor <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSponsorIdTerms();


    /**
     *  Tests if a <code> LocationQuery </code> is available for querying 
     *  sponsors. 
     *
     *  @return <code> true </code> if a sponsor query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSponsorQuery();


    /**
     *  Gets the query for a sponsor. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the sponsor query 
     *  @throws org.osid.UnimplementedException <code> supportsSponsorQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSponsorQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceQuery getSponsorQuery();


    /**
     *  Clears the sponsor terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSponsorTerms();


    /**
     *  Sets the calendar <code> Id </code> for this query. 
     *
     *  @param  calendarId a calendar <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCalendarId(org.osid.id.Id calendarId, boolean match);


    /**
     *  Clears the calendar <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCalendarIdTerms();


    /**
     *  Tests if a <code> CalendarQuery </code> is available for querying 
     *  calendars. 
     *
     *  @return <code> true </code> if a calendar query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCalendarQuery();


    /**
     *  Gets the query for a calendar. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the calendar query 
     *  @throws org.osid.UnimplementedException <code> supportsCalendarQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCalendarQuery() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.CalendarQuery getCalendarQuery();


    /**
     *  Clears the calendar terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCalendarTerms();


    /**
     *  Gets the offset event query record corresponding to the given <code> 
     *  OffsetEvent </code> record <code> Type. </code> Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @param  offsetEventRecordType an offset event query record type 
     *  @return the offset event query record 
     *  @throws org.osid.NullArgumentException <code> offsetEventRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(offsetEventRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.records.OffsetEventQueryRecord getOffsetEventQueryRecord(org.osid.type.Type offsetEventRecordType)
        throws org.osid.OperationFailedException;
}
