//
// org.osid.calendaring.OffsetEventSearch
//
//     The OSID Java specification for org.osid.calendaring.OffsetEventSearch.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p><code> OffsetEventSearch </code> defines the interface for specifying 
 *  offset event search options. </p>
 */

public interface OffsetEventSearch
    extends org.osid.OsidSearch {


    /**
     *  Execute this search among the given list of offset events. 
     *
     *  @param  offsetEventIds list of offset events 
     *  @throws org.osid.NullArgumentException <code> offsetEventIds </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void searchAmongOffsetEvents(org.osid.id.IdList offsetEventIds);


    /**
     *  Specify an ordering to the search results. 
     *
     *  @param  offsetEventSearchOrder offset event search order 
     *  @throws org.osid.NullArgumentException <code> offsetEventSearchOrder 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> offsetEventSearchOrder 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderOffsetEventResults(org.osid.calendaring.OffsetEventSearchOrder offsetEventSearchOrder);


    /**
     *  Gets the offset event search record corresponding to the given offset 
     *  event search record <code> Type. </code> 
     *
     *  @param  offsetEventSearchRecordType an offset event search record type 
     *  @return the offset event search record 
     *  @throws org.osid.NullArgumentException <code> 
     *          offsetEventSearchRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(offsetEventSearchRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.records.OffsetEventSearchRecord getOffsetEventSearchRecord(org.osid.type.Type offsetEventSearchRecordType)
        throws org.osid.OperationFailedException;
}
