//
// org.osid.calendaring.OffsetEventSearchOrder
//
//     The OSID Java specification for org.osid.calendaring.OffsetEventSearchOrder.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>An interface for specifying the ordering of search results. </p>
 */

public interface OffsetEventSearchOrder
    extends org.osid.OsidRuleSearchOrder {


    /**
     *  Specified a preference for ordering results by the fixed start time. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByFixedStartTime(org.osid.SearchOrderStyle style);


    /**
     *  Specified a preference for ordering results by the starting reference 
     *  event. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByStartReferenceEvent(org.osid.SearchOrderStyle style);


    /**
     *  Tests if an <code> EventSearchOrder </code> is available. 
     *
     *  @return <code> true </code> if an event search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStartReferenceEventSearchOrder();


    /**
     *  Gets the search order for an event. 
     *
     *  @return the event search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStartReferenceEventSearchOrder() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStartReferenceEventSearchOrder() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.EventSearchOrder getStartReferenceEventSearchOrder();


    /**
     *  Specified a preference for ordering results by the fixed offset. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByFixedStartOffset(org.osid.SearchOrderStyle style);


    /**
     *  Specified a preference for ordering results by the relative weekday 
     *  offset. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByRelativeWeekdayStartOffset(org.osid.SearchOrderStyle style);


    /**
     *  Specified a preference for ordering results by the relative weekday. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByRelativeStartWeekday(org.osid.SearchOrderStyle style);


    /**
     *  Specified a preference for ordering results by the fixed duration. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByFixedDuration(org.osid.SearchOrderStyle style);


    /**
     *  Specified a preference for ordering results by the ending reference 
     *  event. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByEndReferenceEvent(org.osid.SearchOrderStyle style);


    /**
     *  Tests if an <code> EventSearchOrder </code> is available. 
     *
     *  @return <code> true </code> if an event search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEndReferenceEventSearchOrder();


    /**
     *  Gets the search order for an event. 
     *
     *  @return the event search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEndReferenceEventSearchOrder() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEndReferenceEventSearchOrder() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.EventSearchOrder getEndReferenceEventSearchOrder();


    /**
     *  Specified a preference for ordering results by the fixed offset. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByFixedEndOffset(org.osid.SearchOrderStyle style);


    /**
     *  Specified a preference for ordering results by the relative weekday 
     *  offset. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByRelativeWeekdayEndOffset(org.osid.SearchOrderStyle style);


    /**
     *  Specified a preference for ordering results by the relative weekday. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByRelativeEndWeekday(org.osid.SearchOrderStyle style);


    /**
     *  Specified a preference for ordering results by the location 
     *  description. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByLocationDescription(org.osid.SearchOrderStyle style);


    /**
     *  Specified a preference for ordering results by the location. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByLocation(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a <code> LocationSearchOrder </code> is available. 
     *
     *  @return <code> true </code> if a location search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLocationSearchOrder();


    /**
     *  Gets the search order for a location. 
     *
     *  @return the location search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsLocationSearchOrder() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLocationSearchOrder() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.mapping.LocationSearchOrder getLocationSearchOrder();


    /**
     *  Gets the offset event search order record corresponding to the given 
     *  offset event record <code> Type. </code> Multiple retrievals return 
     *  the same underlying object. 
     *
     *  @param  offsetEventRecordType an offset event record type 
     *  @return the offset event search order record 
     *  @throws org.osid.NullArgumentException <code> offsetEventRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(offsetEventRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.records.OffsetEventSearchOrderRecord getOffsetEventSearchOrderRecord(org.osid.type.Type offsetEventRecordType)
        throws org.osid.OperationFailedException;
}
