//
// org.osid.calendaring.RecurringEventQuery
//
//     The OSID Java specification for org.osid.calendaring.RecurringEventQuery.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>This is the query for searching recurring events. Each method match 
 *  request produces an <code> AND </code> term while multiple invocations of 
 *  a method produces a nested <code> OR. </code> </p>
 */

public interface RecurringEventQuery
    extends org.osid.OsidRuleQuery,
            org.osid.OsidContainableQuery {


    /**
     *  Sets the schedule <code> Id </code> for this query for matching 
     *  schedules. 
     *
     *  @param  scheduleId a schedule <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> scheduleId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchScheduleId(org.osid.id.Id scheduleId, boolean match);


    /**
     *  Clears the schedule <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearScheduleIdTerms();


    /**
     *  Tests if a <code> ScheduleQuery </code> is available for querying 
     *  schedules. 
     *
     *  @return <code> true </code> if a schedule query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsScheduleQuery();


    /**
     *  Gets the query for a schedule. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the schedule query 
     *  @throws org.osid.UnimplementedException <code> supportsScheduleQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsScheduleQuery() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.ScheduleQuery getScheduleQuery();


    /**
     *  Matches a recurring event that has any schedule assigned. 
     *
     *  @param  match <code> true </code> to match recurring events with any 
     *          schedules, <code> false </code> to match recurring events with 
     *          no schedules 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnySchedule(boolean match);


    /**
     *  Clears the schedule terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearScheduleTerms();


    /**
     *  Sets the superseding event <code> Id </code> for this query. 
     *
     *  @param  supersedingEventId a superseding event <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> supersedingEventId 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSupersedingEventId(org.osid.id.Id supersedingEventId, 
                                        boolean match);


    /**
     *  Clears the superseding event <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSupersedingEventIdTerms();


    /**
     *  Tests if a <code> SupersedingEventQuery </code> is available for 
     *  querying superseding events. 
     *
     *  @return <code> true </code> if a superseding event query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSupersedingEventQuery();


    /**
     *  Gets the query for a superseding event. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the superseding event query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSupersedingEventQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSupersedingEventQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.SupersedingEventQuery getSupersedingEventQuery();


    /**
     *  Matches a recurring event that has any superseding event assigned. 
     *
     *  @param  match <code> true </code> to match recurring events with any 
     *          superseding events, <code> false </code> to match events with 
     *          no superseding events 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnySupersedingEvent(boolean match);


    /**
     *  Clears the superseding event terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSupersedingEventTerms();


    /**
     *  Matches recurring events with specific dates between the given range 
     *  inclusive. 
     *
     *  @param  start start date 
     *  @param  end end date 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> end </code> is less 
     *          than <code> start </code> 
     *  @throws org.osid.NullArgumentException <code> start </code> or <code> 
     *          end </code> is <code> zero </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSpecificMeetingTime(org.osid.calendaring.DateTime start, 
                                         org.osid.calendaring.DateTime end, 
                                         boolean match);


    /**
     *  Matches a recurring event that has any specific date assigned. 
     *
     *  @param  match <code> true </code> to match recurring events with any 
     *          specific date, <code> false </code> to match recurring events 
     *          with no specific date 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnySpecificMeetingTime(boolean match);


    /**
     *  Clears the blackout terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSpecificMeetingTimeTerms();


    /**
     *  Sets the composed event <code> Id </code> for this query. 
     *
     *  @param  eventId an event <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> eventId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchEventId(org.osid.id.Id eventId, boolean match);


    /**
     *  Clears the event <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEventIdTerms();


    /**
     *  Tests if an <code> EventQuery </code> is available for querying 
     *  composed events. 
     *
     *  @return <code> true </code> if an event query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEventQuery();


    /**
     *  Gets the query for an event. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the event query 
     *  @throws org.osid.UnimplementedException <code> supportsEventQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEventQuery() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.EventQuery getEventQuery();


    /**
     *  Matches a recurring event that has any composed event assigned. 
     *
     *  @param  match <code> true </code> to match recurring events with any 
     *          composed events, <code> false </code> to match events with no 
     *          composed events 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyEvent(boolean match);


    /**
     *  Clears the event terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEventTerms();


    /**
     *  Matches a blackout that contains the given date time. 
     *
     *  @param  datetime a datetime 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> datetime </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBlackout(org.osid.calendaring.DateTime datetime, 
                              boolean match);


    /**
     *  Matches a recurring event that has any blackout assigned. 
     *
     *  @param  match <code> true </code> to match recurring events with any 
     *          blackout, <code> false </code> to match recurring events with 
     *          no blackout 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyBlackout(boolean match);


    /**
     *  Clears the blackout terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBlackoutTerms();


    /**
     *  Matches recurring events with blackouts between the given range 
     *  inclusive. 
     *
     *  @param  start start date 
     *  @param  end end date 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> end </code> is less 
     *          than <code> start </code> 
     *  @throws org.osid.NullArgumentException <code> start </code> or <code> 
     *          end </code> is <code> zero </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBlackoutInclusive(org.osid.calendaring.DateTime start, 
                                       org.osid.calendaring.DateTime end, 
                                       boolean match);


    /**
     *  Clears the blackout terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBlackoutInclusiveTerms();


    /**
     *  Sets the sponsor <code> Id </code> for this query. 
     *
     *  @param  sponsorId a sponsor <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> sponsorId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSponsorId(org.osid.id.Id sponsorId, boolean match);


    /**
     *  Clears the sponsor <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSponsorIdTerms();


    /**
     *  Tests if a <code> LocationQuery </code> is available for querying 
     *  sponsors. 
     *
     *  @return <code> true </code> if a sponsor query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSponsorQuery();


    /**
     *  Gets the query for a sponsor. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the sponsor query 
     *  @throws org.osid.UnimplementedException <code> supportsSponsorQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSponsorQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceQuery getSponsorQuery();


    /**
     *  Clears the sponsor terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSponsorTerms();


    /**
     *  Sets the calendar <code> Id </code> for this query. 
     *
     *  @param  calendarId a calendar <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCalendarId(org.osid.id.Id calendarId, boolean match);


    /**
     *  Clears the calendar <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCalendarIdTerms();


    /**
     *  Tests if a <code> CalendarQuery </code> is available for querying 
     *  calendars. 
     *
     *  @return <code> true </code> if a calendar query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCalendarQuery();


    /**
     *  Gets the query for a calendar. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the calendar query 
     *  @throws org.osid.UnimplementedException <code> supportsCalendarQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCalendarQuery() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.CalendarQuery getCalendarQuery();


    /**
     *  Clears the calendar terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCalendarTerms();


    /**
     *  Gets the recurring event query recod corresponding to the given <code> 
     *  RecurringEvent </code> record <code> Type. </code> Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @param  recurringEventRecordType a recurring event query record type 
     *  @return the recurring event query record 
     *  @throws org.osid.NullArgumentException <code> recurringEventRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(recurringEventRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.records.RecurringEventQueryRecord getRecurringEventQueryRecord(org.osid.type.Type recurringEventRecordType)
        throws org.osid.OperationFailedException;
}
