//
// org.osid.calendaring.RecurringEventSearchSession
//
//     The OSID Java specification for org.osid.calendaring.RecurringEventSearchSession.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>This session provides methods for searching <code> RecurringEvent 
 *  </code> objects. The search query is constructed using the <code> 
 *  RecurringEventQuery. </code> The recurring event record <code> Type 
 *  </code> also specifies the record for the recurring event query. </p> 
 *  
 *  <p> <code> getRecurringEventsByQuery() </code> is the basic search method 
 *  and returns a list of <code> RecurringEvents. </code> A more advanced 
 *  search may be performed with <code> geRecurringEventsBySearch(). </code> 
 *  It accepts a <code> RecurringEventSearch </code> in addition to the query 
 *  for the purpose of specifying additional options affecting the entire 
 *  search, such as ordering. <code> getRecurringEventsBySearch() </code> 
 *  returns a <code> RecurringEventSearchResults </code> that can be used to 
 *  access the resulting <code> RecurringEventList </code> or be used to 
 *  perform a search within the result set through <code> 
 *  RecurringEventSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated calendar view: searches include recurring events in 
 *      calendars of which this calendar is a ancestor in the calendar 
 *      hierarchy </li> 
 *      <li> isolated calendar view: searches are restricted to recurring 
 *      events in this calendar </li> 
 *  </ul>
 *  
 *  
 *  <p> Recurring events may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> 
 *  RecurringEventQuery. </code> </p>
 */

public interface RecurringEventSearchSession
    extends org.osid.calendaring.RecurringEventQuerySession {


    /**
     *  Gets a recurring event search. 
     *
     *  @return the recurring event search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.RecurringEventSearch getRecurringEventSearch();


    /**
     *  Gets a recurring event search order. The <code> 
     *  RecurringEventSearchOrder </code> is supplied to a <code> 
     *  RecurringEventSearch </code> to specify the ordering of results. 
     *
     *  @return the recurring event search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.RecurringEventSearchOrder getRecurringEventSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  recurringEventQuery the recurring event search query 
     *  @param  recurringEventSearch the recurring event search 
     *  @return the recurring event search results 
     *  @throws org.osid.NullArgumentException <code> recurringEventQuery 
     *          </code> or <code> recurringEventSearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> recurringEventSearch 
     *          </code> or <code> recurringEventQuery </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.RecurringEventSearchResults getRecurringEventsBySearch(org.osid.calendaring.RecurringEventQuery recurringEventQuery, 
                                                                                       org.osid.calendaring.RecurringEventSearch recurringEventSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a recurring event query from an inspector. The inspector is 
     *  available from a <code> RecurringEventSearchResults. </code> 
     *
     *  @param  recurringEventQueryInspector a recurring event query inspector 
     *  @return the recurring event query 
     *  @throws org.osid.NullArgumentException <code> 
     *          recurringEventQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          recurringEventQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.RecurringEventQuery getRecurringEventQueryFromInspector(org.osid.calendaring.RecurringEventQueryInspector recurringEventQueryInspector);
}
