//
// org.osid.calendaring.RecurringEventSmartCalendarSession
//
//     The OSID Java specification for org.osid.calendaring.RecurringEventSmartCalendarSession.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. A <code> RecurringEventQuery </code> can be retrieved from this 
 *  session and mapped to this <code> Calendar </code> to create a virtual 
 *  collection of <code> RecurringEvents. </code> The entries may be sequenced 
 *  using the <code> RecurringEventSearchOrder </code> from this session. </p> 
 *  
 *  <p> This <code> Calendar </code> has a default query that matches any 
 *  recurring event and a default search order that specifies no sequencing. 
 *  The queries may be examined using a <code> RecurringEventQueryInspector. 
 *  </code> The query may be modified by converting the inspector back to a 
 *  <code> RecurringEventQuery. </code> </p>
 */

public interface RecurringEventSmartCalendarSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Calendar </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Calendar Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCalendarId();


    /**
     *  Gets the <code> Calendar </code> associated with this session. 
     *
     *  @return the <code> Calendar </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Calendar getCalendar()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart calendars. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer smart operations. 
     *
     *  @return <code> false </code> if smart calendar methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartCalendars();


    /**
     *  Gets a recurring event query. 
     *
     *  @return the recurring event query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.RecurringEventQuery getRecurringEventQuery();


    /**
     *  Gets a recurring event search order. 
     *
     *  @return the recurring event search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.RecurringEventSearchOrder getRecurringEventSearchOrder();


    /**
     *  Applies a recurring event query to this calendar. 
     *
     *  @param  recurringEventQuery the recurring event query 
     *  @throws org.osid.NullArgumentException <code> recurringEventQuery 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> recurringEventQuery 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyRecurringEventQuery(org.osid.calendaring.RecurringEventQuery recurringEventQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a recurring event query inspector for this calendar. 
     *
     *  @return the recruring event query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.RecurringEventQueryInspector inspectRecurringEventQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a recurring event search order to this calendar. 
     *
     *  @param  recurringEventSearchOrder the recurring event search order 
     *  @throws org.osid.NullArgumentException <code> 
     *          recurringEventSearchOrder </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> recurringEventSearchOrder 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyRecurringEventSequencing(org.osid.calendaring.RecurringEventSearchOrder recurringEventSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a recurring event query from an inspector. 
     *
     *  @param  recurringEventQueryInspector a recurring event query inspector 
     *  @return the recurring event query 
     *  @throws org.osid.NullArgumentException <code> 
     *          recruringEventQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          recurringEventQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.RecurringEventQuery getRecurringEventQueryFromInspector(org.osid.calendaring.RecurringEventQueryInspector recurringEventQueryInspector);
}
