//
// org.osid.calendaring.Schedule
//
//     The OSID Java specification for org.osid.calendaring.Schedule.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>A <code> Schedule </code> is a scheduled time slot offered within a 
 *  time interval at a location. The time interval may be inferred from an 
 *  associated <code> TimePeriod </code> or managed explicitly without a 
 *  <code> TimePeriod. </code> </p>
 */

public interface Schedule
    extends org.osid.OsidObject {


    /**
     *  Gets the <code> Id </code> of the schedule slot. 
     *
     *  @return the schedule slot <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getScheduleSlotId();


    /**
     *  Gets the schedule slot included inside this one. 
     *
     *  @return the schedule slot 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.ScheduleSlot getScheduleSlot()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if a <code> TimePeriod </code> is associated with this schedule. 
     *  The time period determines the start and end time of the recurring 
     *  series. 
     *
     *  @return <code> true </code> if there is an associated <code> 
     *          TimePeriod, </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasTimePeriod();


    /**
     *  Gets the <code> TimePeriod Id </code> for this recurring event. A 
     *  <code> Schedule </code> with an associated <code> TimePeriod </code> 
     *  overrides any start or end date set. 
     *
     *  @return the time period <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> hasTimePeriod() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getTimePeriodId();


    /**
     *  Gets the <code> TimePeriod </code> for this recurring event. A <code> 
     *  Schedule </code> with an associated <code> TimePeriod </code> 
     *  overrides any start or end date set. 
     *
     *  @return the time period 
     *  @throws org.osid.IllegalStateException <code> hasTimePeriod() </code> 
     *          is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.TimePeriod getTimePeriod()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the start date of this schedule. If <code> hasTimePeriod() 
     *  </code> is <code> true, </code> the start date is the start date of 
     *  the associated <code> TimePeriod. </code> 
     *
     *  @return the start date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getScheduleStart();


    /**
     *  Gets the end date of this schedule. If <code> hasTimePeriod() </code> 
     *  is <code> true, </code> the end date is the end date of the associated 
     *  <code> TimePeriod. </code> 
     *
     *  @return the end date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getScheduleEnd();


    /**
     *  Tests if this schedule has a limit on the number of occurrences. 
     *
     *  @return <code> true </code> if there is a limit <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasLimit();


    /**
     *  Gets the limit of the number of occurences of this schedule. 
     *
     *  @return the limit 
     *  @throws org.osid.IllegalStateException <code> hasLimitl() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getLimit();


    /**
     *  Gets a descriptive location. 
     *
     *  @return the location 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getLocationDescription();


    /**
     *  Tests if a location is associated with this event. 
     *
     *  @return <code> true </code> if there is an associated location, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasLocation();


    /**
     *  Gets the location <code> Id </code> . 
     *
     *  @return a location <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> hasLocation() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getLocationId();


    /**
     *  Gets the <code> Location. </code> 
     *
     *  @return a location 
     *  @throws org.osid.IllegalStateException <code> hasLocation() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Location getLocation()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a total duration for the entire schedule based on the duration of 
     *  schedule slots and span of the schedule. 
     *
     *  @return the total duration 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Duration getTotalDuration();


    /**
     *  Gets the schedule record corresponding to the given <code> Schedule 
     *  </code> record <code> Type. </code> This method is used to retrieve an 
     *  object implementing the requested record. The <code> 
     *  scheduleRecordType </code> may be the <code> Type </code> returned in 
     *  <code> getRecordTypes() </code> or any of its parents in a <code> Type 
     *  </code> hierarchy where <code> hasRecordType(scheduleRecordType) 
     *  </code> is <code> true </code> . 
     *
     *  @param  scheduleRecordType the type of the record to retrieve 
     *  @return the schedule record 
     *  @throws org.osid.NullArgumentException <code> scheduleRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(scheduleRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.records.ScheduleRecord getScheduleRecord(org.osid.type.Type scheduleRecordType)
        throws org.osid.OperationFailedException;
}
