//
// org.osid.calendaring.ScheduleForm
//
//     The OSID Java specification for org.osid.calendaring.ScheduleForm.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>This is the form for creating and updating <code> Schedules. </code> 
 *  Like all <code> OsidForm </code> objects, various data elements may be set 
 *  here for use in the create and update methods in the <code> 
 *  ScheduleAdminSession. </code> For each data element that may be set, 
 *  metadata may be examined to provide display hints or data constraints. 
 *  </p>
 */

public interface ScheduleForm
    extends org.osid.OsidObjectForm {


    /**
     *  Gets the metadata for the schedule slot. 
     *
     *  @return metadata for the schedule slot 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getScheduleSlotMetadata();


    /**
     *  Sets the schedule slot. 
     *
     *  @param  scheduleSlotId the new schedule slot <code> Id </code> 
     *  @throws org.osid.InvalidArgumentException <code> scheduleSlotId 
     *          </code> is invalid 
     *  @throws org.osid.NoAccessException <code> scheduleSlotId </code> 
     *          cannot be modified 
     *  @throws org.osid.NullArgumentException <code> scheduleSlotId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setScheduleSlot(org.osid.id.Id scheduleSlotId);


    /**
     *  Clears the schedule slot. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearScheduleSlot();


    /**
     *  Gets the metadata for the time period. 
     *
     *  @return metadata for the time period 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getTimePeriodMetadata();


    /**
     *  Sets the time period. 
     *
     *  @param  timePeriodId the new time period <code> Id </code> 
     *  @throws org.osid.InvalidArgumentException <code> timePeriodId </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> timePeriodId </code> cannot 
     *          be modified 
     *  @throws org.osid.NullArgumentException <code> timePeriodId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setTimePeriod(org.osid.id.Id timePeriodId);


    /**
     *  Clears the time period. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTimePeriod();


    /**
     *  Gets the metadata for the schedule start date. 
     *
     *  @return metadata for the schedule start 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getScheduleStartMetadata();


    /**
     *  Sets the schedule start date. This may be set in lieu of a time period 
     *  to set a specific date range. 
     *
     *  @param  start the new start date 
     *  @throws org.osid.InvalidArgumentException <code> start </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> start </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> start </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setScheduleStart(org.osid.calendaring.DateTime start);


    /**
     *  Clears the schedule start. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearScheduleStart();


    /**
     *  Gets the metadata for the schedule end date. 
     *
     *  @return metadata for the schedule end 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getScheduleEndMetadata();


    /**
     *  Sets the schedule end date. This may be set in lieu of a time period 
     *  to set a specific date range. 
     *
     *  @param  start the new end date 
     *  @throws org.osid.InvalidArgumentException <code> end </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> end </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> end </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setScheduleEnd(org.osid.calendaring.DateTime start);


    /**
     *  Clears the schedule end. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearScheduleEnd();


    /**
     *  Gets the metadata for the weekdays of a weekly schedule. 
     *
     *  @return metadata for the weekday 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getLimitMetadata();


    /**
     *  Sets the weekdays of a weekly schedule. 
     *
     *  @param  weekdays the new weekday set 
     *  @throws org.osid.InvalidArgumentException <code> weekdays </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> weekdays </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> weekdays </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setLimit(long[] weekdays);


    /**
     *  Clears the limit. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLimit();


    /**
     *  Sets the location description. 
     *
     *  @param  location the new location description 
     *  @throws org.osid.InvalidArgumentException <code> location </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> location </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> location </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setLocationDescription(String location);


    /**
     *  Clears the location description. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLocationDescription();


    /**
     *  Gets the metadata for a location. 
     *
     *  @return metadata for the location 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getLocationMetadata();


    /**
     *  Sets the location. 
     *
     *  @param  locationId the new location 
     *  @throws org.osid.InvalidArgumentException <code> locationId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> locationId </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> locationId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setLocation(org.osid.id.Id locationId);


    /**
     *  Clears the location. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLocation();


    /**
     *  Gets the <code> ScheduleFormRecord </code> corresponding to the given 
     *  schedule record <code> Type. </code> 
     *
     *  @param  scheduleRecordType the schedule record type 
     *  @return the schedule form record 
     *  @throws org.osid.NullArgumentException <code> scheduleRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(scheduleRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.records.ScheduleFormRecord getScheduleSlotFormRecord(org.osid.type.Type scheduleRecordType)
        throws org.osid.OperationFailedException;
}
