//
// org.osid.calendaring.ScheduleQueryInspector
//
//     The OSID Java specification for org.osid.calendaring.ScheduleQueryInspector.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>This is the query inspector for examining schedule queries. </p>
 */

public interface ScheduleQueryInspector
    extends org.osid.OsidObjectQueryInspector {


    /**
     *  Gets the schedule slot <code> Id </code> terms. 
     *
     *  @return the schedule slot <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getScheduleSlotIdTerms();


    /**
     *  Gets the schedule slot terms. 
     *
     *  @return the schedule slot terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.ScheduleSlotQueryInspector[] getScheduleSlotTerms();


    /**
     *  Gets the time period <code> Id </code> terms. 
     *
     *  @return the time period <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getTimePeriodIdTerms();


    /**
     *  Gets the time period terms. 
     *
     *  @return the time period terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.TimePeriodQueryInspector[] getTimePeriodTerms();


    /**
     *  Gets the schedule start terms. 
     *
     *  @return the schedule start terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DateTimeRangeTerm[] getScheduleStartTerms();


    /**
     *  Gets the schedule end terms. 
     *
     *  @return the schedule end terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DateTimeRangeTerm[] getScheduleEndTerms();


    /**
     *  Gets the schedule time terms. 
     *
     *  @return the schedule time terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DateTimeTerm[] getScheduleTimeTerms();


    /**
     *  Gets the schedule inclusive time terms. 
     *
     *  @return the schedule time range terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DateTimeRangeTerm[] getScheduleTimeInclusiveTerms();


    /**
     *  Gets the limit terms. 
     *
     *  @return the limit terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.CardinalTerm[] getLimitTerms();


    /**
     *  Gets the location description terms. 
     *
     *  @return the location description terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.StringTerm[] getLocationDescriptionTerms();


    /**
     *  Gets the location <code> Id </code> terms. 
     *
     *  @return the location <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getLocationIdTerms();


    /**
     *  Gets the location terms. 
     *
     *  @return the location terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.LocationQueryInspector[] getLocationTerms();


    /**
     *  Gets the total duration terms. 
     *
     *  @return the duration terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DurationRangeTerm[] getTotalDurationTerms();


    /**
     *  Gets the calendar <code> Id </code> terms. 
     *
     *  @return the calendar <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getCalendarIdTerms();


    /**
     *  Gets the calendar terms. 
     *
     *  @return the calendar terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.CalendarQueryInspector[] getCalendarTerms();


    /**
     *  Gets the schedule query inspector record corresponding to the given 
     *  <code> Schedule </code> record <code> Type. </code> 
     *
     *  @param  scheduleRecordType a schedule query record type 
     *  @return the schedule query inspector record 
     *  @throws org.osid.NullArgumentException <code> scheduleRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(scheduleRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.records.ScheduleQueryInspectorRecord getScheduleQueryInspectorRecord(org.osid.type.Type scheduleRecordType)
        throws org.osid.OperationFailedException;
}
