//
// org.osid.calendaring.ScheduleSearchSession
//
//     The OSID Java specification for org.osid.calendaring.ScheduleSearchSession.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>This session provides methods for searching <code> Schedule </code> 
 *  objects. The search query is constructed using the <code> ScheduleQuery. 
 *  </code> The schedule record <code> Type </code> also specifies the record 
 *  for the schedule query. </p> 
 *  
 *  <p> <code> getSchedulesByQuery() </code> is the basic search method and 
 *  returns a list of <code> Schedules. </code> A more advanced search may be 
 *  performed with <code> getSchedulesBySearch(). </code> It accepts a <code> 
 *  ScheduleSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getSchedulesBySearch() </code> returns a <code> 
 *  ScheduleSearchResults </code> that can be used to access the resulting 
 *  <code> SchedulesList </code> or be used to perform a search within the 
 *  result set through <code> ScheduleSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated calendar view: searches include schedules in calendars 
 *      of which this calendar is a ancestor in the calendar hierarchy </li> 
 *      <li> isolated calendar view: searches are restricted to schedules in 
 *      this calendar </li> 
 *  </ul>
 *  
 *  
 *  <p> Schedules may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> ScheduleQuery. </code> 
 *  </p>
 */

public interface ScheduleSearchSession
    extends org.osid.calendaring.ScheduleQuerySession {


    /**
     *  Gets a schedule search. 
     *
     *  @return the schedule search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.ScheduleSearch getScheduleSearch();


    /**
     *  Gets a schedule search order. The <code> ScheduleSearchOrder </code> 
     *  is supplied to a <code> ScheduleSearch </code> to specify the ordering 
     *  of results. 
     *
     *  @return the schedule search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.ScheduleSearchOrder getScheduleSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  scheduleQuery the schedule query 
     *  @param  scheduleSearch the schedule search 
     *  @return the schedule search results 
     *  @throws org.osid.NullArgumentException <code> scheduleQuery </code> or 
     *          <code> scheduleSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> scheduleSearch </code> or 
     *          <code> scheduleQuery </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.ScheduleSearchResults getSchedulesBySearch(org.osid.calendaring.ScheduleQuery scheduleQuery, 
                                                                           org.osid.calendaring.ScheduleSearch scheduleSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a schedule query from an inspector. The inspector is available 
     *  from an <code> ScheduleSearchResults. </code> 
     *
     *  @param  scheduleQueryInspector a schedule query inspector 
     *  @return the schedule query 
     *  @throws org.osid.NullArgumentException <code> scheduleQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> scheduleQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.ScheduleQuery getScheduleQueryFromInspector(org.osid.calendaring.ScheduleQueryInspector scheduleQueryInspector);
}
