//
// org.osid.calendaring.ScheduleSlotForm
//
//     The OSID Java specification for org.osid.calendaring.ScheduleSlotForm.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>This is the form for creating and updating <code> ScheduleSlots. 
 *  </code> Like all <code> OsidForm </code> objects, various data elements 
 *  may be set here for use in the create and update methods in the <code> 
 *  ScheduleSlotAdminSession. </code> For each data element that may be set, 
 *  metadata may be examined to provide display hints or data constraints. 
 *  </p>
 */

public interface ScheduleSlotForm
    extends org.osid.OsidObjectForm,
            org.osid.OsidContainableForm {


    /**
     *  Gets the metadata for the weekdays of a weekly schedule. 
     *
     *  @return metadata for the weekday 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getWeekdayMetadata();


    /**
     *  Sets the weekdays of a weekly schedule. 
     *
     *  @param  weekdays the new weekday set 
     *  @throws org.osid.InvalidArgumentException <code> weekdays </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> weekdays </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> weekdays </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setWeekdays(long[] weekdays);


    /**
     *  Gets the metadata for the interval of a weekly schedule. 
     *
     *  @return metadata for the weekly interval 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getWeeklyIntervalMetadata();


    /**
     *  Sets the interval of a weekly schedule. 
     *
     *  @param  interval the new weekly interval 
     *  @throws org.osid.InvalidArgumentException <code> interval </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> interval </code> cannot be 
     *          modified 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setWeeklyInterval(long interval);


    /**
     *  Gets the metadata for the week of the month of a weekly schedule. 
     *
     *  @return metadata for the week of the month 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getWeekOfMonthMetadata();


    /**
     *  Sets the week of the month of a weekly schedule. 
     *
     *  @param  week the new week of the month 
     *  @throws org.osid.InvalidArgumentException <code> week </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> week </code> cannot be 
     *          modified 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setWeekOfMonth(long week);


    /**
     *  Gets the metadata for the weekday time of a weekly schedule. 
     *
     *  @return metadata for the weekday time 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getWeekdayTimeMetadata();


    /**
     *  Sets the weekday time of a weekly schedule. 
     *
     *  @param  time the new time 
     *  @throws org.osid.InvalidArgumentException <code> time </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> time </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> time </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setWeekdayTime(org.osid.calendaring.Time time);


    /**
     *  Clears the weekday schedule items. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearWeekdaySchedule();


    /**
     *  Gets the metadata for the fixed interval. 
     *
     *  @return metadata for the fixed interval. 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getFixedIntervalMetadata();


    /**
     *  Sets the fixed interval. 
     *
     *  @param  interval the new fixed interval 
     *  @throws org.osid.InvalidArgumentException <code> interval </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> interval </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> interval </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setFixedInterval(org.osid.calendaring.Duration interval);


    /**
     *  Clears the fixed interval items. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFixedInterval();


    /**
     *  Gets the metadata for the duration of the slot. 
     *
     *  @return metadata for the duration 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getDurationMetadata();


    /**
     *  Sets the duration. 
     *
     *  @param  duration the new duration 
     *  @throws org.osid.InvalidArgumentException <code> duration </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> duration </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> duration </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setDuration(org.osid.calendaring.Duration duration);


    /**
     *  Clears the duration terms. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDuration();


    /**
     *  Gets the <code> ScheduleSlotFormRecord </code> corresponding to the 
     *  given schedule record <code> Type. </code> 
     *
     *  @param  scheduleSlotRecordType the schedule slot record type 
     *  @return the schedule slot form record 
     *  @throws org.osid.NullArgumentException <code> scheduleSlotRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(scheduleSlotRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.records.ScheduleSlotFormRecord getScheduleSlotFormRecord(org.osid.type.Type scheduleSlotRecordType)
        throws org.osid.OperationFailedException;
}
