//
// org.osid.calendaring.ScheduleSlotQuery
//
//     The OSID Java specification for org.osid.calendaring.ScheduleSlotQuery.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>This is the query for searching schedule slots. Each method match 
 *  request produces an <code> AND </code> term while multiple invocations of 
 *  a method produces a nested <code> OR. </code> </p>
 */

public interface ScheduleSlotQuery
    extends org.osid.OsidObjectQuery,
            org.osid.OsidContainableQuery {


    /**
     *  Sets the schedule <code> Id </code> for this query for matching nested 
     *  schedule slots. 
     *
     *  @param  scheduleSlotId a schedule slot <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> scheduleSlotId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchScheduleSlotId(org.osid.id.Id scheduleSlotId, 
                                    boolean match);


    /**
     *  Clears the schedule slot <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearScheduleSlotIdTerms();


    /**
     *  Tests if a <code> ScheduleSlotQuery </code> is available for querying 
     *  sechedule slots. 
     *
     *  @return <code> true </code> if a schedule slot query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsScheduleSlotQuery();


    /**
     *  Gets the query for a schedul slot. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the schedule slot query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsScheduleSlotQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsScheduleSlotQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.ScheduleSlotQuery getScheduleSlotQuery();


    /**
     *  Matches a schedule that has any schedule slot assigned. 
     *
     *  @param  match <code> true </code> to match schedule with any schedule 
     *          slots, <code> false </code> to match schedules with no 
     *          schedule slots 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyScheduleSlot(boolean match);


    /**
     *  Clears the schedule slot terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearScheduleSlotTerms();


    /**
     *  Matches schedules that have the given weekday. 
     *
     *  @param  weekday a weekday 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchWeekday(long weekday, boolean match);


    /**
     *  Matches schedules with any weekday set. 
     *
     *  @param  match <code> true </code> to match schedules with any weekday, 
     *          <code> false </code> to match schedules with no weekday 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyWeekday(boolean match);


    /**
     *  Clears the weekday terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearWeekdayTerms();


    /**
     *  Matches schedules that have the given weekly interval in the given 
     *  range inclusive. 
     *
     *  @param  from start range 
     *  @param  to end range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchWeeklyInterval(long from, long to, boolean match);


    /**
     *  Matches schedules with any weekly interval set. 
     *
     *  @param  match <code> true </code> to match schedules with any weekly 
     *          interval, <code> false </code> to match schedules with no 
     *          weekly interval 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyWeeklyInterval(boolean match);


    /**
     *  Clears the weekly interval terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearWeeklyIntervalTerms();


    /**
     *  Matches schedules that have a week of month in the given range 
     *  inclusive. 
     *
     *  @param  from start range 
     *  @param  to end range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchWeekOfMonth(long from, long to, boolean match);


    /**
     *  Matches schedules with any month week set. 
     *
     *  @param  match <code> true </code> to match schedules with any week of 
     *          month, <code> false </code> to match schedules with no month 
     *          week 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyWeekOfMonth(boolean match);


    /**
     *  Clears the week of month terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearWeekOfMonthTerms();


    /**
     *  Matches schedules that have a weekday time in the given range 
     *  inclusive. 
     *
     *  @param  from start range 
     *  @param  to end range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchWeekdayTime(org.osid.calendaring.Time from, 
                                 org.osid.calendaring.Time to, boolean match);


    /**
     *  Matches schedules with any weekday time. 
     *
     *  @param  match <code> true </code> to match schedules with any weekday 
     *          time, <code> false </code> to match schedules with no weekday 
     *          time 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyWeekdayTime(boolean match);


    /**
     *  Clears the weekday time terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearWeekdayTimeTerms();


    /**
     *  Matches schedules that have the given fixed interval in the given 
     *  range inclusive. 
     *
     *  @param  from start range 
     *  @param  to end range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchFixedInterval(org.osid.calendaring.Duration from, 
                                   org.osid.calendaring.Duration to, 
                                   boolean match);


    /**
     *  Matches schedules with any fixed interval. 
     *
     *  @param  match <code> true </code> to match schedules with any fixed 
     *          interval, <code> false </code> to match schedules with no 
     *          fixed interval 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyFixedInterval(boolean match);


    /**
     *  Clears the fixed interval terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFixedIntervalTerms();


    /**
     *  Matches the duration between the given range inclusive. 
     *
     *  @param  low low duration range 
     *  @param  high high duration range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> high </code> is less 
     *          than <code> low </code> 
     *  @throws org.osid.NullArgumentException <code> high </code> or <code> 
     *          low </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDuration(org.osid.calendaring.Duration low, 
                              org.osid.calendaring.Duration high, 
                              boolean match);


    /**
     *  Matches a schedule slot that has any duration. 
     *
     *  @param  match <code> true </code> to match schedules with any 
     *          duration, <code> false </code> to match schedules with no 
     *          start time 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDuration(boolean match);


    /**
     *  Clears the duration terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDurationTerms();


    /**
     *  Sets the calendar <code> Id </code> for this query. 
     *
     *  @param  calendarId a calendar <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCalendarId(org.osid.id.Id calendarId, boolean match);


    /**
     *  Clears the calendar <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCalendarIdTerms();


    /**
     *  Tests if a <code> CalendarQuery </code> is available for querying 
     *  calendars. 
     *
     *  @return <code> true </code> if a calendar query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCalendarQuery();


    /**
     *  Gets the query for a calendar. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the calendar query 
     *  @throws org.osid.UnimplementedException <code> supportsCalendarQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCalendarQuery() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.CalendarQuery getCalendarQuery();


    /**
     *  Clears the calendar terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCalendarTerms();


    /**
     *  Gets the schedule slot query record corresponding to the given <code> 
     *  ScheduleSlot </code> record <code> Type. </code> Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @param  scheduleSlotRecordType a schedule slot query record type 
     *  @return the schedule slot query record 
     *  @throws org.osid.NullArgumentException <code> scheduleSlotRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(scheduleSlotRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.records.ScheduleSlotQueryRecord getScheduleSlotQueryRecord(org.osid.type.Type scheduleSlotRecordType)
        throws org.osid.OperationFailedException;
}
