//
// org.osid.calendaring.SupersedingEvent
//
//     The OSID Java specification for org.osid.calendaring.SupersedingEvent.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>A <code> SupersedingEvent </code> represents an override of an event 
 *  such as an individual item in a recurring series. The event which is to 
 *  supersede another must already be created. The <code> SupersedingEvent 
 *  </code> rule causes the superseded <code> Event </code> to be overidden 
 *  with the superseding <code> Event </code> at the superseding <code> Event 
 *  </code> 's date and time. </p>
 */

public interface SupersedingEvent
    extends org.osid.OsidRule {


    /**
     *  Gets the event <code> Id </code> that is to be superseded. 
     *
     *  @return the superseding event <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getSupersededEventId();


    /**
     *  Gets the event that is to be superseded. 
     *
     *  @return the superseding event 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Event getSupersededEvent()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the event <code> Id </code> that is superseding another. 
     *
     *  @return the superseding event <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getSupersedingEventId();


    /**
     *  Gets the event that is superseding another. 
     *
     *  @return the superseding event 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Event getSupersedingEvent()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if the superseding event replaces an event within a recurring 
     *  series offered at a specific date/time. If <code> supersedesByDate() 
     *  </code> is true, then <code> supersedesByPosition() </code> must be 
     *  false. 
     *
     *  @return <code> true </code> if an event is superseded by date, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supersedesByDate();


    /**
     *  Gets the date of an event to replace if a recurring event is offered 
     *  on that date. 
     *
     *  @return the date of the event to replace 
     *  @throws org.osid.IllegalStateException <code> supersedesByDate() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getSupersededDate();


    /**
     *  Tests if the superseding event replaces an event within a recurring 
     *  series identified by its denormalized position in the series. A 
     *  negative number counts from the end of the series. If <code> 
     *  supersedesByPosition() </code> is <code> true, </code> then <code> 
     *  supersedesByDate() </code> must be <code> false. </code> 
     *
     *  @return <code> true </code> if an event is superseded by position, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supersedesByPosition();


    /**
     *  Gets the position in the denormalized recurring series of the event to 
     *  replace. Positive numbers count from the start and negative numbers 
     *  count from the end. Zero is invalid. 
     *
     *  @return the position of the event to replace 
     *  @throws org.osid.IllegalStateException <code> supersedesByPosition() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getSupersededEventPosition();


    /**
     *  Gets the superseding event record corresponding to the given <code> 
     *  SupersedingEvent </code> record <code> Type. </code> This method is 
     *  used to retrieve an object implementing the requested record. The 
     *  <code> supersedingEventRecordType </code> may be the <code> Type 
     *  </code> returned in <code> getRecordTypes() </code> or any of its 
     *  parents in a <code> Type </code> hierarchy where <code> 
     *  hasRecordType(supersedingEventRecordType) </code> is <code> true 
     *  </code> . 
     *
     *  @param  supersedingEventRecordType the type of the record to retrieve 
     *  @return the superseding event record 
     *  @throws org.osid.NullArgumentException <code> 
     *          supersedingEventRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(supersedingEventRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.records.SupersedingEventRecord getSupersedingEventRecord(org.osid.type.Type supersedingEventRecordType)
        throws org.osid.OperationFailedException;
}
