//
// org.osid.calendaring.SupersedingEventLookupSession
//
//     The OSID Java specification for org.osid.calendaring.SupersedingEventLookupSession.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>This session provides methods for retrieving <code> SupersedingEvents. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated calendar view: All superseding event methods in this 
 *      session operate, retrieve and pertain to superseding events defined 
 *      explicitly in the current calendar. Using an isolated view is useful 
 *      for managing events with the <code> SupersedingEventAdminSession. 
 *      </code> </li> 
 *      <li> federated calendar view: All superseding event methods in this 
 *      session operate, retrieve and pertain to all superseding events 
 *      defined in this calendar and any other calendars implicitly available 
 *      in this calendar through calendar inheritence. </li> 
 *      <li> active superseding event view: All superseding event lookup 
 *      methods return active superseding events. </li> 
 *      <li> any status superseding event view: Superseding events of any 
 *      active or inactive status are returned from methods. </li> 
 *  </ul>
 *  
 */

public interface SupersedingEventLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Calendar </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Calendar Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCalendarId();


    /**
     *  Gets the <code> Calendar </code> associated with this session. 
     *
     *  @return the <code> Calendar </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Calendar getCalendar()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> SupersedingEvent </code> 
     *  lookups. A return of true does not guarantee successful authorization. 
     *  A return of false indicates that it is known all methods in this 
     *  session will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer lookup 
     *  operations to unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupSupersedingEvents();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeSupersedingEventView();


    /**
     *  A complete view of the <code> SupersedingEvent </code> returns is 
     *  desired. Methods will return what is requested or result in an error. 
     *  This view is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenarySupersedingEventView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include supserseding events in calendars which are children of this 
     *  calendar in the calendar hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCalendarView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this calendar only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCalendarView();


    /**
     *  Only active superseding events are returned by methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveSupersedingEventView();


    /**
     *  All active and inactive superseding events are returned by methods in 
     *  this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusSupersedingEventView();


    /**
     *  Gets the <code> Superseding </code> specified by its <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  SupersedingEvent </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> Superseding </code> and retained for 
     *  compatibility. 
     *  
     *  In active mode, supersdeing events are returned that are currently 
     *  active. In any status mode, active and inactive superseding events are 
     *  returned. 
     *
     *  @param  supersedingEventId <code> Id </code> of the <code> 
     *          SupersedingEvent </code> 
     *  @return the superseding event 
     *  @throws org.osid.NotFoundException <code> supersedngEventId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> supersedingEventId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.calendaring.SupersedingEvent getSupersedingEvent(org.osid.id.Id supersedingEventId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SupersedingEventList </code> corresponding to the given 
     *  <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  superseding events specified in the <code> Id </code> list, in the 
     *  order of the list, including duplicates, or an error results if an 
     *  <code> Id </code> in the supplied list is not found or inaccessible. 
     *  Otherwise, inaccessible <code> SupersedingEvents </code> may be 
     *  omitted from the list and may present the elements in any order 
     *  including returning a unique set. 
     *  
     *  In active mode, supersdeing events are returned that are currently 
     *  active. In any status mode, active and inactive superseding events are 
     *  returned. 
     *
     *  @param  supersedingEventIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> SupersedingEvent </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> supersedingEventIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.SupersedingEventList getSupersedingEventsByIds(org.osid.id.IdList supersedingEventIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SupersedingEventList </code> corresponding to the given 
     *  superseding event genus <code> Type </code> which does not include 
     *  superseding events of genus types derived from the specified <code> 
     *  Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  superseding events or an error results. Otherwise, the returned list 
     *  may contain only those superseding events that are accessible through 
     *  this session. 
     *  
     *  In active mode, supersdeing events are returned that are currently 
     *  active. In any status mode, active and inactive superseding events are 
     *  returned. 
     *
     *  @param  supersedingEventGenusType a superseding event genus type 
     *  @return the returned <code> SupersedingEvent </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          supersedingEventGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.SupersedingEventList getSupersedingEventsByGenusType(org.osid.type.Type supersedingEventGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SupersedingEventList </code> corresponding to the given 
     *  superseding event genus <code> Type </code> and include any additional 
     *  superseding event with genus types derived from the specified <code> 
     *  Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  superseding events or an error results. Otherwise, the returned list 
     *  may contain only those superseding events that are accessible through 
     *  this session. 
     *  
     *  In active mode, supersdeing events are returned that are currently 
     *  active. In any status mode, active and inactive superseding events are 
     *  returned. 
     *
     *  @param  supersedingEventGenusType a superseding event genus type 
     *  @return the returned <code> SupersedingEvent </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          supersedingEventGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.SupersedingEventList getSupersedingEventsByParentGenusType(org.osid.type.Type supersedingEventGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SupersedingEventList </code> containing the given 
     *  superseding event record <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  superseding events or an error results. Otherwise, the returned list 
     *  may contain only those superseding events that are accessible through 
     *  this session. 
     *  
     *  In active mode, supersdeing events are returned that are currently 
     *  active. In any status mode, active and inactive superseding events are 
     *  returned. 
     *
     *  @param  supersedingEventRecordType a superseding event record type 
     *  @return the returned <code> SupersedingEvent </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          supersedingEventRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.SupersedingEventList getSupersedingEventsByRecordType(org.osid.type.Type supersedingEventRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> SupersedingEvents </code> related to the relative 
     *  event <code> Id. </code> 
     *  
     *  In plenary mode, the returned list contains all known superseding 
     *  events or an error results. Otherwise, the returned list may contain 
     *  only those superseding events that are accessible through this 
     *  session. 
     *  
     *  In active mode, supersdeing events are returned that are currently 
     *  active. In any status mode, active and inactive superseding events are 
     *  returned. 
     *
     *  @param  supersededEventId <code> Id </code> of the related event 
     *  @return the superseding events 
     *  @throws org.osid.NotFoundException <code> supersededEventId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> supersededEventId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.calendaring.SupersedingEventList getSupersedingEventsBySupersededEvent(org.osid.id.Id supersededEventId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> SupersedingEvents. </code> 
     *  
     *  In plenary mode, the returned list contains all known superseding 
     *  events or an error results. Otherwise, the returned list may contain 
     *  only those superseding events that are accessible through this 
     *  session. 
     *  
     *  In active mode, supersdeing events are returned that are currently 
     *  active. In any status mode, active and inactive superseding events are 
     *  returned. 
     *
     *  @return a <code> SupersedingEventList </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.SupersedingEventList getSupersedingEvents()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
