//
// org.osid.calendaring.SupersedingEventQueryInspector
//
//     The OSID Java specification for org.osid.calendaring.SupersedingEventQueryInspector.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>This is the query inspector for examining superseding event queries. 
 *  </p>
 */

public interface SupersedingEventQueryInspector
    extends org.osid.OsidRuleQueryInspector {


    /**
     *  Gets the superseded event <code> Id </code> terms. 
     *
     *  @return the superseded event <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getSupersededEventIdTerms();


    /**
     *  Gets the superseded event terms. 
     *
     *  @return the superseded event terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.EventQueryInspector[] getSupersededEventTerms();


    /**
     *  Gets the superseding event <code> Id </code> terms. 
     *
     *  @return the superseding event <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getSupersedingEventIdTerms();


    /**
     *  Gets the superseding event terms. 
     *
     *  @return the superseding event terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.EventQueryInspector[] getSupersedingEventTerms();


    /**
     *  Gets the superseded date range terms. 
     *
     *  @return the superseded date range terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DateTimeRangeTerm[] getSupersededDateTerms();


    /**
     *  Gets the superseded event position terms. 
     *
     *  @return the superseded event position terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IntegerRangeTerm[] getSupersededEventPositionTerms();


    /**
     *  Gets the calendar <code> Id </code> terms. 
     *
     *  @return the calendar <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getCalendarIdTerms();


    /**
     *  Gets the calendar terms. 
     *
     *  @return the calendar terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.CalendarQueryInspector[] getCalendarTerms();


    /**
     *  Gets the superseding event query inspector record corresponding to the 
     *  given <code> SupersedingEvent </code> record <code> Type. </code> 
     *
     *  @param  supersedingEventRecordType a superseding event query record 
     *          type 
     *  @return the superseding event query inspector record 
     *  @throws org.osid.NullArgumentException <code> 
     *          supersedingEventRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(supersedingEventRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.records.SupersedingEventQueryInspectorRecord getSupersedingEventQueryInspectorRecord(org.osid.type.Type supersedingEventRecordType)
        throws org.osid.OperationFailedException;
}
