//
// org.osid.calendaring.SupersedingEventSearchSession
//
//     The OSID Java specification for org.osid.calendaring.SupersedingEventSearchSession.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>This session provides methods for searching <code> SupersedingEvent 
 *  </code> objects. The search query is constructed using the <code> 
 *  SupersedingEventQuery. </code> The superseding event record <code> Type 
 *  </code> also specifies the record for the superseding event query. </p> 
 *  
 *  <p> <code> getSupersedingEventsByQuery() </code> is the basic search 
 *  method and returns a list of <code> SupersedingEvents. </code> A more 
 *  advanced search may be performed with <code> 
 *  getSupersedingEventsBySearch(). </code> It accepts a <code> 
 *  SupersedingEventSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getSupersedingEventsBySearch() </code> returns a <code> 
 *  SupersedingEventSearchResults </code> that can be used to access the 
 *  resulting <code> SupersedingEventList </code> or be used to perform a 
 *  search within the result set through <code> SupersedingEventSearch. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated calendar view: searches include superseding events in 
 *      calendars of which this calendar is a ancestor in the calendar 
 *      hierarchy </li> 
 *      <li> isolated calendar view: searches are restricted to superseding 
 *      events in this calendar </li> 
 *  </ul>
 *  
 *  
 *  <p> Superseding events may have a query record indicated by their 
 *  respective record types. The query record is accessed via the <code> 
 *  SupersedingEventQuery. </code> </p>
 */

public interface SupersedingEventSearchSession
    extends org.osid.calendaring.SupersedingEventQuerySession {


    /**
     *  Gets a superseding event search. 
     *
     *  @return the superseding event search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.SupersedingEventSearch getSupersedingEventSearch();


    /**
     *  Gets a superseding event search order. The <code> 
     *  SupersedingEventSearchOrder </code> is supplied to a <code> 
     *  SupersedingEventSearch </code> to specify the ordering of results. 
     *
     *  @return the superseding event search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.SupersedingEventSearchOrder getSupersedingEventSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  supersedingEventQuery the superseding search query 
     *  @param  supersedingEventSearch the superseding search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> supersedingEventQuery 
     *          </code> or <code> supersedingEventSearch </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> supersedingEventQuery 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.SupersedingEventSearchResults getSupersedingEventsBySearch(org.osid.calendaring.SupersedingEventQuery supersedingEventQuery, 
                                                                                           org.osid.calendaring.SupersedingEventSearch supersedingEventSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a superseding event query from an inspector. The inspector is 
     *  available from a <code> SupersedingEventSearchResults. </code> 
     *
     *  @param  supersedingEventQueryInspector a superseding event query 
     *          inspector 
     *  @return the superseding event query 
     *  @throws org.osid.NullArgumentException <code> 
     *          supersedingEventQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supersedingEventQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.SupersedingEventQuery getSupersedingEventQueryFromInspector(org.osid.calendaring.SupersedingEventQueryInspector supersedingEventQueryInspector);
}
