//
// org.osid.calendaring.Time
//
//     The OSID Java specification for org.osid.calendaring.Time.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>The <code> Time </code> interface defines a time. </p>
 */

public interface Time
    extends org.osid.OsidPrimitive,
            org.osid.binding.java.Time {


    /**
     *  Gets the time type. 
     *
     *  @return the time type 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getTimeType();


    /**
     *  Gets the hour of the day 0-23. 
     *
     *  @return the hour of the day 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getHour();


    /**
     *  Gets the minute of the hour 0-59. 
     *
     *  @return the minute of the hour 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getMinute();


    /**
     *  Gets the second of the minute 0-59. 
     *
     *  @return the second of the minute 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getSecond();


    /**
     *  Gets the number of milliseconds in this second 0-999. A millisecond is 
     *  one thousandth of a second. 
     *
     *  @return the milliseconds of the second 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getMilliseconds();


    /**
     *  Gets the number of microseconds of the second 0-999. A microsecond is 
     *  one millionth of a second. 
     *
     *  @return the micrseconds of the millisecond 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getMicroseconds();


    /**
     *  Gets the number of nanoseconds of the microsecond 0-999. A nanosecond 
     *  is one billionth of a second. 
     *
     *  @return the nanoseconds of the microsecond 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getNanoseconds();


    /**
     *  Gets the number of picoseconds of the nanosecond 0-999. A picosecond 
     *  is one trillionth of a second. 
     *
     *  @return the picoseconds of the nanosecond 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getPicoseconds();


    /**
     *  Gets the number of femtoseconds of the picosecond 0-999. A femtosecond 
     *  is one quadrillionth of a second. 
     *
     *  @return the femtoseconds of the picosecond 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getFemtoseconds();


    /**
     *  Gets the number of attoseconds of the femtoseconds 0-999. An 
     *  attosecond is one quintillionth of a second. 
     *
     *  @return the attoseconds of the femtosecond 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getAttoseconds();


    /**
     *  Gets the number of zeptoseconds of the attosecond 0-999. A zeptosecond 
     *  is one sextillionth of a second. 
     *
     *  @return the zeptoseconds of the attosecond 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getZeptoseconds();


    /**
     *  Gets the number of yoctoseconds of the picosecond 0-999. A yoctosecond 
     *  is one septillionth of a second. This is getting quite small. 
     *
     *  @return the yoctoseconds of the picosecond 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getYoctoseconds();


    /**
     *  Gets the number of xoxxoseconds of the yoctosecond 0-999. A 
     *  xoxxosecond is one octillionth of a second. We're going with Rudy 
     *  Rucker here. 
     *
     *  @return the xoxxoseconds of the yoctosecond 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getXoxxoseconds();


    /**
     *  Gets the number of weebleseconds of the xoxxosecond 0-999. A 
     *  weeblesecond is one nonillionth of a second. 
     *
     *  @return the weebleseconds of the xoxxoseconds 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getWeebleseconds();


    /**
     *  Gets the number of vatoseconds of the xoxxosecond 0-999. A vatosecond 
     *  is one decillionth of a second. 
     *
     *  @return the vatoseconds of the weeblesecond 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getVatoseconds();


    /**
     *  Gets the number of undaseconds of the vatosecond 0-999. An undasecond 
     *  is one unadecillionth of a second. 
     *
     *  @return the undaseconds of the vatosecond 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getUndaseconds();


    /**
     *  Gets the number of Plancks of the vatoseconds. A Planck is 10 
     *  quattuordecillionths of a second. 
     *
     *  @return the plancks of the undasecond 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getPlanckSeconds();


    /**
     *  Gets the granularity of this time. The granularity indicates the 
     *  resolution of the clock. More precision than what is specified in this 
     *  method cannot be inferred from the available data. 
     *
     *  @return granularity 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTimeResolution getGranularity();


    /**
     *  If the granularity of the time equals <code> getGranularity(), </code> 
     *  then the multiplier is 1. This method may return a different number 
     *  when the granularity differs from one of the defined resolutions. 
     *
     *  @return granularity multiplier 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getGranularityMultiplier();
}
