//
// org.osid.calendaring.TimePeriodForm
//
//     The OSID Java specification for org.osid.calendaring.TimePeriodForm.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>This is the form for creating and updating <code> TimePeriods. </code> 
 *  Like all <code> OsidForm </code> objects, various data elements may be set 
 *  here for use in the create and update methods in the <code> 
 *  TimePeriodAdminSession. </code> For each data element that may be set, 
 *  metadata may be examined to provide display hints or data constraints. 
 *  </p>
 */

public interface TimePeriodForm
    extends org.osid.OsidObjectForm {


    /**
     *  Gets the metadata for a start time. 
     *
     *  @return metadata for the start time 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getStartMetadata();


    /**
     *  Sets the start time. 
     *
     *  @param  start the new start time 
     *  @throws org.osid.InvalidArgumentException <code> start </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> start </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> start </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setStart(org.osid.calendaring.DateTime start);


    /**
     *  Clears the start time. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStart();


    /**
     *  Gets the metadata for an end time. 
     *
     *  @return metadata for the end time 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getEndMetadata();


    /**
     *  Sets the end time. 
     *
     *  @param  end the new end time 
     *  @throws org.osid.InvalidArgumentException <code> end </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> end </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> end </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setEnd(org.osid.calendaring.DateTime end);


    /**
     *  Clears the time period end. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEnd();


    /**
     *  Gets the <code> TimePeriodFormRecord </code> corresponding to the 
     *  given time period record <code> Type. </code> 
     *
     *  @param  timePeriodRecordType the time period record type 
     *  @return the time period form record 
     *  @throws org.osid.NullArgumentException <code> timePeriodRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(timePeriodRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.records.TimePeriodFormRecord getTimePeriodFormRecord(org.osid.type.Type timePeriodRecordType)
        throws org.osid.OperationFailedException;
}
