//
// org.osid.calendaring.TimePeriodQuery
//
//     The OSID Java specification for org.osid.calendaring.TimePeriodQuery.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>This is the query for searching time periods. Each method match request 
 *  produces an <code> AND </code> term while multiple invocations of a method 
 *  produces a nested <code> OR. </code> </p>
 */

public interface TimePeriodQuery
    extends org.osid.OsidObjectQuery {


    /**
     *  Matches the time period start time between the given range inclusive. 
     *
     *  @param  low low time range 
     *  @param  high high time range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> high </code> is less 
     *          than <code> low </code> 
     *  @throws org.osid.NullArgumentException <code> high </code> or <code> 
     *          low </code> is <code> zero </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchStart(org.osid.calendaring.DateTime low, 
                           org.osid.calendaring.DateTime high, boolean match);


    /**
     *  Matches a time period that has any start time assigned. 
     *
     *  @param  match <code> true </code> to match time periods with any start 
     *          time, <code> false </code> to match time periods with no start 
     *          time 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyStart(boolean match);


    /**
     *  Clears the time period start terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStartTerms();


    /**
     *  Matches the time period end time between the given range inclusive. 
     *
     *  @param  low low time range 
     *  @param  high high time range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> high </code> is less 
     *          than <code> low </code> 
     *  @throws org.osid.NullArgumentException <code> high </code> or <code> 
     *          low </code> is <code> zero </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchEnd(org.osid.calendaring.DateTime low, 
                         org.osid.calendaring.DateTime high, boolean match);


    /**
     *  Matches a time period that has any end time assigned. 
     *
     *  @param  match <code> true </code> to match time periods with any end 
     *          time, <code> false </code> to match time periods with no end 
     *          time 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyEnd(boolean match);


    /**
     *  Clears the time period end terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEndTerms();


    /**
     *  Matches time periods that include the given time. 
     *
     *  @param  time date 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchTime(org.osid.calendaring.DateTime time, boolean match);


    /**
     *  Matches a time period that has any time assigned. 
     *
     *  @param  match <code> true </code> to match time periods with any time, 
     *          <code> false </code> to match time periods with no time 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyTime(boolean match);


    /**
     *  Clears the time terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTimeTerms();


    /**
     *  Matches time periods with start and end times between the given range 
     *  inclusive. 
     *
     *  @param  start start date 
     *  @param  end end date 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> end </code> is less 
     *          than <code> start </code> 
     *  @throws org.osid.NullArgumentException <code> start </code> or <code> 
     *          end </code> is <code> zero </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchTimeInclusive(org.osid.calendaring.DateTime start, 
                                   org.osid.calendaring.DateTime end, 
                                   boolean match);


    /**
     *  Clears the time inclusive terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTimeInclusiveTerms();


    /**
     *  Matches the time period duration between the given range inclusive. 
     *
     *  @param  low low duration range 
     *  @param  high high duration range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> high </code> is less 
     *          than <code> low </code> 
     *  @throws org.osid.NullArgumentException <code> high </code> or <code> 
     *          low </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDuration(org.osid.calendaring.Duration low, 
                              org.osid.calendaring.Duration high, 
                              boolean match);


    /**
     *  Clears the duration terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDurationTerms();


    /**
     *  Sets the event <code> Id </code> for this query to match exceptions. 
     *
     *  @param  eventId an exception event <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> eventId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchExceptionId(org.osid.id.Id eventId, boolean match);


    /**
     *  Clears the exception event <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearExceptionIdTerms();


    /**
     *  Tests if an <code> EventQuery </code> is available for querying 
     *  exception events. 
     *
     *  @return <code> true </code> if a exception query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsExceptionQuery();


    /**
     *  Gets the query for an exception event. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the event query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsExceptionQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsExceptionQuery() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.EventQuery getExceptionQuery();


    /**
     *  Matches a time period that has any exception event assigned. 
     *
     *  @param  match <code> true </code> to match time periods with any 
     *          exception, <code> false </code> to match time periods with no 
     *          exception 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyException(boolean match);


    /**
     *  Clears the exception event terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearExceptionTerms();


    /**
     *  Sets the event <code> Id </code> for this query. 
     *
     *  @param  eventId an event or recurring event <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> eventId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchEventId(org.osid.id.Id eventId, boolean match);


    /**
     *  Clears the event <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEventIdTerms();


    /**
     *  Tests if an <code> EventQuery </code> is available for querying 
     *  events. 
     *
     *  @return <code> true </code> if an event query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEventQuery();


    /**
     *  Gets the query for an event or recurring event. Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @return the event query 
     *  @throws org.osid.UnimplementedException <code> supportsEventQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEventQuery() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.EventQuery getEventQuery();


    /**
     *  Matches a time period that has any event assigned. 
     *
     *  @param  match <code> true </code> to match time periods with any 
     *          event, <code> false </code> to match time periods with no 
     *          events 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyEvent(boolean match);


    /**
     *  Clears the event terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEventTerms();


    /**
     *  Sets the calendar <code> Id </code> for this query. 
     *
     *  @param  calendarId a calendar <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCalendarId(org.osid.id.Id calendarId, boolean match);


    /**
     *  Clears the calendar <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCalendarIdTerms();


    /**
     *  Tests if a <code> CalendarQuery </code> is available for querying 
     *  resources. 
     *
     *  @return <code> true </code> if a calendar query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCalendarQuery();


    /**
     *  Gets the query for a calendar. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the calendar query 
     *  @throws org.osid.UnimplementedException <code> supportsCalendarQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCalendarQuery() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.CalendarQuery getCalendarQuery();


    /**
     *  Clears the calendar terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCalendarTerms();


    /**
     *  Gets the time period query record corresponding to the given <code> 
     *  TimePeriod </code> record <code> Type. </code> Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @param  timePeriodRecordType a time period query record type 
     *  @return the time period query record 
     *  @throws org.osid.NullArgumentException <code> timePeriodRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(timePeriodRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.records.TimePeriodQueryRecord getTimePeriodQueryRecord(org.osid.type.Type timePeriodRecordType)
        throws org.osid.OperationFailedException;
}
