//
// org.osid.calendaring.cycle.CalendaringCycleProfile
//
//     The OSID Java specification for org.osid.calendaring.cycle.CalendaringCycleProfile.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring.cycle;


/**
 *  <p>The <code> CalendaringCycleProfile </code> describes the 
 *  interoperability among calendaring cycle services. </p>
 */

public interface CalendaringCycleProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if federation is visible. 
     *
     *  @return <code> true </code> if visible federation is supported <code> 
     *          , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if a cyclic event lookup service is supported. a cyclic event 
     *  lookup service defines methods to access cyclic events. 
     *
     *  @return true if cyclic event lookup is supported, false otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCyclicEventLookup();


    /**
     *  Tests if a cyclic event query service is supported. 
     *
     *  @return <code> true </code> if cyclic event query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCyclicEventQuery();


    /**
     *  Tests if a cyclic event search service is supported. 
     *
     *  @return <code> true </code> if cyclic event search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCyclicEventSearch();


    /**
     *  Tests if a cyclic event administrative service is supported. 
     *
     *  @return <code> true </code> if cyclic event admin is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCyclicEventAdmin();


    /**
     *  Tests if cyclic event notification is supported. Messages may be sent 
     *  when cyclic events are created, modified, or deleted. 
     *
     *  @return <code> true </code> if cyclic event notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCyclicEventNotification();


    /**
     *  Tests if a cyclic event to calendar lookup session is available. 
     *
     *  @return <code> true </code> if cyclic event calendar lookup session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCyclicEventCalendar();


    /**
     *  Tests if a cyclic event to calendar assignment session is available. 
     *
     *  @return <code> true </code> if cyclic event calendar assignment is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCyclicEventCalendarAssignment();


    /**
     *  Tests if cyclic event smart calendaring is available. 
     *
     *  @return <code> true </code> if cyclic event smart calendaring is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCyclicEventSmartCalendar();


    /**
     *  Tests if a session to look up associations between events and cyclic 
     *  events is available. 
     *
     *  @return <code> true </code> if an event to cyclic event lookup session 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEventCyclicEventLookup();


    /**
     *  Tests if a session for manually assigning events to cyclic events is 
     *  available. 
     *
     *  @return <code> true </code> if an event to cyclic event assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEventCyclicEventAssignment();


    /**
     *  Tests if a cyclic time period lookup service is supported. 
     *
     *  @return <code> true </code> if cyclic time period lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCyclicTimePeriodLookup();


    /**
     *  Tests if a cyclic time period search service is supported. 
     *
     *  @return <code> true </code> if cyclic time period search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCyclicTimePeriodSearch();


    /**
     *  Tests if a cyclic time period administrative service is supported. 
     *
     *  @return <code> true </code> if cyclic time period admin is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCyclicTimePeriodAdmin();


    /**
     *  Tests if cyclic time period notification is supported. Messages may be 
     *  sent when cyclic time periods are created, modified, or deleted. 
     *
     *  @return <code> true </code> if cyclic time period notification is 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCyclicTimePeriodNotification();


    /**
     *  Tests if a cyclic time period to calendar lookup session is available. 
     *
     *  @return <code> true </code> if cyclic time period calendar lookup 
     *          session is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCyclicTimePeriodCalendar();


    /**
     *  Tests if a cyclic time period to calendar assignment session is 
     *  available. 
     *
     *  @return <code> true </code> if cyclic time period calendar assignment 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCyclicTimePeriodCalendarAssignment();


    /**
     *  Tests if cyclic time period smart calendaring is available. 
     *
     *  @return <code> true </code> if cyclic time period smart calendaring is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCyclicTimePeriodSmartCalendar();


    /**
     *  Tests if a session to look up associations between time periods and 
     *  cyclic time periods is available. 
     *
     *  @return <code> true </code> if a time period to cyclic time period 
     *          lookup session is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTimePeriodCyclicTimePeriodLookup();


    /**
     *  Tests if a session for manually assigning time periods to cyclic time 
     *  periods is available. 
     *
     *  @return <code> true </code> if a time period to cyclic time period 
     *          assignment service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTimePeriodCyclicTimePeriodAssignment();


    /**
     *  Tests if a calendaring cycle batch service is available. 
     *
     *  @return <code> true </code> if a calndaring cycle batch service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCalendaringCycleBatch();


    /**
     *  Gets the supported <code> CyclicEvent </code> record types. 
     *
     *  @return a list containing the supported <code> CyclicEvent </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCyclicEventRecordTypes();


    /**
     *  Tests if the given <code> CyclicEvent </code> record type is 
     *  supported. 
     *
     *  @param  cyclicEventRecordType a <code> Type </code> indicating a 
     *          <code> CyclicEvent </code> record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> cyclicEventRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCyclicEventRecordType(org.osid.type.Type cyclicEventRecordType);


    /**
     *  Gets the supported <code> CyclicEvent </code> search record types. 
     *
     *  @return a list containing the supported <code> CyclicEvent </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCyclicEventSearchRecordTypes();


    /**
     *  Tests if the given <code> CyclicEvent </code> search record type is 
     *  supported. 
     *
     *  @param  cyclicEventSearchRecordType a <code> Type </code> indicating a 
     *          <code> CyclicEvent </code> search record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          cyclicEventSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCyclicEventSearchRecordType(org.osid.type.Type cyclicEventSearchRecordType);


    /**
     *  Gets the supported <code> CyclicTimePeriod </code> record types. 
     *
     *  @return a list containing the supported <code> CyclicTimePeriod 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCyclicTimePeriodRecordTypes();


    /**
     *  Tests if the given <code> CyclicTimePeriod </code> record type is 
     *  supported. 
     *
     *  @param  cyclicTimePeriodRecordType a <code> Type </code> indicating a 
     *          <code> CyclicTimePeriod </code> record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          cyclicTimePeriodRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCyclicTimePeriodRecordType(org.osid.type.Type cyclicTimePeriodRecordType);


    /**
     *  Gets the supported <code> CyclicTimePeriod </code> search record 
     *  types. 
     *
     *  @return a list containing the supported <code> CyclicTimePeriod 
     *          </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCyclicTimePeriodSearchRecordTypes();


    /**
     *  Tests if the given <code> CyclicTimePeriod </code> search record type 
     *  is supported. 
     *
     *  @param  cyclicTimePeriodSearchRecordType a <code> Type </code> 
     *          indicating a <code> CyclicTimePeriod </code> search record 
     *          type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          cyclicTimePeriodSearchRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCyclicTimePeriodSearchRecordType(org.osid.type.Type cyclicTimePeriodSearchRecordType);
}
