//
// org.osid.calendaring.cycle.CalendaringCycleProxyManager
//
//     The OSID Java specification for org.osid.calendaring.cycle.CalendaringCycleProxyManager.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring.cycle;


/**
 *  <p>The calendaring manager provides access to calendaring sessions and 
 *  provides interoperability tests for various aspects of this service. 
 *  Methods in this manager support the passing of a <code> Proxy </code> 
 *  object. The sessions included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> CyclicEventLookupSession: </code> a session to look up 
 *      cyclic events </li> 
 *      <li> <code> CyclicEventQuerySession: </code> a session to query cyclic 
 *      events <code> </code> </li> 
 *      <li> <code> CyclicEventSearchSession: </code> a session to search 
 *      cyclic events </li> 
 *      <li> <code> CyclicEventAdminSession: </code> a session to create, 
 *      modify and delete cyclic events <code> </code> </li> 
 *      <li> <code> CyclicEventNotificationSession: a </code> session to 
 *      receive messages pertaining to cyclic event <code> </code> changes 
 *      </li> 
 *      <li> <code> CyclicEventCalendarSession: </code> a session for 
 *      retriieving cyclic event and calendar mappings </li> 
 *      <li> <code> CyclicEventCalendarAssignmentSession: </code> a session 
 *      for managing cyclic event and calendar mappings </li> 
 *      <li> <code> CyclicEventSmartCalendarSession: </code> a session to 
 *      manage dynamic cyclic event catalogs </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> CyclicTimePeriodLookupSession: </code> a session to look 
 *      up cyclic time periods </li> 
 *      <li> <code> CyclicTimePeriodQuerySession: </code> a session to query 
 *      cyclic time periods <code> </code> </li> 
 *      <li> <code> CyclicTimePeriodSearchSession: </code> a session to search 
 *      cyclic time periods </li> 
 *      <li> <code> CyclicTimePeriodAdminSession: </code> a session to create, 
 *      modify and delete cyclic time periods <code> </code> </li> 
 *      <li> <code> CyclicTimePeriodNotificationSession: a </code> session to 
 *      receive messages pertaining to cyclic time period <code> </code> 
 *      changes </li> 
 *      <li> <code> CyclicTimePeriodCalendarSession: </code> a session for 
 *      retriieving cyclic time period and calendar mappings </li> 
 *      <li> <code> CyclicTimePeriodCalendarAssignmentSession: </code> a 
 *      session for managing cyclic time period and calendar mappings </li> 
 *      <li> <code> CyclicTimePeriodSmartCalendarSession: </code> a session to 
 *      manage dynamic cyclic time period catalogs </li> 
 *  </ul>
 *  
 */

public interface CalendaringCycleProxyManager
    extends org.osid.OsidProxyManager,
            org.osid.calendaring.cycle.CalendaringCycleProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the cyclic event 
     *  lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> EventLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsEventLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEventLookup() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.cycle.CyclicEventLookupSession getCyclicEventLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the cyclic event 
     *  lookup service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @param  proxy a proxy 
     *  @return <code> CyclicEventLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsEventLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEventLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.CyclicEventLookupSession getCyclicEventLookupSessionForCalendar(org.osid.id.Id calendarId, 
                                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the cyclic event 
     *  query service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> EventQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsEventQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEventQuery() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.cycle.CyclicEventQuerySession getCyclicEventQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the cyclic event 
     *  query service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @param  proxy a proxy 
     *  @return <code> CyclicEventQuerySession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsEventQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEventQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.CyclicEventQuerySession getCyclicEventQuerySessionForCalendar(org.osid.id.Id calendarId, 
                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the cyclic event 
     *  search service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> EventSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsEventSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEventSearch() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.cycle.CyclicEventSearchSession getCyclicEventSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the cyclic event 
     *  search service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @param  proxy a proxy 
     *  @return <code> CyclicEventSearchSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsEventSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEventSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.CyclicEventSearchSession getCyclicEventSearchSessionForCalendar(org.osid.id.Id calendarId, 
                                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the cyclic event 
     *  administration service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> EventAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsEventAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEventAdmin() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.cycle.CyclicEventAdminSession getCyclicEventAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the cyclic event 
     *  admin service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @param  proxy a proxy 
     *  @return <code> CyclicEventAdminSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsEventAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEventAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.CyclicEventAdminSession getCyclicEventAdminSessionForCalendar(org.osid.id.Id calendarId, 
                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to event 
     *  changes. 
     *
     *  @param  eventReceiver the cyclic event receiver 
     *  @param  proxy a proxy 
     *  @return an <code> EventNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> eventReceiver </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEventNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEventNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.CyclicEventNotificationSession getCyclicEventNotificationSession(org.osid.calendaring.cycle.CyclicEventReceiver eventReceiver, 
                                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the cyclic event 
     *  notification service for the given calendar. 
     *
     *  @param  eventReceiver the cyclic event receiver 
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @param  proxy a proxy 
     *  @return <code> CyclicEventNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> eventReceiver, </code> 
     *          <code> calendarId </code> or <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEventNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEventNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.CyclicEventNotificationSession getCyclicEventNotificationSessionForCalendar(org.osid.calendaring.cycle.CyclicEventReceiver eventReceiver, 
                                                                                                                  org.osid.id.Id calendarId, 
                                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving event to calendar mappings. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> EventCalendarSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsEventCalendar() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEventCalendar() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.cycle.CyclicEventCalendarSession getCyclicEventCalendarSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning event to calendar mappings. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> EventCalendarAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEventCalendarAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEventCalendarAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.CyclicEventCalendarAssignmentSession getCyclicEventCalendarAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session associated with the cyclic event smart calendar for 
     *  the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @param  proxy a proxy 
     *  @return an <code> EventSmartCalendarSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEventSmartCalendar() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEventSmartCalendar() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.CyclicEventSmartCalendarSession getCyclicEventSmartCalendarSession(org.osid.id.Id calendarId, 
                                                                                                         org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving event to cyclic event associations. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> EventCyclicEventLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEventCyclicEventLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEventCyclicEventLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.EventCyclicEventLookupSession getEventCyclicEventLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the event cyclic 
     *  event lookup service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @param  proxy a proxy 
     *  @return an <code> EventCyclicEventLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEventCyclicEventLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEventCyclicEventLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.EventCyclicEventLookupSession getEventCyclicEventLookupSessionForCalendar(org.osid.id.Id calendarId, 
                                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for manually making event to cyclic event 
     *  associations. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> EventCyclicEventAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEventCyclicEventAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEventCyclicEventAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.cycle.EventCyclicEventAssignmentSession getEventCyclicEventAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the event cyclic 
     *  event assignment service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @param  proxy a proxy 
     *  @return an <code> EventCyclicEventAssignmentSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEventCyclicEventAssignment() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEventCyclicEventAssignment() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.EventCyclicEventAssignmentSession getEventCyclicEventAssignmentSessionForCalendar(org.osid.id.Id calendarId, 
                                                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the cyclic time 
     *  period lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> CyclicTimePeriodLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCyclicTimePeriodLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCyclicTimePeriodLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.CyclicTimePeriodLookupSession getCyclicTimePeriodLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the cyclic time 
     *  period lookup service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @param  proxy a proxy 
     *  @return a <code> CyclicTimePeriodLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCyclicTimePeriodLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCyclicTimePeriodLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.CyclicTimePeriodLookupSession getCyclicTimePeriodLookupSessionForCalendar(org.osid.id.Id calendarId, 
                                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the cyclic time 
     *  period query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> CyclicTimePeriodQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCyclicTimePeriodQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCyclicTimePeriodQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.CyclicTimePeriodQuerySession getCyclicTimePeriodQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the cyclic time 
     *  period query service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @param  proxy a proxy 
     *  @return a <code> CyclicTimePeriodQuerySession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCyclicTimePeriodQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCyclicTimePeriodQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.CyclicTimePeriodQuerySession getCyclicTimePeriodQuerySessionForCalendar(org.osid.id.Id calendarId, 
                                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the cyclic time 
     *  period search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> CyclicTimePeriodSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCyclicTimePeriodSearch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCyclicTimePeriodSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.CyclicTimePeriodSearchSession getCyclicTimePeriodSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the cyclic time 
     *  period search service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @param  proxy a proxy 
     *  @return a <code> CyclicTimePeriodSearchSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCyclicTimePeriodSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCyclicTimePeriodSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.CyclicTimePeriodSearchSession getCyclicTimePeriodSearchSessionForCalendar(org.osid.id.Id calendarId, 
                                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the cyclic time 
     *  period administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> CyclicTimePeriodAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCyclicTimePeriodAdmin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCyclicTimePeriodAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.CyclicTimePeriodAdminSession getCyclicTimePeriodAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the cyclic time 
     *  period admin service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @param  proxy a proxy 
     *  @return <code> calendarId </code> not found 
     *  @throws org.osid.NotFoundException a <code> 
     *          CyclicTimePeriodAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> calendarId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCyclicTimePeriodAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCyclicTimePeriodAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.CyclicTimePeriodAdminSession getCyclicTimePeriodAdminSessionForCalendar(org.osid.id.Id calendarId, 
                                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to cyclic 
     *  time period changes. 
     *
     *  @param  cyclicTimePeriodReceiver the cyclic time period receiver 
     *  @param  proxy a proxy 
     *  @return a <code> CyclicTimePeriodNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> cyclicTimePeriodReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCyclicTimePeriodNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCyclicTimePeriodNotification() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.cycle.CyclicTimePeriodNotificationSession getCyclicTimePeriodNotificationSession(org.osid.calendaring.cycle.CyclicTimePeriodReceiver cyclicTimePeriodReceiver, 
                                                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the cyclic time 
     *  period notification service for the given calendar. 
     *
     *  @param  cyclicTimePeriodReceiver the cyclic time period receiver 
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @param  proxy a proxy 
     *  @return <code> a CyclicTimePeriodNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> cyclicTimePeriodReceiver 
     *          </code> or <code> calendarId </code> or <code> proxy </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCyclicTimePeriodNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCyclicTimePeriodNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.CyclicTimePeriodNotificationSession getCyclicTimePeriodNotificationSessionForCalendar(org.osid.calendaring.cycle.CyclicTimePeriodReceiver cyclicTimePeriodReceiver, 
                                                                                                                            org.osid.id.Id calendarId, 
                                                                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving cyclic time period to calendar 
     *  mappings. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> CyclicTimePeriodCalendarSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCyclicTimePeriodCalendar() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCyclicTimePeriodCalendar() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.CyclicTimePeriodCalendarSession getCyclicTimePeriodCalendarSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning cyclic time period to calendar 
     *  mappings. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> CyclicTimePeriodCalendarAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCyclicTimePeriodCalendarAssignment() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCyclicTimePeriodCalendarAssignment() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.calendaring.cycle.CyclicTimePeriodCalendarAssignmentSession getCyclicTimePeriodCalendarAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session associated with the cyclic time period smart calendar 
     *  for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @param  proxy a proxy 
     *  @return a <code> CyclicTimePeriodSmartCalendarSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCyclicTimePeriodSmartCalendar() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCyclicTimePeriodSmartCalendar() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.cycle.CyclicTimePeriodSmartCalendarSession getCyclicTimePeriodSmartCalendarSession(org.osid.id.Id calendarId, 
                                                                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving time period to cyclic time period 
     *  associations. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> TimePeriodCyclicTimePeriodLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTimePeriodCyclicTimePeriodLookup() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTimePeriodCyclicTimePeriodLookup() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.calendaring.cycle.TimePeriodCyclicTimePeriodLookupSession getTimePeriodCyclicTimePeriodLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the time period 
     *  cyclic time period lookup service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @param  proxy a proxy 
     *  @return a <code> TimePeriodCyclicTimePeriodLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTimePeriodCyclicTimePeriodLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTimePeriodCyclicTimePeriodLookup() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.cycle.TimePeriodCyclicTimePeriodLookupSession getTimePeriodCyclicTimePeriodLookupSessionForCalendar(org.osid.id.Id calendarId, 
                                                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for manually making time period to cyclic time period 
     *  associations. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> TimePeriodCyclicTimePeriodAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTimePeriodCyclicTimePeriodAssignment() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTimePeriodCyclicTimePeriodAssignment() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.calendaring.cycle.TimePeriodCyclicTimePeriodAssignmentSession getTimePeriodCyclicTimePeriodAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the time period 
     *  cyclic time period assignment service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @param  proxy a proxy 
     *  @return a <code> TimePeriodCyclicTimePeriodAssignmentSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTimePeriodCyclicTimePeriodAssignment() </code> or 
     *          <code> supportsVisibleFederation() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTimePeriodCyclicTimePeriodAssignment() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.cycle.TimePeriodCyclicTimePeriodAssignmentSession getTimePeriodCyclicTimePeriodAssignmentSessionForCalendar(org.osid.id.Id calendarId, 
                                                                                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets a <code> CalendaringCycleBatchProxyManager. </code> 
     *
     *  @return a <code> CalendaringCycleBatchProxyManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCalendaringCycleBatch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCalendaringCycleBatch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.batch.CalendaringCycleBatchProxyManager getCalendaringCycleBatchProxyManager()
        throws org.osid.OperationFailedException;
}
