//
// org.osid.calendaring.cycle.CyclicEventCalendarAssignmentSession
//
//     The OSID Java specification for org.osid.calendaring.cycle.CyclicEventCalendarAssignmentSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring.cycle;


/**
 *  <p>This session provides methods to re-assign <code> CyclicEvents </code> 
 *  to <code> Calendars. </code> A <code> CyclicEvent </code> may map to 
 *  multiple <code> Calendars </code> and removing the last reference to a 
 *  <code> CyclicEvent </code> is the equivalent of deleting it. Each <code> 
 *  Calendar </code> may have its own authorizations governing who is allowed 
 *  to operate on it. </p> 
 *  
 *  <p> Moving or adding a reference of a <code> CyclicEvent </code> to 
 *  another <code> Calendar </code> is not a copy operation (eg: does not 
 *  change its <code> Id </code> ). </p>
 */

public interface CyclicEventCalendarAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter cyclic event/calendar mappings. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignCyclicEvents();


    /**
     *  Tests if this user can alter cyclic event/calendar mappings. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a PERMISSION_DENIED. This is intended as a hint to an application 
     *  that may opt not to offer assignment operations to unauthorized users. 
     *
     *  @param  calendarId the <code> Id </code> of the <code> Calendar 
     *          </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignCyclicEventsToCalendar(org.osid.id.Id calendarId);


    /**
     *  Gets a list of calendars including and under the given calendar node 
     *  in which any cyclic event can be assigned. 
     *
     *  @param  calendarId the <code> Id </code> of the <code> Calendar 
     *          </code> 
     *  @return list of assignable calendar <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableCalendarIds(org.osid.id.Id calendarId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of calendars including and under the given calendar node 
     *  in which a specific cyclic event can be assigned. 
     *
     *  @param  calendarId the <code> Id </code> of the <code> Calendar 
     *          </code> 
     *  @param  cyclicEventId the <code> Id </code> of the <code> CyclicEvent 
     *          </code> 
     *  @return list of assignable calendar <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> or 
     *          <code> cyclicEventId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableCalendarIdsForCyclicEvent(org.osid.id.Id calendarId, 
                                                                     org.osid.id.Id cyclicEventId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> CyclicEvent </code> to a <code> Calendar. 
     *  </code> 
     *
     *  @param  cyclicEventId the <code> Id </code> of the <code> CyclicEvent 
     *          </code> 
     *  @param  calendarId the <code> Id </code> of the <code> Calendar 
     *          </code> 
     *  @throws org.osid.AlreadyExistsException <code> cyclicEventId </code> 
     *          is already assigned to <code> calendarId </code> 
     *  @throws org.osid.NotFoundException <code> cyclicEventId </code> or 
     *          <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> cyclicEventId </code> or 
     *          <code> calendarId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignCyclicEventToCalendar(org.osid.id.Id cyclicEventId, 
                                            org.osid.id.Id calendarId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> CyclicEvent </code> from a <code> Calendar. </code> 
     *
     *  @param  cyclicEventId the <code> Id </code> of the <code> CyclicEvent 
     *          </code> 
     *  @param  calendarId the <code> Id </code> of the <code> Calendar 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> cyclicEventId </code> or 
     *          <code> calendarId </code> not found or <code> cyclicEventId 
     *          </code> not assigned to <code> calendarId </code> 
     *  @throws org.osid.NullArgumentException <code> cyclicEventId </code> or 
     *          <code> calendarId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignCyclicEventFromCalendar(org.osid.id.Id cyclicEventId, 
                                                org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Moves a <code> CyclicEvent </code> from one <code> Calendar </code> to 
     *  another. Mappings to other <code> Calendars </code> are unaffected. 
     *
     *  @param  cyclicEventId the <code> Id </code> of the <code> CyclicEvent 
     *          </code> 
     *  @param  fromCalendarId the <code> Id </code> of the current <code> 
     *          Calendar </code> 
     *  @param  toCalendarId the <code> Id </code> of the destination <code> 
     *          Calendar </code> 
     *  @throws org.osid.NotFoundException <code> cyclicEvemtId 
     *          fromCalendarId, </code> or <code> toCalendarId </code> not 
     *          found or <code> cyclicEventId </code> not mapped to <code> 
     *          fromCalendarId </code> 
     *  @throws org.osid.NullArgumentException <code> cyclicEventId, 
     *          fromCalendarId, </code> or <code> toCalendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void reassignCyclicEventToCalendar(org.osid.id.Id cyclicEventId, 
                                              org.osid.id.Id fromCalendarId, 
                                              org.osid.id.Id toCalendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
