//
// org.osid.calendaring.cycle.CyclicEventSearchSession
//
//     The OSID Java specification for org.osid.calendaring.cycle.CyclicEventSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring.cycle;


/**
 *  <p>This session provides methods for searching <code> Event </code> 
 *  objects. The search query is constructed using the <code> 
 *  CyclicEventQuery. </code> the cyclic event record <code> Type </code> also 
 *  specifies the record for the cyclic event query. </p> 
 *  
 *  <p> <code> getCyclicEventsByQuery() </code> is the basic search method and 
 *  returns a list of <code> CyclicEvents. </code> A more advanced search may 
 *  be performed with <code> getCyclicEventsBySearch(). </code> It accepts a 
 *  <code> CyclicEventSearch </code> in addition to the query for the purpose 
 *  of specifying additional options affecting the entire search, such as 
 *  ordering. <code> getCyclicEventsBySearch() </code> returns a <code> 
 *  CyclicEventSearchResults </code> that can be used to access the resulting 
 *  <code> CyclicEventList </code> or be used to perform a search within the 
 *  result set through <code> CyclicEventSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated calendar view: searches include cyclic events in 
 *      calendars of which this calendar is a ancestor in the calendar 
 *      hierarchy </li> 
 *      <li> isolated calendar view: searches are restricted to cyclic events 
 *      in this calendar </li> 
 *  </ul>
 *  
 *  
 *  <p> Cyclic events may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> 
 *  CyclicEventQuery. </code> </p>
 */

public interface CyclicEventSearchSession
    extends org.osid.calendaring.cycle.CyclicEventQuerySession {


    /**
     *  Gets a cyclic event search. 
     *
     *  @return the cyclic event search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.cycle.CyclicEventSearch getCyclicEventSearch();


    /**
     *  Gets a cyclic event search order. The <code> CyclicEventSearchOrder 
     *  </code> is supplied to a <code> CyclicEventSearch </code> to specify 
     *  the ordering of results. 
     *
     *  @return the cyclic event search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.cycle.CyclicEventSearchOrder getCyclicEventSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  cyclicEventQuery the cyclic event search query 
     *  @param  cyclicEventSearch the cyclic event search 
     *  @return the cyclic event search results 
     *  @throws org.osid.NullArgumentException <code> cyclicEventQuery </code> 
     *          or <code> cyclicEventSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> cyclicEventSearch </code> 
     *          or <code> cyclicEventQuery </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.cycle.CyclicEventSearchResults getCyclicEventsBySearch(org.osid.calendaring.cycle.CyclicEventQuery cyclicEventQuery, 
                                                                                       org.osid.calendaring.cycle.CyclicEventSearch cyclicEventSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a cyclic event query from an inspector. The inspector is 
     *  available from a <code> CyclicEventSearchResults. </code> 
     *
     *  @param  cyclicEventQueryInspector a cyclic event query inspector 
     *  @return the cyclic event query 
     *  @throws org.osid.NullArgumentException <code> 
     *          cyclicEventQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> cyclicEventQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.cycle.CyclicEventQuery getCyclicEventQueryFromInspector(org.osid.calendaring.cycle.CyclicEventQueryInspector cyclicEventQueryInspector);
}
