//
// org.osid.calendaring.cycle.CyclicTimePeriodAdminSession
//
//     The OSID Java specification for org.osid.calendaring.cycle.CyclicTimePeriodAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring.cycle;


/**
 *  <p>This session creates, updates, and deletes <code> CyclicTimePeriods. 
 *  </code> The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  CyclicTimePeriod, </code> a <code> CyclicTimePeriodForm </code> is 
 *  requested using <code> getCyclicTimePeriodFormForCreate() </code> 
 *  specifying the desired record <code> Types </code> or none if no record 
 *  <code> Types </code> are needed. The returned <code> CyclicTimePeriodForm 
 *  </code> will indicate that it is to be used with a create operation and 
 *  can be used to examine metdata or validate data prior to creation. Once 
 *  the <code> CyclicTimePeriodForm </code> is submiited to a create 
 *  operation, it cannot be reused with another create operation unless the 
 *  first operation was unsuccessful. Each <code> CyclicTimePeriodForm </code> 
 *  corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> CyclicTimePeriodForms </code> are requested to the 
 *  <code> CyclicTimePeriod </code> <code> Id </code> that is to be updated 
 *  using <code> getCyclicTimePeriodFormForUpdate(). </code> Similarly, the 
 *  <code> CyclicTimePeriodForm </code> has metadata about the data that can 
 *  be updated and it can perform validation before submitting the update. The 
 *  <code> CyclicTimePeriodForm </code> can only be used once for a successful 
 *  update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete CyclicTimePeriodForms. To unmap a <code> 
 *  CyclicTimePeriodFor </code> from the current <code> Calendar, </code> the 
 *  <code> CyclicTimePeriodCalendarAssignmentSession </code> should be used. 
 *  These delete operations attempt to remove the <code> CyclicTimePeriod 
 *  </code> itself thus removing it from all known <code> Calendar </code> 
 *  catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface CyclicTimePeriodAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Calendar </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Calendar Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCalendarId();


    /**
     *  Gets the <code> Calendar </code> associated with this session. 
     *
     *  @return the <code> Calendar </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Calendar getCalendar()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> CyclicTimePeriods. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known creating a CyclicTimePeriod will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer create operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> CyclicTimePeriod </code> 
     *          creation is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateCyclicTimePeriods();


    /**
     *  Tests if this user can create a single <code> CyclicTimePeriod </code> 
     *  using the desired record types. While <code> 
     *  CalendaringCycleManager.getCyclicTimePeriodRecordTypes() </code> can 
     *  be used to examine which records are supported, this method tests 
     *  which record(s) are required for creating a specific <code> 
     *  CyclicTimePeriod. </code> Providing an empty array tests if a <code> 
     *  CyclicTimePeriod </code> can be created with no records. 
     *
     *  @param  cyclicTimePeriodRecordTypes array of cyclic time period record 
     *          types 
     *  @return <code> true </code> if <code> CyclicTimePeriod </code> 
     *          creation using the specified record <code> Types </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          cyclicTimePeriodRecordTypes </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateCyclicTimePeriodWithRecordTypes(org.osid.type.Type[] cyclicTimePeriodRecordTypes);


    /**
     *  Gets the cyclic time period form for creating new cyclic time periods. 
     *  A new form should be requested for each create transaction. 
     *
     *  @param  cyclicTimePeriodRecordTypes array of cyclic time period record 
     *          types 
     *  @return the cyclic time period form 
     *  @throws org.osid.NullArgumentException <code> 
     *          cyclicTimePeriodRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.cycle.CyclicTimePeriodForm getCyclicTimePeriodFormForCreate(org.osid.type.Type[] cyclicTimePeriodRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> CyclicTimePeriod. </code> 
     *
     *  @param  cyclicTimePeriodForm the forms for this <code> 
     *          CyclicTimePeriod </code> 
     *  @return the new <code> CyclicTimePeriod </code> 
     *  @throws org.osid.IllegalStateException <code> cyclicTimePeriodForm 
     *          </code> already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> cyclicTimePeriodForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> cyclicTimePeriodForm 
     *          </code> did not originate from <code> 
     *          getCyclicTimePeriodFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.cycle.CyclicTimePeriod createCyclicTimePeriod(org.osid.calendaring.cycle.CyclicTimePeriodForm cyclicTimePeriodForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> CyclicTimePeriods. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known updating a <code> CyclicTimePeriod 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer update 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if cyclic time period modification is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateCyclicTimePeriods();


    /**
     *  Gets the cyclic time period form for updating an existing cyclic time 
     *  period. A new cyclic time period form should be requested for each 
     *  update transaction. 
     *
     *  @param  cyclicTimePeriodId the <code> Id </code> of the <code> 
     *          CyclicTimePeriod </code> 
     *  @return the cyclic time period form 
     *  @throws org.osid.NotFoundException <code> cyclicTimePeriodId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> cyclicTimePeriodid 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.cycle.CyclicTimePeriodForm getCyclicTimePeriodFormForUpdate(org.osid.id.Id cyclicTimePeriodId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing tiem period. 
     *
     *  @param  cyclicTimePeriodForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> cyclicTimePeriodForm 
     *          </code> already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> cyclicTimePeriodForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> cyclicTimePeriodForm 
     *          </code> did not originate from <code> 
     *          getCyclicTimePeriodFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateCyclicTimePeriod(org.osid.calendaring.cycle.CyclicTimePeriodForm cyclicTimePeriodForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> CyclicTimePeriods. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known deleting a <code> CyclicTimePeriod 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer delete 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> CyclicTimePeriod </code> 
     *          deletion is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteCyclicTimePeriods();


    /**
     *  Deletes the <code> CyclicTimePeriod </code> identified by the given 
     *  <code> Id. </code> 
     *
     *  @param  cyclicTimePeriodId the <code> Id </code> of the <code> 
     *          CyclicTimePeriod </code> to delete 
     *  @throws org.osid.NotFoundException a <code> CyclicTimePeriod </code> 
     *          was not found identified by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> cyclicTimePeriodId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteCyclicTimePeriod(org.osid.id.Id cyclicTimePeriodId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  CyclicTimePeriods. </code> A return of true does not guarantee 
     *  successful authorization. A return of false indicates that it is known 
     *  changing an alias will result in a <code> PERMISSION_DENIED. </code> 
     *  This is intended as a hint to an application that may opt not to offer 
     *  alias operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> CyclicTimePeriod </code> 
     *          aliasing is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageCyclicTimePeriodAliases();


    /**
     *  Adds an <code> Id </code> to a <code> CyclicTimePeriod </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> CyclicTimePeriod </code> is determined by the provider. The 
     *  new <code> Id </code> performs as an alias to the primary <code> Id. 
     *  </code> If the alias is a pointer to another cyclic time period, it is 
     *  reassigned to the given cyclic time period <code> Id. </code> 
     *
     *  @param  cyclicTimePeriodId the <code> Id </code> of a <code> 
     *          CyclicTimePeriod </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> cyclicTimePeriodId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> cyclicTimePeriodId 
     *          </code> or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasCyclicTimePeriod(org.osid.id.Id cyclicTimePeriodId, 
                                      org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
