//
// org.osid.calendaring.cycle.CyclicTimePeriodCalendarSession
//
//     The OSID Java specification for org.osid.calendaring.cycle.CyclicTimePeriodCalendarSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring.cycle;


/**
 *  <p>This session provides methods to retrieve <code> CyclicTimePeriod 
 *  </code> to <code> Calendar </code> mappings. A <code> CyclicTimePeriod 
 *  </code> may appear in multiple <code> Calendars. </code> Each <code> 
 *  Calendar </code> may have its own authorizations governing who is allowed 
 *  to look at it. </p> 
 *  
 *  <p> This lookup session defines two views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *  </ul>
 *  
 */

public interface CyclicTimePeriodCalendarSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can perform lookups of cyclic time period/calendar 
     *  mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known lookup 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if looking up mappings is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupCyclicTimePeriodCalendarMappings();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeCalendarView();


    /**
     *  A complete view of the <code> CyclicTimePeriod </code> and <code> 
     *  Calendar </code> returns is desired. Methods will return what is 
     *  requested or result in an error. This view is used when greater 
     *  precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryCalendarView();


    /**
     *  Gets the list of <code> CyclicTimePeriod </code> <code> Ids </code> 
     *  associated with an <code> Calendar. </code> 
     *
     *  @param  calendarId <code> Id </code> of the <code> Calendar </code> 
     *  @return list of related cyclic time period <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getCyclicTimePeriodIdsByCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> CyclicTimePeriods </code> associated with an 
     *  <code> Calendar. </code> 
     *
     *  @param  calendarId <code> Id </code> of the <code> Calendar </code> 
     *  @return list of related cyclic time periods 
     *  @throws org.osid.NotFoundException <code> calendarId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.cycle.CyclicTimePeriodList getCyclicTimePeriodsByCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> CyclicTimePeriod Ids </code> corresponding to 
     *  a list of <code> Calendars. </code> 
     *
     *  @param  calendarIds list of calendar <code> Ids </code> 
     *  @return list of cyclic time period <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> calendarIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getCyclicTimePeriodIdsByCalendars(org.osid.id.IdList calendarIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> CyclicTimePeriods </code> corresponding to a 
     *  list of <code> Calendars. </code> 
     *
     *  @param  calendarIds list of calendar <code> Ids </code> 
     *  @return list of cyclic time periods 
     *  @throws org.osid.NullArgumentException <code> calendarIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.cycle.CyclicTimePeriodList getCyclicTimePeriodsByCalendars(org.osid.id.IdList calendarIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> Calendar Ids </code> mapped to a <code> 
     *  CyclicTimePeriod. </code> 
     *
     *  @param  cyclicTimePeriodId <code> Id </code> of a <code> 
     *          CyclicTimePeriod </code> 
     *  @return list of calendar <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> cyclicTimePeriodId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> cyclicTimePeriodId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getCalendarIdsByCyclicTimePeriod(org.osid.id.Id cyclicTimePeriodId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> Calendars </code> mapped to a <code> 
     *  CyclicTimePeriod. </code> 
     *
     *  @param  cyclicTimePeriodId <code> Id </code> of a <code> 
     *          CyclicTimePeriod </code> 
     *  @return list of calendar <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> cyclicTimePeriodId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> cyclicTimePeriodId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.CalendarList getCalendarsByCyclicTimePeriod(org.osid.id.Id cyclicTimePeriodId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
