//
// org.osid.calendaring.cycle.CyclicTimePeriodLookupSession
//
//     The OSID Java specification for org.osid.calendaring.cycle.CyclicTimePeriodLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring.cycle;


/**
 *  <p>This session provides methods for retrieving <code> CyclicTimePeriod 
 *  </code> objects. </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated calendar view: All cyclic time period methods in this 
 *      session operate, retrieve and pertain to cyclic time periods defined 
 *      explicitly in the current calendar. Using an isolated view is useful 
 *      for managing cyclic time periods with the <code> 
 *      CyclicTimePeriodAdminSession. </code> </li> 
 *      <li> federated calendar view: All cyclic time period methods in this 
 *      session operate, retrieve and pertain to all cyclic time periods 
 *      defined in this calendar and any other calendars implicitly available 
 *      in this calendar through calendar inheritence. </li> 
 *  </ul>
 *  
 *  
 *  <p> Cyclic time periods may have an additional records indicated by their 
 *  respective record types. The record may not be accessed through a cast of 
 *  the <code> CyclicTimePeriod. </code> </p>
 */

public interface CyclicTimePeriodLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Calendar </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Calendar Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCalendarId();


    /**
     *  Gets the <code> Calendar </code> associated with this session. 
     *
     *  @return the <code> Calendar </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Calendar getCalendar()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> CyclicTimePeriod </code> 
     *  lookups. A return of true does not guarantee successful authorization. 
     *  A return of false indicates that it is known all methods in this 
     *  session will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer lookup 
     *  operations to unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupCyclicTimePeriods();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeCyclicTimePeriodView();


    /**
     *  A complete view of the <code> CyclicTimePeriod </code> returns is 
     *  desired. Methods will return what is requested or result in an error. 
     *  This view is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryCyclicTimePeriodView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include cyclic time periods in calendars which are children of this 
     *  calendar in the calendar hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCalendarView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this calendar only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCalendarView();


    /**
     *  Gets the <code> CyclicTimePeriod </code> specified by its <code> Id. 
     *  </code> In plenary mode, the exact <code> Id </code> is found or a 
     *  <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  CyclicTimePeriod </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> CyclicTimePeriod </code> and retained for 
     *  compatibility. 
     *
     *  @param  cyclicTimePeriodId <code> Id </code> of the <code> 
     *          CyclicTimePeriod </code> 
     *  @return the cyclic time period 
     *  @throws org.osid.NotFoundException <code> cyclicTimePeriodId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> cyclicTimePeriodId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.calendaring.cycle.CyclicTimePeriod getCyclicTimePeriod(org.osid.id.Id cyclicTimePeriodId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CyclicTimePeriodList </code> corresponding to the given 
     *  <code> IdList. </code> In plenary mode, the returned list contains all 
     *  of the cyclic time periods specified in the <code> Id </code> list, in 
     *  the order of the list, including duplicates, or an error results if an 
     *  <code> Id </code> in the supplied list is not found or inaccessible. 
     *  Otherwise, inaccessible <code> CyclicTimePeriods </code> may be 
     *  omitted from the list and may present the elements in any order 
     *  including returning a unique set. 
     *
     *  @param  cyclicTimePeriodIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> CyclicTimePeriod </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> rimePeriodIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.cycle.CyclicTimePeriodList getCyclicTimePeriodsByIds(org.osid.id.IdList cyclicTimePeriodIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CyclicTimePeriodList </code> corresponding to the given 
     *  cyclic time period genus <code> Type </code> which does not include 
     *  cyclic time periods of genus types derived from the specified <code> 
     *  Type. </code> In plenary mode, the returned list contains all known 
     *  cyclic time periods or an error results. Otherwise, the returned list 
     *  may contain only those cyclic time periods that are accessible through 
     *  this session. 
     *
     *  @param  cyclicTimePeriodGenusType a cyclic time period genus type 
     *  @return the returned <code> CyclicTimePeriod </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          cyclicTimePeriodGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.cycle.CyclicTimePeriodList getCyclicTimePeriodsByGenusType(org.osid.type.Type cyclicTimePeriodGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CyclicTimePeriodList </code> corresponding to the given 
     *  cyclic time period genus <code> Type </code> and include any 
     *  additional cyclic time periods with genus types derived from the 
     *  specified <code> Type. </code> In plenary mode, the returned list 
     *  contains all known cyclic time periods or an error results. Otherwise, 
     *  the returned list may contain only those cyclic time periods that are 
     *  accessible through this session. 
     *
     *  @param  cyclicTimePeriodGenusType a cyclic time period genus type 
     *  @return the returned <code> CyclicTimePeriod </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          cyclicTimePeriodGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.cycle.CyclicTimePeriodList getCyclicTimePeriodsByParentGenusType(org.osid.type.Type cyclicTimePeriodGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CyclicTimePeriodList </code> containing the given cyclic 
     *  time period record <code> Type. </code> In plenary mode, the returned 
     *  list contains all known cyclic time periods or an error results. 
     *  Otherwise, the returned list may contain only those cyclic time 
     *  periods that are accessible through this session. 
     *
     *  @param  cyclicTimePeriodRecordType a cyclic time period record type 
     *  @return the returned <code> CyclicTimePeriod </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          cyclicTimePeriodRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.cycle.CyclicTimePeriodList getCyclicTimePeriodsByRecordType(org.osid.type.Type cyclicTimePeriodRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> CyclicTimePeriods. </code> In plenary mode, the 
     *  returned list contains all known cyclic time periods or an error 
     *  results. Otherwise, the returned list may contain only those cyclic 
     *  time periods that are accessible through this session. In both cases, 
     *  the order of the set is not specified. 
     *
     *  @return a <code> CyclicTimePeriodList </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.cycle.CyclicTimePeriodList getCyclicTimePeriods()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
