//
// org.osid.calendaring.cycle.CyclicTimePeriodQuery
//
//     The OSID Java specification for org.osid.calendaring.cycle.CyclicTimePeriodQuery.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring.cycle;


/**
 *  <p>This is the query for searching cyclic time periods. Each method match 
 *  request produces an <code> AND </code> term while multiple invocations of 
 *  a method produces a nested <code> OR. </code> </p>
 */

public interface CyclicTimePeriodQuery
    extends org.osid.OsidObjectQuery {


    /**
     *  Sets the time period <code> Id </code> for this query to match cyclic 
     *  time periods with the given mapped time period. 
     *
     *  @param  timePeriodId a tiem period <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> timePeriodId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchTimePeriodId(org.osid.id.Id timePeriodId, boolean match);


    /**
     *  Clears the cyclic time period <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTimePeriodIdTerms();


    /**
     *  Tests if a <code> TimePeriodQuery </code> is available for querying 
     *  time periods. 
     *
     *  @return <code> true </code> if a time period query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTimePeriodQuery();


    /**
     *  Gets the query for a time period. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the time period query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTimePeriodQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTimePeriodQuery() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.TimePeriodQuery getTimePeriodQuery();


    /**
     *  Matches a cyclic time period that has any time period assigned. 
     *
     *  @param  match <code> true </code> to match cyclic time periods with 
     *          any tiem period, <code> false </code> to match cyclic time 
     *          periods with no tiem periods 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyTimePeriod(boolean match);


    /**
     *  Clears the time period terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTimePeriodTerms();


    /**
     *  Sets the calendar <code> Id </code> for this query. 
     *
     *  @param  calendarId a calendar <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCalendarId(org.osid.id.Id calendarId, boolean match);


    /**
     *  Clears the calendar <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCalendarIdTerms();


    /**
     *  Tests if a <code> CalendarQuery </code> is available for querying 
     *  resources. 
     *
     *  @return <code> true </code> if a calendar query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCalendarQuery();


    /**
     *  Gets the query for a calendar. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the calendar query 
     *  @throws org.osid.UnimplementedException <code> supportsCalendarQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCalendarQuery() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.CalendarQuery getCalendarQuery();


    /**
     *  Clears the calendar terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCalendarTerms();


    /**
     *  Gets the cyclic time period query record corresponding to the given 
     *  <code> CyclicTimePeriod </code> record <code> Type. </code> Multiple 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  cyclicTimePeriodRecordType a cyclic time period query record 
     *          type 
     *  @return the cyclic time period query record 
     *  @throws org.osid.NullArgumentException <code> 
     *          cyclicTimePeriodRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(cyclicTimePeriodRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.cycle.records.CyclicTimePeriodQueryRecord getCyclicTimePeriodQueryRecord(org.osid.type.Type cyclicTimePeriodRecordType)
        throws org.osid.OperationFailedException;
}
