//
// org.osid.calendaring.cycle.EventCyclicEventAssignmentSession
//
//     The OSID Java specification for org.osid.calendaring.cycle.EventCyclicEventAssignmentSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring.cycle;


/**
 *  <p>This session provides methods to manually assign <code> Events </code> 
 *  to <code> CyclicEvents. </code> An <code> Event </code> may be the product 
 *  of a <code> OsidRule </code> originating from a <code> SupersedingEvent, 
 *  </code> <code> OffsetEvent, </code> or a <code> RecurringEvent </code> in 
 *  which case the <code> CyclicEvent </code> is applied to the rule. </p>
 */

public interface EventCyclicEventAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Calendar </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Calendar Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCalendarId();


    /**
     *  Gets the <code> Calendar </code> associated with this session. 
     *
     *  @return the <code> Calendar </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Calendar getCalendar()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter event/cyclic event mappings. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignEvents();


    /**
     *  Tests if this user can alter event/cyclic event mappings. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a PERMISSION_DENIED. This is intended as a hint to an application 
     *  that may opt not to offer assignment operations to unauthorized users. 
     *
     *  @param  cyclicEventId the <code> Id </code> of the <code> CyclicEvent 
     *          </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> cyclicEventId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignCyclicEventsToCyclicEvent(org.osid.id.Id cyclicEventId);


    /**
     *  Gets a list of cyclic event <code> Ids. </code> 
     *
     *  @return list of assignable cyclic event <code> Ids </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableCyclicEventIds()
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> Event </code> to a <code> CyclicEvent. </code> 
     *
     *  @param  eventId the <code> Id </code> of the <code> Event </code> 
     *  @param  cyclicEventId the <code> Id </code> of the <code> CyclicEvent 
     *          </code> 
     *  @throws org.osid.AlreadyExistsException <code> eventId </code> is 
     *          already assigned to <code> cyclicEventId </code> 
     *  @throws org.osid.NotFoundException <code> eventId </code> or <code> 
     *          cyclicEventId </code> not found 
     *  @throws org.osid.NullArgumentException <code> eventId </code> or 
     *          <code> cyclicEventId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignEventToCyclicEvent(org.osid.id.Id eventId, 
                                         org.osid.id.Id cyclicEventId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes an <code> Event </code> from a <code> CyclicEvent. </code> 
     *
     *  @param  eventId the <code> Id </code> of the <code> Event </code> 
     *  @param  cyclicEventId the <code> Id </code> of the <code> CyclicEvent 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> eventId </code> or <code> 
     *          cyclicEventId </code> not found or <code> eventId </code> is 
     *          not assigned to <code> cyclicEventId </code> 
     *  @throws org.osid.NullArgumentException <code> eventId </code> or 
     *          <code> cyclicEventId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignEventFromCyclicEvent(org.osid.id.Id eventId, 
                                             org.osid.id.Id cyclicEventId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
