//
// org.osid.calendaring.cycle.TimePeriodCyclicTimePeriodAssignmentSession
//
//     The OSID Java specification for org.osid.calendaring.cycle.TimePeriodCyclicTimePeriodAssignmentSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring.cycle;


/**
 *  <p>This session provides methods to manually assign <code> TimePeriods 
 *  </code> to <code> CyclicTimePeriods. </code> </p>
 */

public interface TimePeriodCyclicTimePeriodAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Calendar </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Calendar Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCalendarId();


    /**
     *  Gets the <code> Calendar </code> associated with this session. 
     *
     *  @return the <code> Calendar </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Calendar getCalendar()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter time period/cyclic time period mappings. 
     *  A return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer assignment 
     *  operations to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignTimePeriods();


    /**
     *  Tests if this user can alter time period/cyclic time period mappings. 
     *  A return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a PERMISSION_DENIED. This is intended as a hint to an 
     *  application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @param  cyclicTimePeriodId the <code> Id </code> of the <code> 
     *          CyclicTimePeriod </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> cyclicTimePeriodId 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignCyclicTimePeriodsToCyclicTimePeriod(org.osid.id.Id cyclicTimePeriodId);


    /**
     *  Gets a list of cyclic time period <code> Ids. </code> 
     *
     *  @return list of assignable cyclic time period <code> Ids </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableCyclicTimePeriodIds()
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> TimePeriod </code> to a <code> 
     *  CyclicTimePeriod. </code> 
     *
     *  @param  timePeriodId the <code> Id </code> of the <code> TimePeriod 
     *          </code> 
     *  @param  cyclicTimePeriodId the <code> Id </code> of the <code> 
     *          CyclicTimePeriod </code> 
     *  @throws org.osid.AlreadyExistsException <code> timePeriodId </code> is 
     *          alrteady assigned to <code> cyclicTimePeriodId </code> 
     *  @throws org.osid.NotFoundException <code> timePeriodId </code> or 
     *          <code> cyclicTimePeriodId </code> not found 
     *  @throws org.osid.NullArgumentException <code> timePeriodId </code> or 
     *          <code> cyclicTimePeriodId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignTimePeriodToCyclicTimePeriod(org.osid.id.Id timePeriodId, 
                                                   org.osid.id.Id cyclicTimePeriodId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> TimePeriod </code> from a <code> CyclicTimePeriod. 
     *  </code> 
     *
     *  @param  timePeriodId the <code> Id </code> of the <code> TimePeriod 
     *          </code> 
     *  @param  cyclicTimePeriodId the <code> Id </code> of the <code> 
     *          CyclicTimePeriod </code> 
     *  @throws org.osid.NotFoundException <code> timePeriodId </code> or 
     *          <code> cyclicTimePeriodId </code> not found or <code> 
     *          timePeriodId </code> is not asigned to <code> 
     *          cyclicTimePeriodId </code> 
     *  @throws org.osid.NullArgumentException <code> timePeriodId </code> or 
     *          <code> cyclicTimePeriodId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignTimePeriodFromCyclicTimePeriod(org.osid.id.Id timePeriodId, 
                                                       org.osid.id.Id cyclicTimePeriodId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
