//
// org.osid.calendaring.rules.CommitmentEnablerLookupSession
//
//     The OSID Java specification for org.osid.calendaring.rules.CommitmentEnablerLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring.rules;


/**
 *  <p>This session provides methods for retrieving <code> CommitmentEnablers. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated calendar view: All commitment enabler methods in this 
 *      session operate, retrieve and pertain to commitment enablers defined 
 *      explicitly in the current calendar. Using an isolated view is useful 
 *      for managing <code> CommitmentEnablers </code> with the <code> 
 *      CommitmentEnablerAdminSession. </code> </li> 
 *      <li> federated calendar view: All commitment enabler methods in this 
 *      session operate, retrieve and pertain to all commitment enablers 
 *      defined in this calendar and any other commitment enablers implicitly 
 *      available in this calendar through calendar inheritence. </li> 
 *      <li> active commitment enabler view: All commitment enabler lookup 
 *      methods return active commitment enablers. </li> 
 *      <li> any status commitment enabler view: Commitment enablers of any 
 *      active or inactive status are returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedDistributorView() </code> and <code> 
 *  useIsolatedDistributorView() </code> behave as a radio group and one 
 *  should be selected before invoking the methods in this session. </p>
 */

public interface CommitmentEnablerLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Calendar </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Calendar Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCalendarId();


    /**
     *  Gets the <code> Calendar </code> associated with this session. 
     *
     *  @return the calendar 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Calendar getCalendar()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> CommitmentEnablers </code> 
     *  lookups. A return of true does not guarantee successful authorization. 
     *  A return of false indicates that it is known all methods in this 
     *  session will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer lookup 
     *  operations to unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupCommitmentEnablers();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeCommitmentEnablerView();


    /**
     *  A complete view of the <code> CommitmentEnabler </code> returns is 
     *  desired. Methods will return what is requested or result in an error. 
     *  This view is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryCommitmentEnablerView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include commitment enablers in calendars which are children of this 
     *  calendar in the calendar hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCalendarView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this calendar only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCalendarView();


    /**
     *  Only active commitment enablers are returned by methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveCommitmentEnablerView();


    /**
     *  All active and inactive commitment enablers are returned by methods in 
     *  this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusCommitmentEnablerView();


    /**
     *  Gets the <code> CommitmentEnabler </code> specified by its <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  CommitmentEnabler </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> CommitmentEnabler </code> and retained for 
     *  compatibility. 
     *  
     *  In active mode, commitment enablers are returned that are currently 
     *  active. In any status mode, active and inactive commitment enablers 
     *  are returned. 
     *
     *  @param  commitmentEnablerId <code> Id </code> of the <code> 
     *          CommitmentEnabler </code> 
     *  @return the commitment enabler 
     *  @throws org.osid.NotFoundException <code> commitmentEnablerId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> commitmentEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.calendaring.rules.CommitmentEnabler getCommitmentEnabler(org.osid.id.Id commitmentEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CommitmentEnablerList </code> corresponding to the given 
     *  <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  commitment enablers specified in the <code> Id </code> list, in the 
     *  order of the list, including duplicates, or an error results if an 
     *  <code> Id </code> in the supplied list is not found or inaccessible. 
     *  Otherwise, inaccessible <code> CommitmentEnablers </code> may be 
     *  omitted from the list and may present the elements in any order 
     *  including returning a unique set. 
     *  
     *  In active mode, commitment enablers are returned that are currently 
     *  active. In any status mode, active and inactive commitment enablers 
     *  are returned. 
     *
     *  @param  commitmentEnablerIds the list of <code> Ids </code> to 
     *          retrieve 
     *  @return the returned <code> CommitmentEnabler </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> commitmentEnablerIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.rules.CommitmentEnablerList getCommitmentEnablersByIds(org.osid.id.IdList commitmentEnablerIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CommitmentEnablerList </code> corresponding to the given 
     *  commitment enabler genus <code> Type </code> which does not include 
     *  commitment enablers of genus types derived from the specified <code> 
     *  Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  commitment enablers or an error results. Otherwise, the returned list 
     *  may contain only those commitment enablers that are accessible through 
     *  this session. 
     *  
     *  In active mode, commitment enablers are returned that are currently 
     *  active. In any status mode, active and inactive commitment enablers 
     *  are returned. 
     *
     *  @param  commitmentEnablerGenusType a commitment enabler genus type 
     *  @return the returned <code> CommitmentEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          commitmentEnablerGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.rules.CommitmentEnablerList getCommitmentEnablersByGenusType(org.osid.type.Type commitmentEnablerGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CommitmentEnablerList </code> corresponding to the given 
     *  commitment enabler genus <code> Type </code> and include any 
     *  additional commitment enablers with genus types derived from the 
     *  specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  commitment enablers or an error results. Otherwise, the returned list 
     *  may contain only those commitment enablers that are accessible through 
     *  this session. 
     *  
     *  In active mode, commitment enablers are returned that are currently 
     *  active. In any status mode, active and inactive commitment enablers 
     *  are returned. 
     *
     *  @param  commitmentEnablerGenusType a commitment enabler genus type 
     *  @return the returned <code> CommitmentEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          commitmentEnablerGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.rules.CommitmentEnablerList getCommitmentEnablersByParentGenusType(org.osid.type.Type commitmentEnablerGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CommitmentEnablerList </code> containing the given 
     *  commitment enabler record <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  commitment enablers or an error results. Otherwise, the returned list 
     *  may contain only those commitment enablers that are accessible through 
     *  this session. 
     *  
     *  In effective mode, commitments are returned that are currently 
     *  effective. In any effective mode, effective commitments and those 
     *  currently expired are returned. 
     *
     *  @param  commitmentEnablerRecordType a commitment enabler record type 
     *  @return the returned <code> CommitmentEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          commitmentEnablerRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.rules.CommitmentEnablerList getCommitmentEnablersByRecordType(org.osid.type.Type commitmentEnablerRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CommitmentEnablerList </code> effective during the 
     *  entire given date range inclusive but not confined to the date range 
     *  for any agent. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  commitment enablers or an error results. Otherwise, the returned list 
     *  may contain only those commitment enablers that are accessible through 
     *  this session. 
     *  
     *  In active mode, commitment enablers are returned that are currently 
     *  active in addition to being effective during the given date range. In 
     *  any status mode, active and inactive commitment enablers are returned. 
     *
     *  @param  from a start date 
     *  @param  to an end date 
     *  @return the returned <code> CommitmentEnabler </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.rules.CommitmentEnablerList getCommitmentEnablersOnDate(org.osid.calendaring.DateTime from, 
                                                                                        org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CommitmentEnablerList </code> effective during the 
     *  entire given date range inclusive but not confined to the date range 
     *  evaluated against the given agent. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  commitment enablers or an error results. Otherwise, the returned list 
     *  may contain only those commitment enablers that are accessible through 
     *  this session. 
     *  
     *  In active mode, commitment enablers are returned that are currently 
     *  active in addition to being effective during the given date range. In 
     *  any status mode, active and inactive commitment enablers are returned. 
     *
     *  @param  agentId an agent Id 
     *  @param  from a start date 
     *  @param  to an end date 
     *  @return the returned <code> CommitmentEnabler </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> agent, from, </code> or 
     *          <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.rules.CommitmentEnablerList getCommitmentEnablersOnDateWithAgent(org.osid.id.Id agentId, 
                                                                                                 org.osid.calendaring.DateTime from, 
                                                                                                 org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> CommitmentEnablers. </code> 
     *  
     *  In plenary mode, the returned list contains all known commitment 
     *  enablers or an error results. Otherwise, the returned list may contain 
     *  only those commitment enablers that are accessible through this 
     *  session. 
     *  
     *  In active mode, commitment enablers are returned that are currently 
     *  active. In any status mode, active and inactive commitment enablers 
     *  are returned. 
     *
     *  @return the returned <code> CommitmentEnabler </code> list 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.rules.CommitmentEnablerList getCommitmentEnablers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
