//
// org.osid.calendaring.rules.CommitmentEnablerQuery
//
//     The OSID Java specification for org.osid.calendaring.rules.CommitmentEnablerQuery.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring.rules;


/**
 *  <p>This is the query for searching commitment enablers. Each method match 
 *  specifies an <code> AND </code> term while multiple invocations of the 
 *  same method produce a nested <code> OR. </code> </p>
 */

public interface CommitmentEnablerQuery
    extends org.osid.OsidEnablerQuery {


    /**
     *  Matches enablers mapped to the commitment. 
     *
     *  @param  commitmentId the commitment book <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> commitmentBookId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRuledCommitmentId(org.osid.id.Id commitmentId, 
                                       boolean match);


    /**
     *  Clears the commitment <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRuledCommitmentIdTerms();


    /**
     *  Tests if a <code> CommitmentBookQuery </code> is available. 
     *
     *  @return <code> true </code> if a commitment query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRuledCommitmentQuery();


    /**
     *  Gets the query for a commitment. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the calendar query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommitmentQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommitmentQuery() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.CommitmentQuery getRuledCommitmentQuery();


    /**
     *  Matches enablers mapped to any commitment. 
     *
     *  @param  match <code> true </code> for enablers mapped to any 
     *          commitment, <code> false </code> to match enablers mapped to 
     *          no commitment 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRuledCommitment(boolean match);


    /**
     *  Clears the commitment query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRuledCommitmentTerms();


    /**
     *  Matches enablers mapped to the calendar. 
     *
     *  @param  calendarId the calendar <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCalendarId(org.osid.id.Id calendarId, boolean match);


    /**
     *  Clears the calendar <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCalendarIdTerms();


    /**
     *  Tests if an <code> CalendarQuery </code> is available. 
     *
     *  @return <code> true </code> if an calendar query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCalendarQuery();


    /**
     *  Gets the query for an calendar. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the calendar query 
     *  @throws org.osid.UnimplementedException <code> supportsCalendarQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCalendarQuery() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.CalendarQuery getCalendarQuery();


    /**
     *  Clears the calendar query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCalendarTerms();


    /**
     *  Gets the commitment enabler query record corresponding to the given 
     *  <code> CommitmentEnabler </code> record <code> Type. </code> Multiple 
     *  record retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  commitmentEnablerRecordType a commitment enabler record type 
     *  @return the commitment enabler query record 
     *  @throws org.osid.NullArgumentException <code> 
     *          commitmentEnablerRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(commitmentEnablerRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.rules.records.CommitmentEnablerQueryRecord getCommitmentEnablerQueryRecord(org.osid.type.Type commitmentEnablerRecordType)
        throws org.osid.OperationFailedException;
}
