//
// org.osid.calendaring.rules.OffsetEventEnablerAdminSession
//
//     The OSID Java specification for org.osid.calendaring.rules.OffsetEventEnablerAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring.rules;


/**
 *  <p>This session creates and removes offset event enablers. The data for 
 *  create and update is provided via the <code> OffsetEventEnablerForm. 
 *  </code> </p>
 */

public interface OffsetEventEnablerAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Calendar </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Calendar Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCalendarId();


    /**
     *  Gets the <code> Calendar </code> associated with this session. 
     *
     *  @return the calendar 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Calendar getCalendar()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create offset event enablers. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating an <code> OffsetEventEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer create 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> OffsetEventEnabler </code> 
     *          creation is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateOffsetEventEnabler();


    /**
     *  Tests if this user can create a single <code> OffsetEventEnabler 
     *  </code> using the desired record types. While <code> 
     *  CalendarRulesManager.getOffsetEventEnablerRecordTypes() </code> can be 
     *  used to examine which records are supported, this method tests which 
     *  record(s) are required for creating a specific <code> 
     *  OffsetEventEnabler. </code> Providing an empty array tests if an 
     *  <code> OffsetEventEnabler </code> can be created with no records. 
     *
     *  @param  offsetEventEnablerRecordTypes array of offset event enabler 
     *          record types 
     *  @return <code> true </code> if <code> OffsetEventEnabler </code> 
     *          creation using the specified record <code> Types </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          offsetEventEnablerRecordTypes </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateOffsetEventEnablerWithRecordTypes(org.osid.type.Type[] offsetEventEnablerRecordTypes);


    /**
     *  Gets the offset event enabler form for creating new offset event 
     *  enablers. A new form should be requested for each create transaction. 
     *
     *  @param  offsetEventEnablerRecordTypes array of offset event enabler 
     *          record types 
     *  @return the offset event enabler form 
     *  @throws org.osid.NullArgumentException <code> 
     *          offsetEventEnablerRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.rules.OffsetEventEnablerForm getOffsetEventEnablerFormForCreate(org.osid.type.Type[] offsetEventEnablerRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> OffsetEventEnabler. </code> 
     *
     *  @param  offsetEventEnablerForm the form for this <code> 
     *          OffsetEventEnabler </code> 
     *  @return the new <code> OffsetEventEnabler </code> 
     *  @throws org.osid.IllegalStateException <code> offsetEventEnablerForm 
     *          </code> already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> offsetEventEnablerForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> offsetEventEnablerForm 
     *          </code> did not originate from <code> 
     *          getOffsetEventEnablerFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.rules.OffsetEventEnabler createOffsetEventEnabler(org.osid.calendaring.rules.OffsetEventEnablerForm offsetEventEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update offset event enablers. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating an <code> OffsetEventEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer update 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> OffsetEventEnabler </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateOffsetEventEnablers();


    /**
     *  Gets the offset event enabler form for updating an existing offset 
     *  event enabler. A new offset event enabler form should be requested for 
     *  each update transaction. 
     *
     *  @param  offsetEventEnablerId the <code> Id </code> of the <code> 
     *          OffsetEventEnabler </code> 
     *  @return the offset event enabler form 
     *  @throws org.osid.NotFoundException <code> offsetEventEnablerId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> offsetEventEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.rules.OffsetEventEnablerForm getOffsetEventEnablerFormForUpdate(org.osid.id.Id offsetEventEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing offset event enabler. 
     *
     *  @param  offsetEventEnablerForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> offsetEventEnablerForm 
     *          </code> already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> offsetEventEnablerForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> offsetEventEnablerForm 
     *          </code> did not originate from <code> 
     *          getOffsetEventEnablerFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateOffsetEventEnabler(org.osid.calendaring.rules.OffsetEventEnablerForm offsetEventEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete offset event enablers. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting an <code> OffsetEventEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer delete 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> OffsetEventEnabler </code> 
     *          deletion is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteOffsetEventEnablers();


    /**
     *  Deletes an <code> OffsetEventEnabler. </code> 
     *
     *  @param  offsetEventEnablerId the <code> Id </code> of the <code> 
     *          OffsetEventEnabler </code> to remove 
     *  @throws org.osid.NotFoundException <code> offsetEventEnablerId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> offsetEventEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteOffsetEventEnabler(org.osid.id.Id offsetEventEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for offset 
     *  event enablers. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> OffsetEventEnabler </code> 
     *          aliasing is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageOffsetEventEnablerAliases();


    /**
     *  Adds an <code> Id </code> to an <code> OffsetEventEnabler </code> for 
     *  the purpose of creating compatibility. The primary <code> Id </code> 
     *  of the <code> OffsetEventEnabler </code> is determined by the 
     *  provider. The new <code> Id </code> performs as an alias to the 
     *  primary <code> Id </code> . If the alias is a pointer to another 
     *  offset event enabler. it is reassigned to the given offset event 
     *  enabler <code> Id. </code> 
     *
     *  @param  offsetEventEnablerId the <code> Id </code> of an <code> 
     *          OffsetEventEnabler </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> offsetEventEnablerId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> offsetEventEnablerId 
     *          </code> or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasOffsetEventEnabler(org.osid.id.Id offsetEventEnablerId, 
                                        org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
