//
// org.osid.calendaring.rules.OffsetEventEnablerQuery
//
//     The OSID Java specification for org.osid.calendaring.rules.OffsetEventEnablerQuery.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring.rules;


/**
 *  <p>This is the query for searching offset event enablers. Each method 
 *  match specifies an <code> AND </code> term while multiple invocations of 
 *  the same method produce a nested <code> OR. </code> </p>
 */

public interface OffsetEventEnablerQuery
    extends org.osid.OsidEnablerQuery {


    /**
     *  Matches enablers mapped to the offset event. 
     *
     *  @param  offsetEventId the offset event <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> offsetEventId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRuledOffsetEventId(org.osid.id.Id offsetEventId, 
                                        boolean match);


    /**
     *  Clears the offset event <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRuledOffsetEventIdTerms();


    /**
     *  Tests if an <code> OffsetEventQuery </code> is available. 
     *
     *  @return <code> true </code> if an offset event query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRuledOffsetEventQuery();


    /**
     *  Gets the query for an offset event. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the offset event query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRuledOffsetEventQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRuledOffsetEventQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.OffsetEventQuery getRuledOffsetEventQuery();


    /**
     *  Matches enablers mapped to any offset event. 
     *
     *  @param  match <code> true </code> for enablers mapped to any offset 
     *          event, <code> false </code> to match enablers mapped to no 
     *          offset events 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRuledOffsetEvent(boolean match);


    /**
     *  Clears the offset event query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRuledOffsetEventTerms();


    /**
     *  Matches enablers mapped to the calendar. 
     *
     *  @param  calendarId the calendar <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCalendarId(org.osid.id.Id calendarId, boolean match);


    /**
     *  Clears the calendar <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCalendarIdTerms();


    /**
     *  Tests if a <code> CalendarQuery </code> is available. 
     *
     *  @return <code> true </code> if a calendar query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCalendarQuery();


    /**
     *  Gets the query for a calendar. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the calendar query 
     *  @throws org.osid.UnimplementedException <code> supportsCalendarQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCalendarQuery() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.CalendarQuery getCalendarQuery();


    /**
     *  Clears the calendar query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCalendarTerms();


    /**
     *  Gets the offset event enabler query record corresponding to the given 
     *  <code> OffsetEventEnabler </code> record <code> Type. </code> Multiple 
     *  record retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  offsetEventEnablerRecordType an offset event enabler record 
     *          type 
     *  @return the offset event enabler query record 
     *  @throws org.osid.NullArgumentException <code> 
     *          offsetEventEnablerRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(offsetEventEnablerRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.rules.records.OffsetEventEnablerQueryRecord getOffsetEventEnablerQueryRecord(org.osid.type.Type offsetEventEnablerRecordType)
        throws org.osid.OperationFailedException;
}
