//
// org.osid.calendaring.rules.SupersedingEventEnablerAdminSession
//
//     The OSID Java specification for org.osid.calendaring.rules.SupersedingEventEnablerAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring.rules;


/**
 *  <p>This session creates and removes superseding event enablers. The data 
 *  for create and update is provided via the <code> 
 *  SupersedingEventEnablerForm. </code> </p>
 */

public interface SupersedingEventEnablerAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Calendar </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Calendar Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCalendarId();


    /**
     *  Gets the <code> Calendar </code> associated with this session. 
     *
     *  @return the calendar 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Calendar getCalendar()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create superseding event enablers. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> SupersedingEventEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer create 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> SupersedingEventEnabler </code> 
     *          creation is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateSupersedingEventEnabler();


    /**
     *  Tests if this user can create a single <code> SupersedingEventEnabler 
     *  </code> using the desired record types. While <code> 
     *  CalendaringRulesManager.getSupersedingEventEnablerRecordTypes() 
     *  </code> can be used to examine which records are supported, this 
     *  method tests which record(s) are required for creating a specific 
     *  <code> SupersedingEventEnabler. </code> Providing an empty array tests 
     *  if a <code> SupersedingEventEnabler </code> can be created with no 
     *  records. 
     *
     *  @param  supersedingEventEnablerRecordTypes array of superseding event 
     *          enabler types 
     *  @return <code> true </code> if <code> SupersedingEventEnabler </code> 
     *          creation using the specified record <code> Types </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          supersedingEventEnablerRecordTypes </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateSupersedingEventEnablerWithRecordTypes(org.osid.type.Type[] supersedingEventEnablerRecordTypes);


    /**
     *  Gets the superseding event enabler form for creating new superseding 
     *  event enablers. A new form should be requested for each create 
     *  transaction. 
     *
     *  @param  supersedingEventEnablerRecordTypes array of superseding event 
     *          enabler types 
     *  @return the superseding event enabler form 
     *  @throws org.osid.NullArgumentException <code> 
     *          supersedingEventEnablerRecordTypes </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.rules.SupersedingEventEnablerForm getSupersedingEventEnablerFormForCreate(org.osid.type.Type[] supersedingEventEnablerRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> SupersedingEventEnabler. </code> 
     *
     *  @param  supersedingEventEnablerForm the form for this <code> 
     *          SupersedingEventEnabler </code> 
     *  @return the new <code> SupersedingEventEnabler </code> 
     *  @throws org.osid.IllegalStateException <code> 
     *          supersedingEventEnablerForm </code> already used in a create 
     *          transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> 
     *          supersedingEventEnablerForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> 
     *          supersedingEventEnablerForm </code> did not originate from 
     *          <code> getSupersedingEventFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.rules.SupersedingEventEnabler createSupersedingEventEnabler(org.osid.calendaring.rules.SupersedingEventEnablerForm supersedingEventEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update superseding event enablers. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> SupersedingEventEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer update 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> SupersedingEventEnabler </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateSupersedingEventEnablers();


    /**
     *  Gets the superseding event enabler form for updating an existing 
     *  superseding event enabler. A new superseding event enabler form should 
     *  be requested for each update transaction. 
     *
     *  @param  supersedingEventEnablerId the <code> Id </code> of the <code> 
     *          SupersedingEventEnabler </code> 
     *  @return the superseding event enabler form 
     *  @throws org.osid.NotFoundException <code> supersedingEventEnablerId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          supersedingEventEnablerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.rules.SupersedingEventEnablerForm getSupersedingEventEnablerFormForUpdate(org.osid.id.Id supersedingEventEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing superseding event enabler. 
     *
     *  @param  supersedingEventEnablerForm the form containing the elements 
     *          to be updated 
     *  @throws org.osid.IllegalStateException <code> 
     *          supersedingEventEnablerForm </code> already used in an update 
     *          transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> 
     *          supersedingEventEnablerForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> 
     *          supersedingEventEnablerForm </code> did not originate from 
     *          <code> getSupersedingEventFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateSupersedingEventEnabler(org.osid.calendaring.rules.SupersedingEventEnablerForm supersedingEventEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete superseding event enablers. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> SupersedingEventEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer delete 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> SupersedingEventEnabler </code> 
     *          deletion is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteSupersedingEventEnablers();


    /**
     *  Deletes a <code> SupersedingEventEnabler. </code> 
     *
     *  @param  supersedingEventEnablerId the <code> Id </code> of the <code> 
     *          SupersedingEventEnabler </code> to remove 
     *  @throws org.osid.NotFoundException <code> supersedingEventEnablerId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          supersedingEventEnablerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteSupersedingEventEnabler(org.osid.id.Id supersedingEventEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for 
     *  superseding event enablers. A return of true does not guarantee 
     *  successful authorization. A return of false indicates that it is known 
     *  changing an alias will result in a <code> PERMISSION_DENIED. </code> 
     *  This is intended as a hint to an application that may opt not to offer 
     *  alias operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> SupersedingEventEnabler </code> 
     *          aliasing is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSupersedingEventEnablerAliases();


    /**
     *  Adds an <code> Id </code> to a <code> SupersedingEventEnabler </code> 
     *  for the purpose of creating compatibility. The primary <code> Id 
     *  </code> of the <code> SupersedingEventEnabler </code> is determined by 
     *  the provider. The new <code> Id </code> performs as an alias to the 
     *  primary <code> Id </code> . If the alias is a pointer to another 
     *  superseding event enabler. it is reassigned to the given superseding 
     *  event enabler <code> Id. </code> 
     *
     *  @param  supersedingEventEnablerId the <code> Id </code> of a <code> 
     *          SupersedingEventEnabler </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> supersedingEventEnablerId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          supersedingEventEnablerId </code> or <code> aliasId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasSupersedingEventEnabler(org.osid.id.Id supersedingEventEnablerId, 
                                             org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
