//
// org.osid.calendaring.rules.SupersedingEventEnablerSearchSession
//
//     The OSID Java specification for org.osid.calendaring.rules.SupersedingEventEnablerSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring.rules;


/**
 *  <p>This session provides methods for searching among <code> 
 *  SupersedingEventEnabler </code> objects. The search query is constructed 
 *  using the <code> SupersedingEventEnablerQuery. </code> </p> 
 *  
 *  <p> <code> getSupersedingEventEnablersByQuery() </code> is the basic 
 *  search method and returns a list of <code> SupersedingEventEnablers. 
 *  </code> A more advanced search may be performed with <code> 
 *  getSupersedingEventEnablersBySearch(). </code> It accepts a <code> 
 *  SupersedingEventEnablerSearch </code> in addition to the query for the 
 *  purpose of specifying additional options affecting the entire search, such 
 *  as calendaring. <code> getSupersedingEventEnablersBySearch() </code> 
 *  returns a <code> SupersedingEventEnablerSearchResults </code> that can be 
 *  used to access the resulting <code> SupersedingEventEnablerList </code> or 
 *  be used to perform a search within the result set through <code> 
 *  SupersedingEventEnablerSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated calendar view: searches include superseding event 
 *      enablers in calendars of which this calendar is an ancestor in the 
 *      calendar hierarchy </li> 
 *      <li> isolated calendar view: searches are restricted to superseding 
 *      event enablers in this calendar </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> SupersedingEventEnablers </code> may have a query record 
 *  indicated by their respective record types. The query record is accessed 
 *  via the <code> SupersedingEventEnablerQuery. </code> </p>
 */

public interface SupersedingEventEnablerSearchSession
    extends org.osid.calendaring.rules.SupersedingEventEnablerQuerySession {


    /**
     *  Gets a superseding event enabler search. 
     *
     *  @return the superseding event enabler search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.rules.SupersedingEventEnablerSearch getSupersedingEventEnablerSearch();


    /**
     *  Gets a superseding event enabler search order. The <code> 
     *  SupersedingEventEnablerSearchOrder </code> is supplied to a <code> 
     *  SupersedingEventEnablerSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the superseding event enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.rules.SupersedingEventEnablerSearchOrder getSupersedingEventEnablerSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  supersedingEventEnablerQuery the superseding event enabler 
     *          query 
     *  @param  supersedingEventEnablerSearch the superseding event enabler 
     *          search 
     *  @return the superseding event search results 
     *  @throws org.osid.NullArgumentException <code> 
     *          supersedingEventEnablerQuery </code> or <code> 
     *          supersedingEventEnablerSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> 
     *          supersedingEventEnablerQuery </code> or <code> 
     *          supersedingEventEnablerSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.rules.SupersedingEventEnablerSearchResults getSupersedingEventEnablersBySearch(org.osid.calendaring.rules.SupersedingEventEnablerQuery supersedingEventEnablerQuery, 
                                                                                                               org.osid.calendaring.rules.SupersedingEventEnablerSearch supersedingEventEnablerSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a superseding event enabler query from an inspector. The 
     *  inspector is available from a <code> 
     *  SupersedingEventEnablerSearchResults. </code> 
     *
     *  @param  supersedingEventEnablerQueryInspector a superseding event 
     *          enabler query inspector 
     *  @return the superseding event enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          supersedingEventEnablerQueryInspector </code> is <code> null 
     *          </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supersedingEventEnablerQueryInspector </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.rules.SupersedingEventEnablerQuery getSupersedingEventEnablerQueryFromInspector(org.osid.calendaring.rules.SupersedingEventEnablerQueryInspector supersedingEventEnablerQueryInspector);
}
