//
// org.osid.cataloging.CatalogAssignmentSession
//
//     The OSID Java specification for org.osid.cataloging.CatalogAssignmentSession.
//
// Copyright (C) 2006-2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.cataloging;


/**
 *  <p>This session provides methods to assign OSID <code> Ids </code> to 
 *  <code> Catalogs. </code> An <code> Id </code> may appear in multiple 
 *  <code> Catalogs </code> and removing the last reference to an <code> Id 
 *  </code> is the equivalent of deleting it. Each catalog may have its own 
 *  authorizations as to who is allowed to operate on it. </p>
 */

public interface CatalogAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can perform alter <code> Id/Catalog </code> 
     *  mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known mapping 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer assignment operations to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignCatalogs();


    /**
     *  Adds an <code> Id </code> to a <code> Catalog. </code> 
     *
     *  @param  id an <code> Id </code> 
     *  @param  catalogId the <code> Id </code> of the <code> Catalog </code> 
     *  @throws org.osid.AlreadyExistsException <code> id </code> is already 
     *          mapped to <code> catalogId </code> 
     *  @throws org.osid.NotFoundException <code> id </code> or <code> 
     *          catalogId </code> not found 
     *  @throws org.osid.NullArgumentException <code> id </code> or <code> 
     *          catalogId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignIdToCatalog(org.osid.id.Id id, org.osid.id.Id catalogId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes an <code> Id </code> from a <code> Catalog. </code> 
     *
     *  @param  id an <code> Id </code> 
     *  @param  catalogId the <code> Id </code> of the <code> Catalog </code> 
     *  @throws org.osid.NotFoundException <code> id </code> or <code> 
     *          catalogId </code> not found or <code> id </code> is not mapped 
     *          to <code> catalogId </code> 
     *  @throws org.osid.NullArgumentException <code> id </code> or <code> 
     *          catalogId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignIdFromCatalog(org.osid.id.Id id, 
                                      org.osid.id.Id catalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Moves an <code> Id </code> from one <code> Catalog </code> to another. 
     *  Mappings to other <code> Catalogs </code> are unaffected. 
     *
     *  @param  id the <code> Id </code> 
     *  @param  fromCatalogId the <code> Id </code> of the current <code> 
     *          Catalog </code> 
     *  @param  toCatalogId the <code> Id </code> of the destination <code> 
     *          Catalog </code> 
     *  @throws org.osid.NotFoundException <code> id, fromCatalogId, </code> 
     *          or <code> toCatalogId </code> not found or <code> id </code> 
     *          not mapped to <code> fromCatalogId </code> 
     *  @throws org.osid.NullArgumentException <code> id, fromCatalogId, 
     *          </code> or <code> toCatalogId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void reassignIdToCatalog(org.osid.id.Id id, 
                                    org.osid.id.Id fromCatalogId, 
                                    org.osid.id.Id toCatalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
