//
// org.osid.cataloging.CatalogSearchSession
//
//     The OSID Java specification for org.osid.cataloging.CatalogSearchSession.
//
// Copyright (C) 2006-2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.cataloging;


/**
 *  <p>This session provides methods for searching <code> Catalog </code> 
 *  objects. The search query is constructed using the <code> CatalogQuery 
 *  </code> . The catalog record <code> Type </code> also specifies the record 
 *  for the catalog query. </p> 
 *  
 *  <p> <code> getCatalogsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Catalog </code> elements. A more advanced search 
 *  may be performed with <code> getCatalogsBySearch(). </code> It accepts a 
 *  <code> CatalogSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getCatalogsBySearch() </code> returns a <code> 
 *  CatalogSearchResults </code> that can be used to access the resulting 
 *  <code> CatalogList </code> or be used to perform a search within the 
 *  result set through <code> CatalogSearch. </code> </p> 
 *  
 *  <p> Catalogs may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> CatalogQuery. </code> 
 *  </p>
 */

public interface CatalogSearchSession
    extends org.osid.cataloging.CatalogQuerySession {


    /**
     *  Gets a catalog search. 
     *
     *  @return the catalog search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.cataloging.CatalogSearch getCatalogSearch();


    /**
     *  Gets a subject search order. The <code> CatalogSearchOrder </code> is 
     *  supplied to a <code> CatalogSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the catalog search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.cataloging.CatalogSearchOrder getCatalogSearchOrder();


    /**
     *  Gets the search results matching the given search. 
     *
     *  @param  catalogQuery the catalog query 
     *  @param  catalogSearch the catalog search 
     *  @return the search results 
     *  @throws org.osid.NullArgumentException <code> catalogQuery </code> or 
     *          <code> catalogSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> catalogQuery </code> or 
     *          <code> catalogSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.cataloging.CatalogSearchResults getCatalogsBySearch(org.osid.cataloging.CatalogQuery catalogQuery, 
                                                                        org.osid.cataloging.CatalogSearch catalogSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a catalog query from an inspector. The inspector is available 
     *  from an <code> CatalogSearchResults. </code> 
     *
     *  @param  catalogQueryInspector a catalog query inspector 
     *  @return the catalog query 
     *  @throws org.osid.NullArgumentException <code> catalogQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> catalogQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.cataloging.CatalogQuery getCatalogQueryFromInspector(org.osid.cataloging.CatalogQueryInspector catalogQueryInspector);
}
