//
// org.osid.cataloging.CatalogingProfile
//
//     The OSID Java specification for org.osid.cataloging.CatalogingProfile.
//
// Copyright (C) 2006-2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.cataloging;


/**
 *  <p>The cataloging profile describes the interoperability among cataloging 
 *  services. </p>
 */

public interface CatalogingProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any billing federation is exposed. Federation is exposed when 
     *  a specific catalog may be identified, selected and used to create a 
     *  lookup or admin session. Federation is not exposed when a set of 
     *  catalogs appears as a single catalog. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests for the availability of a cataloging service retrieving <code> 
     *  Id </code> to <code> Catalog </code> mappings. 
     *
     *  @return <code> true </code> if cataloging is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCatalog();


    /**
     *  Tests for the availability of a cataloging service for mapping <code> 
     *  Ids </code> to <code> Catalogs. </code> 
     *
     *  @return <code> true </code> if catalog assignment is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCatalogAssignment();


    /**
     *  Tests for the availability of a cataloging notification service for 
     *  mapping <code> Ids </code> to <code> Catalogs. </code> 
     *
     *  @return <code> true </code> if catalog entry notification is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCatalogEntryNotification();


    /**
     *  Tests for the availability of a catalog lookup service. 
     *
     *  @return <code> true </code> if catalog lookup is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCatalogLookup();


    /**
     *  Tests for the availability of a catalog query service that defines 
     *  more comprehensive queries. 
     *
     *  @return <code> true </code> if catalog query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCatalogQuery();


    /**
     *  Tests for the availability of a catalog search service that defines 
     *  more comprehensive queries. 
     *
     *  @return <code> true </code> if catalog search is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCatalogSearch();


    /**
     *  Tests for the availability of a catalog administration service for the 
     *  addition and deletion of catalogs. 
     *
     *  @return <code> true </code> if catalog administration is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCatalogAdmin();


    /**
     *  Tests for the availability of a catalog notification service. 
     *
     *  @return <code> true </code> if catalog notification is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCatalogNotification();


    /**
     *  Tests for the availability of a catalog hierarchy traversal service. 
     *
     *  @return <code> true </code> if catalog hierarchy traversal is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCatalogHierarchy();


    /**
     *  Tests for the availability of a catalog hierarchy design service. 
     *
     *  @return <code> true </code> if catalog hierarchy design is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsCatalogHierarchyDesign();


    /**
     *  Tests if the cataloging rules sub services is supported. 
     *
     *  @return <code> true </code> if cataloging rules is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCatalogingRules();


    /**
     *  Gets the supported <code> Catalog </code> record types. 
     *
     *  @return a list containing the supported <code> Catalog </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCatalogRecordTypes();


    /**
     *  Tests if the given <code> Catalog </code> record type is supported. 
     *
     *  @param  catalogRecordType a <code> Type </code> indicating a <code> 
     *          Catalog </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> catalogRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCatalogRecordType(org.osid.type.Type catalogRecordType);


    /**
     *  Gets the supported catalog search reciord types. 
     *
     *  @return a list containing the supported search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCatalogSearchRecordTypes();


    /**
     *  Tests if the given catalog search record type is supported. 
     *
     *  @param  catalogSearchRecordType a <code> Type </code> indicating a 
     *          catalog search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> catalogSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCatalogSearchRecordType(org.osid.type.Type catalogSearchRecordType);
}
