//
// org.osid.cataloging.CatalogingProxyManager
//
//     The OSID Java specification for org.osid.cataloging.CatalogingProxyManager.
//
// Copyright (C) 2006-2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.cataloging;


/**
 *  <p>The cataloging manager provides access to cataloging sessions and 
 *  provides interoperability tests for various aspects of this service. 
 *  Methods in this manager support the passing of a <code> Proxy </code> for 
 *  the purposes of passing information from server environments. </p> 
 *  
 *  <ul>
 *      <li> <code> CatalogSession: </code> a session to lookup mappings to 
 *      catalogs </li> 
 *      <li> <code> CatalogAssignmentSession: </code> a session to manage Id 
 *      to Catalog mappings </li> 
 *      <li> <code> CatalogEntryNotificationSession: </code> a session to 
 *      receive notification of changed mappings </li> 
 *      <li> <code> CatalogLookupSession: </code> a session to retrieve 
 *      catalogs </li> 
 *      <li> <code> CatalogQuerySession: </code> a session to query catalogs 
 *      </li> 
 *      <li> <code> CatalogSearchSession: </code> a session to search for 
 *      catalogs </li> 
 *      <li> <code> CatalogAdminSession: </code> a session to create, update 
 *      and delete catalogs </li> 
 *      <li> <code> CatalogNotificationSession: </code> a session to receive 
 *      notifications for changes in catalogs </li> 
 *      <li> <code> CatalogHierarchyTraversalSession: </code> a session to 
 *      traverse hierarchies of catalogs </li> 
 *      <li> <code> CatalogHierarchyDesignSession: </code> a session to manage 
 *      hierarchues of catalogs </li> 
 *  </ul>
 *  
 *  
 *  <p> The cataloging manager also provides a profile for determing the 
 *  supported search types supported by this service. </p>
 */

public interface CatalogingProxyManager
    extends org.osid.OsidProxyManager,
            org.osid.cataloging.CatalogingProfile {


    /**
     *  Gets the catalog session for retrieving <code> Id </code> to <code> 
     *  Catalog </code> mappings. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> CatalogSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsCatalog() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCatalog() </code> is <code> true. </code> 
     */

    public org.osid.cataloging.CatalogSession getCatalogSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the catalog session for mapping <code> Ids </code> to <code> 
     *  Catalogs. </code> 
     *
     *  @param  proxy a proxy 
     *  @return a <code> CatalogAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCatalogAssignment() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCatalogAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.cataloging.CatalogAssignmentSession getCatalogAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the catalog session for mapping <code> Ids </code> to <code> 
     *  Catalogs. </code> 
     *
     *  @param  catalogEntryReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> CatalogEntryNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> catalogEntryReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCatalogEntrytNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCatalogEntryNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.cataloging.CatalogEntryNotificationSession getCatalogEntryNotificationSession(org.osid.cataloging.CatalogEntryReceiver catalogEntryReceiver, 
                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the notification session for subscribing to changes to catalogs 
     *  for the given catalog. 
     *
     *  @param  catalogEntryReceiver the notification callback 
     *  @param  catalogId the <code> Id </code> of the <code> Catalog </code> 
     *  @param  proxy a proxy 
     *  @return a <code> CatalogEntryNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> catalogEntryReceiver, 
     *          catalogId, </code> or <code> proxy </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCatalogEntryNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCatalogEntryNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.cataloging.CatalogEntryNotificationSession getCatalogEntryNotificationSessionForCatalog(org.osid.cataloging.CatalogEntryReceiver catalogEntryReceiver, 
                                                                                                            org.osid.id.Id catalogId, 
                                                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the catalog lookup session. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> CatalogLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsCatalogLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCatalogLookup() </code> is <code> true. </code> 
     */

    public org.osid.cataloging.CatalogLookupSession getCatalogLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the catalog query session. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> CatalogQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsCatalogQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCatalogQuery() </code> is <code> true. </code> 
     */

    public org.osid.cataloging.CatalogQuerySession getCatalogQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the catalog search session. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> CatalogSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsCatalogSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCatalogSearch() </code> is <code> true. </code> 
     */

    public org.osid.cataloging.CatalogSearchSession getCatalogSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the catalog administrative session for creating, updating and 
     *  deleting catalogs. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> CatalogAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsCatalogAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCatalogAdmin() </code> is <code> true. </code> 
     */

    public org.osid.cataloging.CatalogAdminSession getCatalogAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the notification session for subscribing to changes to catalogs. 
     *
     *  @param  catalogReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> CatalogNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> catalogReceiver </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCatalogNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCatalogNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.cataloging.CatalogNotificationSession getCatalogNotificationSession(org.osid.cataloging.CatalogReceiver catalogReceiver, 
                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the catalog hierarchy traversal session. 
     *
     *  @param  proxy proxy 
     *  @return a <code> CatalogHierarchySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is null 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCatalogHierarchy() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCatalogHierarchy() </code> is <code> true. </code> 
     */

    public org.osid.cataloging.CatalogHierarchySession getCatalogHierarchySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the catalog hierarchy design session. 
     *
     *  @param  proxy proxy 
     *  @return a <code> CatalogHierarchyDesignSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is null 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCatalogHierarchyDesign() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCatalogHierarchyDesign() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.cataloging.CatalogHierarchyDesignSession getCatalogHierarchyDesignSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the cataloging rules proxy manager. 
     *
     *  @return a <code> CatalogingRulesManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCatalogingRules() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCatalogingRules() </code> is <code> true. </code> 
     */

    public org.osid.cataloging.rules.CatalogingRulesProxyManager getCatalogingRulesProxyManager()
        throws org.osid.OperationFailedException;
}
