//
// org.osid.cataloging.rules.CatalogEnablerCatalogAssignmentSession
//
//     The OSID Java specification for org.osid.cataloging.rules.CatalogEnablerCatalogAssignmentSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.cataloging.rules;


/**
 *  <p>This session provides methods to re-assign <code> CatalogEnabler 
 *  </code> to <code> Catalog </code> mappings. A <code> CatalogEnabler 
 *  </code> may appear in multiple <code> Catalog </code> objects and removing 
 *  the last reference to a <code> CatalogEnabler </code> is the equivalent of 
 *  deleting it. Each <code> Catalog </code> may have its own authorizations 
 *  governing who is allowed to operate on it. </p> 
 *  
 *  <p> Adding a reference of a <code> CatalogEnabler </code> to another 
 *  <code> Catalog </code> is not a copy operation (eg: does not change its 
 *  <code> Id </code> ). </p>
 */

public interface CatalogEnablerCatalogAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter catalog enabler/catalog mappings. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignCatalogEnablers();


    /**
     *  Tests if this user can alter catalog enabler/catalog mappings. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @param  catalogId the <code> Id </code> of the <code> Catalog </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> catalogId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignCatalogEnablersToCatalog(org.osid.id.Id catalogId);


    /**
     *  Gets a list of catalogs including and under the given catalog node in 
     *  which any catalog enabler can be assigned. 
     *
     *  @param  catalogId the <code> Id </code> of the <code> Catalog </code> 
     *  @return list of assignable catalog <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> catalogId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableCatalogIds(org.osid.id.Id catalogId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of catalogs including and under the given catalog node in 
     *  which a specific catalog enabler can be assigned. 
     *
     *  @param  catalogId the <code> Id </code> of the <code> Catalog </code> 
     *  @param  catalogEnablerId the <code> Id </code> of the <code> 
     *          CatalogEnabler </code> 
     *  @return list of assignable catalog <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> catalogId </code> or 
     *          <code> catalogEnablerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableCatalogIdsForCatalogEnabler(org.osid.id.Id catalogId, 
                                                                       org.osid.id.Id catalogEnablerId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> CatalogEnabler </code> to a <code> Catalog. 
     *  </code> 
     *
     *  @param  catalogEnablerId the <code> Id </code> of the <code> 
     *          CatalogEnabler </code> 
     *  @param  catalogId the <code> Id </code> of the <code> Catalog </code> 
     *  @throws org.osid.AlreadyExistsException <code> catalogEnablerId 
     *          </code> is already assigned to <code> catalogId </code> 
     *  @throws org.osid.NotFoundException <code> catalogEnablerId </code> or 
     *          <code> catalogId </code> not found 
     *  @throws org.osid.NullArgumentException <code> catalogEnablerId </code> 
     *          or <code> catalogId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignCatalogEnablerToCatalog(org.osid.id.Id catalogEnablerId, 
                                              org.osid.id.Id catalogId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> CatalogEnabler </code> from a <code> Catalog. </code> 
     *
     *  @param  catalogEnablerId the <code> Id </code> of the <code> 
     *          CatalogEnabler </code> 
     *  @param  catalogId the <code> Id </code> of the <code> Catalog </code> 
     *  @throws org.osid.NotFoundException <code> catalogEnablerId </code> or 
     *          <code> catalogId </code> not found or <code> catalogEnablerId 
     *          </code> is not assigned to <code> catalogId </code> 
     *  @throws org.osid.NullArgumentException <code> catalogEnablerId </code> 
     *          or <code> catalogId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignCatalogEnablerFromCatalog(org.osid.id.Id catalogEnablerId, 
                                                  org.osid.id.Id catalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Moves a <code> CatalogEnabler </code> from one <code> Catalog </code> 
     *  to another. Mappings to other <code> Catalogs </code> are unaffected. 
     *
     *  @param  catalogEnablerId the <code> Id </code> of the <code> 
     *          CatalogEnabler </code> 
     *  @param  fromCatalogId the <code> Id </code> of the current <code> 
     *          Catalog </code> 
     *  @param  toCatalogId the <code> Id </code> of the destination <code> 
     *          Catalog </code> 
     *  @throws org.osid.NotFoundException <code> catalogEnablerId, 
     *          fromCatalogEnablerId, </code> or <code> toCatalogEnablerId 
     *          </code> not found or <code> catalogEnablerId </code> not 
     *          mapped to <code> fromCatalogId </code> 
     *  @throws org.osid.NullArgumentException <code> catalogEnablerId, 
     *          fromCatalogId, </code> or <code> toCatalogId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void reassignCatalogEnablerToCatalog(org.osid.id.Id catalogEnablerId, 
                                                org.osid.id.Id fromCatalogId, 
                                                org.osid.id.Id toCatalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
