//
// org.osid.cataloging.rules.CatalogEnablerRuleApplicationSession
//
//     The OSID Java specification for org.osid.cataloging.rules.CatalogEnablerRuleApplicationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.cataloging.rules;


/**
 *  <p>This session provides methods to apply <code> CatalogEnablers </code> 
 *  to <code> Catalogs. </code> A <code> Catalog </code> with multiple <code> 
 *  CatalogEnablers </code> means any positive rule evaluation across the 
 *  enablers result in an enabled <code> Catalog. </code> </p>
 */

public interface CatalogEnablerRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Catalog </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Catalog Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCatalogId();


    /**
     *  Gets the <code> Catalog </code> associated with this session. 
     *
     *  @return the catalog 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.cataloging.Catalog getCatalog()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter catalog enabler/catalog mappings. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignCatalogEnablers();


    /**
     *  Adds an existing <code> CatalogEnabler </code> to a <code> Catalog. 
     *  </code> 
     *
     *  @param  catalogEnablerId the <code> Id </code> of the <code> 
     *          CatalogEnabler </code> 
     *  @param  catalogId the <code> Id </code> of the <code> Catalog </code> 
     *  @throws org.osid.AlreadyExistsException <code> catalogEnablerId 
     *          </code> is already applied to <code> catalogId </code> 
     *  @throws org.osid.NotFoundException <code> catalogEnablerId </code> or 
     *          <code> catalogId </code> not found 
     *  @throws org.osid.NullArgumentException <code> catalogEnablerId </code> 
     *          or <code> catalogId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignCatalogEnablerToCatalog(org.osid.id.Id catalogEnablerId, 
                                              org.osid.id.Id catalogId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> CatalogEnabler </code> from a <code> Catalog. </code> 
     *
     *  @param  catalogEnablerId the <code> Id </code> of the <code> 
     *          CatalogEnabler </code> 
     *  @param  catalogId the <code> Id </code> of the <code> Catalog </code> 
     *  @throws org.osid.NotFoundException <code> catalogEnablerId </code> or 
     *          <code> catalogId </code> not found or <code> catalogEnablerId 
     *          </code> is not applied to <code> catalogId </code> 
     *  @throws org.osid.NullArgumentException <code> catalogEnablerId </code> 
     *          or <code> catalogId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignCatalogEnablerFromCatalog(org.osid.id.Id catalogEnablerId, 
                                                  org.osid.id.Id catalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> CatalogEnablers. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known sequencing operations will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> CatalogEnabler </code> ordering 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceCatalogEnablers();


    /**
     *  Reorders catalog enablers for a catalog by moving the specified 
     *  catalog enabler in front of a reference catalog enabler. 
     *
     *  @param  catalogEnablerId the <code> Id </code> of a <code> 
     *          CatalogEnabler </code> 
     *  @param  catalogId the <code> Id </code> of a <code> Catalog </code> 
     *  @param  referenceId the reference catalog enabler <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> catalogEnablerId, catalogId, 
     *          </code> or <code> referenceId </code> not found or, <code> 
     *          catalogEnablerId </code> or <code> referenceId </code> not 
     *          related to <code> catalogId </code> 
     *  @throws org.osid.NullArgumentException <code> catalogEnablerId, 
     *          catalogId </code> or <code> referenceId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveCatalogEnablerAhead(org.osid.id.Id catalogEnablerId, 
                                        org.osid.id.Id catalogId, 
                                        org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders catalog enablers for a catalog by moving the specified 
     *  catalog enabler behind a reference catalog enabler. 
     *
     *  @param  catalogEnablerId the <code> Id </code> of a <code> 
     *          CatalogEnabler </code> 
     *  @param  catalogId the <code> Id </code> of a <code> Catalog </code> 
     *  @param  referenceId the reference catalog enabler <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> catalogEnablerId, catalogId, 
     *          </code> or <code> referenceId </code> not found or, <code> 
     *          catalogEnablerId </code> or <code> referenceId </code> not 
     *          related to <code> catalogId </code> 
     *  @throws org.osid.NullArgumentException <code> catalogEnablerId, 
     *          catalogId </code> or <code> referenceId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveCatalogEnablerBehind(org.osid.id.Id catalogEnablerId, 
                                         org.osid.id.Id catalogId, 
                                         org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of catalog enablers for a catalog. 
     *
     *  @param  catalogEnablerId the <code> Ids </code> for a set of <code> 
     *          CatalogEnablers </code> 
     *  @param  catalogId the <code> Id </code> of a <code> Catalog </code> 
     *  @throws org.osid.NotFoundException <code> catalogId </code> not found 
     *          or, a <code> catalogEnablerId </code> not related to <code> 
     *          catalogId </code> 
     *  @throws org.osid.NullArgumentException <code> catalogEnablerIds 
     *          </code> or <code> catalogId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderCatalogEnablers(org.osid.id.Id[] catalogEnablerId, 
                                     org.osid.id.Id catalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
