//
// org.osid.cataloging.rules.CatalogEnablerRuleLookupSession
//
//     The OSID Java specification for org.osid.cataloging.rules.CatalogEnablerRuleLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.cataloging.rules;


/**
 *  <p>This session provides methods to retrieve <code> CatalogEnabler </code> 
 *  to <code> Catalog </code> mappings. A <code> Catalog </code> with multiple 
 *  <code> CatalogEnablers </code> means any positive rule evaluation across 
 *  the enablers result in an enabled <code> Catalog. </code> </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated catalog view: All methods in this session operate, 
 *      retrieve and pertain catalog enablers defined explicitly in the 
 *      current catalog </li> 
 *      <li> federated catalog view: All methods in this session operate, 
 *      retrieve and pertain to all catalog enablers defined in this catalog 
 *      and any other catalog enablers implicitly available in this catalog 
 *      through catalog inheritence. </li> 
 *  </ul>
 *  
 */

public interface CatalogEnablerRuleLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Catalog </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Catalog Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCatalogId();


    /**
     *  Gets the <code> Catalog </code> associated with this session. 
     *
     *  @return the catalog 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.cataloging.Catalog getCatalog()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform lookups of catalog enabler/catalog 
     *  mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known lookup 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if looking up mappings is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupCatalogEnablerRules();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeCatalogEnablerRuleView();


    /**
     *  A complete view of the <code> CatalogEnabler </code> and <code> 
     *  Catalog </code> returns is desired. Methods will return what is 
     *  requested or result in an error. This view is used when greater 
     *  precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryCatalogEnablerRuleView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include catalog enablers in catalogs which are children of this 
     *  catalog in the catalog hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCatalogView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this catalog only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCatalogView();


    /**
     *  Gets the <code> CatalogEnabler Id </code> associated with a <code> 
     *  Catalog. </code> 
     *
     *  @param  catalogId <code> Id </code> of the <code> Catalog </code> 
     *  @return the catalog enabler <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> catalogId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> catalogId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getCatalogEnablerIdsForCatalog(org.osid.id.Id catalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> CatalogEnabler </code> associated with a <code> 
     *  Catalog. </code> 
     *
     *  @param  catalogId <code> Id </code> of the <code> Catalog </code> 
     *  @return the catalog enablers 
     *  @throws org.osid.NotFoundException <code> catalogId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> catalogId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.cataloging.rules.CatalogEnablerList getCatalogEnablersForCatalog(org.osid.id.Id catalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Catalog </code> <code> Ids </code> mapped to a <code> 
     *  CatalogEnabler. </code> 
     *
     *  @param  catalogEnablerId <code> Id </code> of a <code> CatalogEnabler 
     *          </code> 
     *  @return list of catalog <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> catalogEnablerId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> catalogEnablerId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getCatalogIdsForCatalogEnabler(org.osid.id.Id catalogEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Catalogs </code> mapped to a <code> CatalogEnabler. 
     *  </code> 
     *
     *  @param  catalogEnablerId <code> Id </code> of a <code> CatalogEnabler 
     *          </code> 
     *  @return list of catalogs 
     *  @throws org.osid.NotFoundException <code> catalogEnablerId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> catalogEnablerId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.cataloging.CatalogList getCatalogsForCatalogEnabler(org.osid.id.Id catalogEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
