//
// org.osid.cataloging.rules.CatalogEnablerSearchSession
//
//     The OSID Java specification for org.osid.cataloging.rules.CatalogEnablerSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.cataloging.rules;


/**
 *  <p>This session provides methods for searching among <code> CatalogEnabler 
 *  </code> objects. The search query is constructed using the <code> 
 *  CatalogEnableryQuery. </code> </p> 
 *  
 *  <p> <code> getCatalogEnablersByQuery() </code> is the basic search method 
 *  and returns a list of <code> CatalogEnablers. </code> A more advanced 
 *  search may be performed with <code> getCatalogEnablersBySearch(). </code> 
 *  It accepts a <code> CatalogEnablerSearch </code> in addition to the query 
 *  for the purpose of specifying additional options affecting the entire 
 *  search, such as ordering. <code> getCatalogEnablersBySearch() </code> 
 *  returns a <code> CatalogEnablerSearchResults </code> that can be used to 
 *  access the resulting <code> CatalogEnablerList </code> or be used to 
 *  perform a search within the result set through <code> 
 *  CatalogEnablerSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated catalog view: searches include catalog enablers in 
 *      catalogs of which this catalog is an ancestor in the catalog hierarchy 
 *      </li> 
 *      <li> isolated catalog view: searches are restricted to catalog 
 *      enablers in this catalog </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> CatalogEnablers </code> may have a query record indicated by 
 *  their respective record types. The query record is accessed via the <code> 
 *  CatalogEnablerQuery. </code> </p>
 */

public interface CatalogEnablerSearchSession
    extends org.osid.cataloging.rules.CatalogEnablerQuerySession {


    /**
     *  Gets a catalog enabler search. 
     *
     *  @return the catalog enabler search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.cataloging.rules.CatalogEnablerSearch getCatalogEnablerSearch();


    /**
     *  Gets a catalog enabler search order. The <code> 
     *  CatalogEnablerSearchOrder </code> is supplied to a <code> 
     *  CatalogEnablerSearch </code> to specify the ordering of results. 
     *
     *  @return the catalog enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.cataloging.rules.CatalogEnablerSearchOrder getCatalogEnablerSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  catalogEnablerQuery the catalog enabler query 
     *  @param  catalogEnablerSearch the catalog enabler search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> catalogEnablerQuery 
     *          </code> or <code> catalogEnablerSearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> catalogEnablerQuery 
     *          </code> or <code> catalogEnablerSearch </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.cataloging.rules.CatalogEnablerSearchResults getCatalogEnablersBySearch(org.osid.cataloging.rules.CatalogEnablerQuery catalogEnablerQuery, 
                                                                                            org.osid.cataloging.rules.CatalogEnablerSearch catalogEnablerSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a catalog enabler query from an inspector. The inspector is 
     *  available from a <code> CatalogEnablerSearchResults. </code> 
     *
     *  @param  catalogEnablerQueryInspector a catalog enabler query inspector 
     *  @return the catalog enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          catalogEnablerQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          catalogEnablerQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.cataloging.rules.CatalogEnablerQuery getCatalogEnablerQueryFromInspector(org.osid.cataloging.rules.CatalogEnablerQueryInspector catalogEnablerQueryInspector);
}
