//
// org.osid.checklist.ChecklistManager
//
//     The OSID Java specification for org.osid.checklist.ChecklistManager.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.checklist;


/**
 *  <p>The checklist manager provides access to checklist sessions and 
 *  provides interoperability tests for various aspects of this service. The 
 *  sessions included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> TodoLookupSession: </code> a session to lookup todos </li> 
 *      <li> <code> TodoQuerySession: </code> a session to query todos </li> 
 *      <li> <code> TodoSearchSession: </code> a session to search todos </li> 
 *      <li> <code> TodoAdminSession: </code> a session to manage todos </li> 
 *      <li> <code> TodoNotificationSession: </code> a session to subscribe to 
 *      notifications of todo changes </li> 
 *      <li> <code> TodoHierarchySession: </code> a session to traverse a 
 *      hierarchy of todos </li> 
 *      <li> <code> TodoHierarchyDesignSession: </code> a session to manage a 
 *      todo hierarchy </li> 
 *      <li> <code> TodoChecklistSession: </code> a session for looking up 
 *      todo and checklist mappings </li> 
 *      <li> <code> TodoChecklistAssignmentSession: </code> a session for 
 *      managing todo and checklist mappings </li> 
 *      <li> <code> TodoSmartChecklistSession: </code> a session to manage 
 *      dynamic todo checklists </li> 
 *      <li> <code> ChecklistLookupSession: </code> a session to retrieve 
 *      checklists </li> 
 *      <li> <code> ChecklistQuerySession: </code> a session to query 
 *      checklists </li> 
 *      <li> <code> ChecklistSearchSession: </code> a session to search for 
 *      checklists </li> 
 *      <li> <code> ChecklistAdminSession: </code> a session to create, update 
 *      and delete checklists </li> 
 *      <li> <code> ChecklistNotificationSession: </code> a session to receive 
 *      notifications for changes in checklists </li> 
 *      <li> <code> ChecklistHierarchyTraversalSession: </code> a session to 
 *      traverse hierarchies of checklists </li> 
 *      <li> <code> ChecklistHierarchyDesignSession: </code> a session to 
 *      manage hierarchies of checklists </li> 
 *  </ul>
 *  
 *  
 *  <p> The todoing manager also provides a profile for determing the 
 *  supported search types supported by this service. </p>
 */

public interface ChecklistManager
    extends org.osid.OsidManager,
            org.osid.checklist.ChecklistProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the todo lookup 
     *  service. 
     *
     *  @return a <code> TodoLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsTodoLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTodoLookup() </code> is <code> true. </code> 
     */

    public org.osid.checklist.TodoLookupSession getTodoLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the todo lookup 
     *  service for the given checklist. 
     *
     *  @param  checklistId the <code> Id </code> of the <code> Checklist 
     *          </code> 
     *  @return a <code> TodoLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Checklist </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> checklistId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsTodoLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTodoLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.checklist.TodoLookupSession getTodoLookupSessionForChecklist(org.osid.id.Id checklistId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the todo query 
     *  service. 
     *
     *  @return a <code> TodoQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsTodoQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTodoQuery() </code> is <code> true. </code> 
     */

    public org.osid.checklist.TodoQuerySession getTodoQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the todo query 
     *  service for the given checklist. 
     *
     *  @param  checklistId the <code> Id </code> of the <code> Checklist 
     *          </code> 
     *  @return a <code> TodoQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Checklist </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> checklistId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsTodoQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTodoQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.checklist.TodoQuerySession getTodoQuerySessionForChecklist(org.osid.id.Id checklistId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the todo search 
     *  service. 
     *
     *  @return a <code> TodoSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsTodoSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTodoSearch() </code> is <code> true. </code> 
     */

    public org.osid.checklist.TodoSearchSession getTodoSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the todo search 
     *  service for the given checklist. 
     *
     *  @param  checklistId the <code> Id </code> of the <code> Checklist 
     *          </code> 
     *  @return a <code> TodoSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Checklist </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> checklistId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsTodoSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTodoSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.checklist.TodoSearchSession getTodoSearchSessionForChecklist(org.osid.id.Id checklistId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the todo 
     *  administration service. 
     *
     *  @return a <code> TodoAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsTodoAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTodoAdmin() </code> is <code> true. </code> 
     */

    public org.osid.checklist.TodoAdminSession getTodoAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the todo 
     *  administration service for the given checklist. 
     *
     *  @param  checklistId the <code> Id </code> of the <code> Checklist 
     *          </code> 
     *  @return a <code> TodoAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Checklist </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> checklistId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsTodoAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTodoAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.checklist.TodoAdminSession getTodoAdminSessionForChecklist(org.osid.id.Id checklistId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the todo 
     *  notification service. 
     *
     *  @param  todoReceiver the receiver 
     *  @return a <code> TodoNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> todoReceiver </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTodoNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTodoNotification() </code> is <code> true. </code> 
     */

    public org.osid.checklist.TodoNotificationSession getTodoNotificationSession(org.osid.checklist.TodoReceiver todoReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the todo 
     *  notification service for the given checklist. 
     *
     *  @param  todoReceiver the receiver 
     *  @param  checklistId the <code> Id </code> of the <code> Checklist 
     *          </code> 
     *  @return a <code> TodoNotificationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Checklist </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> todoReceiver </code> or 
     *          <code> checklistId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTodoNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTodoNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.checklist.TodoNotificationSession getTodoNotificationSessionForChecklist(org.osid.checklist.TodoReceiver todoReceiver, 
                                                                                             org.osid.id.Id checklistId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the todo hierarchy traversal session. 
     *
     *  @return <code> a TodoHierarchySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsTodoHierarchy() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTodoHierarchy() </code> is <code> true. </code> 
     */

    public org.osid.checklist.TodoHierarchySession getTodoHierarchySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the todo hierarchy traversal session for the given checklist. 
     *
     *  @param  checklistId the <code> Id </code> of the <code> Checklist 
     *          </code> 
     *  @return <code> a TodoHierarchySession </code> 
     *  @throws org.osid.NotFoundException no checklist found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> checklistId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsTodoHierarchy() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTodoHierarchy() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.checklist.TodoHierarchySession getTodoHierarchySessionForChecklist(org.osid.id.Id checklistId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the todo hierarchy design session. 
     *
     *  @return a <code> TodoHierarchyDesignSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTodoHierarchyDesign() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTodoHierarchyDesign() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.checklist.TodoHierarchyDesignSession getTodoHierarchyDesignSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the todo hierarchy design session for the given checklist. 
     *
     *  @param  businessId the <code> Id </code> of the <code> Checklist 
     *          </code> 
     *  @return a <code> TodoHierarchyDesignSession </code> 
     *  @throws org.osid.NotFoundException no checklist found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> checklistId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTodoHierarchyDesign() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTodoHierarchyDesign() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.checklist.TodoHierarchyDesignSession getTodoHierarchyDesignSessionForChecklist(org.osid.id.Id businessId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving todo to checklist mappings. 
     *
     *  @return a <code> TodoChecklistSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsTodoChecklist() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTodoChecklist() </code> is <code> true. </code> 
     */

    public org.osid.checklist.TodoChecklistSession getTodoChecklistSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning todo to checklist mappings. 
     *
     *  @return a <code> TodoChecklistAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTodoChecklistAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTodoChecklistAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.checklist.TodoChecklistAssignmentSession getTodoChecklistAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session associated with the todo smart checklist for the 
     *  given checklist. 
     *
     *  @param  checklistId the <code> Id </code> of the checklist 
     *  @return a <code> TodoSmartChecklistSession </code> 
     *  @throws org.osid.NotFoundException <code> checklistId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> checklistId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTodoSmartChecklist() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTodoSmartChecklist() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.checklist.TodoSmartChecklistSession getTodoSmartChecklistSession(org.osid.id.Id checklistId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the checklist 
     *  lookup service. 
     *
     *  @return a <code> ChecklistLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsChecklistLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsChecklistLookup() </code> is <code> true. </code> 
     */

    public org.osid.checklist.ChecklistLookupSession getChecklistLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the checklist 
     *  query service. 
     *
     *  @return a <code> ChecklistQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsChecklistQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsChecklistQuery() </code> is <code> true. </code> 
     */

    public org.osid.checklist.ChecklistQuerySession getChecklistQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the checklist 
     *  search service. 
     *
     *  @return a <code> ChecklistSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsChecklistSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsChecklistSearch() </code> is <code> true. </code> 
     */

    public org.osid.checklist.ChecklistSearchSession getChecklistSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the checklist 
     *  administrative service. 
     *
     *  @return a <code> ChecklistAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsChecklistAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsChecklistAdmin() </code> is <code> true. </code> 
     */

    public org.osid.checklist.ChecklistAdminSession getChecklistAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the checklist 
     *  notification service. 
     *
     *  @param  checklistReceiver the receiver 
     *  @return a <code> ChecklistNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> checklistReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsChecklistNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsChecklistNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.checklist.ChecklistNotificationSession getChecklistNotificationSession(org.osid.checklist.ChecklistReceiver checklistReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the checklist 
     *  hierarchy service. 
     *
     *  @return a <code> ChecklistHierarchySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsChecklistHierarchy() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsChecklistHierarchy() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.checklist.ChecklistHierarchySession getChecklistHierarchySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the checklist 
     *  hierarchy design service. 
     *
     *  @return a <code> ChecklistHierarchyDesignSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsChecklistHierarchyDesign() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsChecklistHierarchyDesign() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.checklist.ChecklistHierarchyDesignSession getChecklistHierarchyDesignSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a <code> ChecklistBatchManager. </code> 
     *
     *  @return a <code> ChecklistBatchManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsChecklistBatch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsChecklistBatch() </code> is <code> true. </code> 
     */

    public org.osid.checklist.batch.ChecklistBatchManager getChecklistBatchManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a <code> ChecklistMasonManager. </code> 
     *
     *  @return a <code> ChecklistMasonManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsChecklistMason() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsChecklistMason() </code> is <code> true. </code> 
     */

    public org.osid.checklist.mason.ChecklistMasonManager getChecklistMasonManager()
        throws org.osid.OperationFailedException;
}
