//
// org.osid.checklist.ChecklistProfile
//
//     The OSID Java specification for org.osid.checklist.ChecklistProfile.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.checklist;


/**
 *  <p>The todoing profile describes the interoperability among todoing 
 *  services. </p>
 */

public interface ChecklistProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any checklist federation is exposed. Federation is exposed 
     *  when a specific checklist may be identified, selected and used to 
     *  create a lookup or admin session. Federation is not exposed when a set 
     *  of checklists appears as a single checklist. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests for the availability of a todo lookup service. 
     *
     *  @return <code> true </code> if todo lookup is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTodoLookup();


    /**
     *  Tests if querying todos is available. 
     *
     *  @return <code> true </code> if todo query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTodoQuery();


    /**
     *  Tests if searching for todos is available. 
     *
     *  @return <code> true </code> if todo search is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTodoSearch();


    /**
     *  Tests if managing todos is available. 
     *
     *  @return <code> true </code> if todo admin is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTodoAdmin();


    /**
     *  Tests if todo notification is available. 
     *
     *  @return <code> true </code> if todo notification is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTodoNotification();


    /**
     *  Tests if todo <code> </code> hierarchy traversal service is supported. 
     *
     *  @return <code> true </code> if todo hierarchy is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTodoHierarchy();


    /**
     *  Tests if a todo <code> </code> hierarchy design service is supported. 
     *
     *  @return <code> true </code> if todo hierarchy design is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTodoHierarchyDesign();


    /**
     *  Tests if a todo to checklist lookup session is available. 
     *
     *  @return <code> true </code> if todo checklist lookup session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTodoChecklist();


    /**
     *  Tests if a todo to checklist assignment session is available. 
     *
     *  @return <code> true </code> if todo checklist assignment is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTodoChecklistAssignment();


    /**
     *  Tests if a todo smart checklisting session is available. 
     *
     *  @return <code> true </code> if todo smart checklisting is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTodoSmartChecklist();


    /**
     *  Tests for the availability of an checklist lookup service. 
     *
     *  @return <code> true </code> if checklist lookup is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsChecklistLookup();


    /**
     *  Tests if querying checklists is available. 
     *
     *  @return <code> true </code> if checklist query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsChecklistQuery();


    /**
     *  Tests if searching for checklists is available. 
     *
     *  @return <code> true </code> if checklist search is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsChecklistSearch();


    /**
     *  Tests for the availability of a checklist administrative service for 
     *  creating and deleting checklists. 
     *
     *  @return <code> true </code> if checklist administration is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsChecklistAdmin();


    /**
     *  Tests for the availability of a checklist notification service. 
     *
     *  @return <code> true </code> if checklist notification is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsChecklistNotification();


    /**
     *  Tests for the availability of a checklist hierarchy traversal service. 
     *
     *  @return <code> true </code> if checklist hierarchy traversal is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsChecklistHierarchy();


    /**
     *  Tests for the availability of a checklist hierarchy design service. 
     *
     *  @return <code> true </code> if checklist hierarchy design is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsChecklistHierarchyDesign();


    /**
     *  Tests for the availability of a checklist batch service. 
     *
     *  @return <code> true </code> if checklist batch service is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsChecklistBatch();


    /**
     *  Tests for the availability of a checklist mason service. 
     *
     *  @return <code> true </code> if checklist mason service is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsChecklistMason();


    /**
     *  Gets the supported <code> Todo </code> record types. 
     *
     *  @return a list containing the supported todo record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getTodoRecordTypes();


    /**
     *  Tests if the given <code> Todo </code> record type is supported. 
     *
     *  @param  todoRecordType a <code> Type </code> indicating a <code> Todo 
     *          </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> todoRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTodoRecordType(org.osid.type.Type todoRecordType);


    /**
     *  Gets the supported todo search record types. 
     *
     *  @return a list containing the supported todo search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getTodoSearchRecordTypes();


    /**
     *  Tests if the given todo search record type is supported. 
     *
     *  @param  todoSearchRecordType a <code> Type </code> indicating a todo 
     *          record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> todoSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTodoSearchRecordType(org.osid.type.Type todoSearchRecordType);


    /**
     *  Gets the supported <code> Checklist </code> record types. 
     *
     *  @return a list containing the supported checklist record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getChecklistRecordTypes();


    /**
     *  Tests if the given <code> Checklist </code> record type is supported. 
     *
     *  @param  checklistRecordType a <code> Type </code> indicating a <code> 
     *          Checklist </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> checklistRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsChecklistRecordType(org.osid.type.Type checklistRecordType);


    /**
     *  Gets the supported checklist search record types. 
     *
     *  @return a list containing the supported checklist search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getChecklistSearchRecordTypes();


    /**
     *  Tests if the given checklist search record type is supported. 
     *
     *  @param  checklistSearchRecordType a <code> Type </code> indicating a 
     *          checklist record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          checklistSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsChecklistSearchRecordType(org.osid.type.Type checklistSearchRecordType);


    /**
     *  Gets the supported priority types. 
     *
     *  @return a list containing the supported priority types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getPriorityTypes();


    /**
     *  Tests if the given priority type is supported. 
     *
     *  @param  priorityType a <code> Type </code> indicating a priority type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> priorityType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPriorityType(org.osid.type.Type priorityType);
}
