//
// org.osid.checklist.TodoForm
//
//     The OSID Java specification for org.osid.checklist.TodoForm.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.checklist;


/**
 *  <p>This is the form for creating and updating <code> Todo </code> objects. 
 *  Like all <code> OsidForm </code> objects, various data elements may be set 
 *  here for use in the create and update methods in the <code> 
 *  TodoAdminSession. </code> For each data element that may be set, metadata 
 *  may be examined to provide display hints or data constraints. </p>
 */

public interface TodoForm
    extends org.osid.OsidObjectForm,
            org.osid.OsidContainableForm,
            org.osid.OsidTemporalForm,
            org.osid.OsidFederateableForm {


    /**
     *  Gets the metadata for the completed status. 
     *
     *  @return metadata for the completed status 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getCompleteMetadata();


    /**
     *  Sets the completed status. 
     *
     *  @param  complete the new completed status 
     *  @throws org.osid.InvalidArgumentException <code> complete </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setComplete(boolean complete);


    /**
     *  Clears the complete status. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearComplete();


    /**
     *  Gets the metadata for the priority. 
     *
     *  @return metadata for the priority 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getPriorityMetadata();


    /**
     *  Sets the priority. 
     *
     *  @param  priorityType the new priority 
     *  @throws org.osid.InvalidArgumentException <code> priorityType </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> priorityType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setPriority(org.osid.type.Type priorityType);


    /**
     *  Clears the priority. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPriority();


    /**
     *  Gets the metadata for the due date. 
     *
     *  @return metadata for the due date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getDueDateMetadata();


    /**
     *  Sets the due date. 
     *
     *  @param  date the new due date 
     *  @throws org.osid.InvalidArgumentException <code> date </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setDueDate(org.osid.calendaring.DateTime date);


    /**
     *  Clears the due date. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDueDate();


    /**
     *  Gets the metadata for the dependencies. 
     *
     *  @return metadata for the dependencies 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getDependenciesMetadata();


    /**
     *  Sets the dependencies. 
     *
     *  @param  todoIds the new dependencies 
     *  @throws org.osid.InvalidArgumentException <code> todoIds </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> todoIds </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setDependencies(org.osid.id.Id[] todoIds);


    /**
     *  Clears the dependencies. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDependencies();


    /**
     *  Gets the <code> TodoFormRecord </code> corresponding to the given todo 
     *  record <code> Type. </code> 
     *
     *  @param  todoRecordType the todo record type 
     *  @return the todo form record 
     *  @throws org.osid.NullArgumentException <code> todoRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(todoRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.checklist.records.TodoFormRecord getTodoFormRecord(org.osid.type.Type todoRecordType)
        throws org.osid.OperationFailedException;
}
