//
// org.osid.checklist.TodoQuery
//
//     The OSID Java specification for org.osid.checklist.TodoQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.checklist;


/**
 *  <p>This is the query for searching todos. Each method specifies an <code> 
 *  AND </code> term while multiple invocations of the same method produce a 
 *  nested <code> OR. </code> </p>
 */

public interface TodoQuery
    extends org.osid.OsidObjectQuery,
            org.osid.OsidContainableQuery,
            org.osid.OsidTemporalQuery,
            org.osid.OsidFederateableQuery {


    /**
     *  Matches completed todos. 
     *
     *  @param  match <code> true </code> for to match completed todos, <code> 
     *          false </code> to match incomplete todos 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchComplete(boolean match);


    /**
     *  Clears the complete terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCompleteTerms();


    /**
     *  Matches todos of the given priority. 
     *
     *  @param  priorityType a priority type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> priorityType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchPriority(org.osid.type.Type priorityType, boolean match);


    /**
     *  Matches todos with any priority set. 
     *
     *  @param  match <code> true </code> for to match todos with any 
     *          priority, <code> false </code> to match todos with no priority 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyPriority(boolean match);


    /**
     *  Clears the priority terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPriorityTerms();


    /**
     *  Matches todos of the given priority or greater. 
     *
     *  @param  priorityType a priority type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> priorityType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMinimumPriority(org.osid.type.Type priorityType, 
                                     boolean match);


    /**
     *  Clears the minimum priority terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMinimumPriorityTerms();


    /**
     *  Matches todos with dues dates within the given date range inclusive. 
     *
     *  @param  from starting date 
     *  @param  to ending date 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDueDate(org.osid.calendaring.DateTime from, 
                             org.osid.calendaring.DateTime to, boolean match);


    /**
     *  Matches todos with any due date. 
     *
     *  @param  match <code> true </code> for to match todos with any due 
     *          date, <code> false </code> to match todos with no due date 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDueDate(boolean match);


    /**
     *  Clears the due date terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDueDateTerms();


    /**
     *  Matches a depednency todo. 
     *
     *  @param  todoId a todo <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> todoId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDependencyId(org.osid.id.Id todoId, boolean match);


    /**
     *  Clears the todo <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDependencyIdTerms();


    /**
     *  Tests if a <code> TodoQuery </code> is available. 
     *
     *  @return <code> true </code> if a todo query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDependencyQuery();


    /**
     *  Gets the query for a todo query. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the checklist query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDependencyQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDependencyQuery() </code> is <code> true. </code> 
     */

    public org.osid.checklist.TodoQuery getDependencyQuery();


    /**
     *  Matches tdos with any dependencies. 
     *
     *  @param  match <code> true </code> for to matchc todos with any 
     *          dependency, <code> false </code> to matchtodos with no 
     *          dependencies 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDependency(boolean match);


    /**
     *  Clears the dependency terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDependencyTerms();


    /**
     *  Sets the todo <code> Id </code> for this query to match todos that 
     *  have the specified todo as an ancestor. 
     *
     *  @param  todoId a todo <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> todoId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorTodoId(org.osid.id.Id todoId, boolean match);


    /**
     *  Clears the ancestor todo <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorTodoIdTerms();


    /**
     *  Tests if a <code> TodoQuery </code> is available. 
     *
     *  @return <code> true </code> if a todo query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorTodoQuery();


    /**
     *  Gets the query for a todo. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the todo query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorTodoQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorTodoQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.checklist.TodoQuery getAncestorTodoQuery();


    /**
     *  Matches todos that have any ancestor. 
     *
     *  @param  match <code> true </code> to match todos with any ancestor, 
     *          <code> false </code> to match root todos 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorTodo(boolean match);


    /**
     *  Clears the ancestor todo query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorTodoTerms();


    /**
     *  Sets the todo <code> Id </code> for this query to match todos that 
     *  have the specified todo as a descendant. 
     *
     *  @param  todoId a todo <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> todoId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantTodoId(org.osid.id.Id todoId, boolean match);


    /**
     *  Clears the descendant todo <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantTodoIdTerms();


    /**
     *  Tests if a <code> TodoQuery </code> is available. 
     *
     *  @return <code> true </code> if a todo query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantTodoQuery();


    /**
     *  Gets the query for a todo. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the todo query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantTodoQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantTodoQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.checklist.TodoQuery getDescendantTodoQuery();


    /**
     *  Matches todos that have any descendant. 
     *
     *  @param  match <code> true </code> to match todos with any descendant, 
     *          <code> false </code> to match leaf todos 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantTodo(boolean match);


    /**
     *  Clears the descendant todo query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantTodoTerms();


    /**
     *  Sets the checklist <code> Id </code> for this query to match todos 
     *  assigned to checklists. 
     *
     *  @param  checklistId a checklist <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> checklistId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchChecklistId(org.osid.id.Id checklistId, boolean match);


    /**
     *  Clears the checklist <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearChecklistIdTerms();


    /**
     *  Tests if a <code> ChecklistQuery </code> is available. 
     *
     *  @return <code> true </code> if a checklist query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsChecklistQuery();


    /**
     *  Gets the query for a checklist query. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the checklist query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsChecklistQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsChecklistQuery() </code> is <code> true. </code> 
     */

    public org.osid.checklist.ChecklistQuery getChecklistQuery();


    /**
     *  Clears the checklist terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearChecklistTerms();


    /**
     *  Gets the todo query record corresponding to the given <code> Todo 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @param  todoRecordType a todo record type 
     *  @return the todo query record 
     *  @throws org.osid.NullArgumentException <code> todoRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(todoRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.checklist.records.TodoQueryRecord getTodoQueryRecord(org.osid.type.Type todoRecordType)
        throws org.osid.OperationFailedException;
}
