//
// org.osid.checklist.TodoQueryInspector
//
//     The OSID Java specification for org.osid.checklist.TodoQueryInspector.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.checklist;


/**
 *  <p>The todo query inspector for examining todo queries. </p>
 */

public interface TodoQueryInspector
    extends org.osid.OsidObjectQueryInspector,
            org.osid.OsidContainableQueryInspector,
            org.osid.OsidTemporalQueryInspector,
            org.osid.OsidFederateableQueryInspector {


    /**
     *  Gets the complete terms. 
     *
     *  @return the completed query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.BooleanTerm[] getCompleteTerms();


    /**
     *  Gets the priority terms. 
     *
     *  @return the priority query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.TypeTerm[] getPriorityTerms();


    /**
     *  Gets the minimum priority terms. 
     *
     *  @return the priority query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.TypeTerm[] getMinimumPriorityTerms();


    /**
     *  Gets the due date terms. 
     *
     *  @return the date query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DateTimeRangeTerm[] getDueDateTerms();


    /**
     *  Gets the dependency <code> Id </code> terms. 
     *
     *  @return the todo query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getDependencyIdTerms();


    /**
     *  Gets the dependency terms. 
     *
     *  @return the todo query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.checklist.TodoQueryInspector[] getDependencyTerms();


    /**
     *  Gets the ancestor todo <code> Id </code> query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getAncestorTodoIdTerms();


    /**
     *  Gets the ancestor todo query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.checklist.TodoQueryInspector[] getAncestorTodoTerms();


    /**
     *  Gets the descendant todo <code> Id </code> query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getDescendantTodoIdTerms();


    /**
     *  Gets the descendant todo query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.checklist.TodoQueryInspector[] getDescendantTodoTerms();


    /**
     *  Gets the checklist <code> Id </code> query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getChecklistIdTerms();


    /**
     *  Gets the checklist query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.checklist.ChecklistQueryInspector[] getChecklistTerms();


    /**
     *  Gets the todo query inspector record corresponding to the given <code> 
     *  Todo </code> record <code> Type. </code> 
     *
     *  @param  todoRecordType a todo record type 
     *  @return the todo query inspector record 
     *  @throws org.osid.NullArgumentException <code> todoRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(todoRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.checklist.records.TodoQueryInspectorRecord getTodoQueryInspectorRecord(org.osid.type.Type todoRecordType)
        throws org.osid.OperationFailedException;
}
