//
// org.osid.checklist.mason.ChecklistMasonProxyManager
//
//     The OSID Java specification for org.osid.checklist.mason.ChecklistMasonProxyManager.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.checklist.mason;


/**
 *  <p>The checklist mason proxy manager provides access to checklist mason 
 *  sessions and provides interoperability tests for various aspects of this 
 *  service. Methods in this manager pass a <code> Proxy </code> for passing 
 *  information from server environments. The sessions included in this 
 *  manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> TodoProducerLookupSession: </code> a session to retrieve 
 *      todo producers </li> 
 *      <li> <code> TodoProducerQuerySession: </code> a session to query for 
 *      todo producers </li> 
 *      <li> <code> TodoProducerSearchSession: </code> a session to search for 
 *      todo producers </li> 
 *      <li> <code> TodoProducerAdminSession: </code> a session to create and 
 *      delete todo producers </li> 
 *      <li> <code> TodoProducerNotificationSession: </code> a session to 
 *      receive notifications pertaining to todo producer changes </li> 
 *      <li> <code> TodoProducerChecklistSession: </code> a session to look up 
 *      todo producer checklist mappings </li> 
 *      <li> <code> TodoProducerChecklistAssignmentSession: </code> a session 
 *      to manage todo producer to checklist mappings </li> 
 *      <li> <code> TodoProducerSmartChecklistSession: </code> a session to 
 *      manage dynamic checklists of todo producers </li> 
 *  </ul>
 *  
 */

public interface ChecklistMasonProxyManager
    extends org.osid.OsidProxyManager,
            org.osid.checklist.mason.ChecklistMasonProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the todo producer 
     *  lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> TodoProducerLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTodoProducerLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTodoProducerLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.checklist.mason.TodoProducerLookupSession getTodoProducerLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the todo producer 
     *  lookup service for the given checklist. 
     *
     *  @param  checklistId the <code> Id </code> of the <code> Checklist 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> TodoProducerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Checklist </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> checklistId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTodoProducerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTodoProducerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.checklist.mason.TodoProducerLookupSession getTodoProducerLookupSessionForChecklist(org.osid.id.Id checklistId, 
                                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the todo producer 
     *  query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> TodoProducerQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTodoProducerQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTodoProducerQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.checklist.mason.TodoProducerQuerySession getTodoProducerQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the todo producer 
     *  query service for the given checklist. 
     *
     *  @param  checklistId the <code> Id </code> of the <code> Checklist 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> TodoProducerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Checklist </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> checklistId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTodoProducerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTodoProducerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.checklist.mason.TodoProducerQuerySession getTodoProducerQuerySessionForChecklist(org.osid.id.Id checklistId, 
                                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the todo producer 
     *  search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> TodoProducerSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTodoProducerSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTodoProducerSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.checklist.mason.TodoProducerSearchSession getTodoProducerSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the todo producers 
     *  earch service for the given checklist. 
     *
     *  @param  checklistId the <code> Id </code> of the <code> Checklist 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> TodoProducerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Checklist </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> checklistId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTodoProducerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTodoProducerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.checklist.mason.TodoProducerSearchSession getTodoProducerSearchSessionForChecklist(org.osid.id.Id checklistId, 
                                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the todo producer 
     *  administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> TodoProducerAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTodoProducerAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTodoProducerAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.checklist.mason.TodoProducerAdminSession getTodoProducerAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the todo producer 
     *  administration service for the given checklist. 
     *
     *  @param  checklistId the <code> Id </code> of the <code> Checklist 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> TodoProducerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Checklist </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> checklistId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTodoProducerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTodoProducerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.checklist.mason.TodoProducerAdminSession getTodoProducerAdminSessionForChecklist(org.osid.id.Id checklistId, 
                                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the todo producer 
     *  notification service. 
     *
     *  @param  todoProducerReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> TodoProducerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> todoProducerReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTodoProducerNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTodoProducerNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.checklist.mason.TodoProducerNotificationSession getTodoProducerNotificationSession(org.osid.checklist.mason.TodoProducerReceiver todoProducerReceiver, 
                                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the todo producer 
     *  notification service for the given checklist. 
     *
     *  @param  todoProducerReceiver the notification callback 
     *  @param  checklistId the <code> Id </code> of the <code> Checklist 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> TodoProducerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no checklist found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> todoProducerReceiver, 
     *          checklistId </code> or <code> proxy </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTodoProducerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTodoProducerNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.checklist.mason.TodoProducerNotificationSession getTodoProducerNotificationSessionForChecklist(org.osid.checklist.mason.TodoProducerReceiver todoProducerReceiver, 
                                                                                                                   org.osid.id.Id checklistId, 
                                                                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup todo producer/checklist 
     *  mappings for todo producers. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> TodoProducerChecklistSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTodoProducerChecklist() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTodoProducerChecklist() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.checklist.mason.TodoProducerChecklistSession getTodoProducerChecklistSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning todo 
     *  producers to checklists for todo. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> TodoProducerChecklistAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTodoProducerChecklistAssignment() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTodoProducerChecklistAssignment() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.checklist.mason.TodoProducerChecklistAssignmentSession getTodoProducerChecklistAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage todo producer smart 
     *  checklists. 
     *
     *  @param  checklistId the <code> Id </code> of the <code> Checklist 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> TodoProducerSmartChecklistSession </code> 
     *  @throws org.osid.NotFoundException no <code> Checklist </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> checklistId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTodoProducerSmartChecklist() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTodoProducerSmartChecklist() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.checklist.mason.TodoProducerSmartChecklistSession getTodoProducerSmartChecklistSession(org.osid.id.Id checklistId, 
                                                                                                           org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;
}
