//
// org.osid.checklist.mason.TodoProducer
//
//     The OSID Java specification for org.osid.checklist.mason.TodoProducer.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.checklist.mason;


/**
 *  <p>A <code> TodoProducer </code> describes the mason for making <code> 
 *  Todos. </code> </p>
 */

public interface TodoProducer
    extends org.osid.OsidRule {


    /**
     *  Tests if a todo should be created or destroyed. 
     *
     *  @return <code> true </code> if a creation rule, <code> false </code> 
     *          if a destruction rule 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isCreationRule();


    /**
     *  Tests if a todo should be produced based on a time cycle. 
     *
     *  @return <code> true </code> if based on a timecycle, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isBasedOnTimeCycle();


    /**
     *  Gets the cyclic event <code> Id. </code> 
     *
     *  @return the cyclic event <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> isBasedOnTimeCycle() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCyclicEventId();


    /**
     *  Gets the cyclic event. 
     *
     *  @return the cyclic event 
     *  @throws org.osid.IllegalStateException <code> isBasedOnTimeCycle() 
     *          </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.cycle.CyclicEvent getCyclicEvent()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if a todo should be produced based on an item level in a stock. 
     *
     *  @return <code> true </code> if based on a stock, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isBasedOnStock();


    /**
     *  Gets the stock level. 
     *
     *  @return the stock level 
     *  @throws org.osid.IllegalStateException <code> isBasedOnStock() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getStockLevel();


    /**
     *  Gets the stock <code> Id. </code> 
     *
     *  @return the stock <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> isBasedOnStock() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getStockId();


    /**
     *  Gets the stock. 
     *
     *  @return the stock 
     *  @throws org.osid.IllegalStateException <code> isBasedOnStock() </code> 
     *          is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.Stock getStock()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the todo producer record corresponding to the given <code> 
     *  TodoProducer </code> record <code> Type. </code> This method is used 
     *  to retrieve an object implementing the requested record. The <code> 
     *  todoProducerRecordType </code> may be the <code> Type </code> returned 
     *  in <code> getRecordTypes() </code> or any of its parents in a <code> 
     *  Type </code> hierarchy where <code> 
     *  hasRecordType(todoProducerRecordType) </code> is <code> true </code> . 
     *
     *  @param  todoProducerRecordType the type of todo producer record to 
     *          retrieve 
     *  @return the todo producer record 
     *  @throws org.osid.NullArgumentException <code> todoProducerRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(todoProducerRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.checklist.mason.records.TodoProducerRecord getTodoProducerRecord(org.osid.type.Type todoProducerRecordType)
        throws org.osid.OperationFailedException;
}
