//
// org.osid.checklist.mason.TodoProducerAdminSession
//
//     The OSID Java specification for org.osid.checklist.mason.TodoProducerAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.checklist.mason;


/**
 *  <p>This session creates and removes todo producers. The data for create 
 *  and update is provided via the <code> TodoProducerForm. </code> </p>
 */

public interface TodoProducerAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Checklist </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Checklist Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getChecklistId();


    /**
     *  Gets the <code> Checklist </code> associated with this session. 
     *
     *  @return the checklist 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.checklist.Checklist getChecklist()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create todo producers. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known creating a <code> TodoProducer </code> will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer create operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> TodoProducer </code> creation 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateTodoProducer();


    /**
     *  Tests if this user can create a single <code> TodoProducer </code> 
     *  using the desired record types. While <code> 
     *  ChecklistMasonManager.getTodoProducerRecordTypes() </code> can be used 
     *  to examine which records are supported, this method tests which 
     *  record(s) are required for creating a specific <code> TodoProducer. 
     *  </code> Providing an empty array tests if a <code> TodoProducer 
     *  </code> can be created with no records. 
     *
     *  @param  todoProducerRecordTypes array of todo producer record types 
     *  @return <code> true </code> if <code> TodoProducer </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> todoProducerRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateTodoProducerWithRecordTypes(org.osid.type.Type[] todoProducerRecordTypes);


    /**
     *  Gets the todo producer form for creating new todo producers. A new 
     *  form should be requested for each create transaction. 
     *
     *  @param  todoProducerRecordTypes array of todo producer record types 
     *  @return the todo producer form 
     *  @throws org.osid.NullArgumentException <code> todoProducerRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.checklist.mason.TodoProducerForm getTodoProducerFormForCreate(org.osid.type.Type[] todoProducerRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> TodoProducer. </code> 
     *
     *  @param  todoProducerForm the form for this <code> TodoProducer </code> 
     *  @return the new <code> TodoProducer </code> 
     *  @throws org.osid.IllegalStateException <code> todoProducerForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> todoProducerForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> todoProducerForm </code> 
     *          did not originate from <code> getTodoProducerFormForCreate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.checklist.mason.TodoProducer createTodoProducer(org.osid.checklist.mason.TodoProducerForm todoProducerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update todo producers. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known updating a <code> TodoProducer </code> will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer update operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> TodoProducer </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateTodoProducers();


    /**
     *  Gets the todo producer form for updating an existing todo producer. A 
     *  new todo producer form should be requested for each update 
     *  transaction. 
     *
     *  @param  todoProducerId the <code> Id </code> of the <code> 
     *          TodoProducer </code> 
     *  @return the todo producer form 
     *  @throws org.osid.NotFoundException <code> todoProducerId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> todoProducerId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.checklist.mason.TodoProducerForm getTodoProducerFormForUpdate(org.osid.id.Id todoProducerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing todo producer. 
     *
     *  @param  todoProducerForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> todoProducerForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> todoProducerForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> todoProducerForm </code> 
     *          did not originate from <code> getTodoProducerFormForUpdate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateTodoProducer(org.osid.checklist.mason.TodoProducerForm todoProducerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete todo producers. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known deleting a <code> TodoProducer </code> will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer delete operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> TodoProducer </code> deletion 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteTodoProducers();


    /**
     *  Deletes a <code> TodoProducer. </code> 
     *
     *  @param  todoProducerId the <code> Id </code> of the <code> 
     *          TodoProducer </code> to remove 
     *  @throws org.osid.NotFoundException <code> todoProducerId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> todoProducerId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteTodoProducer(org.osid.id.Id todoProducerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for todo 
     *  producers. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> TodoProducer </code> aliasing 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageTodoProducerAliases();


    /**
     *  Adds an <code> Id </code> to a <code> TodoProducer </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> TodoProducer </code> is determined by the provider. The new 
     *  <code> Id </code> performs as an alias to the primary <code> Id 
     *  </code> . If the alias is a pointer to another todo producer. it is 
     *  reassigned to the given todo producer <code> Id. </code> 
     *
     *  @param  todoProducerId the <code> Id </code> of a <code> TodoProducer 
     *          </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> todoProducerId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> todoProducerId </code> 
     *          or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasTodoProducer(org.osid.id.Id todoProducerId, 
                                  org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
