//
// org.osid.checklist.mason.TodoProducerChecklistAssignmentSession
//
//     The OSID Java specification for org.osid.checklist.mason.TodoProducerChecklistAssignmentSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.checklist.mason;


/**
 *  <p>This session provides methods to re-assign <code> TodoProducer </code> 
 *  to <code> Checklist </code> mappings. A <code> TodoProducer </code> may 
 *  appear in multiple <code> Checklist </code> objects and removing the last 
 *  reference to a <code> TodoProducer </code> is the equivalent of deleting 
 *  it. Each <code> Checklist </code> may have its own authorizations 
 *  governing who is allowed to operate on it. </p> 
 *  
 *  <p> Adding a reference of a <code> TodoProducer </code> to another <code> 
 *  Checklist </code> is not a copy operation (eg: does not change its <code> 
 *  Id </code> ). </p>
 */

public interface TodoProducerChecklistAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter todo producer/checklist mappings. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignTodoProducers();


    /**
     *  Tests if this user can alter todo producer/checklist mappings. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @param  checklistId the <code> Id </code> of the <code> Checklist 
     *          </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> checklistId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignTodoProducersToChecklist(org.osid.id.Id checklistId);


    /**
     *  Gets a list of checklists including and under the given checklist node 
     *  in which any todo producer can be assigned. 
     *
     *  @param  checklistId the <code> Id </code> of the <code> Checklist 
     *          </code> 
     *  @return list of assignable checklist <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> checklistId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableChecklistIds(org.osid.id.Id checklistId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of checklists including and under the given checklist node 
     *  in which a specific todo producer can be assigned. 
     *
     *  @param  checklistId the <code> Id </code> of the <code> Checklist 
     *          </code> 
     *  @param  todoProducerId the <code> Id </code> of the <code> 
     *          TodoProducer </code> 
     *  @return list of assignable checklist <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> checklistId </code> or 
     *          <code> todoProducerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableChecklistIdsForTodoProducer(org.osid.id.Id checklistId, 
                                                                       org.osid.id.Id todoProducerId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> TodoProducer </code> to an <code> Checklist. 
     *  </code> 
     *
     *  @param  todoProducerId the <code> Id </code> of the <code> 
     *          TodoProducer </code> 
     *  @param  checklistId the <code> Id </code> of the <code> Checklist 
     *          </code> 
     *  @throws org.osid.AlreadyExistsException <code> todoProducerId </code> 
     *          is already assigned to <code> checklistId </code> 
     *  @throws org.osid.NotFoundException <code> todoProducerId </code> or 
     *          <code> checklistId </code> not found 
     *  @throws org.osid.NullArgumentException <code> todoProducerId </code> 
     *          or <code> checklistId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignTodoProducerToChecklist(org.osid.id.Id todoProducerId, 
                                              org.osid.id.Id checklistId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> TodoProducer </code> from an <code> Checklist. 
     *  </code> 
     *
     *  @param  todoProducerId the <code> Id </code> of the <code> 
     *          TodoProducer </code> 
     *  @param  checklistId the <code> Id </code> of the <code> Checklist 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> todoProducerId </code> or 
     *          <code> checklistId </code> not found or <code> todoProducerId 
     *          </code> is not assigned to <code> checklistId </code> 
     *  @throws org.osid.NullArgumentException <code> todoProducerId </code> 
     *          or <code> checklistId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignTodoProducerFromChecklist(org.osid.id.Id todoProducerId, 
                                                  org.osid.id.Id checklistId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Moves a <code> TodoProducer </code> from one <code> Checklist </code> 
     *  to another. Mappings to other <code> Checklists </code> are 
     *  unaffected. 
     *
     *  @param  todoProducerId the <code> Id </code> of the <code> 
     *          TodoProducer </code> 
     *  @param  fromChecklistId the <code> Id </code> of the current <code> 
     *          Checklist </code> 
     *  @param  toChecklistId the <code> Id </code> of the destination <code> 
     *          Checklist </code> 
     *  @throws org.osid.NotFoundException <code> todoProducerId, 
     *          fromChecklistId, </code> or <code> toChecklistId </code> not 
     *          found or <code> todoProducerId, </code> not mapped to <code> 
     *          fromChecklistId </code> 
     *  @throws org.osid.NullArgumentException <code> todoProducerId,, 
     *          fromChecklistId, </code> or <code> toChecklistId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void reassignTodoProducerToChecklist(org.osid.id.Id todoProducerId, 
                                                org.osid.id.Id fromChecklistId, 
                                                org.osid.id.Id toChecklistId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
