//
// org.osid.checklist.mason.TodoProducerQuery
//
//     The OSID Java specification for org.osid.checklist.mason.TodoProducerQuery.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.checklist.mason;


/**
 *  <p>This is the query for searching todo producers. Each method match 
 *  specifies an <code> AND </code> term while multiple invocations of the 
 *  same method produce a nested <code> OR. </code> </p>
 */

public interface TodoProducerQuery
    extends org.osid.OsidRuleQuery {


    /**
     *  Matches producers that create todos. 
     *
     *  @param  match <code> true </code> to match creation rules, <code> 
     *          false </code> to match destruction rules 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCreationRule(boolean match);


    /**
     *  Clears the creation rule query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCreationRuleTerms();


    /**
     *  Matches producers based on a cyclic event. 
     *
     *  @param  cyclicEventId the cyclic event <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> cyclicEventId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCyclicEventId(org.osid.id.Id cyclicEventId, boolean match);


    /**
     *  Clears the cyclic event <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCyclicEventIdTerms();


    /**
     *  Tests if a <code> CyclicEventQuery </code> is available. 
     *
     *  @return <code> true </code> if a cyclic event query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCyclicEventQuery();


    /**
     *  Gets the query for a cyclic event. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the cyclic event query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCyclicEventQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCyclicEventQuery() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.cycle.CyclicEventQuery getCyclicEventQuery();


    /**
     *  Matches producers based on any cyclic event. 
     *
     *  @param  match <code> true </code> for producers based on any cyclic 
     *          event, <code> false </code> to match producers based on no 
     *          cyclic event 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCyclicEvent(boolean match);


    /**
     *  Clears the cyclic event query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCyclicEventTerms();


    /**
     *  Matches producers based on a stock. 
     *
     *  @param  stockId the stock <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> stockId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchStockId(org.osid.id.Id stockId, boolean match);


    /**
     *  Clears the stock <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStockIdTerms();


    /**
     *  Tests if a <code> StockQuery </code> is available. 
     *
     *  @return <code> true </code> if a stock query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStockQuery();


    /**
     *  Gets the query for a stock. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the stock query 
     *  @throws org.osid.UnimplementedException <code> supportsStockQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStockQuery() </code> is <code> true. </code> 
     */

    public org.osid.inventory.StockQuery getStockQuery();


    /**
     *  Matches producers based on any stock. 
     *
     *  @param  match <code> true </code> for producers based on any stock, 
     *          <code> false </code> to match producers based on no stock 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyStock(boolean match);


    /**
     *  Clears the stock query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStockTerms();


    /**
     *  Matches producers with a stock level between the given range 
     *  inclusive. 
     *
     *  @param  from start of range 
     *  @param  to end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchStockLevel(long from, long to, boolean match);


    /**
     *  Matches producers with any stock level. 
     *
     *  @param  match <code> true </code> for producers with any stock, <code> 
     *          false </code> to match producers with no stock 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyStockLevel(boolean match);


    /**
     *  Clears the stock level query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStockLevelTerms();


    /**
     *  Matches producers producing to the todo. 
     *
     *  @param  todoId the todo <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> todoBookId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchProducedTodoId(org.osid.id.Id todoId, boolean match);


    /**
     *  Clears the produced todo <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProducedTodoIdTerms();


    /**
     *  Tests if a <code> TodoBookQuery </code> is available. 
     *
     *  @return <code> true </code> if a todo query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProducedTodoQuery();


    /**
     *  Gets the query for a todo. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the todo query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProducedTodoQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProducedTodoQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.checklist.TodoQuery getProducedTodoQuery();


    /**
     *  Matches producers producing to any todo. 
     *
     *  @param  match <code> true </code> for producers producing any todo, 
     *          <code> false </code> to match producers producing no todo 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyProducedTodo(boolean match);


    /**
     *  Clears the todo query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProducedTodoTerms();


    /**
     *  Matches producers mapped to the checklist. 
     *
     *  @param  checklistId the checklist <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> checklistId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchChecklistId(org.osid.id.Id checklistId, boolean match);


    /**
     *  Clears the checklist <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearChecklistIdTerms();


    /**
     *  Tests if an <code> ChecklistQuery </code> is available. 
     *
     *  @return <code> true </code> if a checklist query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsChecklistQuery();


    /**
     *  Gets the query for a checklist. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the checklist query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsChecklistQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsChecklistQuery() </code> is <code> true. </code> 
     */

    public org.osid.checklist.ChecklistQuery getChecklistQuery();


    /**
     *  Clears the checklist query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearChecklistTerms();


    /**
     *  Gets the todo producer query record corresponding to the given <code> 
     *  TodoProducer </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  todoProducerRecordType a todo producer record type 
     *  @return the todo producer query record 
     *  @throws org.osid.NullArgumentException <code> todoProducerRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(todoProducerRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.checklist.mason.records.TodoProducerQueryRecord getTodoProducerQueryRecord(org.osid.type.Type todoProducerRecordType)
        throws org.osid.OperationFailedException;
}
