//
// org.osid.checklist.mason.TodoProducerQuerySession
//
//     The OSID Java specification for org.osid.checklist.mason.TodoProducerQuerySession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.checklist.mason;


/**
 *  <p>This session provides methods for searching among <code> TodoProducer 
 *  </code> objects. The search query is constructed using the <code> 
 *  TodoProducerQuery. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated checklist view: searches include todo producers in 
 *      checklists of which this checklist is an ancestor in the checklist 
 *      hierarchy </li> 
 *      <li> isolated checklist view: searches are restricted to todo 
 *      producers in this checklist </li> 
 *  </ul>
 *  
 *  
 *  <p> Todo producers may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> 
 *  TodoProducerQuery. </code> </p>
 */

public interface TodoProducerQuerySession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Checklist </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Checklist Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getChecklistId();


    /**
     *  Gets the <code> Checklist </code> associated with this session. 
     *
     *  @return the checklist 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.checklist.Checklist getChecklist()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> TodoProducer </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if search methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSearchTodoProducers();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include todo producers in checklists which are children of this broker 
     *  in the checklist hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedChecklistView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this checklist only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedChecklistView();


    /**
     *  Gets a todo producer query. 
     *
     *  @return the todo producer query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.checklist.mason.TodoProducerQuery getTodoProducerQuery();


    /**
     *  Gets a list of <code> TodoProducers </code> matching the given todo 
     *  producer query. 
     *
     *  @param  todoProducerQuery the todo producer query 
     *  @return the returned <code> TodoProducerList </code> 
     *  @throws org.osid.NullArgumentException <code> todoProducerQuery 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> todoProducerQuery </code> 
     *          is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.checklist.mason.TodoProducerList getTodoProducersByQuery(org.osid.checklist.mason.TodoProducerQuery todoProducerQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
