//
// org.osid.checklist.mason.TodoProducerSearchOrder
//
//     The OSID Java specification for org.osid.checklist.mason.TodoProducerSearchOrder.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.checklist.mason;


/**
 *  <p>An interface for specifying the ordering of search results. </p>
 */

public interface TodoProducerSearchOrder
    extends org.osid.OsidRuleSearchOrder {


    /**
     *  Specifies a preference for ordering the result set by the creation 
     *  rule flag. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByCreationRule(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the cyclic 
     *  event. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByCyclicEvent(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a cyclic event search order is available. 
     *
     *  @return <code> true </code> if a cyclic event search order is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCyclicEventSearchOrder();


    /**
     *  Gets the cyclic event search order. 
     *
     *  @return the cyclic event search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCyclicEventSearchOrder() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCyclicEventSearchOrder() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.CyclicEventSearchOrder getCyclicEventSearchOrder();


    /**
     *  Specifies a preference for ordering the result set by the stock. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByStock(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a stock search order is available. 
     *
     *  @return <code> true </code> if a stock search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStockSearchOrder();


    /**
     *  Gets the stock search order. 
     *
     *  @return the stock search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStockSearchOrder() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStockSearchOrder() </code> is <code> true. </code> 
     */

    public org.osid.inventory.StockSearchOrder getStockSearchOrder();


    /**
     *  Specifies a preference for ordering the result set by the stock level. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByStockLevel(org.osid.SearchOrderStyle style);


    /**
     *  Gets the todo producer search order record corresponding to the given 
     *  todo producer record <code> Type. </code> Multiple retrievals return 
     *  the same underlying object. 
     *
     *  @param  todoProducerRecordType a todo producer record type 
     *  @return the todo producer search order record 
     *  @throws org.osid.NullArgumentException <code> todoProducerRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(todoProducerRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.checklist.mason.records.TodoProducerSearchOrderRecord getTodoProducerSearchOrderRecord(org.osid.type.Type todoProducerRecordType)
        throws org.osid.OperationFailedException;
}
