//
// org.osid.checklist.mason.TodoProducerSmartChecklistSession
//
//     The OSID Java specification for org.osid.checklist.mason.TodoProducerSmartChecklistSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.checklist.mason;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  checklists. A <code> TodoProducerQuery </code> can be retrieved from this 
 *  session and mapped to this <code> Checklist </code> to create a virtual 
 *  collection of todo producers. The todo producers may be sequenced using 
 *  the <code> TodoProducerSearchOrder </code> from this session. </p> 
 *  
 *  <p> This <code> Checklist </code> has a default query that matches any 
 *  todo producer and a default search order that specifies no sequencing. The 
 *  queries may be examined using a <code> TodoProducerQueryInspector. </code> 
 *  The query may be modified by converting the inspector back to a <code> 
 *  TodoProducerQuery. </code> </p>
 */

public interface TodoProducerSmartChecklistSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Checklist </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Checklist Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getChecklistId();


    /**
     *  Gets the <code> Checklist </code> associated with this session. 
     *
     *  @return the checklist 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.checklist.Checklist getChecklist()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart checklists. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart checklist management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartChecklists();


    /**
     *  Gets a todo producer query. 
     *
     *  @return the todo producer query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.checklist.mason.TodoProducerQuery getTodoProducerQuery();


    /**
     *  Gets a todo producer search order. 
     *
     *  @return the todo producer search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.checklist.mason.TodoProducerSearchOrder getTodoProducerSearchOrder();


    /**
     *  Applies a todo producer query to this checklist. 
     *
     *  @param  todoProducerQuery the todo producer query 
     *  @throws org.osid.NullArgumentException <code> todoProducerQuery 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> todoProducerQuery </code> 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyTodoProducerQuery(org.osid.checklist.mason.TodoProducerQuery todoProducerQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a todo producer query inspector for this checklist. 
     *
     *  @return the todo producer query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.checklist.mason.TodoProducerQueryInspector inspectTodoProducerQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a todo producer search order to this checklist. 
     *
     *  @param  todoProducerSearchOrder the todo producer search order 
     *  @throws org.osid.NullArgumentException <code> todoProducerSearchOrder 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> todoProducerSearchOrder 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyTodoProducerSequencing(org.osid.checklist.mason.TodoProducerSearchOrder todoProducerSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a todo producer query from an inspector. 
     *
     *  @param  todoProducerQueryInspector a todo producer query inspector 
     *  @return the todo producer query 
     *  @throws org.osid.NullArgumentException <code> 
     *          todoProducerQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          todoProducerQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.checklist.mason.TodoProducerQuery getTodoProducerQueryFromInspector(org.osid.checklist.mason.TodoProducerQueryInspector todoProducerQueryInspector);
}
