//
// org.osid.commenting.BookQuery
//
//     The OSID Java specification for org.osid.commenting.BookQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.commenting;


/**
 *  <p>This is the query for searching books. Each method specifies an <code> 
 *  AND </code> term while multiple invocations of the same method produce a 
 *  nested <code> OR. </code> </p>
 */

public interface BookQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Sets the comment <code> Id </code> for this query to match comments 
     *  assigned to books. 
     *
     *  @param  commentId a comment <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> commentId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCommentId(org.osid.id.Id commentId, boolean match);


    /**
     *  Clears the comment <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCommentIdTerms();


    /**
     *  Tests if a comment query is available. 
     *
     *  @return <code> true </code> if a comment query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommentQuery();


    /**
     *  Gets the query for a comment. 
     *
     *  @return the comment query 
     *  @throws org.osid.UnimplementedException <code> supportsCommentQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommentQuery() </code> is <code> true. </code> 
     */

    public org.osid.commenting.CommentQuery getCommentQuery();


    /**
     *  Matches books with any comment. 
     *
     *  @param  match <code> true </code> to match books with any comment, 
     *          <code> false </code> to match books with no comments 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyComment(boolean match);


    /**
     *  Clears the comment terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCommentTerms();


    /**
     *  Sets the book <code> Id </code> for this query to match books that 
     *  have the specified book as an ancestor. 
     *
     *  @param  bookId a book <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, a <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> bookId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorBookId(org.osid.id.Id bookId, boolean match);


    /**
     *  Clears the ancestor book <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorBookIdTerms();


    /**
     *  Tests if a <code> BookQuery </code> is available. 
     *
     *  @return <code> true </code> if a book query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorBookQuery();


    /**
     *  Gets the query for a book. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the book query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorBookQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorBookQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.commenting.BookQuery getAncestorBookQuery();


    /**
     *  Matches books with any ancestor. 
     *
     *  @param  match <code> true </code> to match books with any ancestor, 
     *          <code> false </code> to match root books 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorBook(boolean match);


    /**
     *  Clears the ancestor book terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorBookTerms();


    /**
     *  Sets the book <code> Id </code> for this query to match books that 
     *  have the specified book as a descendant. 
     *
     *  @param  bookId a book <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> bookId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantBookId(org.osid.id.Id bookId, boolean match);


    /**
     *  Clears the descendant book <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantBookIdTerms();


    /**
     *  Tests if a <code> BookQuery </code> is available. 
     *
     *  @return <code> true </code> if a book query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantBookQuery();


    /**
     *  Gets the query for a book. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the book query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantBookQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantBookQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.commenting.BookQuery getDescendantBookQuery();


    /**
     *  Matches books with any descendant. 
     *
     *  @param  match <code> true </code> to match books with any descendant, 
     *          <code> false </code> to match leaf books 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantBook(boolean match);


    /**
     *  Clears the descendant book terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantBookTerms();


    /**
     *  Gets the book query record corresponding to the given <code> Book 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested boolean <code> OR </code> term. 
     *
     *  @param  bookRecordType a book record type 
     *  @return the book query record 
     *  @throws org.osid.NullArgumentException <code> bookRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(bookRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.commenting.records.BookQueryRecord getBookQueryRecord(org.osid.type.Type bookRecordType)
        throws org.osid.OperationFailedException;
}
