//
// org.osid.commenting.BookSearchSession
//
//     The OSID Java specification for org.osid.commenting.BookSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.commenting;


/**
 *  <p>This session provides methods for searching <code> Book </code> 
 *  objects. The search query is constructed using the <code> BookQuery. 
 *  </code> The book record <code> Type </code> also specifies the record for 
 *  the book query. </p> 
 *  
 *  <p> <code> getBooksByQuery() </code> is the basic search method and 
 *  returns a list of <code> Book </code> elements. A more advanced search may 
 *  be performed with <code> getBooksBySearch(). </code> It accepts a <code> 
 *  BookSearch </code> in addition to the query for the purpose of specifying 
 *  additional options affecting the entire search, such as ordering. <code> 
 *  getBooksBySearch() </code> returns a <code> BookSearchResults </code> that 
 *  can be used to access the resulting <code> BookList </code> or be used to 
 *  perform a search within the result set through <code> BookSearch. </code> 
 *  </p> 
 *  
 *  <p> Books may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> BookQuery. </code> The 
 *  returns in this session may not be cast directly to these interfaces. </p>
 */

public interface BookSearchSession
    extends org.osid.commenting.BookQuerySession {


    /**
     *  Gets a book search. 
     *
     *  @return the book search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.commenting.BookSearch getBookSearch();


    /**
     *  Gets a book search order. The <code> BookSearchOrder </code> is 
     *  supplied to a <code> BookSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the book search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.commenting.BookSearchOrder getBookSearchOrder();


    /**
     *  Gets the search results matching the given search. 
     *
     *  @param  bookQuery the book query 
     *  @param  bookSearch the book search 
     *  @return the search results 
     *  @throws org.osid.NullArgumentException <code> bookQuery </code> or 
     *          <code> bookSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> bookQuery </code> or 
     *          <code> bookSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.commenting.BookSearchResults getBooksBySearch(org.osid.commenting.BookQuery bookQuery, 
                                                                  org.osid.commenting.BookSearch bookSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an entry query from an inspector. The inspector is available from 
     *  an <code> BookSearchResults. </code> 
     *
     *  @param  bookQueryInspector a book query inspector 
     *  @return the book query 
     *  @throws org.osid.NullArgumentException <code> bookQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> bookQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.commenting.BookQuery getBookQueryFromInspector(org.osid.commenting.BookQueryInspector bookQueryInspector);
}
