//
// org.osid.commenting.Comment
//
//     The OSID Java specification for org.osid.commenting.Comment.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.commenting;


/**
 *  <p>A <code> Comment </code> represents a comment and/or rating related to 
 *  a reference object in a book. </p>
 */

public interface Comment
    extends org.osid.OsidRelationship {


    /**
     *  Gets the <code> Id </code> of the referenced object to which this 
     *  comment pertains. 
     *
     *  @return the reference <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getReferenceId();


    /**
     *  Gets the <code> Id </code> of the resource who created this comment. 
     *
     *  @return the <code> Resource </code> <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCommentorId();


    /**
     *  Gets the resource who created this comment. 
     *
     *  @return the <code> Resource </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getCommentor()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of the agent who created this comment. 
     *
     *  @return the <code> Agent </code> <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCommentingAgentId();


    /**
     *  Gets the agent who created this comment. 
     *
     *  @return the <code> Agent </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.Agent getCommentingAgent()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the comment text. 
     *
     *  @return the comment text 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getText();


    /**
     *  Tests if this comment includes a rating. 
     *
     *  @return <code> true </code> if this comment includes a rating, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasRating();


    /**
     *  Gets the <code> Id </code> of the <code> Grade. </code> 
     *
     *  @return the <code> Agent </code> <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> hasRating() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getRatingId();


    /**
     *  Gets the <code> Grade. </code> 
     *
     *  @return the <code> Grade </code> 
     *  @throws org.osid.IllegalStateException <code> hasRating() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.Grade getRating()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the comment record corresponding to the given <code> Comment 
     *  </code> record <code> Type. </code> This method is used to retrieve an 
     *  object implementing the requested record. The <code> commentRecordType 
     *  </code> may be the <code> Type </code> returned in <code> 
     *  getRecordTypes() </code> or any of its parents in a <code> Type 
     *  </code> hierarchy where <code> hasRecordType(commentRecordType) 
     *  </code> is <code> true </code> . 
     *
     *  @param  commentRecordType the type of comment record to retrieve 
     *  @return the comment record 
     *  @throws org.osid.NullArgumentException <code> commentRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(commentRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.commenting.records.CommentRecord getCommentRecord(org.osid.type.Type commentRecordType)
        throws org.osid.OperationFailedException;
}
