//
// org.osid.commenting.CommentLookupSession
//
//     The OSID Java specification for org.osid.commenting.CommentLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.commenting;


/**
 *  <p>This session defines methods for retrieving comments. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated book view: All comment methods in this session operate, 
 *      retrieve and pertain to comments defined explicitly in the current 
 *      book. Using an isolated view is useful for managing comments with the 
 *      <code> CommentAdminSession. </code> </li> 
 *      <li> federated book view: All comment lookup methods in this session 
 *      operate, retrieve and pertain to all comments defined in this book and 
 *      any other books implicitly available in this book through book 
 *      inheritence. </li> 
 *      <li> effective comment view: All comment lookup methods return 
 *      comments where the current dates falls in between the effective dates 
 *      inclusive. </li> 
 *      <li> any effective comment view: Comments of any effective date are 
 *      returned. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedBookView() </code> and <code> 
 *  useIsolatedBookView() </code> behave as a radio group and one should be 
 *  selected before invoking any lookup methods. </p>
 */

public interface CommentLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Book </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Book Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBookId();


    /**
     *  Gets the <code> Book </code> associated with this session. 
     *
     *  @return the book 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.commenting.Book getBook()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can examine this book. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer these operations. 
     *
     *  @return <code> false </code> if book reading methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupComments();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeCommentView();


    /**
     *  A complete view of the <code> Comment </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryCommentView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include comments in books which are children of this book in the book 
     *  hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedBookView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this book only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedBookView();


    /**
     *  Only comments whose effective dates are current are returned by 
     *  methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useEffectiveCommentView();


    /**
     *  All comments of any effective dates are returned by all methods in 
     *  this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyEffectiveCommentView();


    /**
     *  Gets the <code> Comment </code> specified by its <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Comment </code> may have a different <code> Id </code> than requested, 
     *  such as the case where a duplicate <code> Id </code> was assigned to a 
     *  <code> Comment </code> and retained for compatibility. 
     *  
     *  In effective mode, comments are returned that are currently effective. 
     *  In any effective mode, effective comments and those currently expired 
     *  are returned. 
     *
     *  @param  commentId the <code> Id </code> of the <code> Comment </code> 
     *          to retrieve 
     *  @return the returned <code> Comment </code> 
     *  @throws org.osid.NotFoundException no <code> Comment </code> found 
     *          with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> commentId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.commenting.Comment getComment(org.osid.id.Id commentId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CommentList </code> corresponding to the given <code> 
     *  IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  comments specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible comments may be omitted from the list and may present the 
     *  elements in any order including returning a unique set. 
     *  
     *  In effective mode, comments are returned that are currently effective. 
     *  In any effective mode, effective comments and those currently expired 
     *  are returned. 
     *
     *  @param  commentIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Comment list </code> 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> commentIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.commenting.CommentList getCommentsByIds(org.osid.id.IdList commentIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CommentList </code> corresponding to the given comment 
     *  genus <code> Type </code> which does not include comments of genus 
     *  types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  comments or an error results. Otherwise, the returned list may contain 
     *  only those comments that are accessible through this session. 
     *  
     *  In effective mode, comments are returned that are currently effective. 
     *  In any effective mode, effective comments and those currently expired 
     *  are returned. 
     *
     *  @param  commentGenusType a comment genus type 
     *  @return the returned <code> Comment </code> list 
     *  @throws org.osid.NullArgumentException <code> commentGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.commenting.CommentList getCommentsByGenusType(org.osid.type.Type commentGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CommentList </code> corresponding to the given comment 
     *  genus <code> Type </code> and include any additional comments with 
     *  genus types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  comments or an error results. Otherwise, the returned list may contain 
     *  only those comments that are accessible through this session. 
     *  
     *  In effective mode, comments are returned that are currently effective. 
     *  In any effective mode, effective comments and those currently expired 
     *  are returned. 
     *
     *  @param  commentGenusType a comment genus type 
     *  @return the returned <code> Comment </code> list 
     *  @throws org.osid.NullArgumentException <code> commentGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.commenting.CommentList getCommentsByParentGenusType(org.osid.type.Type commentGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CommentList </code> containing the given comment record 
     *  <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  comments or an error results. Otherwise, the returned list may contain 
     *  only those comments that are accessible through this session. 
     *  
     *  In effective mode, comments are returned that are currently effective. 
     *  In any effective mode, effective comments and those currently expired 
     *  are returned. 
     *
     *  @param  commentRecordType a comment record type 
     *  @return the returned <code> Comment </code> list 
     *  @throws org.osid.NullArgumentException <code> commentRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.commenting.CommentList getCommentsByRecordType(org.osid.type.Type commentRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CommentList </code> effective during the entire given 
     *  date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known comments or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  comments that are accessible through this session. 
     *  
     *  In effective mode, comments are returned that are currently effective. 
     *  In any effective mode, effective comments and those currently expired 
     *  are returned. 
     *
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> Comment </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.commenting.CommentList getCommentsOnDate(org.osid.calendaring.DateTime from, 
                                                             org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CommentList </code> of a given genus type and effective 
     *  during the entire given date range inclusive but not confined to the 
     *  date range. 
     *  
     *  In plenary mode, the returned list contains all known comments or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  comments that are accessible through this session. 
     *  
     *  In effective mode, comments are returned that are currently effective. 
     *  In any effective mode, effective comments and those currently expired 
     *  are returned. 
     *
     *  @param  commentGenusType a comment genus type 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> Comment </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> commentGenusType, from, 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.commenting.CommentList getCommentsByGenusTypeOnDate(org.osid.type.Type commentGenusType, 
                                                                        org.osid.calendaring.DateTime from, 
                                                                        org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of comments corresponding to a resource <code> Id. </code> 
     *  
     *  In plenary mode, the returned list contains all known comments or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  comments that are accessible through this session. 
     *  
     *  In effective mode, comments are returned that are currently effective. 
     *  In any effective mode, effective comments and those currently expired 
     *  are returned. 
     *
     *  @param  resourceId the <code> Id </code> of the resource 
     *  @return the returned <code> CommentList </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.commenting.CommentList getCommentsForCommentor(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all comments corresponding to a resource <code> Id 
     *  </code> and effective during the entire given date range inclusive but 
     *  not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known comments or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  comments that are accessible through this session. 
     *  
     *  In effective mode, comments are returned that are currently effective. 
     *  In any effective mode, effective comments and those currently expired 
     *  are returned. 
     *
     *  @param  resourceId the <code> Id </code> of the resource 
     *  @param  from from date 
     *  @param  to to date 
     *  @return the returned <code> CommentList </code> 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, from, 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.commenting.CommentList getCommentsForCommentorOnDate(org.osid.id.Id resourceId, 
                                                                         org.osid.calendaring.DateTime from, 
                                                                         org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of comments of the given genus type corresponding to a 
     *  resource <code> Id. </code> 
     *  
     *  In plenary mode, the returned list contains all known comments or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  comments that are accessible through this session. 
     *  
     *  In effective mode, comments are returned that are currently effective. 
     *  In any effective mode, effective comments and those currently expired 
     *  are returned. 
     *
     *  @param  resourceId the <code> Id </code> of the resource 
     *  @param  commentGenusType the comment genus type 
     *  @return the returned <code> CommentList </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> or 
     *          <code> commentGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.commenting.CommentList getCommentsByGenusTypeForCommentor(org.osid.id.Id resourceId, 
                                                                              org.osid.type.Type commentGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all comments of the given genus type corresponding to a 
     *  resource <code> Id </code> and effective during the entire given date 
     *  range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known comments or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  comments that are accessible through this session. 
     *  
     *  In effective mode, comments are returned that are currently effective. 
     *  In any effective mode, effective comments and those currently expired 
     *  are returned. 
     *
     *  @param  resourceId the <code> Id </code> of the resource 
     *  @param  commentGenusType the comment genus type 
     *  @param  from from date 
     *  @param  to to date 
     *  @return the returned <code> CommentList </code> 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, 
     *          commentGenusType, from, </code> or <code> to </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.commenting.CommentList getCommentsByGenusTypeForCommentorOnDate(org.osid.id.Id resourceId, 
                                                                                    org.osid.type.Type commentGenusType, 
                                                                                    org.osid.calendaring.DateTime from, 
                                                                                    org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of comments corresponding to a reference <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  comments or an error results. Otherwise, the returned list may contain 
     *  only those comments that are accessible through this session. 
     *  
     *  In effective mode, comments are returned that are currently effective. 
     *  In any effective mode, effective comments and those currently expired 
     *  are returned. 
     *
     *  @param  referenceId the <code> Id </code> of the reference 
     *  @return the returned <code> CommentList </code> 
     *  @throws org.osid.NullArgumentException <code> referenceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.commenting.CommentList getCommentsForReference(org.osid.id.Id referenceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all comments corresponding to a reference <code> Id 
     *  </code> and effective during the entire given date range inclusive but 
     *  not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known comments or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  comments that are accessible through this session. 
     *  
     *  In effective mode, comments are returned that are currently effective. 
     *  In any effective mode, effective comments and those currently expired 
     *  are returned. 
     *
     *  @param  referenceId a reference <code> Id </code> 
     *  @param  from from date 
     *  @param  to to date 
     *  @return the returned <code> CommentList </code> 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> referenceId, from, 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.commenting.CommentList getCommentsForReferenceOnDate(org.osid.id.Id referenceId, 
                                                                         org.osid.calendaring.DateTime from, 
                                                                         org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of comments of the given genus type corresponding to a 
     *  reference <code> Id. </code> 
     *  
     *  In plenary mode, the returned list contains all known comments or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  comments that are accessible through this session. 
     *  
     *  In effective mode, comments are returned that are currently effective. 
     *  In any effective mode, effective comments and those currently expired 
     *  are returned. 
     *
     *  @param  referenceId the <code> Id </code> of the reference 
     *  @param  commentGenusType the comment genus type 
     *  @return the returned <code> CommentList </code> 
     *  @throws org.osid.NullArgumentException <code> referenceId </code> or 
     *          <code> commentGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.commenting.CommentList getCommentsByGenusTypeForReference(org.osid.id.Id referenceId, 
                                                                              org.osid.type.Type commentGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all comments of the given genus type corresponding to a 
     *  reference <code> Id </code> and effective during the entire given date 
     *  range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known comments or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  comments that are accessible through this session. 
     *  
     *  In effective mode, comments are returned that are currently effective. 
     *  In any effective mode, effective comments and those currently expired 
     *  are returned. 
     *
     *  @param  referenceId a reference <code> Id </code> 
     *  @param  commentGenusType the comment genus type 
     *  @param  from from date 
     *  @param  to to date 
     *  @return the returned <code> CommentList </code> 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> referenceId, 
     *          commentGenusType, from, </code> or <code> to </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.commenting.CommentList getCommentsByGenusTypeForReferenceOnDate(org.osid.id.Id referenceId, 
                                                                                    org.osid.type.Type commentGenusType, 
                                                                                    org.osid.calendaring.DateTime from, 
                                                                                    org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of comments corresponding to a resource and reference 
     *  <code> Id. </code> 
     *  
     *  In plenary mode, the returned list contains all known comments or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  comments that are accessible through this session. 
     *  
     *  In effective mode, comments are returned that are currently effective. 
     *  In any effective mode, effective comments and those currently expired 
     *  are returned. 
     *
     *  @param  resourceId the <code> Id </code> of the resource 
     *  @param  referenceId the <code> Id </code> of the reference 
     *  @return the returned <code> CommentList </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> or 
     *          <code> referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.commenting.CommentList getCommentsForCommentorAndReference(org.osid.id.Id resourceId, 
                                                                               org.osid.id.Id referenceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all comments corresponding to a resource and reference 
     *  <code> Id </code> and effective during the entire given date range 
     *  inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known comments or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  comments that are accessible through this session. 
     *  
     *  In effective mode, comments are returned that are currently effective. 
     *  In any effective mode, effective comments and those currently expired 
     *  are returned. 
     *
     *  @param  resourceId the <code> Id </code> of the resource 
     *  @param  referenceId a reference <code> Id </code> 
     *  @param  from from date 
     *  @param  to to date 
     *  @return the returned <code> CommentList </code> 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, referenceId, 
     *          from, </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.commenting.CommentList getCommentsForCommentorAndReferenceOnDate(org.osid.id.Id resourceId, 
                                                                                     org.osid.id.Id referenceId, 
                                                                                     org.osid.calendaring.DateTime from, 
                                                                                     org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of comments of the given genus type corresponding to a 
     *  resource and reference <code> Id. </code> 
     *  
     *  In plenary mode, the returned list contains all known comments or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  comments that are accessible through this session. 
     *  
     *  In effective mode, comments are returned that are currently effective. 
     *  In any effective mode, effective comments and those currently expired 
     *  are returned. 
     *
     *  @param  resourceId the <code> Id </code> of the resource 
     *  @param  referenceId the <code> Id </code> of the reference 
     *  @param  commentGenusType the comment genus type 
     *  @return the returned <code> CommentList </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, referenceId 
     *          </code> or <code> commentGenusType </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.commenting.CommentList getCommentsByGenusTypeForCommentorAndReference(org.osid.id.Id resourceId, 
                                                                                          org.osid.id.Id referenceId, 
                                                                                          org.osid.type.Type commentGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all comments corresponding to a resource and reference 
     *  <code> Id </code> and effective during the entire given date range 
     *  inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known comments or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  comments that are accessible through this session. 
     *  
     *  In effective mode, comments are returned that are currently effective. 
     *  In any effective mode, effective comments and those currently expired 
     *  are returned. 
     *
     *  @param  resourceId the <code> Id </code> of the resource 
     *  @param  referenceId a reference <code> Id </code> 
     *  @param  commentGenusType the comment genus type 
     *  @param  from from date 
     *  @param  to to date 
     *  @return the returned <code> CommentList </code> 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, referenceId, 
     *          commentGenusType, from, </code> or <code> to </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.commenting.CommentList getCommentsByGenusTypeForCommentorAndReferenceOnDate(org.osid.id.Id resourceId, 
                                                                                                org.osid.id.Id referenceId, 
                                                                                                org.osid.type.Type commentGenusType, 
                                                                                                org.osid.calendaring.DateTime from, 
                                                                                                org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all comments. 
     *  
     *  In plenary mode, the returned list contains all known comments or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  comments that are accessible through this session. 
     *  
     *  In effective mode, comments are returned that are currently effective. 
     *  In any effective mode, effective comments and those currently expired 
     *  are returned. 
     *
     *  @return a list of comments 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.commenting.CommentList getComments()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
