//
// org.osid.commenting.CommentQuery
//
//     The OSID Java specification for org.osid.commenting.CommentQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.commenting;


/**
 *  <p>This is the query for searching comments. Each method specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface CommentQuery
    extends org.osid.OsidRelationshipQuery {


    /**
     *  Sets reference <code> Id. </code> 
     *
     *  @param  sourceId a source <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> sourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchReferenceId(org.osid.id.Id sourceId, boolean match);


    /**
     *  Clears the reference <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearReferenceIdTerms();


    /**
     *  Sets a resource <code> Id </code> to match a commentor. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCommentorId(org.osid.id.Id resourceId, boolean match);


    /**
     *  Clears the resource <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCommentorIdTerms();


    /**
     *  Tests if a <code> ResourceQuery </code> is available. 
     *
     *  @return <code> true </code> if a resource query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommentorQuery();


    /**
     *  Gets the query for a resource query. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the resource query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommentorQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommentorQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceQuery getCommentorQuery();


    /**
     *  Clears the resource terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCommentorTerms();


    /**
     *  Sets an agent <code> Id. </code> 
     *
     *  @param  agentId an agent <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> agentId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCommentingAgentId(org.osid.id.Id agentId, boolean match);


    /**
     *  Clears the agent <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCommentingAgentIdTerms();


    /**
     *  Tests if an <code> AgentQuery </code> is available. 
     *
     *  @return <code> true </code> if an agent query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommentingAgentQuery();


    /**
     *  Gets the query for an agent query. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the agent query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommentingAgentQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommentingAgentQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.authentication.AgentQuery getCommentingAgentQuery();


    /**
     *  Clears the agent terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCommentingAgentTerms();


    /**
     *  Matches text. 
     *
     *  @param  text the text 
     *  @param  stringMatchType a string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> text </code> is not 
     *          of <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> text </code> is <code> 
     *          null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchText(String text, org.osid.type.Type stringMatchType, 
                          boolean match);


    /**
     *  Matches a comment that has any text assigned. 
     *
     *  @param  match <code> true </code> to match comments with any text, 
     *          <code> false </code> to match comments with no text 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyText(boolean match);


    /**
     *  Clears the text terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTextTerms();


    /**
     *  Sets a grade <code> Id. </code> 
     *
     *  @param  gradeId a grade <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> gradeId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRatingId(org.osid.id.Id gradeId, boolean match);


    /**
     *  Clears the rating <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRatingIdTerms();


    /**
     *  Tests if a <code> GradeQuery </code> is available. 
     *
     *  @return <code> true </code> if a rating query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRatingQuery();


    /**
     *  Gets the query for a rating query. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the rating query 
     *  @throws org.osid.UnimplementedException <code> supportsRatingQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRatingQuery() </code> is <code> true. </code> 
     */

    public org.osid.grading.GradeQuery getRatingQuery();


    /**
     *  Matches books with any rating. 
     *
     *  @param  match <code> true </code> to match comments with any rating, 
     *          <code> false </code> to match comments with no ratings 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRating(boolean match);


    /**
     *  Clears the rating terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRatingTerms();


    /**
     *  Sets the book <code> Id </code> for this query to match comments 
     *  assigned to books. 
     *
     *  @param  bookId a book <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> bookId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBookId(org.osid.id.Id bookId, boolean match);


    /**
     *  Clears the book <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBookIdTerms();


    /**
     *  Tests if a <code> BookQuery </code> is available. 
     *
     *  @return <code> true </code> if a book query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBookQuery();


    /**
     *  Gets the query for a book query. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the book query 
     *  @throws org.osid.UnimplementedException <code> supportsBookQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBookQuery() </code> is <code> true. </code> 
     */

    public org.osid.commenting.BookQuery getBookQuery();


    /**
     *  Clears the book terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBookTerms();


    /**
     *  Gets the comment query record corresponding to the given <code> 
     *  Comment </code> record <code> Type. </code> Multiple record retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @param  commentRecordType a comment record type 
     *  @return the comment query record 
     *  @throws org.osid.NullArgumentException <code> commentRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(commentRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.commenting.records.CommentQueryRecord getCommentQueryRecord(org.osid.type.Type commentRecordType)
        throws org.osid.OperationFailedException;
}
