//
// org.osid.commenting.CommentQueryInspector
//
//     The OSID Java specification for org.osid.commenting.CommentQueryInspector.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.commenting;


/**
 *  <p>The comment query inspector for examining comment queries. </p>
 */

public interface CommentQueryInspector
    extends org.osid.OsidRelationshipQueryInspector {


    /**
     *  Gets the reference <code> Id </code> terms. 
     *
     *  @return the reference <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getReferenceIdTerms();


    /**
     *  Gets the resource <code> Id </code> terms. 
     *
     *  @return the resource <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getCommentorIdTerms();


    /**
     *  Gets the resource terms. 
     *
     *  @return the resource terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceQueryInspector[] getCommentorTerms();


    /**
     *  Gets the agent <code> Id </code> terms. 
     *
     *  @return the agent <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getCommentingAgentIdTerms();


    /**
     *  Gets the agent terms. 
     *
     *  @return the agent terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.AgentQueryInspector[] getCommentingAgentTerms();


    /**
     *  Gets the text query terms. 
     *
     *  @return the text query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.StringTerm[] getTextTerms();


    /**
     *  Gets the rating <code> Id </code> terms. 
     *
     *  @return the rating <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getRatingIdTerms();


    /**
     *  Gets the rating terms. 
     *
     *  @return the rating terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeQueryInspector[] getRatingTerms();


    /**
     *  Gets the book <code> Id </code> terms. 
     *
     *  @return the book <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getBookIdTerms();


    /**
     *  Gets the book terms. 
     *
     *  @return the book terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.commenting.BookQueryInspector[] getBookTerms();


    /**
     *  Gets the comment query inspector record corresponding to the given 
     *  <code> Comment </code> record <code> Type. </code> 
     *
     *  @param  commentRecordType a comment record type 
     *  @return the comment query inspector record 
     *  @throws org.osid.NullArgumentException <code> commentRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(commentRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.commenting.records.CommentQueryInspectorRecord getCommentQueryInspectorRecord(org.osid.type.Type commentRecordType)
        throws org.osid.OperationFailedException;
}
