//
// org.osid.commenting.CommentSmartBookSession
//
//     The OSID Java specification for org.osid.commenting.CommentSmartBookSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.commenting;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. A <code> CommentQuery </code> can be retrieved from this session 
 *  and mapped to this <code> Book </code> to create a virtual collection of 
 *  <code> Comments. </code> The comments may be sequenced using the <code> 
 *  CommentSearchOrder </code> from this session. </p> 
 *  
 *  <p> This <code> Book </code> has a default query that matches any comment 
 *  and a default search order that specifies no sequencing. The queries may 
 *  be examined using a <code> CommentQueryInspector. </code> The query may be 
 *  modified by converting the inspector back to a <code> CommentQuery. 
 *  </code> </p>
 */

public interface CommentSmartBookSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Book </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Book Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBookId();


    /**
     *  Gets the <code> Book </code> associated with this session. 
     *
     *  @return the <code> Book </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.commenting.Book getBook()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart books. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart book management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartBooks();


    /**
     *  Gets a comment query. 
     *
     *  @return the comment query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.commenting.CommentQuery getCommentQuery();


    /**
     *  Gets a comment search order. 
     *
     *  @return the comment search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.commenting.CommentSearchOrder getCommentSearchOrder();


    /**
     *  Applies a comment query to this book. 
     *
     *  @param  commentQuery the comment query 
     *  @throws org.osid.NullArgumentException <code> commentQuery </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> commentQuery </code> not 
     *          of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyCommentQuery(org.osid.commenting.CommentQuery commentQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a comment query inspector for this book. 
     *
     *  @return the comment query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.commenting.CommentQueryInspector inspectCommentQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a comment search order to this book. 
     *
     *  @param  commentSearchOrder the comment search order 
     *  @throws org.osid.NullArgumentException <code> commentSearchOrder 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> commentSearchOrder 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyCommentSequencing(org.osid.commenting.CommentSearchOrder commentSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a comment query from an inspector. 
     *
     *  @param  commentQueryInspector a query inspector 
     *  @return the comment query 
     *  @throws org.osid.NullArgumentException <code> commentQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> commentQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.commenting.CommentQuery getCommentQueryFromInspector(org.osid.commenting.CommentQueryInspector commentQueryInspector);
}
