//
// org.osid.commenting.CommentingManager
//
//     The OSID Java specification for org.osid.commenting.CommentingManager.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.commenting;


/**
 *  <p>The commenting manager provides access to commenting sessions and 
 *  provides interoperability tests for various aspects of this service. The 
 *  sessions included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> CommentLookupSession: </code> a session to lookup comments 
 *      </li> 
 *      <li> <code> RatingLookupSession: </code> a session to lookup comments 
 *      </li> 
 *      <li> <code> CommentQuerySession: </code> a session to query comments 
 *      </li> 
 *      <li> <code> CommentSearchSession: </code> a session to search comments 
 *      </li> 
 *      <li> <code> CommentAdminSession: </code> a session to manage comments 
 *      </li> 
 *      <li> <code> CommentNotificationSession: </code> a session to subscribe 
 *      to notifications of comment changes </li> 
 *      <li> <code> CommentBookSession: </code> a session for looking up 
 *      comment and book mappings </li> 
 *      <li> <code> CommentBookAssignmentSession: </code> a session for 
 *      managing comment and book mappings </li> 
 *      <li> <code> CommentSmartBookSession: </code> a session to manage 
 *      dynamic comment books </li> 
 *      <li> <code> BookLookupSession: </code> a session to retrieve books 
 *      </li> 
 *      <li> <code> BookQuerySession: </code> a session to query books </li> 
 *      <li> <code> BookSearchSession: </code> a session to search for books 
 *      </li> 
 *      <li> <code> BookAdminSession: </code> a session to create, update and 
 *      delete books </li> 
 *      <li> <code> BookNotificationSession: </code> a session to receive 
 *      notifications for changes in books </li> 
 *      <li> <code> BookHierarchyTraversalSession: </code> a session to 
 *      traverse hierarchies of books </li> 
 *      <li> <code> BookHierarchyDesignSession: </code> a session to manage 
 *      hierarchies of books </li> 
 *  </ul>
 *  
 *  
 *  <p> The commenting manager also provides a profile for determing the 
 *  supported search types supported by this service. </p>
 */

public interface CommentingManager
    extends org.osid.OsidManager,
            org.osid.commenting.CommentingProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the comment lookup 
     *  service. 
     *
     *  @return a <code> CommentLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsCommentLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommentLookup() </code> is <code> true. </code> 
     */

    public org.osid.commenting.CommentLookupSession getCommentLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the comment lookup 
     *  service for the given book. 
     *
     *  @param  bookId the <code> Id </code> of the <code> Book </code> 
     *  @return a <code> CommentLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Book </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> bookId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsCommentLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommentLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.commenting.CommentLookupSession getCommentLookupSessionForBook(org.osid.id.Id bookId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the rating lookup 
     *  service. 
     *
     *  @return a <code> RatingLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRatingLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRatingLookup() </code> is <code> true. </code> 
     */

    public org.osid.commenting.RatingLookupSession getRatingLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the rating lookup 
     *  service for the given book. 
     *
     *  @param  bookId the <code> Id </code> of the <code> Book </code> 
     *  @return a <code> RatingLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Book </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> bookId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRatingLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRatingLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.commenting.RatingLookupSession getRatingLookupSessionForBook(org.osid.id.Id bookId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the comment query 
     *  service. 
     *
     *  @return a <code> CommentQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsCommentQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommentQuery() </code> is <code> true. </code> 
     */

    public org.osid.commenting.CommentQuerySession getCommentQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the comment query 
     *  service for the given book. 
     *
     *  @param  bookId the <code> Id </code> of the <code> Book </code> 
     *  @return a <code> CommentQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Book </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> bookId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsCommentQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommentQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.commenting.CommentQuerySession getCommentQuerySessionForBook(org.osid.id.Id bookId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the comment search 
     *  service. 
     *
     *  @return a <code> CommentSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsCommentSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommentSearch() </code> is <code> true. </code> 
     */

    public org.osid.commenting.CommentSearchSession getCommentSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the comment search 
     *  service for the given book. 
     *
     *  @param  bookId the <code> Id </code> of the <code> Book </code> 
     *  @return a <code> CommentSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Book </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> bookId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsCommentSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommentSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.commenting.CommentSearchSession getCommentSearchSessionForBook(org.osid.id.Id bookId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the comment 
     *  administration service. 
     *
     *  @return a <code> CommentAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsCommentAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommentAdmin() </code> is <code> true. </code> 
     */

    public org.osid.commenting.CommentAdminSession getCommentAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the comment 
     *  administration service for the given book. 
     *
     *  @param  bookId the <code> Id </code> of the <code> Book </code> 
     *  @return a <code> CommentAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Book </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> bookId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsCommentAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommentAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.commenting.CommentAdminSession getCommentAdminSessionForBook(org.osid.id.Id bookId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the comment 
     *  notification service. 
     *
     *  @param  commentReceiver the receiver 
     *  @return a <code> CommentNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> commentReceiver </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommentNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommentNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.commenting.CommentNotificationSession getCommentNotificationSession(org.osid.commenting.CommentReceiver commentReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the comment 
     *  notification service for the given book. 
     *
     *  @param  commentReceiver the receiver 
     *  @param  bookId the <code> Id </code> of the <code> Book </code> 
     *  @return a <code> CommentNotificationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Book </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> commentReceiver </code> 
     *          or <code> bookId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommentNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommentNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.commenting.CommentNotificationSession getCommentNotificationSessionForBook(org.osid.commenting.CommentReceiver commentReceiver, 
                                                                                               org.osid.id.Id bookId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving comment to book mappings. 
     *
     *  @return a <code> CommentBookSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsCommentBook() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommentBook() </code> is <code> true. </code> 
     */

    public org.osid.commenting.CommentBookSession getCommentBookSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning comment to book mappings. 
     *
     *  @return a <code> CommentBookAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommentBookAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommentBookAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.commenting.CommentBookAssignmentSession getCommentBookAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session associated with the comment smart book for the given 
     *  book. 
     *
     *  @param  bookId the <code> Id </code> of the book 
     *  @return a <code> CommentSmartBookSession </code> 
     *  @throws org.osid.NotFoundException <code> bookId </code> not found 
     *  @throws org.osid.NullArgumentException <code> bookId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommentSmartBook() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommentSmartBook() </code> is <code> true. </code> 
     */

    public org.osid.commenting.CommentSmartBookSession getCommentSmartBookSession(org.osid.id.Id bookId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the book lookup 
     *  service. 
     *
     *  @return a <code> BookLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBookLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBookLookup() </code> is <code> true. </code> 
     */

    public org.osid.commenting.BookLookupSession getBookLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the book query 
     *  service. 
     *
     *  @return a <code> BookQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBookQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBookQuery() </code> is <code> true. </code> 
     */

    public org.osid.commenting.BookQuerySession getBookQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the book search 
     *  service. 
     *
     *  @return a <code> BookSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBookSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBookSearch() </code> is <code> true. </code> 
     */

    public org.osid.commenting.BookSearchSession getBookSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the book 
     *  administrative service. 
     *
     *  @return a <code> BookAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBookAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBookAdmin() </code> is <code> true. </code> 
     */

    public org.osid.commenting.BookAdminSession getBookAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the book 
     *  notification service. 
     *
     *  @param  bookReceiver the receiver 
     *  @return a <code> BookNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> bookReceiver </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBookNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBookNotification() </code> is <code> true. </code> 
     */

    public org.osid.commenting.BookNotificationSession getBookNotificationSession(org.osid.commenting.BookReceiver bookReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the book hierarchy 
     *  service. 
     *
     *  @return a <code> BookHierarchySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBookHierarchy() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBookHierarchy() </code> is <code> true. </code> 
     */

    public org.osid.commenting.BookHierarchySession getBookHierarchySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the book hierarchy 
     *  design service. 
     *
     *  @return a <code> BookHierarchyDesignSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBookHierarchyDesign() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBookHierarchyDesign() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.commenting.BookHierarchyDesignSession getBookHierarchyDesignSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a <code> CommentingBatchManager. </code> 
     *
     *  @return a <code> CommentingBatchManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommentingBatch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommentingBatch() </code> is <code> true. </code> 
     */

    public org.osid.commenting.batch.CommentingBatchManager getCommentingBatchManager()
        throws org.osid.OperationFailedException;
}
