//
// org.osid.commenting.CommentingProfile
//
//     The OSID Java specification for org.osid.commenting.CommentingProfile.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.commenting;


/**
 *  <p>The commenting profile describes the interoperability among commenting 
 *  services. </p>
 */

public interface CommentingProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any book federation is exposed. Federation is exposed when a 
     *  specific book may be identified, selected and used to create a lookup 
     *  or admin session. Federation is not exposed when a set of books 
     *  appears as a single book. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests for the availability of a comment lookup service. 
     *
     *  @return <code> true </code> if comment lookup is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommentLookup();


    /**
     *  Tests for the availability of a rating lookup service. 
     *
     *  @return <code> true </code> if rating lookup is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRatingLookup();


    /**
     *  Tests if querying comments is available. 
     *
     *  @return <code> true </code> if comment query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommentQuery();


    /**
     *  Tests if searching for comments is available. 
     *
     *  @return <code> true </code> if comment search is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommentSearch();


    /**
     *  Tests if managing comments is available. 
     *
     *  @return <code> true </code> if comment admin is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommentAdmin();


    /**
     *  Tests if comment notification is available. 
     *
     *  @return <code> true </code> if comment notification is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommentNotification();


    /**
     *  Tests if a comment to book lookup session is available. 
     *
     *  @return <code> true </code> if comment book lookup session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommentBook();


    /**
     *  Tests if a comment to book assignment session is available. 
     *
     *  @return <code> true </code> if comment book assignment is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommentBookAssignment();


    /**
     *  Tests if a comment smart booking session is available. 
     *
     *  @return <code> true </code> if comment smart booking is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommentSmartBook();


    /**
     *  Tests for the availability of an book lookup service. 
     *
     *  @return <code> true </code> if book lookup is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBookLookup();


    /**
     *  Tests if querying books is available. 
     *
     *  @return <code> true </code> if book query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBookQuery();


    /**
     *  Tests if searching for books is available. 
     *
     *  @return <code> true </code> if book search is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBookSearch();


    /**
     *  Tests for the availability of a book administrative service for 
     *  creating and deleting books. 
     *
     *  @return <code> true </code> if book administration is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBookAdmin();


    /**
     *  Tests for the availability of a book notification service. 
     *
     *  @return <code> true </code> if book notification is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsBookNotification();


    /**
     *  Tests for the availability of a book hierarchy traversal service. 
     *
     *  @return <code> true </code> if book hierarchy traversal is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBookHierarchy();


    /**
     *  Tests for the availability of a book hierarchy design service. 
     *
     *  @return <code> true </code> if book hierarchy design is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsBookHierarchyDesign();


    /**
     *  Tests for the availability of a commenting batch service. 
     *
     *  @return <code> true </code> if commenting batch service is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsCommentingBatch();


    /**
     *  Gets the supported <code> Comment </code> record types. 
     *
     *  @return a list containing the supported comment record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCommentRecordTypes();


    /**
     *  Tests if the given <code> Comment </code> record type is supported. 
     *
     *  @param  commentRecordType a <code> Type </code> indicating a <code> 
     *          Comment </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> commentRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommentRecordType(org.osid.type.Type commentRecordType);


    /**
     *  Gets the supported comment search record types. 
     *
     *  @return a list containing the supported comment search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCommentSearchRecordTypes();


    /**
     *  Tests if the given comment search record type is supported. 
     *
     *  @param  commentSearchRecordType a <code> Type </code> indicating a 
     *          comment record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> commentSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommentSearchRecordType(org.osid.type.Type commentSearchRecordType);


    /**
     *  Gets the supported <code> Book </code> record types. 
     *
     *  @return a list containing the supported book record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getBookRecordTypes();


    /**
     *  Tests if the given <code> Book </code> record type is supported. 
     *
     *  @param  bookRecordType a <code> Type </code> indicating a <code> Book 
     *          </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> bookRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBookRecordType(org.osid.type.Type bookRecordType);


    /**
     *  Gets the supported book search record types. 
     *
     *  @return a list containing the supported book search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getBookSearchRecordTypes();


    /**
     *  Tests if the given book search record type is supported. 
     *
     *  @param  bookSearchRecordType a <code> Type </code> indicating a book 
     *          record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> bookSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBookSearchRecordType(org.osid.type.Type bookSearchRecordType);
}
