//
// org.osid.configuration.ConfigurationAdminSession
//
//     The OSID Java specification for org.osid.configuration.ConfigurationAdminSession.
//
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.configuration;


/**
 *  <p>This session creates, updates, and deletes <code> Configuration. 
 *  </code> The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Configuration, </code> a <code> ConfigurationForm </code> is requested 
 *  using <code> getConfigurationFormForCreate() </code> specifying the 
 *  desired record <code> Types </code> or none if no record <code> Types 
 *  </code> are needed. The returned <code> ConfigurationForm </code> will 
 *  indicate that it is to be used with a create operation and can be used to 
 *  examine metdata or validate data prior to creation. Once the <code> 
 *  ConfigurationForm </code> is submiited to a create operation, it cannot be 
 *  reused with another create operation unless the first operation was 
 *  unsuccessful. Each <code> ConfigurationForm </code> corresponds to an 
 *  attempted transaction. </p> 
 *  
 *  <p> For updates, <code> ConfigurationForms </code> are requested to the 
 *  <code> Configuration </code> <code> Id </code> that is to be updated using 
 *  <code> getConfigurationFormForUpdate(). </code> Similarly, the <code> 
 *  ConfigurationForm </code> has metadata about the data that can be updated 
 *  and it can perform validation before submitting the update. The <code> 
 *  ConfigurationForm </code> can only be used once for a successful update 
 *  and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Configurations. </code> </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface ConfigurationAdminSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can create <code> Configurations. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a C <code> onfiguration </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer create operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Configuration </code> creation 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateConfigurations();


    /**
     *  Tests if this user can create a single <code> Configuration </code> 
     *  using the desired record types. While <code> 
     *  ConfigurationManager.getConfigurationRecordTypes() </code> can be used 
     *  to examine which records are supported, this method tests which 
     *  record(s) are required for creating a specific <code> Configuration. 
     *  </code> Providing an empty array tests if a <code> Configuration 
     *  </code> can be created with no records. 
     *
     *  @param  configurationRecordTypes array of configuration record types 
     *  @return <code> true </code> if <code> Configuration </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> configurationRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateConfigurationWithRecordTypes(org.osid.type.Type[] configurationRecordTypes);


    /**
     *  Gets the configuration form for creating new configurations. A new 
     *  form should be requested for each create transaction. 
     *
     *  @param  configurationRecordTypes array of configuration record types 
     *  @return the configuration form 
     *  @throws org.osid.NullArgumentException <code> configurationRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.ConfigurationForm getConfigurationFormForCreate(org.osid.type.Type[] configurationRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Configuration. </code> 
     *
     *  @param  configurationForm the configuration form 
     *  @return the new <code> Configuration </code> 
     *  @throws org.osid.IllegalStateException <code> configurationForm 
     *          </code> already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> configurationForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> configurationForm </code> 
     *          did not originate from <code> getConfigurationFormForCreate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.Configuration createConfiguration(org.osid.configuration.ConfigurationForm configurationForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Configurations. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a C <code> onfiguration </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer update operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Configuration </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateConfigurations();


    /**
     *  Gets the configuration form for updating existing configurations. A 
     *  new configuration form should be requested for each update 
     *  transaction. 
     *
     *  @param  configurationId <code> Id </code> of a <code> Configuration 
     *          </code> 
     *  @return the configuration form 
     *  @throws org.osid.NotFoundException <code> configurationId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> configurationId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.ConfigurationForm getConfigurationFormForUpdate(org.osid.id.Id configurationId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing <code> Configuration. </code> 
     *
     *  @param  configurationForm the configuration form 
     *  @throws org.osid.IllegalStateException <code> configurationForm 
     *          </code> already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> configurationForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> configurationForm </code> 
     *          did not originate from <code> getConfigurationFormForUpdate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateConfiguration(org.osid.configuration.ConfigurationForm configurationForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> Configurations. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> Configuration </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer delete operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Configuration </code> deletion 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteConfigurations();


    /**
     *  Deletes a <code> Configuration. </code> 
     *
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> to delete 
     *  @throws org.osid.NotFoundException <code> configurationId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> configurationId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteConfiguration(org.osid.id.Id configurationId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Configurations. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Configuration </code> aliasing 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageConfigurationAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Configuration </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Configuration </code> is determined by the provider. The 
     *  new <code> Id </code> performs as an alias to the primary <code> Id. 
     *  </code> If the alias is a pointer to another configuration it is 
     *  reassigned to the given configuration <code> Id. </code> 
     *
     *  @param  configurationId the <code> Id </code> of a <code> 
     *          Configuration </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> configurationId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> configurationId </code> 
     *          or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasConfiguration(org.osid.id.Id configurationId, 
                                   org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
