//
// org.osid.configuration.ConfigurationQuery
//
//     The OSID Java specification for org.osid.configuration.ConfigurationQuery.
//
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.configuration;


/**
 *  <p>This is the query for searching configurations. Each method match 
 *  request produces an <code> AND </code> term while multiple invocations of 
 *  a method produces a nested <code> OR, </code> except for accessing the 
 *  <code> ConfigurationQuery </code> subinterface. </p>
 */

public interface ConfigurationQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Matches configurations which are parameter registries. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRegistry(boolean match);


    /**
     *  Clears the registry terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRegistryTerms();


    /**
     *  Adds a parameter <code> Id </code> for this query. 
     *
     *  @param  parameterId a parameter <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> parameterId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchParameterId(org.osid.id.Id parameterId, boolean match);


    /**
     *  Clears the parameter <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearParameterIdTerms();


    /**
     *  Tests if a <code> ParameterQuery </code> is available. 
     *
     *  @return <code> true </code> if a parameter query interface is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsParameterQuery();


    /**
     *  Gets the query interface for a parameter. 
     *
     *  @return the parameter query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParameterQuery() </code> is <code> true. </code> 
     */

    public org.osid.configuration.ParameterQuery getParameterQuery();


    /**
     *  Matches configurations that have any parameter. 
     *
     *  @param  match <code> true </code> to match configurations with any 
     *          parameter, <code> false </code> to match configurations with 
     *          no parameter 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyParameter(boolean match);


    /**
     *  Clears the parameter terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearParameterTerms();


    /**
     *  Adds a configuration <code> Id </code> for this query to match 
     *  configurations which have as an ancestor the specified configuration. 
     *
     *  @param  configurationId a configuration <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> configurationId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorConfigurationId(org.osid.id.Id configurationId, 
                                             boolean match);


    /**
     *  Clears the ancestor configuration <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorConfigurationIdTerms();


    /**
     *  Tests if a <code> ConfigurationQuery </code> is available. 
     *
     *  @return <code> true </code> if a configuration query interface is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorConfigurationQuery();


    /**
     *  Gets the query interface for a configuration. 
     *
     *  @return the configuration query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorConfigurationQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorConfigurationQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.configuration.ConfigurationQuery getAncestorConfigurationQuery();


    /**
     *  Matches configurations that have any ancestor. 
     *
     *  @param  match <code> true </code> to match configurations with any 
     *          ancestor, <code> false </code> to match root configurations 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorConfiguration(boolean match);


    /**
     *  Clears the ancestor configuration terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorConfigurationTerms();


    /**
     *  Adds a configuration <code> Id </code> for this query to match 
     *  configurations which have as a descendant the specified configuration. 
     *
     *  @param  configurationId a configuration <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> configurationId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantConfigurationId(org.osid.id.Id configurationId, 
                                               boolean match);


    /**
     *  Clears the descendant configuration <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantConfigurationIdTerms();


    /**
     *  Tests if a <code> ConfigurationQuery </code> is available. 
     *
     *  @return <code> true </code> if a configuration query interface is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantConfigurationQuery();


    /**
     *  Gets the query interface for a configuration. 
     *
     *  @return the configuration query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantConfigurationQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantConfigurationQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.configuration.ConfigurationQuery getDescendantConfigurationQuery();


    /**
     *  Matches configurations that have any descendant. 
     *
     *  @param  match <code> true </code> to match configurations with any 
     *          descendant, <code> false </code> to match leaf configurations 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantConfiguration(boolean match);


    /**
     *  Clears the descendant configuration terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantConfigurationTerms();


    /**
     *  Gets the configuration query record corresponding to the given <code> 
     *  Configuration </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  configurationRecordType a configuration record type 
     *  @return the configuration query record 
     *  @throws org.osid.NullArgumentException <code> configurationRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(configurationRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.records.ConfigurationQueryRecord getConfigurationQueryRecord(org.osid.type.Type configurationRecordType)
        throws org.osid.OperationFailedException;
}
