//
// org.osid.configuration.ConfigurationSearchSession
//
//     The OSID Java specification for org.osid.configuration.ConfigurationSearchSession.
//
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.configuration;


/**
 *  <p>This session provides methods for searching among <code> Configuration 
 *  </code> objects. The search query is constructed using the <code> 
 *  ConfigurationQuery. </code> </p> 
 *  
 *  <p> <code> getConfigurationsByQuery() </code> is the basic search method 
 *  and returns a list of <code> Configuration </code> objects.A more advanced 
 *  search may be performed with <code> getConfigurationsBySearch(). </code> 
 *  It accepts a <code> ConfigurationSearch </code> in addition to the query 
 *  for the purpose of specifying additional options affecting the entire 
 *  search, such as ordering. <code> getConfigurationsBySearch() </code> 
 *  returns a <code> ConfigurationSearchResults </code> that can be used to 
 *  access the resulting <code> ConfigurationList </code> or be used to 
 *  perform a search within the result set through <code> ConfigurationSearch. 
 *  </code> </p> 
 *  
 *  <p> Configurations may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> 
 *  ConfigurationQuery. </code> The returns in this session may not be cast 
 *  directly to these interfaces. </p>
 */

public interface ConfigurationSearchSession
    extends org.osid.configuration.ConfigurationQuerySession {


    /**
     *  Gets a configuration search. 
     *
     *  @return the configuration search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.ConfigurationSearch getConfigurationSearch();


    /**
     *  Gets a log search order. The <code> ConfigurationSearchOrder </code> 
     *  is supplied to a <code> ConfigurationSearch </code> to specify the 
     *  ordering of results. 
     *
     *  @return the configuration search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.ConfigurationSearchOrder getConfigurationSearchOrder();


    /**
     *  Gets a list of <code> Configurations </code> matching the given 
     *  search. Each element in the array is OR'd. 
     *
     *  @param  configurationQuery the configuration query 
     *  @param  configurationSearch the configuration search 
     *  @return the configuration search results 
     *  @throws org.osid.NullArgumentException <code> configurationQuery 
     *          </code> or <code> configurationSearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> configurationQuery 
     *          </code> or <code> configurationSearch </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.ConfigurationSearchResults getConfigurationsBySearch(org.osid.configuration.ConfigurationQuery configurationQuery, 
                                                                                       org.osid.configuration.ConfigurationSearch configurationSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a configuration query from an inspector. The inspector is 
     *  available from a <code> ConfigurationSearchResults. </code> 
     *
     *  @param  configurationQueryInspector a configuration query inspector 
     *  @return the configuration query 
     *  @throws org.osid.NullArgumentException <code> 
     *          configurationQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          configurationQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.ConfigurationQuery getConfigurationQueryFromInspector(org.osid.configuration.ConfigurationQueryInspector configurationQueryInspector);
}
