//
// org.osid.configuration.ParameterConfigurationAssignmentSession
//
//     The OSID Java specification for org.osid.configuration.ParameterConfigurationAssignmentSession.
//
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.configuration;


/**
 *  <p>This session provides methods to re-assign <code> Parameters </code> to 
 *  <code> Configurations. </code> A <code> Parameter </code> may appear in 
 *  multiple <code> Configurations </code> and removing the last reference to 
 *  a <code> Parameter </code> is the equivalent of deleting it which may or 
 *  may not be permitted. Each <code> Configuration </code> may have its own 
 *  authorizations as to who is allowed to operate on it. </p> 
 *  
 *  <p> Moving or adding a reference of a <code> Parameter </code> to another 
 *  <code> Configuration </code> is not a copy operation (eg: does not change 
 *  its <code> Id </code> ). </p>
 */

public interface ParameterConfigurationAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can change parameter configuration mappings. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not wish to offer assignment 
     *  operations. 
     *
     *  @return <code> false </code> if parameter configuration assignment is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignParameterConfigurations();


    /**
     *  Tests if this user can alter parameter/configuration parameters. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known parameter methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> 
     *  @return <code> false </code> if configuration is not authorized, 
     *          <code> true </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> configurationId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignParametersToConfiguration(org.osid.id.Id configurationId);


    /**
     *  Gets a list of configurations including and under the given 
     *  configuration node in which any parameter can be assigned. 
     *
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> 
     *  @return list of assignable configuration <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> configurationId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableConfigurationIds(org.osid.id.Id configurationId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of configurations including and under the given 
     *  configuration node in which a specific parameter can be assigned. 
     *
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> 
     *  @param  parameterId the <code> Id </code> of the <code> Parameter 
     *          </code> 
     *  @return list of assignable configuration <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> configurationId </code> 
     *          or <code> parameterId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableConfigurationIdsForParameter(org.osid.id.Id configurationId, 
                                                                        org.osid.id.Id parameterId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> Parameter </code> to a <code> Configuration. 
     *  </code> 
     *
     *  @param  parameterId the <code> Id </code> of the <code> Parameter 
     *          </code> 
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> 
     *  @throws org.osid.AlreadyExistsException <code> parameterId </code> and 
     *          <code> configurationId </code> already mapped 
     *  @throws org.osid.NotFoundException <code> parameterId </code> or 
     *          <code> configurationId </code> not found 
     *  @throws org.osid.NullArgumentException <code> parameterId </code> or 
     *          <code> configurationId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignParameterToConfiguration(org.osid.id.Id parameterId, 
                                               org.osid.id.Id configurationId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> Parameter </code> from a <code> Configuration. 
     *  </code> 
     *
     *  @param  parameterId the Id of the <code> Parameter </code> 
     *  @param  configurationId the Id of the <code> Configuration </code> 
     *  @throws org.osid.NotFoundException <code> parameterId </code> or 
     *          <code> configurationId </code> not found or is not mapped 
     *  @throws org.osid.NullArgumentException <code> parameterId </code> or 
     *          <code> configurationId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignParameterFromConfiguration(org.osid.id.Id parameterId, 
                                                   org.osid.id.Id configurationId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Moves a <code> Parameter </code> from one <code> Configuration </code> 
     *  to another. Mappings to other <code> Configurations </code> are 
     *  unaffected. 
     *
     *  @param  parameterId the <code> Id </code> of the <code> Parameter 
     *          </code> 
     *  @param  fromConfigurationId the <code> Id </code> of the current 
     *          <code> Configuration </code> 
     *  @param  toConfigurationId the <code> Id </code> of the destination 
     *          <code> Configuration </code> 
     *  @throws org.osid.NotFoundException <code> parameterId 
     *          fromConfigurationId, </code> or <code> toConfigurationId 
     *          </code> not found or <code> creditId </code> not mapped to 
     *          <code> fromConfigurationId </code> 
     *  @throws org.osid.NullArgumentException <code> parameterId, 
     *          fromConfigurationId, </code> or <code> toConfigurationId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void reassignParameterToConfiguration(org.osid.id.Id parameterId, 
                                                 org.osid.id.Id fromConfigurationId, 
                                                 org.osid.id.Id toConfigurationId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
