//
// org.osid.configuration.ParameterQuery
//
//     The OSID Java specification for org.osid.configuration.ParameterQuery.
//
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.configuration;


/**
 *  <p>The <code> ParameterQuery </code> is used to assemble search queries. A 
 *  <code> Parameter </code> is available from a <code> ParameterSearchSession 
 *  </code> and defines methods to query for a <code> Parameter </code> that 
 *  includes setting a display name and a description. Once the desired 
 *  parameters are set, the <code> ParameterQuery </code> is given to the 
 *  designated search method. The same <code> ParameterQuery </code> returned 
 *  from the session must be used in the search as the provider may utilize 
 *  implementation-specific data wiithin the object. </p> 
 *  
 *  <p> If multiple data elements are set, the results matching all the given 
 *  data (eg: <code> AND </code> ) are returned. Search methods throughout the 
 *  OSIDs accept multiple <code> OsidQuery </code> interfaces. Each <code> 
 *  ParameterQuery </code> in the array behaves like an <code> OR </code> such 
 *  that results are returned that match any of the given <code> 
 *  ParameterQuery </code> objects. </p> 
 *  
 *  <p> Any match method inside a <code> ParameterQuery </code> may be invoked 
 *  multiple times. In the case of a match method, each invocation adds an 
 *  element to an <code> OR </code> expression. Any of these terms may also be 
 *  negated through the <code> match </code> flag. </p> 
 *  
 *  <pre>
 *       
 *       
 *       Parameter { ParameterQuery.matchDisplayName AND (ParameterQuery.matchDescription OR Parameter.matchDescription)} OR ParameterQuery
 *       
 *                   
 *       
 *  </pre>
 *  
 *  
 *  <p> String searches are described using a string search Type that 
 *  indicates the type of regular expression or wildcarding encoding. 
 *  Compatibility with a strings search Type can be tested within this 
 *  interface. </p>
 */

public interface ParameterQuery
    extends org.osid.OsidRuleQuery {


    /**
     *  Adds a match for parameters of a given value syntax. Multiple matches 
     *  can be added to perform a boolean <code> OR </code> among them. 
     *
     *  @param  syntax the parameter value syntax 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> syntax </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchValueSyntax(org.osid.Syntax syntax, boolean match);


    /**
     *  Clears the value syntax terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearValueSyntaxTerms();


    /**
     *  Adds a match for parameters with a given coordinate type for a 
     *  coordinate value. Multiple matches can be added to perform a boolean 
     *  <code> OR </code> among them. 
     *
     *  @param  coordinateType the coordinate type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> coordinateType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchValueCoordinateType(org.osid.type.Type coordinateType, 
                                         boolean match);


    /**
     *  Clears the coordinate type terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearValueCoordinateTypeTerms();


    /**
     *  Adds a match for parameters with a given heading type for a coordinate 
     *  value. Multiple matches can be added to perform a boolean <code> OR 
     *  </code> among them. 
     *
     *  @param  headingType the heading type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> headingType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchValueHeadingType(org.osid.type.Type headingType, 
                                      boolean match);


    /**
     *  Clears the coorheadingdinate record type terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearValueHeadingTypeTerms();


    /**
     *  Adds a match for parameters with a given object type for an object 
     *  value. Multiple matches can be added to perform a boolean <code> OR 
     *  </code> among them. 
     *
     *  @param  objectType the object type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> objectType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchValueObjectType(org.osid.type.Type objectType, 
                                     boolean match);


    /**
     *  Clears the object value type terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearValueObjectTypeTerms();


    /**
     *  Adds a match for parameters with a given spatial unit record type for 
     *  a coordinate value. Multiple matches can be added to perform a boolean 
     *  <code> OR </code> among them. 
     *
     *  @param  spatialUnitRecordType the spatial unit record type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> spatialUnitRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchValueSpatialUnitRecordType(org.osid.type.Type spatialUnitRecordType, 
                                                boolean match);


    /**
     *  Clears the spatial unit record type terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearValueSpatialUnitRecordTypeTerms();


    /**
     *  Adds a match for parameters with a given version type for a version 
     *  value. Multiple matches can be added to perform a boolean <code> OR 
     *  </code> among them. 
     *
     *  @param  versionType the version type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> versionType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchValueVersionScheme(org.osid.type.Type versionType, 
                                        boolean match);


    /**
     *  Clears the value type terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearValueVersionSchemeTerms();


    /**
     *  Tests if a <code> ValueQuery </code> is available. 
     *
     *  @return <code> true </code> if a value query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsValueQuery();


    /**
     *  Gets the query for a value. 
     *
     *  @return the value query 
     *  @throws org.osid.UnimplementedException <code> supportsValueQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsValueQuery() </code> is <code> true. </code> 
     */

    public org.osid.configuration.ValueQuery getValueQuery();


    /**
     *  Matches parameters that have any value. 
     *
     *  @param  match <code> true </code> to match parameters with any value, 
     *          <code> false </code> to match parameters with no value 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyValue(boolean match);


    /**
     *  Clears the value terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearValueTerms();


    /**
     *  Matches shuffle order. 
     *
     *  @param  shuffle <code> true </code> to match shuffle by weight, false 
     *          to match order by index 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchValuesShuffled(boolean shuffle);


    /**
     *  Matches parameters that have any shuffle value. 
     *
     *  @param  match <code> true </code> to match parameters with any shuffle 
     *          value, <code> false </code> to match parameters with no 
     *          shuffle value 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyValuesShuffled(boolean match);


    /**
     *  Clears the shuffle terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearValuesShuffledTerms();


    /**
     *  Sets the configuration <code> Id </code> for this query. 
     *
     *  @param  configurationId a configuration <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> configurationId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchConfigurationId(org.osid.id.Id configurationId, 
                                     boolean match);


    /**
     *  Clears the configuration <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearConfigurationIdTerms();


    /**
     *  Tests if a <code> ConfigurationQuery </code> is available. 
     *
     *  @return <code> true </code> if a configuration query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsConfigurationQuery();


    /**
     *  Gets the query for a configuration. 
     *
     *  @return the configuration query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsConfigurationQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsConfigurationQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.configuration.ConfigurationQuery getConfigurationQuery();


    /**
     *  Clears the configuration terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearConfigurationTerms();


    /**
     *  Gets the parameter query record corresponding to the given <code> 
     *  Parameter </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  parameterRecordType a parameter record type 
     *  @return the parameter query record 
     *  @throws org.osid.NullArgumentException <code> parameterRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(parameterRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.records.ParameterQueryRecord getParameterQueryRecord(org.osid.type.Type parameterRecordType)
        throws org.osid.OperationFailedException;
}
