//
// org.osid.configuration.ValueForm
//
//     The OSID Java specification for org.osid.configuration.ValueForm.
//
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.configuration;


/**
 *  <p>This is the form for creating and updating <code> Values. </code> 
 *  Various data elements may be set here for use in the create and update 
 *  methods in the <code> ValueAdminSession </code> For each data element that 
 *  may be set, metadata may be examined to provide display hints or data 
 *  constraints. </p>
 */

public interface ValueForm
    extends org.osid.OsidObjectForm,
            org.osid.OsidOperableForm,
            org.osid.OsidSubjugateableForm {


    /**
     *  Gets the metadata for the value priority. The metadata returned may 
     *  depend on the state of the shuffle behavior. 
     *
     *  @return metadata for the priority 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getPriorityMetadata();


    /**
     *  Sets the priority. 
     *
     *  @param  priority the new priority 
     *  @throws org.osid.InvalidArgumentException <code> priority </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> priority </code> cannot be 
     *          modified 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setPriority(long priority);


    /**
     *  Clears the priority. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPriority();


    /**
     *  Gets the metadata for a boolean value. 
     *
     *  @return metadata for a boolean 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          BOOLEAN </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getBooleanValueMetadata();


    /**
     *  Sets a boolean value. 
     *
     *  @param  value the new boolean value 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          BOOLEAN </code> 
     *  @throws org.osid.InvalidArgumentException <code> value </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> value </code> cannot be 
     *          modified 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setBooleanValue(boolean value);


    /**
     *  Gets the metadata for a byte value. 
     *
     *  @return metadata for a byte 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          BYTE </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getByteValueMetadata();


    /**
     *  Sets a byte value. 
     *
     *  @param  value the new byte value 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          BYTE </code> 
     *  @throws org.osid.InvalidArgumentException <code> value </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> value </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> value </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setBytesValue(byte[] value);


    /**
     *  Gets the metadata for a cardinal value. 
     *
     *  @return metadata for a cardinal 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          CARDINAL </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getCardinalValueMetadata();


    /**
     *  Sets a cardinal value. 
     *
     *  @param  value the new cardinal value 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          CARDINAL </code> 
     *  @throws org.osid.InvalidArgumentException <code> value </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> value </code> cannot be 
     *          modified 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setCardinalValue(long value);


    /**
     *  Gets the metadata for a coordinate value. 
     *
     *  @return metadata for a coordinate 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          COORDINATE </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getCoordinateValueMetadata();


    /**
     *  Sets a coordinate value. 
     *
     *  @param  value the new coordinate value 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          COORDINATE </code> 
     *  @throws org.osid.InvalidArgumentException <code> value </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> value </code> cannot be 
     *          modified 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setCoordinateValue(org.osid.mapping.Coordinate value);


    /**
     *  Gets the metadata for a currency value. 
     *
     *  @return metadata for a currency 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          CURRENCY </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getCurrencyValueMetadata();


    /**
     *  Sets a currency value. 
     *
     *  @param  value the new currency value 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          CURRENCY </code> 
     *  @throws org.osid.InvalidArgumentException <code> value </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> value </code> cannot be 
     *          modified 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setCurrencyValue(org.osid.financials.Currency value);


    /**
     *  Gets the metadata for a <code> DateTime </code> value. 
     *
     *  @return metadata for a datetime 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          DATETIME </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getDateTimeValueMetadata();


    /**
     *  Sets a <code> DateTime </code> value. 
     *
     *  @param  value the new datetime value 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          DATETIME </code> 
     *  @throws org.osid.InvalidArgumentException <code> value </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> value </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> value </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setDateTimeValue(org.osid.calendaring.DateTime value);


    /**
     *  Gets the metadata for a decimal value. 
     *
     *  @return metadata for a decimal 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          DECIMAL </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getDecimalValueMetadata();


    /**
     *  Sets a decimal value. 
     *
     *  @param  value the new decimal value 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          DECIMAL </code> 
     *  @throws org.osid.InvalidArgumentException <code> value </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> value </code> cannot be 
     *          modified 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setDecimalValue(java.math.BigDecimal value);


    /**
     *  Gets the metadata for a <code> Distance </code> value. 
     *
     *  @return metadata for a distance 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          DISTANCE </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getDistanceValueMetadata();


    /**
     *  Sets a <code> Distance </code> value. 
     *
     *  @param  value the new distance value 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          DISTANCE </code> 
     *  @throws org.osid.InvalidArgumentException <code> value </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> value </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> value </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setDistanceValue(org.osid.mapping.Distance value);


    /**
     *  Gets the metadata for a <code> Duration </code> value. 
     *
     *  @return metadata for a duration 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          DURATION </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getDurationValueMetadata();


    /**
     *  Sets a <code> Duration </code> value. 
     *
     *  @param  value the new duration value 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          DURATION </code> 
     *  @throws org.osid.InvalidArgumentException <code> value </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> value </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> value </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setDurationValue(org.osid.calendaring.Duration value);


    /**
     *  Gets the metadata for an <code> Id </code> value. 
     *
     *  @return metadata for an <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          ID </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getIdValueMetadata();


    /**
     *  Sets an <code> Id </code> value. 
     *
     *  @param  value the new <code> Id </code> value 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          ID </code> 
     *  @throws org.osid.InvalidArgumentException <code> value </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> value </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> value </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setIdValue(org.osid.id.Id value);


    /**
     *  Gets the metadata for an integer value. 
     *
     *  @return metadata for an integer 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          INTEGER </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getIntegerValueMetadata();


    /**
     *  Sets an integer value. 
     *
     *  @param  value the new integer value 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          INTEGER </code> 
     *  @throws org.osid.InvalidArgumentException <code> value </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> value </code> cannot be 
     *          modified 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setIntegerValue(long value);


    /**
     *  Gets the metadata for a spatial unit value. 
     *
     *  @return metadata for a spatial unit 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          SPATIALUNIT </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getSpatialUnitValueMetadata();


    /**
     *  Sets a spatial unit value. 
     *
     *  @param  value the new spatial unit value 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          SPATIALUNIT </code> 
     *  @throws org.osid.InvalidArgumentException <code> value </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> value </code> cannot be 
     *          modified 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setSpatialUnitValue(org.osid.mapping.SpatialUnit value);


    /**
     *  Gets the metadata for a speed value. 
     *
     *  @return metadata for a speed 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          SPEED </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getSpeedValueMetadata();


    /**
     *  Sets a speed value. 
     *
     *  @param  value the new speed value 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          SPEED </code> 
     *  @throws org.osid.InvalidArgumentException <code> value </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> value </code> cannot be 
     *          modified 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setSpeedValue(org.osid.mapping.Speed value);


    /**
     *  Gets the metadata for a string value. 
     *
     *  @return metadata for a string 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          STRING </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getStringValueMetadata();


    /**
     *  Sets a string value. 
     *
     *  @param  value the new string value 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          STRING </code> 
     *  @throws org.osid.InvalidArgumentException <code> value </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> value </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> value </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setStringValue(String value);


    /**
     *  Gets the metadata for a <code> Time </code> value. 
     *
     *  @return metadata for a <code> Time </code> 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          TIME </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getTimeValueMetadata();


    /**
     *  Sets a <code> Time </code> value. 
     *
     *  @param  value the new <code> Time </code> value 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          TIME </code> 
     *  @throws org.osid.InvalidArgumentException <code> value </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> value </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> value </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setTimeValue(org.osid.calendaring.Time value);


    /**
     *  Gets the metadata for a <code> Type </code> value. 
     *
     *  @return metadata for a <code> Type </code> 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          TYPE </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getTypeValueMetadata();


    /**
     *  Sets a <code> Type </code> value. 
     *
     *  @param  value the new <code> Type </code> value 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          TYPE </code> 
     *  @throws org.osid.InvalidArgumentException <code> value </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> value </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> value </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setTypeValue(org.osid.type.Type value);


    /**
     *  Gets the metadata for a <code> Version </code> value. 
     *
     *  @return metadata for a <code> Version </code> 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          VERSION </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getVersionValueMetadata();


    /**
     *  Sets a <code> Version </code> value. 
     *
     *  @param  value the new <code> Version </code> value 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          VERSION </code> 
     *  @throws org.osid.InvalidArgumentException <code> value </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> value </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> value </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setVersionValue(org.osid.installation.Version value);


    /**
     *  Gets the metadata for an object value. 
     *
     *  @return metadata for an object 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          OBJECT </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getObjectValueMetadata();


    /**
     *  Sets an object value. 
     *
     *  @param  value the new object value 
     *  @param  objectType the object type 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          OBJECT </code> 
     *  @throws org.osid.InvalidArgumentException <code> value </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> value </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> value </code> or <code> 
     *          objectType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          Metadata.supportsObjectType(objectType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setObjectValue(java.lang.Object value, 
                               org.osid.type.Type objectType);


    /**
     *  Clears the value. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearValue();


    /**
     *  Gets the <code> ValueFormRecord </code> corresponding to the given 
     *  value record <code> Type. </code> 
     *
     *  @param  valueRecordType a value record type 
     *  @return the value form record 
     *  @throws org.osid.NullArgumentException <code> valueRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(valueRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.records.ValueFormRecord getValueFormRecord(org.osid.type.Type valueRecordType)
        throws org.osid.OperationFailedException;
}
