//
// org.osid.configuration.ValueQueryInspector
//
//     The OSID Java specification for org.osid.configuration.ValueQueryInspector.
//
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.configuration;


/**
 *  <p>The interface to inspect a value query. </p>
 */

public interface ValueQueryInspector
    extends org.osid.OsidIdentifiableQueryInspector,
            org.osid.OsidOperableQueryInspector,
            org.osid.OsidSubjugateableQueryInspector {


    /**
     *  Gets the priority query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.CardinalRangeTerm[] getPriorityTerms();


    /**
     *  Gets the boolean value query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.BooleanTerm[] getBooleanValueTerms();


    /**
     *  Gets the bytes value query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.BytesTerm[] getBytesValueTerms();


    /**
     *  Gets the cardinal value query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.CardinalRangeTerm[] getCardinalValueTerms();


    /**
     *  Gets the coordinate value query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.CoordinateTerm[] getCoordinateValueTerms();


    /**
     *  Gets the currency value query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.CurrencyTerm[] getCurrencyValueTerms();


    /**
     *  Gets the date time value query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DateTimeRangeTerm[] getDateTimeValueTerms();


    /**
     *  Gets the decimal value query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DecimalRangeTerm[] getDecimalValueTerms();


    /**
     *  Gets the distance value query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DistanceTerm[] getDistanceValueTerms();


    /**
     *  Gets the duration value query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DurationTerm[] getDurationValueTerms();


    /**
     *  Gets the heading value query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.HeadingTerm[] getHeadingValueTerms();


    /**
     *  Gets the Id value query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getIdValueTerms();


    /**
     *  Gets the integer value query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IntegerRangeTerm[] getIntegerValueTerms();


    /**
     *  Gets the spatial unit value query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.SpatialUnitTerm[] getSpatialUnitValueTerms();


    /**
     *  Gets the speed value query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.SpeedTerm[] getSpeedValueTerms();


    /**
     *  Gets the string value query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.StringTerm[] getStringValueTerms();


    /**
     *  Gets the time value query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.TimeTerm[] getTimeValueTerms();


    /**
     *  Gets the type value query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.TypeTerm[] getTypeValueTerms();


    /**
     *  Gets the version value query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.VersionRangeTerm[] getVersionValueTerms();


    /**
     *  Gets the object value type query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.TypeTerm[] getObjectValueTypeTerms();


    /**
     *  Gets the object value query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.ObjectTerm[] getObjectValueTerms();


    /**
     *  Gets the parameter <code> Id </code> query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getParameterIdTerms();


    /**
     *  Gets the parameter query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.ParameterQueryInspector[] getParameterTerms();


    /**
     *  Gets the configuration <code> Id </code> query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getConfigurationIdTerms();


    /**
     *  Gets the configuration query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.ConfigurationQueryInspector[] getConfigurationTerms();


    /**
     *  Gets the value query record corresponding to the given <code> Value 
     *  </code> record <code> Type. </code> 
     *
     *  @param  valueRecordType a value record type 
     *  @return the value query inspector record 
     *  @throws org.osid.NullArgumentException <code> valueRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(valueRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.records.ValueQueryInspectorRecord getValueQueryInspectorRecord(org.osid.type.Type valueRecordType)
        throws org.osid.OperationFailedException;
}
