//
// org.osid.configuration.ValueRetrievalSession
//
//     The OSID Java specification for org.osid.configuration.ValueRetrievalSession.
//
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.configuration;


/**
 *  <p>This session is used to retrieve active configuration values. Two views 
 *  of the configuration data are defined: </p> 
 *  
 *  <ul>
 *      <li> federated: parameters defined in configurations that are a parent 
 *      of this configuration in the configuration hierarchy are included 
 *      </li> 
 *      <li> isolated: parameters are contained to within this configuration 
 *      </li> 
 *      <li> conditional: values are filtered that do not pass any defined 
 *      conditions, whether or not they are explciity passed into the lookup 
 *      methods of this session </li> 
 *      <li> unconditional: values are filtered only for the conditions that 
 *      are explicity passed as parameters. Any conditions defined for the 
 *      value that do not require explicit data for retrieval are ignored. 
 *      </li> 
 *  </ul>
 *  
 *  
 *  <p> This session assumes an active view. </p> 
 *  
 *  <p> Values are not OSID objects and are obtained using a reference to a 
 *  Parameter. </p>
 */

public interface ValueRetrievalSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Configuration </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> Configuration </code> <code> Id </code> associated 
     *          with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getConfigurationId();


    /**
     *  Gets the <code> Configuration </code> associated with this session. 
     *
     *  @return the <code> Configuration </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.Configuration getConfiguration()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Value </code> lookups. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupValues();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeValueView();


    /**
     *  A complete view of the <code> Value </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryValueView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include values from parent configurations in the configuration 
     *  hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedConfigurationView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this configuration only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedConfigurationView();


    /**
     *  Returns only values that pass the defined parameter condition. Some 
     *  parameter conditions do not require explicit conditional data to be 
     *  passed and the <code> Values </code> returned from any method in this 
     *  session are filtered on an implicit condition. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useConditionalView();


    /**
     *  Values that are filtered based on an implicit condition are not 
     *  filtered out from methods in this session. Methods that take an 
     *  explicit condition as a parameter are filtered on only those 
     *  conditions that are specified. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useUnconditionalView();


    /**
     *  Gets a <code> Value </code> for the given parameter <code> Id. </code> 
     *  If more than one value exists for the given parameter, the most 
     *  preferred value is returned. This method can be used as a convenience 
     *  when only one value is expected. <code> getValuesByParameters() 
     *  </code> should be used for getting all the active values. 
     *
     *  @param  parameterId the <code> Id </code> of the <code> Parameter 
     *          </code> to retrieve 
     *  @return the value 
     *  @throws org.osid.NotFoundException the <code> parameterId </code> not 
     *          found or no value available 
     *  @throws org.osid.NullArgumentException the <code> parameterId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.Value getValueByParameter(org.osid.id.Id parameterId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all the <code> Values </code> for the given parameter <code> Id. 
     *  </code> 
     *  
     *  In plenary mode, all values are returned in the order requested or an 
     *  error results. In comparative mode, inaccessible values may be omitted 
     *  or the values reordered. 
     *  
     *  In conditional mode, the values are filtered through evaluation. In 
     *  unconditional mode, the values are returned unfiltered. 
     *
     *  @param  parameterId the <code> Id </code> of the <code> Parameter 
     *          </code> to retrieve 
     *  @return the value list 
     *  @throws org.osid.NotFoundException the <code> parameterId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException the <code> parameterId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.ValueList getValuesByParameter(org.osid.id.Id parameterId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Values </code> for the given parameter <code> Ids. 
     *  </code> 
     *  
     *  In plenary mode, the values for all parameters are returned in the 
     *  order requested or an error results. In comparative mode, inaccessible 
     *  values may be omitted or the values reordered. 
     *  
     *  In conditional mode, the values are filtered through evaluation. In 
     *  unconditional mode, the values are returned unfiltered. 
     *
     *  @param  parameterIds the <code> Id </code> of the <code> Parameter 
     *          </code> to retrieve 
     *  @return the value list 
     *  @throws org.osid.NotFoundException a parameter <code> Id </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> parameterIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.ValueList getValuesByParameters(org.osid.id.IdList parameterIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a value condition for the given parameter. 
     *
     *  @param  parameterId the <code> Id </code> of a <code> Parameter 
     *          </code> 
     *  @return a value condition 
     *  @throws org.osid.NullArgumentException <code> parameterId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.ValueCondition getValueCondition(org.osid.id.Id parameterId);


    /**
     *  Gets a value in this configuration based on a condition. If multiple 
     *  values are available the most preferred one is returned. The condition 
     *  specified is applied to any or all parameters in this configuration as 
     *  applicable. 
     *
     *  @param  parameterId the <code> Id </code> of a <code> Parameter 
     *          </code> 
     *  @param  valueCondition the condition 
     *  @return the value 
     *  @throws org.osid.NotFoundException parameter <code> Id </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> parameterId </code> or 
     *          <code> valueCondition </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> valueCondition </code> 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.Value getValueByParameterOnCondition(org.osid.id.Id parameterId, 
                                                                       org.osid.configuration.ValueCondition valueCondition)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all the values for a parameter based on a condition. In plenary 
     *  mode, all values are returned or an error results. In comparative 
     *  mode, inaccessible values may be omitted. 
     *
     *  @param  parameterId the <code> Id </code> of a <code> Parameter 
     *          </code> 
     *  @param  valueCondition the condition 
     *  @return the value list 
     *  @throws org.osid.NotFoundException parameter <code> Id </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> parameterId </code> or 
     *          <code> valueCondition </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> valueCondition </code> is 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.ValueList getValuesByParameterOnCondition(org.osid.id.Id parameterId, 
                                                                            org.osid.configuration.ValueCondition valueCondition)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the values for parameters based on a condition. The specified 
     *  condition is applied to any or all of the parameters as applicable. In 
     *  plenary mode, all values are returned or an error results. In 
     *  comparative mode, inaccessible values may be omitted. 
     *
     *  @param  parameterIds the <code> Id </code> of a <code> Parameter 
     *          </code> 
     *  @param  valueCondition the condition 
     *  @return the value list 
     *  @throws org.osid.NotFoundException a parameter <code> Id </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> parameterIds </code> or 
     *          <code> valueCondition </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> valueCondition </code> 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.ValueList getValuesByParametersOnCondition(org.osid.id.IdList parameterIds, 
                                                                             org.osid.configuration.ValueCondition valueCondition)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
