//
// org.osid.configuration.ValueSearchSession
//
//     The OSID Java specification for org.osid.configuration.ValueSearchSession.
//
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.configuration;


/**
 *  <p>This session provides methods for searching <code> Value </code> 
 *  objects. The search query is constructed using the <code> ValueQuery. 
 *  </code> The parameter <code> Type </code> also specifies the record for 
 *  the value query. </p> 
 *  
 *  <p> <code> getValuesByQuery() </code> is the basic search method and 
 *  returns a list of <code> Values. </code> A more advanced search may be 
 *  performed with <code> getValuesBySearch(). </code> It accepts a <code> 
 *  ValueSearch </code> in addition to the query for the purpose of specifying 
 *  additional options affecting the entire search, such as ordering. <code> 
 *  getValuesBySearch() </code> returns a <code> ValueSearchResults </code> 
 *  that can be used to access the resulting <code> ValueList </code> or be 
 *  used to perform a search within the result set through <code> ValueSearch. 
 *  </code> </p> 
 *  
 *  <p> Two views of the configuration data are defined; </p> 
 *  
 *  <ul>
 *      <li> federated: values defined in configurations that are a parent of 
 *      this configuration in the configuration hierarchy are included </li> 
 *      <li> isolated: values are contained to within this configuration </li> 
 *  </ul>
 *  
 */

public interface ValueSearchSession
    extends org.osid.configuration.ValueQuerySession {


    /**
     *  Gets a value search. 
     *
     *  @return the value search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.ValueSearch getValueSearch();


    /**
     *  Gets a value search order. The <code> ValueSearchOrder </code> is 
     *  supplied to a <code> ValueSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the value search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.ValueSearchOrder getValueSearchOrder();


    /**
     *  Gets a list of <code> Values </code> matching the given search query 
     *  using the given search. 
     *
     *  @param  valueQuery the value query 
     *  @param  valueSearch the value search 
     *  @return the serach results 
     *  @throws org.osid.NullArgumentException <code> valueQuery </code> or 
     *          <code> valueSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> valueQuery </code> or 
     *          <code> valueSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.ValueSearchResults getValuesBySearch(org.osid.configuration.ValueQuery valueQuery, 
                                                                       org.osid.configuration.ValueSearch valueSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a value query from an inspector. The inspector is available from 
     *  a <code> ValueSearchResults. </code> 
     *
     *  @param  valueQueryInspector a value query inspector 
     *  @return the value query 
     *  @throws org.osid.NullArgumentException <code> valueQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> valueQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.ValueQuery getValueQueryFromInspector(org.osid.configuration.ValueQueryInspector valueQueryInspector);
}
