//
// org.osid.configuration.rules.ConfigurationRulesProfile
//
//     The OSID Java specification for org.osid.configuration.rules.ConfigurationRulesProfile.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.configuration.rules;


/**
 *  <p>The configuration rules profile describes the interoperability among 
 *  configuration rules services. </p>
 */

public interface ConfigurationRulesProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any broker federation is exposed. Federation is exposed when 
     *  a specific broker may be identified, selected and used to create a 
     *  lookup or admin session. Federation is not exposed when a set of 
     *  brokers appears as a single broker. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if looking up value enablers is supported. 
     *
     *  @return <code> true </code> if value enabler lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsValueEnablerLookup();


    /**
     *  Tests if querying value enablers is supported. 
     *
     *  @return <code> true </code> if value enabler query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsValueEnablerQuery();


    /**
     *  Tests if searching value enablers is supported. 
     *
     *  @return <code> true </code> if value enabler search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsValueEnablerSearch();


    /**
     *  Tests if a value enabler administrative service is supported. 
     *
     *  @return <code> true </code> if value enabler administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsValueEnablerAdmin();


    /**
     *  Tests if a value enabler notification service is supported. 
     *
     *  @return <code> true </code> if value enabler notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsValueEnablerNotification();


    /**
     *  Tests if a value enabler configuration lookup service is supported. 
     *
     *  @return <code> true </code> if a value enabler configuration lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsValueEnablerConfiguration();


    /**
     *  Tests if a value enabler configuration service is supported. 
     *
     *  @return <code> true </code> if value enabler configuration assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsValueEnablerConfigurationAssignment();


    /**
     *  Tests if a value enabler configuration lookup service is supported. 
     *
     *  @return <code> true </code> if a value enabler configuration service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsValueEnablerSmartConfiguration();


    /**
     *  Tests if a value enabler rule lookup service is supported. 
     *
     *  @return <code> true </code> if a value enabler rule lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsValueEnablerRuleLookup();


    /**
     *  Tests if a value enabler rule application service is supported. 
     *
     *  @return <code> true </code> if value enabler rule application service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsValueEnablerRuleApplication();


    /**
     *  Tests if looking up parameter processor is supported. 
     *
     *  @return <code> true </code> if parameter processor lookup is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsParameterProcessorLookup();


    /**
     *  Tests if querying parameter processor is supported. 
     *
     *  @return <code> true </code> if parameter processor query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsParameterProcessorQuery();


    /**
     *  Tests if searching parameter processor is supported. 
     *
     *  @return <code> true </code> if parameter processor search is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsParameterProcessorSearch();


    /**
     *  Tests if a parameter processor administrative service is supported. 
     *
     *  @return <code> true </code> if parameter processor administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsParameterProcessorAdmin();


    /**
     *  Tests if a parameter processor notification service is supported. 
     *
     *  @return <code> true </code> if parameter processor notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsParameterProcessorNotification();


    /**
     *  Tests if a parameter processor configuration lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if a parameter processor configuration 
     *          lookup service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsParameterProcessorConfiguration();


    /**
     *  Tests if a parameter processor configuration service is supported. 
     *
     *  @return <code> true </code> if parameter processor configuration 
     *          assignment service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsParameterProcessorConfigurationAssignment();


    /**
     *  Tests if a parameter processor configuration lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if a parameter processor configuration 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsParameterProcessorSmartConfiguration();


    /**
     *  Tests if a parameter processor rule lookup service is supported. 
     *
     *  @return <code> true </code> if a parameter processor rule lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsParameterProcessorRuleLookup();


    /**
     *  Tests if a parameter processor rule application service is supported. 
     *
     *  @return <code> true </code> if parameter processor rule application 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsParameterProcessorRuleApplication();


    /**
     *  Tests if looking up parameter processor enablers is supported. 
     *
     *  @return <code> true </code> if parameter processor enabler lookup is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsParameterProcessorEnablerLookup();


    /**
     *  Tests if querying parameter processor enablers is supported. 
     *
     *  @return <code> true </code> if parameter processor enabler query is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsParameterProcessorEnablerQuery();


    /**
     *  Tests if searching parameter processor enablers is supported. 
     *
     *  @return <code> true </code> if parameter processor enabler search is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsParameterProcessorEnablerSearch();


    /**
     *  Tests if a parameter processor enabler administrative service is 
     *  supported. 
     *
     *  @return <code> true </code> if parameter processor enabler 
     *          administration is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsParameterProcessorEnablerAdmin();


    /**
     *  Tests if a parameter processor enabler notification service is 
     *  supported. 
     *
     *  @return <code> true </code> if parameter processor enabler 
     *          notification is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsParameterProcessorEnablerNotification();


    /**
     *  Tests if a parameter processor enabler configuration lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if a parameter processor enabler 
     *          configuration lookup service is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsParameterProcessorEnablerConfiguration();


    /**
     *  Tests if a parameter processor enabler configuration service is 
     *  supported. 
     *
     *  @return <code> true </code> if parameter processor enabler 
     *          configuration assignment service is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsParameterProcessorEnablerConfigurationAssignment();


    /**
     *  Tests if a parameter processor enabler configuration lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if a parameter processor enabler 
     *          configuration service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsParameterProcessorEnablerSmartConfiguration();


    /**
     *  Tests if a parameter processor enabler rule lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if a processor enabler rule lookup service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsParameterProcessorEnablerRuleLookup();


    /**
     *  Tests if a parameter processor enabler rule application service is 
     *  supported. 
     *
     *  @return <code> true </code> if parameter processor enabler rule 
     *          application service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsParameterProcessorEnablerRuleApplication();


    /**
     *  Gets the supported <code> ValueEnabler </code> record types. 
     *
     *  @return a list containing the supported <code> ValueEnabler </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getValueEnablerRecordTypes();


    /**
     *  Tests if the given <code> ValueEnabler </code> record type is 
     *  supported. 
     *
     *  @param  valueEnablerRecordType a <code> Type </code> indicating a 
     *          <code> ValueEnabler </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> valueEnablerRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsValueEnablerRecordType(org.osid.type.Type valueEnablerRecordType);


    /**
     *  Gets the supported <code> ValueEnabler </code> search record types. 
     *
     *  @return a list containing the supported <code> ValueEnabler </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getValueEnablerSearchRecordTypes();


    /**
     *  Tests if the given <code> ValueEnabler </code> search record type is 
     *  supported. 
     *
     *  @param  valueEnablerSearchRecordType a <code> Type </code> indicating 
     *          a <code> ValueEnabler </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          valueEnablerSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsValueEnablerSearchRecordType(org.osid.type.Type valueEnablerSearchRecordType);


    /**
     *  Gets the supported <code> ParameterProcessor </code> record types. 
     *
     *  @return a list containing the supported <code> ParameterProcessor 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getParameterProcessorRecordTypes();


    /**
     *  Tests if the given <code> ParameterProcessor </code> record type is 
     *  supported. 
     *
     *  @param  parameterProcessorRecordType a <code> Type </code> indicating 
     *          a <code> ParameterProcessor </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          parameterProcessorRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsParameterProcessorRecordType(org.osid.type.Type parameterProcessorRecordType);


    /**
     *  Gets the supported <code> ParameterProcessor </code> search record 
     *  types. 
     *
     *  @return a list containing the supported <code> ParameterProcessor 
     *          </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getParameterProcessorSearchRecordTypes();


    /**
     *  Tests if the given <code> ParameterProcessor </code> search record 
     *  type is supported. 
     *
     *  @param  parameterProcessorSearchRecordType a <code> Type </code> 
     *          indicating a <code> ParameterProcessor </code> search record 
     *          type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          parameterProcessorSearchRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsParameterProcessorSearchRecordType(org.osid.type.Type parameterProcessorSearchRecordType);


    /**
     *  Gets the supported <code> ParameterProcessorEnabler </code> record 
     *  types. 
     *
     *  @return a list containing the supported <code> 
     *          ParameterProcessorEnabler </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getParameterProcessorEnablerRecordTypes();


    /**
     *  Tests if the given <code> ParameterProcessorEnabler </code> record 
     *  type is supported. 
     *
     *  @param  parameterProcessorEnablerRecordType a <code> Type </code> 
     *          indicating a <code> ParameterProcessorEnabler </code> record 
     *          type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          parameterProcessorEnablerRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsParameterProcessorEnablerRecordType(org.osid.type.Type parameterProcessorEnablerRecordType);


    /**
     *  Gets the supported <code> ParameterProcessorEnabler </code> search 
     *  record types. 
     *
     *  @return a list containing the supported <code> 
     *          ParameterProcessorEnabler </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getParameterProcessorEnablerSearchRecordTypes();


    /**
     *  Tests if the given <code> ParameterProcessorEnabler </code> search 
     *  record type is supported. 
     *
     *  @param  parameterProcessorEnablerSearchRecordType a <code> Type 
     *          </code> indicating a <code> ParameterProcessorEnabler </code> 
     *          search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          parameterProcessorEnablerSearchRecordType </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsParameterProcessorEnablerSearchRecordType(org.osid.type.Type parameterProcessorEnablerSearchRecordType);
}
