//
// org.osid.configuration.rules.ConfigurationRulesProxyManager
//
//     The OSID Java specification for org.osid.configuration.rules.ConfigurationRulesProxyManager.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.configuration.rules;


/**
 *  <p>The configuration rules proxy manager provides access to configuration 
 *  rules sessions and provides interoperability tests for various aspects of 
 *  this service. Methods in this manager pass a <code> Proxy </code> for 
 *  passing information from server environments. The sessions included in 
 *  this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> ValueEnablerLookupSession: </code> a session to retrieve 
 *      value enablers </li> 
 *      <li> <code> ValueEnablerQuerySession: </code> a session to query for 
 *      value enablers </li> 
 *      <li> <code> ValueEnablerSearchSession: </code> a session to search for 
 *      value enablers </li> 
 *      <li> <code> ValueEnablerAdminSession: </code> a session to create and 
 *      delete value enablers </li> 
 *      <li> <code> ValueEnablerNotificationSession: </code> a session to 
 *      receive notifications pertaining to value enabler changes </li> 
 *      <li> <code> ValueEnablerConfigurationSession: </code> a session to 
 *      look up value enabler configuration mappings </li> 
 *      <li> <code> ValueEnablerConfigurationAssignmentSession: </code> a 
 *      session to manage value enabler to configuration mappings </li> 
 *      <li> <code> ValueEnablerSmartConfigurationSession: </code> a session 
 *      to manage dynamic configurations of value enablers </li> 
 *      <li> <code> ValueEnablerRuleLookupSession: </code> a session to look 
 *      up value enabler mappings </li> 
 *      <li> <code> ValueEnablerRuleApplicationSession: </code> a session to 
 *      apply value enablers </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> ParameterProcessorLookupSession: </code> a session to 
 *      retrieve parameter processor </li> 
 *      <li> <code> ParameterProcessorQuerySession: </code> a session to query 
 *      for parameter processor </li> 
 *      <li> <code> ParameterProcessorSearchSession: </code> a session to 
 *      search for parameter processor </li> 
 *      <li> <code> ParameterProcessorAdminSession: </code> a session to 
 *      create and delete parameter processor </li> 
 *      <li> <code> ParameterProcessorNotificationSession: </code> a session 
 *      to receive notifications pertaining to parameter processor changes 
 *      </li> 
 *      <li> <code> ParameterProcessorConfigurationSession: </code> a session 
 *      to look up parameter processor configuration mappings </li> 
 *      <li> <code> ParameterProcessorConfigurationAssignmentSession: </code> 
 *      a session to manage parameter processor to configuration mappings 
 *      </li> 
 *      <li> <code> ParameterProcessorSmartConfigurationSession: </code> a 
 *      session to manage dynamic configurations of parameter processor </li> 
 *      <li> <code> ParameterProcessorRuleLookupSession: </code> a session to 
 *      look up parameter processor to parameter mappings </li> 
 *      <li> <code> ParameterProcessorRuleApplicationSession: </code> a 
 *      session to apply parameter processor to parameters </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> ParameterProcessorEnablerLookupSession: </code> a session 
 *      to retrieve parameter processor enablers </li> 
 *      <li> <code> ParameterProcessorEnablerQuerySession: </code> a session 
 *      to query for parameter processor enablers </li> 
 *      <li> <code> ParameterProcessorEnablerSearchSession: </code> a session 
 *      to search for parameter processor enablers </li> 
 *      <li> <code> ParameterProcessorEnablerAdminSession: </code> a session 
 *      to create and delete parameter processor enablers </li> 
 *      <li> <code> ParameterProcessorEnablerNotificationSession: </code> a 
 *      session to receive notifications pertaining to parameter processor 
 *      enabler changes </li> 
 *      <li> <code> ParameterProcessorEnablerConfigurationSession: </code> a 
 *      session to look up parameter processor enabler configuration mappings 
 *      </li> 
 *      <li> <code> ParameterProcessorEnablerConfigurationAssignmentSession: 
 *      </code> a session to manage parameter processor enabler to 
 *      configuration mappings </li> 
 *      <li> <code> ParameterProcessorEnablerSmartConfigurationSession: 
 *      </code> a session to manage dynamic configurations of parameter 
 *      processor enablers </li> 
 *      <li> <code> ParameterProcessorEnablerRuleLookupSession: </code> a 
 *      session to look up parameter processor enabler mappings </li> 
 *      <li> <code> ParameterProcessorEnablerRuleApplicationSession: </code> a 
 *      session to apply parameter processor enablers </li> 
 *  </ul>
 *  
 */

public interface ConfigurationRulesProxyManager
    extends org.osid.OsidProxyManager,
            org.osid.configuration.rules.ConfigurationRulesProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the value enabler 
     *  lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ValueEnablerLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsValueEnablerLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsValueEnablerLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.configuration.rules.ValueEnablerLookupSession getValueEnablerLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the value enabler 
     *  lookup service for the given configuration. 
     *
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ValueEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Configuration </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> configurationId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsValueEnablerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsValueEnablerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.configuration.rules.ValueEnablerLookupSession getValueEnablerLookupSessionForConfiguration(org.osid.id.Id configurationId, 
                                                                                                               org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the value enabler 
     *  query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ValueEnablerQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsValueEnablerQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsValueEnablerQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.configuration.rules.ValueEnablerQuerySession getValueEnablerQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the value enabler 
     *  query service for the given configuration. 
     *
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ValueEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Configuration </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> configurationId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsValueEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsValueEnablerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.configuration.rules.ValueEnablerQuerySession getValueEnablerQuerySessionForConfiguration(org.osid.id.Id configurationId, 
                                                                                                             org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the value enabler 
     *  search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ValueEnablerSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsValueEnablerSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsValueEnablerSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.configuration.rules.ValueEnablerSearchSession getValueEnablerSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the value enablers 
     *  earch service for the given configuration. 
     *
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ValueEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Configuration </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> configurationId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsValueEnablerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsValueEnablerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.configuration.rules.ValueEnablerSearchSession getValueEnablerSearchSessionForConfiguration(org.osid.id.Id configurationId, 
                                                                                                               org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the value enabler 
     *  administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ValueEnablerAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsValueEnablerAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsValueEnablerAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.configuration.rules.ValueEnablerAdminSession getValueEnablerAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the value enabler 
     *  administration service for the given configuration. 
     *
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ValueEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Configuration </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> configurationId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsValueEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsValueEnablerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.configuration.rules.ValueEnablerAdminSession getValueEnablerAdminSessionForConfiguration(org.osid.id.Id configurationId, 
                                                                                                             org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the value enabler 
     *  notification service. 
     *
     *  @param  valueEnablerReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> ValueEnablerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> valueEnablerReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsValueEnablerNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsValueEnablerNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.configuration.rules.ValueEnablerNotificationSession getValueEnablerNotificationSession(org.osid.configuration.rules.ValueEnablerReceiver valueEnablerReceiver, 
                                                                                                           org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the value enabler 
     *  notification service for the given configuration. 
     *
     *  @param  valueEnablerReceiver the notification callback 
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ValueEnablerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no configuration found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> valueEnablerReceiver, 
     *          configurationId </code> or <code> proxy </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsValueEnablerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsValueEnablerNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.configuration.rules.ValueEnablerNotificationSession getValueEnablerNotificationSessionForConfiguration(org.osid.configuration.rules.ValueEnablerReceiver valueEnablerReceiver, 
                                                                                                                           org.osid.id.Id configurationId, 
                                                                                                                           org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup value 
     *  enabler/configuration mappings for value enablers. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ValueEnablerConfigurationSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsValueEnablerConfiguration() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsValueEnablerConfiguration() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.configuration.rules.ValueEnablerConfigurationSession getValueEnablerConfigurationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning value 
     *  enablers to configurations. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ValueEnablerConfigurationAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsValueEnablerConfigurationAssignment() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsValueEnablerConfigurationAssignment() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.configuration.rules.ValueEnablerConfigurationAssignmentSession getValueEnablerConfigurationAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage value enabler smart 
     *  configurations. 
     *
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ValueEnablerSmartConfigurationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Configuration </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> configurationId </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsValueEnablerSmartConfiguration() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsValueEnablerSmartConfiguration() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.configuration.rules.ValueEnablerSmartConfigurationSession getValueEnablerSmartConfigurationSession(org.osid.id.Id configurationId, 
                                                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the value enabler 
     *  mapping lookup service . 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ValueEnablerRuleLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsValueEnablerRuleLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsValueEnablerRuleLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.configuration.rules.ValueEnablerRuleLookupSession getValueEnablerRuleLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the value enabler 
     *  mapping lookup service for the given configuration. 
     *
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ValueEnablerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Configuration </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> configurationId </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsValueEnablerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsValueEnablerRuleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.configuration.rules.ValueEnablerRuleLookupSession getValueEnablerRuleLookupSessionForConfiguration(org.osid.id.Id configurationId, 
                                                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the value enabler 
     *  assignment service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ValueEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsValueEnablerRuleApplication() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsValueEnablerRuleApplication() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.configuration.rules.ValueEnablerRuleApplicationSession getValueEnablerRuleApplicationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the value enabler 
     *  assignment service for the given configuration. 
     *
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ValueEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Configuration </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> configurationId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsValueEnablerRuleApplication() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsValueEnablerRuleApplication() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.configuration.rules.ValueEnablerRuleApplicationSession getValueEnablerRuleApplicationSessionForConfiguration(org.osid.id.Id configurationId, 
                                                                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the parameter 
     *  processor lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ParameterProcessorLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterProcessorLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParameterProcessorLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.configuration.rules.ParameterProcessorLookupSession getParameterProcessorLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the parameter 
     *  processor lookup service for the given configuration. 
     *
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ParameterProcessorLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Configuration </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> configurationId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterProcessorLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParameterProcessorLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.configuration.rules.ParameterProcessorLookupSession getParameterProcessorLookupSessionForConfiguration(org.osid.id.Id configurationId, 
                                                                                                                           org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the parameter 
     *  processor query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ParameterProcessorQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterProcessorQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParameterProcessorQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.configuration.rules.ParameterProcessorQuerySession getParameterProcessorQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the parameter 
     *  processor query service for the given configuration. 
     *
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ParameterProcessorQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Configuration </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> configurationId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterProcessorQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParameterProcessorQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.configuration.rules.ParameterProcessorQuerySession getParameterProcessorQuerySessionForConfiguration(org.osid.id.Id configurationId, 
                                                                                                                         org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the parameter 
     *  processor search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ParameterProcessorSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterProcessorSearch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParameterProcessorSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.configuration.rules.ParameterProcessorSearchSession getParameterProcessorSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the parameter 
     *  processor earch service for the given configuration. 
     *
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ParameterProcessorSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Configuration </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> configurationId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterProcessorSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParameterProcessorSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.configuration.rules.ParameterProcessorSearchSession getParameterProcessorSearchSessionForConfiguration(org.osid.id.Id configurationId, 
                                                                                                                           org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the parameter 
     *  processor administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ParameterProcessorAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterProcessorAdmin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParameterProcessorAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.configuration.rules.ParameterProcessorAdminSession getParameterProcessorAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the parameter 
     *  processor administration service for the given configuration. 
     *
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ParameterProcessorAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Configuration </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> configurationId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterProcessorAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParameterProcessorAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.configuration.rules.ParameterProcessorAdminSession getParameterProcessorAdminSessionForConfiguration(org.osid.id.Id configurationId, 
                                                                                                                         org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the parameter 
     *  processor notification service. 
     *
     *  @param  paremeterProcessorReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> ParameterProcessorNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          paremeterProcessorReceiver </code> or <code> proxy </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterProcessorNotification() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParameterProcessorNotification() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.configuration.rules.ParameterProcessorNotificationSession getParameterProcessorNotificationSession(org.osid.configuration.rules.ParameterProcessorReceiver paremeterProcessorReceiver, 
                                                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the parameter 
     *  processor notification service for the given configuration. 
     *
     *  @param  paremeterProcessorReceiver the notification callback 
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ParameterProcessorNotificationSession </code> 
     *  @throws org.osid.NotFoundException no configuration found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          paremeterProcessorReceiver, configurationId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterProcessorNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParameterProcessorNotification() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.configuration.rules.ParameterProcessorNotificationSession getParameterProcessorNotificationSessionForConfiguration(org.osid.configuration.rules.ParameterProcessorReceiver paremeterProcessorReceiver, 
                                                                                                                                       org.osid.id.Id configurationId, 
                                                                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup parameter 
     *  processor/configuration mappings for parameter processors. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ParameterProcessorConfigurationSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterProcessorConfiguration() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParameterProcessorConfiguration() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.configuration.rules.ParameterProcessorConfigurationSession getParameterProcessorConfigurationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning 
     *  parameter processor to configurations. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ParameterProcessorConfigurationAssignmentSession 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterProcessorConfigurationAssignment() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParameterProcessorConfigurationAssignment() 
     *              </code> is <code> true. </code> 
     */

    public org.osid.configuration.rules.ParameterProcessorConfigurationAssignmentSession getParameterProcessorConfigurationAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage parameter processor 
     *  smart configurations. 
     *
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ParameterProcessorSmartConfigurationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Configuration </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> configurationId </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterProcessorSmartConfiguration() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParameterProcessorSmartConfiguration() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.configuration.rules.ParameterProcessorSmartConfigurationSession getParameterProcessorSmartConfigurationSession(org.osid.id.Id configurationId, 
                                                                                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the parameter 
     *  processor mapping lookup service for looking up the rules applied to 
     *  the configuration. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ParameterProcessorRuleLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterProcessorRuleLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParameterProcessorRuleLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.configuration.rules.ParameterProcessorRuleLookupSession getParameterProcessorRuleLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the parameter 
     *  processor mapping lookup service for the given configuration for 
     *  looking up rules applied to an configuration. 
     *
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ParameterProcessorRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Configuration </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> configurationId </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterProcessorRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParameterProcessorRuleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.configuration.rules.ParameterProcessorRuleLookupSession getParameterProcessorRuleLookupSessionForConfiguration(org.osid.id.Id configurationId, 
                                                                                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the parameter 
     *  processor assignment service to apply to configurations. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ParameterProcessorRuleApplicationSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterProcessorRuleApplication() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParameterProcessorRuleApplication() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.configuration.rules.ParameterProcessorRuleApplicationSession getParameterProcessorRuleApplicationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the parameter 
     *  processor assignment service for the given configuration to apply to 
     *  configurations. 
     *
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ParameterProcessorRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Configuration </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> configurationId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterProcessorRuleApplication() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParameterProcessorRuleApplication() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.configuration.rules.ParameterProcessorRuleApplicationSession getParameterProcessorRuleApplicationSessionForConfiguration(org.osid.id.Id configurationId, 
                                                                                                                                             org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the parameter 
     *  processor enabler lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ParameterProcessorEnablerLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterProcessorEnablerLookup() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParameterProcessorEnablerLookup() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.configuration.rules.ParameterProcessorEnablerLookupSession getParameterProcessorEnablerLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the parameter 
     *  processor enabler lookup service for the given configuration. 
     *
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ParameterProcessorEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Configuration </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> configurationId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterProcessorEnablerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParameterProcessorEnablerLookup() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.configuration.rules.ParameterProcessorEnablerLookupSession getParameterProcessorEnablerLookupSessionForConfiguration(org.osid.id.Id configurationId, 
                                                                                                                                         org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the parameter 
     *  processor enabler query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ParameterProcessorEnablerQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterProcessorEnablerQuery() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParameterProcessorEnablerQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.configuration.rules.ParameterProcessorEnablerQuerySession getParameterProcessorEnablerQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the parameter 
     *  processor enabler query service for the given configuration. 
     *
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ParameterProcessorEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Configuration </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> configurationId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterProcessorEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParameterProcessorEnablerQuery() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.configuration.rules.ParameterProcessorEnablerQuerySession getParameterProcessorEnablerQuerySessionForConfiguration(org.osid.id.Id configurationId, 
                                                                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the parameter 
     *  processor enabler search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ParameterProcessorEnablerSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterProcessorEnablerSearch() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParameterProcessorEnablerSearch() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.configuration.rules.ParameterProcessorEnablerSearchSession getParameterProcessorEnablerSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the parameter 
     *  processor enablers earch service for the given configuration. 
     *
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ParameterProcessorEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Configuration </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> configurationId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterProcessorEnablerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParameterProcessorEnablerSearch() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.configuration.rules.ParameterProcessorEnablerSearchSession getParameterProcessorEnablerSearchSessionForConfiguration(org.osid.id.Id configurationId, 
                                                                                                                                         org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the parameter 
     *  processor enabler administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ParameterProcessorEnablerAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterProcessorEnablerAdmin() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParameterProcessorEnablerAdmin() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.configuration.rules.ParameterProcessorEnablerAdminSession getParameterProcessorEnablerAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the parameter 
     *  processor enabler administration service for the given configuration. 
     *
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ParameterProcessorEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Configuration </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> configurationId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterProcessorEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParameterProcessorEnablerAdmin() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.configuration.rules.ParameterProcessorEnablerAdminSession getParameterProcessorEnablerAdminSessionForConfiguration(org.osid.id.Id configurationId, 
                                                                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the parameter 
     *  processor enabler notification service. 
     *
     *  @param  parameterProcessorEnablerReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> ParameterProcessorEnablerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          parameterProcessorEnablerReceiver </code> or <code> proxy 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterProcessorEnablerNotification() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParameterProcessorEnablerNotification() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.configuration.rules.ParameterProcessorEnablerNotificationSession getParameterProcessorEnablerNotificationSession(org.osid.configuration.rules.ParameterProcessorEnablerReceiver parameterProcessorEnablerReceiver, 
                                                                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the parameter 
     *  processor enabler notification service for the given configuration. 
     *
     *  @param  parameterProcessorEnablerReceiver the notification callback 
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ParameterProcessorEnablerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no configuration found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          parameterProcessorEnablerReceiver, configurationId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterProcessorEnablerNotification() </code> or 
     *          <code> supportsVisibleFederation() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParameterProcessorEnablerNotification() </code> 
     *              and <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.configuration.rules.ParameterProcessorEnablerNotificationSession getParameterProcessorEnablerNotificationSessionForConfiguration(org.osid.configuration.rules.ParameterProcessorEnablerReceiver parameterProcessorEnablerReceiver, 
                                                                                                                                                     org.osid.id.Id configurationId, 
                                                                                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup parameter processor 
     *  enabler/configuration mappings for parameter processor enablers. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ParameterProcessorEnablerConfigurationSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterProcessorEnablerConfiguration() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParameterProcessorEnablerConfiguration() </code> 
     *              is <code> true. </code> 
     */

    public org.osid.configuration.rules.ParameterProcessorEnablerConfigurationSession getParameterProcessorEnablerConfigurationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning 
     *  parameter processor enablers to configurations. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> 
     *          ParameterProcessorEnablerConfigurationAssignmentSession 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterProcessorEnablerConfigurationAssignment() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParameterProcessorEnablerConfigurationAssignment() 
     *              </code> is <code> true. </code> 
     */

    public org.osid.configuration.rules.ParameterProcessorEnablerConfigurationAssignmentSession getParameterProcessorEnablerConfigurationAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage parameter processor 
     *  enabler smart configurations. 
     *
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ParameterProcessorEnablerSmartConfigurationSession 
     *          </code> 
     *  @throws org.osid.NotFoundException no <code> Configuration </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> configurationId </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterProcessorEnablerSmartConfiguration() </code> 
     *          is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParameterProcessorEnablerSmartConfiguration() 
     *              </code> is <code> true. </code> 
     */

    public org.osid.configuration.rules.ParameterProcessorEnablerSmartConfigurationSession getParameterProcessorEnablerSmartConfigurationSession(org.osid.id.Id configurationId, 
                                                                                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the parameter 
     *  processor enabler mapping lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ParameterProcessorEnablerRuleLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterProcessorEnablerRuleLookup() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParameterProcessorEnablerRuleLookup() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.configuration.rules.ParameterProcessorEnablerRuleLookupSession getParameterProcessorEnablerRuleLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the parameter 
     *  processor enabler mapping lookup service for the given configuration. 
     *
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ParameterProcessorEnablerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Configuration </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> configurationId </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterProcessorEnablerRuleLookup() </code> or 
     *          <code> supportsVisibleFederation() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParameterProcessorEnablerRuleLookup() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.configuration.rules.ParameterProcessorEnablerRuleLookupSession getParameterProcessorEnablerRuleLookupSessionForConfiguration(org.osid.id.Id configurationId, 
                                                                                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the parameter 
     *  processor enabler assignment service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ParameterProcessorEnablerRuleApplicationSession 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterProcessorEnablerRuleApplication() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParameterProcessorEnablerRuleApplication() </code> 
     *              is <code> true. </code> 
     */

    public org.osid.configuration.rules.ParameterProcessorEnablerRuleApplicationSession getParameterProcessorEnablerRuleApplicationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the parameter 
     *  processor enabler assignment service for the given configuration. 
     *
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ParameterProcessorEnablerRuleApplicationSession 
     *          </code> 
     *  @throws org.osid.NotFoundException no <code> Configuration </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> configurationId </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterProcessorEnablerRuleApplication() </code> or 
     *          <code> supportsVisibleFederation() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParameterProcessorEnablerRuleApplication() </code> 
     *              and <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.configuration.rules.ParameterProcessorEnablerRuleApplicationSession getParameterProcessorEnablerRuleApplicationSessionForConfiguration(org.osid.id.Id configurationId, 
                                                                                                                                                           org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;
}
