//
// org.osid.configuration.rules.ParameterProcessorAdminSession
//
//     The OSID Java specification for org.osid.configuration.rules.ParameterProcessorAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.configuration.rules;


/**
 *  <p>This session creates and removes parameter processors. The data for 
 *  create and update is provided via the <code> ParameterProcessorForm. 
 *  </code> </p>
 */

public interface ParameterProcessorAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Configuration </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> Configuration Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getConfigurationId();


    /**
     *  Gets the <code> Configuration </code> associated with this session. 
     *
     *  @return the configuration 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.Configuration getConfiguration()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create parameter processors. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> ParameterProcessor 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer create 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> ParameterProcessor </code> 
     *          creation is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateParameterProcessor();


    /**
     *  Tests if this user can create a single <code> ParameterProcessor 
     *  </code> using the desired record types. While <code> 
     *  ConfigurationRulesManager.getParameterProcessorRecordTypes() </code> 
     *  can be used to examine which records are supported, this method tests 
     *  which record(s) are required for creating a specific <code> 
     *  ParameterProcessor. </code> Providing an empty array tests if a <code> 
     *  ParameterProcessor </code> can be created with no records. 
     *
     *  @param  parameterProcessorRecordTypes array of parameter processor 
     *          record types 
     *  @return <code> true </code> if <code> ParameterProcessor </code> 
     *          creation using the specified record <code> Types </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          parameterProcessorRecordTypes </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateParameterProcessorWithRecordTypes(org.osid.type.Type[] parameterProcessorRecordTypes);


    /**
     *  Gets the parameter processor form for creating new parameter 
     *  processors. A new form should be requested for each create 
     *  transaction. 
     *
     *  @param  parameterProcessorRecordTypes array of parameter processor 
     *          record types 
     *  @return the parameter processor form 
     *  @throws org.osid.NullArgumentException <code> 
     *          parameterProcessorRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.rules.ParameterProcessorForm getParameterProcessorFormForCreate(org.osid.type.Type[] parameterProcessorRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> ParameterProcessor. </code> 
     *
     *  @param  parameterProcessorForm the form for this <code> 
     *          ParameterProcessor </code> 
     *  @return the new <code> ParameterProcessor </code> 
     *  @throws org.osid.IllegalStateException <code> parameterProcessorForm 
     *          </code> already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> parameterProcessorForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> parameterProcessorForm 
     *          </code> did not originate from <code> 
     *          getParameterProcessorFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.rules.ParameterProcessor createParameterProcessor(org.osid.configuration.rules.ParameterProcessorForm parameterProcessorForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update parameter processors. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> ParameterProcessor 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer update 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> ParameterProcessor </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateParameterProcessors();


    /**
     *  Gets the parameter processor form for updating an existing parameter 
     *  processor. A new parameter processor form should be requested for each 
     *  update transaction. 
     *
     *  @param  parameterProcessorId the <code> Id </code> of the <code> 
     *          ParameterProcessor </code> 
     *  @return the parameter processor form 
     *  @throws org.osid.NotFoundException <code> parameterProcessorId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> parameterProcessorId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.rules.ParameterProcessorForm getParameterProcessorFormForUpdate(org.osid.id.Id parameterProcessorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing parameter processor. 
     *
     *  @param  parameterProcessorForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> parameterProcessorForm 
     *          </code> already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> parameterProcessorForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> parameterProcessorForm 
     *          </code> did not originate from <code> 
     *          getParameterProcessorFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateParameterProcessor(org.osid.configuration.rules.ParameterProcessorForm parameterProcessorForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete parameter processors. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> ParameterProcessor 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer delete 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> ParameterProcessor </code> 
     *          deletion is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteParameterProcessors();


    /**
     *  Deletes a <code> ParameterProcessor. </code> 
     *
     *  @param  parameterProcessorId the <code> Id </code> of the <code> 
     *          ParameterProcessor </code> to remove 
     *  @throws org.osid.NotFoundException <code> parameterProcessorId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> parameterProcessorId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteParameterProcessor(org.osid.id.Id parameterProcessorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for parameter 
     *  processors. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> ParameterProcessor </code> 
     *          aliasing is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageParameterProcessorAliases();


    /**
     *  Adds an <code> Id </code> to a <code> ParameterProcessor </code> for 
     *  the purpose of creating compatibility. The primary <code> Id </code> 
     *  of the <code> ParameterProcessor </code> is determined by the 
     *  provider. The new <code> Id </code> performs as an alias to the 
     *  primary <code> Id </code> . If the alias is a pointer to another 
     *  parameter processor. it is reassigned to the given parameter processor 
     *  <code> Id. </code> 
     *
     *  @param  parameterProcessorId the <code> Id </code> of a <code> 
     *          ParameterProcessor </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> parameterProcessorId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> parameterProcessorId 
     *          </code> or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasParameterProcessor(org.osid.id.Id parameterProcessorId, 
                                        org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
