//
// org.osid.configuration.rules.ParameterProcessorEnablerSmartConfigurationSession
//
//     The OSID Java specification for org.osid.configuration.rules.ParameterProcessorEnablerSmartConfigurationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.configuration.rules;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  configurations. A <code> ParameterProcessorEnablerQuery </code> can be 
 *  retrieved from this session and mapped to this <code> Configuration 
 *  </code> to create a virtual collection of parameter processor enablers. 
 *  The parameter processor enablers may be sequenced using the <code> 
 *  ParameterProcessorEnablerSearchOrder </code> from this session. </p> 
 *  
 *  <p> This <code> Configuration </code> has a default query that matches any 
 *  parameter processor enabler and a default search order that specifies no 
 *  sequencing. The queries may be examined using a <code> 
 *  ParameterProcessorEnablerQueryInspector. </code> The query may be modified 
 *  by converting the inspector back to a <code> 
 *  ParameterProcessorEnablerQuery. </code> </p>
 */

public interface ParameterProcessorEnablerSmartConfigurationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Configuration </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> Configuration Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getConfigurationId();


    /**
     *  Gets the <code> Configuration </code> associated with this session. 
     *
     *  @return the configuration 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.Configuration getConfiguration()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart configurations. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known methods in this session will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart configuration management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartConfigurations();


    /**
     *  Gets a parameter processor enabler query. 
     *
     *  @return the parameter processor enabler query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.rules.ParameterProcessorEnablerQuery getParameterProcessorEnablerQuery();


    /**
     *  Gets a parameter processor enabler search order. 
     *
     *  @return the parameter processor enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.rules.ParameterProcessorEnablerSearchOrder getParameterProcessorEnablerSearchOrder();


    /**
     *  Applies a parameter processor enabler query to this configuration. 
     *
     *  @param  parameterProcessorEnablerQuery the parameter processor enabler 
     *          query 
     *  @throws org.osid.NullArgumentException <code> 
     *          parameterProcessorEnablerQuery </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> 
     *          parameterProcessorEnablerQuery </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyParameterProcessorEnablerQuery(org.osid.configuration.rules.ParameterProcessorEnablerQuery parameterProcessorEnablerQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a parameter processor enabler query inspector for this 
     *  configuration. 
     *
     *  @return the parameter processor enabler query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.rules.ParameterProcessorEnablerQueryInspector inspectParameterProcessorEnablerQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a parameter processor enabler search order to this 
     *  configuration. 
     *
     *  @param  parameterProcessorEnablerSearchOrder the parameter processor 
     *          enabler search order 
     *  @throws org.osid.NullArgumentException <code> 
     *          parameterProcessorEnablerSearchOrder </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> 
     *          parameterProcessorEnablerSearchOrder </code> not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyParameterProcessorEnablerSequencing(org.osid.configuration.rules.ParameterProcessorEnablerSearchOrder parameterProcessorEnablerSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a parameter processor enabler query from an inspector. 
     *
     *  @param  parameterProcessorEnablerQueryInspector a parameter processor 
     *          enabler query inspector 
     *  @return the parameter processor enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          parameterProcessorEnablerQueryInspector </code> is <code> null 
     *          </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          parameterProcessorEnablerQueryInspector </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.rules.ParameterProcessorEnablerQuery getParameterProcessorEnablerQueryFromInspector(org.osid.configuration.rules.ParameterProcessorEnablerQueryInspector parameterProcessorEnablerQueryInspector);
}
