//
// org.osid.configuration.rules.ParameterProcessorLookupSession
//
//     The OSID Java specification for org.osid.configuration.rules.ParameterProcessorLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.configuration.rules;


/**
 *  <p>This session provides methods for retrieving <code> 
 *  ParameterProcessors. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated configuration view: All parameter processor methods in 
 *      this session operate, retrieve and pertain to parameter processor 
 *      defined explicitly in the current configuration. Using an isolated 
 *      view is useful for managing <code> ParameterProcessors </code> with 
 *      the <code> ParameterProcessorAdminSession. </code> </li> 
 *      <li> federated configuration view: All parameter processor methods in 
 *      this session operate, retrieve and pertain to all parameter processor 
 *      defined in this configuration and any other parameter processor 
 *      implicitly available in this configuration through configuration 
 *      inheritence. </li> 
 *      <li> active parameter processor view: All parameter processor lookup 
 *      methods return active parameter processors. </li> 
 *      <li> any status parameter processor view: Parameter processors of any 
 *      active or inactive status are returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedDistributorView() </code> and <code> 
 *  useIsolatedDistributorView() </code> behave as a radio group and one 
 *  should be selected before invoking the methods in this session. </p>
 */

public interface ParameterProcessorLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Configuration </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> Configuration Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getConfigurationId();


    /**
     *  Gets the <code> Configuration </code> associated with this session. 
     *
     *  @return the configuration 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.Configuration getConfiguration()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> ParameterProcessors </code> 
     *  lookups. A return of true does not guarantee successful authorization. 
     *  A return of false indicates that it is known all methods in this 
     *  session will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer lookup 
     *  operations to unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupParameterProcessors();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeParameterProcessorView();


    /**
     *  A complete view of the <code> ParameterProcessor </code> returns is 
     *  desired. Methods will return what is requested or result in an error. 
     *  This view is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryParameterProcessorView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include parameter processor in configurations which are children of 
     *  this configuration in the configuration hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedConfigurationView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this configuration only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedConfigurationView();


    /**
     *  Only active parameter processors are returned by methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveParameterProcessorView();


    /**
     *  All active and inactive parameter processors are returned by methods 
     *  in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusParameterProcessorView();


    /**
     *  Gets the <code> ParameterProcessor </code> specified by its <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  ParameterProcessor </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> ParameterProcessor </code> and retained for 
     *  compatibility. 
     *  
     *  In active mode, parameter processors are returned that are currently 
     *  active. In any status mode, active and inactive parameter processors 
     *  are returned. 
     *
     *  @param  parameterProcessorId <code> Id </code> of the <code> 
     *          ParameterProcessor </code> 
     *  @return the parameter processor 
     *  @throws org.osid.NotFoundException <code> parameterProcessorId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> parameterProcessorId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.configuration.rules.ParameterProcessor getParameterProcessor(org.osid.id.Id parameterProcessorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ParameterProcessorList </code> corresponding to the 
     *  given <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  parameter processor specified in the <code> Id </code> list, in the 
     *  order of the list, including duplicates, or an error results if an 
     *  <code> Id </code> in the supplied list is not found or inaccessible. 
     *  Otherwise, inaccessible <code> ParameterProcessors </code> may be 
     *  omitted from the list and may present the elements in any order 
     *  including returning a unique set. 
     *  
     *  In active mode, parameter processors are returned that are currently 
     *  active. In any status mode, active and inactive parameter processors 
     *  are returned. 
     *
     *  @param  parameterProcessorIds the list of <code> Ids </code> to 
     *          retrieve 
     *  @return the returned <code> ParameterProcessor </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> parameterProcessorIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.rules.ParameterProcessorList getParameterProcessorsByIds(org.osid.id.IdList parameterProcessorIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ParameterProcessorList </code> corresponding to the 
     *  given parameter processor genus <code> Type </code> which does not 
     *  include parameter processor of genus types derived from the specified 
     *  <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  parameter processor or an error results. Otherwise, the returned list 
     *  may contain only those parameter processor that are accessible through 
     *  this session. 
     *  
     *  In active mode, parameter processors are returned that are currently 
     *  active. In any status mode, active and inactive parameter processors 
     *  are returned. 
     *
     *  @param  parameterProcessorGenusType a parameter processor genus type 
     *  @return the returned <code> ParameterProcessor </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          parameterProcessorGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.rules.ParameterProcessorList getParameterProcessorsByGenusType(org.osid.type.Type parameterProcessorGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ParameterProcessorList </code> corresponding to the 
     *  given parameter processor genus <code> Type </code> and include any 
     *  additional parameter processor with genus types derived from the 
     *  specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  parameter processor or an error results. Otherwise, the returned list 
     *  may contain only those parameter processor that are accessible through 
     *  this session. 
     *  
     *  In active mode, parameter processors are returned that are currently 
     *  active. In any status mode, active and inactive parameter processors 
     *  are returned. 
     *
     *  @param  parameterProcessorGenusType a parameter processor genus type 
     *  @return the returned <code> ParameterProcessor </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          parameterProcessorGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.rules.ParameterProcessorList getParameterProcessorsByParentGenusType(org.osid.type.Type parameterProcessorGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ParameterProcessorList </code> containing the given 
     *  parameter processor record <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  parameter processor or an error results. Otherwise, the returned list 
     *  may contain only those parameter processor that are accessible through 
     *  this session. 
     *  
     *  In active mode, parameter processors are returned that are currently 
     *  active. In any status mode, active and inactive parameter processors 
     *  are returned. 
     *
     *  @param  parameterProcessorRecordType a parameter processor record type 
     *  @return the returned <code> ParameterProcessor </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          parameterProcessorRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.rules.ParameterProcessorList getParameterProcessorsByRecordType(org.osid.type.Type parameterProcessorRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> ParameterProcessors. </code> 
     *  
     *  In plenary mode, the returned list contains all known parameter 
     *  processor or an error results. Otherwise, the returned list may 
     *  contain only those parameter processor that are accessible through 
     *  this session. 
     *  
     *  In active mode, parameter processors are returned that are currently 
     *  active. In any status mode, active and inactive parameter processors 
     *  are returned. 
     *
     *  @return the returned <code> ParameterProcessor </code> list 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.rules.ParameterProcessorList getParameterProcessors()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
