//
// org.osid.configuration.rules.ParameterProcessorNotificationSession
//
//     The OSID Java specification for org.osid.configuration.rules.ParameterProcessorNotificationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.configuration.rules;


/**
 *  <p>This session defines methods to receive notifications on adds/changes 
 *  to <code> ParameterProcessor </code> objects in this <code> Configuration. 
 *  </code> This also includes existing <code> ParameterProcessors </code> 
 *  that may appear or disappear due to changes in the <code> Configuration 
 *  </code> hierarchy, This session is intended for consumers needing to 
 *  synchronize their state with this service without the use of polling. 
 *  Notifications are cancelled when this session is closed. </p> 
 *  
 *  <p> The two views defined in this session correspond to the views in the 
 *  <code> ParameterProcessorLookupSession. </code> </p>
 */

public interface ParameterProcessorNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Configuration </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> Configuration Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getConfigurationId();


    /**
     *  Gets the <code> Configuration </code> associated with this session. 
     *
     *  @return the configuration 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.Configuration getConfiguration()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can register for <code> ParameterProcessor </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForParameterProcessorNotifications();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include in configurations which are children of this configuration in 
     *  the configuration hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedConfigurationView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts notifications to this configuration only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedConfigurationView();


    /**
     *  Reliable notifications are desired. In reliable mode, notifications 
     *  are to be acknowledged using <code> 
     *  acknowledgeParameterProcessorNotification() </code> . 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void reliableParameterProcessorNotifications();


    /**
     *  Unreliable notifications are desired. In unreliable mode, 
     *  notifications do not need to be acknowledged. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void unreliableParameterProcessorNotifications();


    /**
     *  Acknowledge a parameter processor notification. 
     *
     *  @param  notificationId the <code> Id </code> of the notification 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void acknowledgeParameterProcessorNotification(org.osid.id.Id notificationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new parameter processors. <code> 
     *  ParameterProcessorReceiver.newParameterProcessors() </code> is invoked 
     *  when a new <code> ParameterProcessor </code> appears in this 
     *  configuration. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewParameterProcessors()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated parameter processors. <code> 
     *  ParameterProcessorReceiver.changedParameterProcessors() </code> is 
     *  invoked when a parameter processor in this configuration is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedParameterProcessors()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated parameter processor. <code> 
     *  ProvisionableReceiver.changedParameterProcessors() </code> is invoked 
     *  when the specified parameter processor in this configuration is 
     *  changed. 
     *
     *  @param  parameterProcessorId the <code> Id </code> of the <code> 
     *          ParameterProcessor </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> parameterProcessorId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedParameterProcessor(org.osid.id.Id parameterProcessorId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted parameter processors. <code> 
     *  ParameterProcessorReceiver.deletedParameterProcessors() </code> is 
     *  invoked when a parameter processor is deleted or removed from this 
     *  configuration. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedParameterProcessors()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted parameter processor. <code> 
     *  ParameterProcessorReceiver.deletedParameterProcessors() </code> is 
     *  invoked when the specified parameter processor is deleted or removed 
     *  from this configuration. 
     *
     *  @param  parameterProcessorId the <code> Id </code> of the <code> 
     *          ParameterProcessor </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> parameterProcessorId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedParameterProcessor(org.osid.id.Id parameterProcessorId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
