//
// org.osid.configuration.rules.ParameterProcessorRuleLookupSession
//
//     The OSID Java specification for org.osid.configuration.rules.ParameterProcessorRuleLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.configuration.rules;


/**
 *  <p>This session provides methods to retrieve <code> ParameterProcessor 
 *  </code> to <code> Parameter </code> mappings. <code> </code> </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated configuration view: All methods in this session operate, 
 *      retrieve and pertain parameter processor defined explicitly in the 
 *      current configuration </li> 
 *      <li> federated configuration view: All methods in this session 
 *      operate, retrieve and pertain to all parameter processor defined in 
 *      this configuration and any other parameter processor implicitly 
 *      available in this configuration through configuration inheritence. 
 *      </li> 
 *  </ul>
 *  
 */

public interface ParameterProcessorRuleLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Configuration </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> Configuration Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getConfigurationId();


    /**
     *  Gets the <code> Configuration </code> associated with this session. 
     *
     *  @return the configuration 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.Configuration getConfiguration()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform lookups of parameter 
     *  processor/parameter mappings. A return of true does not guarantee 
     *  successful authorization. A return of false indicates that it is known 
     *  lookup methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if looking up mappings is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupParameterProcessorRules();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeParameterProcessorRuleView();


    /**
     *  A complete view of the <code> ParameterProcessor </code> and <code> 
     *  Parameter </code> returns is desired. Methods will return what is 
     *  requested or result in an error. This view is used when greater 
     *  precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryParameterProcessorRuleView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include parameter processor in configurations which are children of 
     *  this configuration in the configuration hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedConfigurationView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this configuration only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedConfigurationView();


    /**
     *  Gets the <code> ParameterProcessor Id </code> associated with a <code> 
     *  Parameter. </code> 
     *
     *  @param  parameterId <code> Id </code> of the <code> Parameter </code> 
     *  @return the parameter processor <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> parameterId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> parameterId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getParameterProcessorIdsForParameter(org.osid.id.Id parameterId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> ParameterProcessor </code> associated with a <code> 
     *  Parameter. </code> 
     *
     *  @param  parameterId <code> Id </code> of the <code> Parameter </code> 
     *  @return the parameter processors 
     *  @throws org.osid.NotFoundException <code> parameterId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> parameterId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.rules.ParameterProcessorList getParameterProcessorsForParameter(org.osid.id.Id parameterId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Parameter </code> <code> Ids </code> mapped to an 
     *  <code> ParameterProcessor. </code> 
     *
     *  @param  parameterProcessorId <code> Id </code> of an <code> 
     *          ParameterProcessor </code> 
     *  @return list of parameter <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> parameterProcessorId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> parameterProcessorId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getParameterIdsForParameterProcessor(org.osid.id.Id parameterProcessorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Parameters </code> mapped to an <code> 
     *  ParameterProcessor. </code> 
     *
     *  @param  parameterProcessorId <code> Id </code> of an <code> 
     *          ParameterProcessor </code> 
     *  @return list of parameters 
     *  @throws org.osid.NotFoundException <code> parameterProcessorId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> parameterProcessorId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.ParameterList getParametersForParameterProcessor(org.osid.id.Id parameterProcessorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
