//
// org.osid.configuration.rules.ValueEnablerConfigurationAssignmentSession
//
//     The OSID Java specification for org.osid.configuration.rules.ValueEnablerConfigurationAssignmentSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.configuration.rules;


/**
 *  <p>This session provides methods to re-assign <code> ValueEnabler </code> 
 *  to <code> Configuration </code> mappings. A <code> ValueEnabler </code> 
 *  may appear in multiple <code> Configuration </code> objects and removing 
 *  the last reference to a <code> ValueEnabler </code> is the equivalent of 
 *  deleting it. Each <code> Configuration </code> may have its own 
 *  authorizations governing who is allowed to operate on it. </p> 
 *  
 *  <p> Adding a reference of a <code> ValueEnabler </code> to another <code> 
 *  Configuration </code> is not a copy operation (eg: does not change its 
 *  <code> Id </code> ). </p>
 */

public interface ValueEnablerConfigurationAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter value enabler/configuration mappings. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignValueEnablers();


    /**
     *  Tests if this user can alter value enabler/configuration mappings. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> configurationId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignValueEnablersToConfiguration(org.osid.id.Id configurationId);


    /**
     *  Gets a list of configurations including and under the given 
     *  configuration node in which any value enabler can be assigned. 
     *
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> 
     *  @return list of assignable configuration <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> configurationId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableConfigurationIds(org.osid.id.Id configurationId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of configurations including and under the given 
     *  configuration node in which a specific value enabler can be assigned. 
     *
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> 
     *  @param  valueEnablerId the <code> Id </code> of the <code> 
     *          ValueEnabler </code> 
     *  @return list of assignable configuration <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> configurationId </code> 
     *          or <code> valueEnablerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableConfigurationIdsForValueEnabler(org.osid.id.Id configurationId, 
                                                                           org.osid.id.Id valueEnablerId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> ValueEnabler </code> to a <code> 
     *  Configuration. </code> 
     *
     *  @param  valueEnablerId the <code> Id </code> of the <code> 
     *          ValueEnabler </code> 
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> 
     *  @throws org.osid.AlreadyExistsException <code> valueEnablerId </code> 
     *          is already assigned to <code> configurationId </code> 
     *  @throws org.osid.NotFoundException <code> valueEnablerId </code> or 
     *          <code> configurationId </code> not found 
     *  @throws org.osid.NullArgumentException <code> valueEnablerId </code> 
     *          or <code> configurationId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignValueEnablerToConfiguration(org.osid.id.Id valueEnablerId, 
                                                  org.osid.id.Id configurationId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> ValueEnabler </code> from a <code> Configuration. 
     *  </code> 
     *
     *  @param  valueEnablerId the <code> Id </code> of the <code> 
     *          ValueEnabler </code> 
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> 
     *  @throws org.osid.NotFoundException <code> valueEnablerId </code> or 
     *          <code> configurationId </code> not found or <code> 
     *          valueEnablerId </code> is not assigned to <code> 
     *          configurationId </code> 
     *  @throws org.osid.NullArgumentException <code> valueEnablerId </code> 
     *          or <code> configurationId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignValueEnablerFromConfiguration(org.osid.id.Id valueEnablerId, 
                                                      org.osid.id.Id configurationId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Moves a <code> ValueEnabler </code> from one <code> Configuration 
     *  </code> to another. Mappings to other <code> Configurations </code> 
     *  are unaffected. 
     *
     *  @param  valueEnablerId the <code> Id </code> of the <code> 
     *          ValueEnabler </code> 
     *  @param  fromConfigurationId the <code> Id </code> of the current 
     *          <code> Configuration </code> 
     *  @param  toConfigurationId the <code> Id </code> of the destination 
     *          <code> Configuration </code> 
     *  @throws org.osid.NotFoundException <code> valueEnablerId, 
     *          fromConfigurationId, </code> or <code> toConfigurationId 
     *          </code> not found or <code> valueEnablerId </code> not mapped 
     *          to <code> fromConfigurationId </code> 
     *  @throws org.osid.NullArgumentException <code> valueEnablerId, 
     *          cromConfigurationId, </code> or <code> toConfigurationId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void reassignValueEnablerToConfiguration(org.osid.id.Id valueEnablerId, 
                                                    org.osid.id.Id fromConfigurationId, 
                                                    org.osid.id.Id toConfigurationId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
