//
// org.osid.configuration.rules.ValueEnablerLookupSession
//
//     The OSID Java specification for org.osid.configuration.rules.ValueEnablerLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.configuration.rules;


/**
 *  <p>This session provides methods for retrieving <code> ValueEnablers. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated configuration view: All value enabler methods in this 
 *      session operate, retrieve and pertain to value enablers defined 
 *      explicitly in the current configuration. Using an isolated view is 
 *      useful for managing <code> ValueEnablers </code> with the <code> 
 *      ValueEnablerAdminSession. </code> </li> 
 *      <li> federated configuration view: All value enabler methods in this 
 *      session operate, retrieve and pertain to all value enablers defined in 
 *      this configuration and any other value enablers implicitly available 
 *      in this configuration through configuration inheritence. </li> 
 *      <li> active value enabler view: All value enabler lookup methods 
 *      return active value enablers. </li> 
 *      <li> any status value enabler view: value enablers of any active and 
 *      insatcive status are returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedDistributorView() </code> and <code> 
 *  useIsolatedDistributorView() </code> behave as a radio group and one 
 *  should be selected before invoking the methods in this session. </p>
 */

public interface ValueEnablerLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Configuration </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> Configuration Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getConfigurationId();


    /**
     *  Gets the <code> Configuration </code> associated with this session. 
     *
     *  @return the configuration 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.Configuration getConfiguration()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> ValueEnablers </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupValueEnablers();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeValueEnablerView();


    /**
     *  A complete view of the <code> ValueEnabler </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryValueEnablerView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include value enablers in configurations which are children of this 
     *  configuration in the configuration hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedConfigurationView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this configuration only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedConfigurationView();


    /**
     *  Only active value enablers are returned by methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveValueEnablerView();


    /**
     *  All active and inactive value enablers are returned by methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusValueEnablerView();


    /**
     *  Gets the <code> ValueEnabler </code> specified by its <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  ValueEnabler </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> ValueEnabler </code> and retained for 
     *  compatibility. 
     *  
     *  In active mode, value enablers are returned that are currently active. 
     *  In any status mode, active and inactive value enablers are returned. 
     *
     *  @param  valueEnablerId <code> Id </code> of the <code> ValueEnabler 
     *          </code> 
     *  @return the value enabler 
     *  @throws org.osid.NotFoundException <code> valueEnablerId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> valueEnablerId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.configuration.rules.ValueEnabler getValueEnabler(org.osid.id.Id valueEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ValueEnablerList </code> corresponding to the given 
     *  <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  value enablers specified in the <code> Id </code> list, in the order 
     *  of the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> ValueEnablers </code> may be omitted from the list 
     *  and may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In active mode, value enablers are returned that are currently active. 
     *  In any status mode, active and inactive value enablers are returned. 
     *
     *  @param  valueEnablerIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> ValueEnabler </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> valueEnablerIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.rules.ValueEnablerList getValueEnablersByIds(org.osid.id.IdList valueEnablerIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ValueEnablerList </code> corresponding to the given 
     *  value enabler genus <code> Type </code> which does not include value 
     *  enablers of genus types derived from the specified <code> Type. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  value enablers or an error results. Otherwise, the returned list may 
     *  contain only those value enablers that are accessible through this 
     *  session. 
     *  
     *  In active mode, value enablers are returned that are currently active. 
     *  In any status mode, active and inactive value enablers are returned. 
     *
     *  @param  valueEnablerGenusType a value enabler genus type 
     *  @return the returned <code> ValueEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> valueEnablerGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.rules.ValueEnablerList getValueEnablersByGenusType(org.osid.type.Type valueEnablerGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ValueEnablerList </code> corresponding to the given 
     *  value enabler genus <code> Type </code> and include any additional 
     *  value enablers with genus types derived from the specified <code> 
     *  Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  value enablers or an error results. Otherwise, the returned list may 
     *  contain only those value enablers that are accessible through this 
     *  session. 
     *  
     *  In active mode, value enablers are returned that are currently active. 
     *  In any status mode, active and inactive value enablers are returned. 
     *
     *  @param  valueEnablerGenusType a value enabler genus type 
     *  @return the returned <code> ValueEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> valueEnablerGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.rules.ValueEnablerList getValueEnablersByParentGenusType(org.osid.type.Type valueEnablerGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ValueEnablerList </code> containing the given value 
     *  enabler record <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  value enablers or an error results. Otherwise, the returned list may 
     *  contain only those value enablers that are accessible through this 
     *  session. 
     *  
     *  In active mode, value enablers are returned that are currently active. 
     *  In any status mode, active and inactive value enablers are returned. 
     *
     *  @param  valueEnablerRecordType a value enabler record type 
     *  @return the returned <code> ValueEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> valueEnablerRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.rules.ValueEnablerList getValueEnablersByRecordType(org.osid.type.Type valueEnablerRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ValueEnablerList </code> effective within the given date 
     *  range which are effective for the entire given date range inclusive 
     *  but not confined to the date range for any agent. 
     *  
     *  In plenary mode, the returned list contains all known value enablers 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those value enablers that are accessible through this session. 
     *  
     *  In active mode, value enablers are returned that are currently active. 
     *  In any status mode, active and inactive value enablers are returned. 
     *
     *  @param  from a start date 
     *  @param  to an end date 
     *  @return the returned <code> ValueEnabler </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.rules.ValueEnablerList getValueEnablersOnDate(org.osid.calendaring.DateTime from, 
                                                                                org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ValueEnablerList </code> effective within the given date 
     *  range which are effective for the entire given date range inclusive 
     *  but not confined to the date range and evaluated for the given agent. 
     *  
     *  In plenary mode, the returned list contains all known value enablers 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those value enablers that are accessible through this session. 
     *  
     *  In active mode, value enablers are returned that are currently active. 
     *  In any status mode, active and inactive value enablers are returned. 
     *
     *  @param  agentId an agent Id 
     *  @param  from a start date 
     *  @param  to an end date 
     *  @return the returned <code> ValueEnabler </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> agentId, from, </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.rules.ValueEnablerList getValueEnablersOnDateWithAgent(org.osid.id.Id agentId, 
                                                                                         org.osid.calendaring.DateTime from, 
                                                                                         org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> ValueEnablers. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  value enablers or an error results. Otherwise, the returned list may 
     *  contain only those value enablers that are accessible through this 
     *  session. 
     *  
     *  In active mode, value enablers are returned that are currently active. 
     *  In any status mode, active and inactive value enablers are returned. 
     *
     *  @return the returned <code> ValueEnabler </code> list 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.rules.ValueEnablerList getValueEnablers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
