//
// org.osid.configuration.rules.ValueEnablerRuleApplicationSession
//
//     The OSID Java specification for org.osid.configuration.rules.ValueEnablerRuleApplicationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.configuration.rules;


/**
 *  <p>This session provides methods to apply <code> ValueEnablers </code> to 
 *  <code> Values. </code> A <code> Value </code> with multiple <code> 
 *  ValueEnablers </code> means any positive rule evaluation across the 
 *  enablers result in a a visible <code> Value. </code> </p>
 */

public interface ValueEnablerRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Configuration </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> Configuration Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getConfigurationId();


    /**
     *  Gets the <code> Configuration </code> associated with this session. 
     *
     *  @return the configuration 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.Configuration getConfiguration()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter value enabler/value mappings. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignValueEnablers();


    /**
     *  Adds an existing <code> ValueEnabler </code> to a <code> Value. 
     *  </code> 
     *
     *  @param  valueEnablerId the <code> Id </code> of the <code> 
     *          ValueEnabler </code> 
     *  @param  valueId the <code> Id </code> of the <code> Value </code> 
     *  @throws org.osid.AlreadyExistsException <code> valueEnablerId </code> 
     *          is already applied to <code> valueId </code> 
     *  @throws org.osid.NotFoundException <code> valueEnablerId </code> or 
     *          <code> valueId </code> not found 
     *  @throws org.osid.NullArgumentException <code> valueEnablerId </code> 
     *          or <code> valueId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignValueEnablerToValue(org.osid.id.Id valueEnablerId, 
                                          org.osid.id.Id valueId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> ValueEnabler </code> from a <code> Value. </code> 
     *
     *  @param  valueEnablerId the <code> Id </code> of the <code> 
     *          ValueEnabler </code> 
     *  @param  valueId the <code> Id </code> of the <code> Value </code> 
     *  @throws org.osid.NotFoundException <code> valueEnablerId </code> or 
     *          <code> valueId </code> not found or <code> valueEnablerId 
     *          </code> is not applied to <code> valueId </code> 
     *  @throws org.osid.NullArgumentException <code> valueEnablerId </code> 
     *          or <code> valueId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignValueEnablerFromValue(org.osid.id.Id valueEnablerId, 
                                              org.osid.id.Id valueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> ValueEnablers. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known sequencing operations will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> ValueEnabler </code> ordering 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceValueEnablers();


    /**
     *  Reorders value enablers for a value by moving the specified value 
     *  enabler in front of a reference value enabler. 
     *
     *  @param  valueEnablerId the <code> Id </code> of a <code> ValueEnabler 
     *          </code> 
     *  @param  valueId the <code> Id </code> of a <code> Value </code> 
     *  @param  referenceId the reference value enabler <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> valueEnabelrId, valueId, 
     *          </code> or <code> referenceId </code> not found or, <code> 
     *          valueEnablerId, </code> or <code> referenceId </code> not 
     *          related to <code> valueId </code> 
     *  @throws org.osid.NullArgumentException <code> valueEnablerId, valueId, 
     *          </code> or <code> referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveValueEnablerAhead(org.osid.id.Id valueEnablerId, 
                                      org.osid.id.Id valueId, 
                                      org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders value enablers for a value by moving the specified value 
     *  enabler behind a reference value enabler. 
     *
     *  @param  valueEnablerId the <code> Id </code> of a <code> ValueEnabler 
     *          </code> 
     *  @param  valueId the <code> Id </code> of a <code> Value </code> 
     *  @param  referenceId the reference value enabler <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> valueEnabelrId, valueId, 
     *          </code> or <code> referenceId </code> not found or, <code> 
     *          valueEnablerId, </code> or <code> referenceId </code> not 
     *          related to <code> valueId </code> 
     *  @throws org.osid.NullArgumentException <code> valueEnablerId, valueId, 
     *          </code> or <code> referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveValueEnablerBehind(org.osid.id.Id valueEnablerId, 
                                       org.osid.id.Id valueId, 
                                       org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of value enablers for a value. 
     *
     *  @param  valueEnablerIds the <code> Ids </code> for a set of <code> 
     *          ValueEnablers </code> 
     *  @param  valueId the <code> Id </code> of a <code> Value </code> 
     *  @throws org.osid.NotFoundException <code> valueId </code> not found 
     *          or, a <code> valueEnablerId </code> not related to <code> 
     *          valueId </code> 
     *  @throws org.osid.NullArgumentException <code> valueEnablerIds </code> 
     *          or <code> valueId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderValueEnablers(org.osid.id.Id[] valueEnablerIds, 
                                   org.osid.id.Id valueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
