//
// org.osid.contact.AddressAdminSession
//
//     The OSID Java specification for org.osid.contact.AddressAdminSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.contact;


/**
 *  <p>This session creates, updates, and deletes <code> Addresses. </code> 
 *  The data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create an 
 *  <code> Address, </code> an <code> AddressForm </code> is requested using 
 *  <code> getAddressFormForCreate() </code> specifying the desired 
 *  relationship peers and record <code> Types </code> or none if no record 
 *  <code> Types </code> are needed. The returned <code> AddressForm </code> 
 *  will indicate that it is to be used with a create operation and can be 
 *  used to examine metdata or validate data prior to creation. Once the 
 *  <code> AddressForm </code> is submiited to a create operation, it cannot 
 *  be reused with another create operation unless the first operation was 
 *  unsuccessful. Each <code> AddressForm </code> corresponds to an attempted 
 *  transaction. </p> 
 *  
 *  <p> For updates, <code> AddressForms </code> are requested to the <code> 
 *  Address </code> <code> Id </code> that is to be updated using <code> 
 *  getAddressFormForUpdate(). </code> Similarly, the <code> AddressForm 
 *  </code> has metadata about the data that can be updated and it can perform 
 *  validation before submitting the update. The <code> AddressForm </code> 
 *  can only be used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Addresses. </code> To unmap an 
 *  <code> Address </code> from the current <code> AddressBook, </code> the 
 *  <code> AddressAddressBookAssignmentSession </code> should be used. These 
 *  delete operations attempt to remove the <code> Address </code> itself thus 
 *  removing it from all known <code> AddressBook </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface AddressAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> AddressBook </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> AddressBook Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAddressBookId();


    /**
     *  Gets the <code> AddressBook </code> associated with this session. 
     *
     *  @return the address book 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.AddressBook getAddressBook()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> Addresses. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating an <code> Address </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not wish to offer create operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Address </code> creation is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAddresses();


    /**
     *  Tests if this user can create a single <code> Address </code> using 
     *  the desired record types. While <code> 
     *  ContactManager.getAddressRecordTypes() </code> can be used to examine 
     *  which records are supported, this method tests which record(s) are 
     *  required for creating a specific <code> Address. </code> Providing an 
     *  empty array tests if an <code> Address </code> can be created with no 
     *  records. 
     *
     *  @param  addressRecordTypes array of address record types 
     *  @return <code> true </code> if <code> Address </code> creation using 
     *          the specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> addressRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAddressWithRecordTypes(org.osid.type.Type[] addressRecordTypes);


    /**
     *  Gets the address form for creating new addresses. A new form should be 
     *  requested for each create transaction. 
     *
     *  @param  addressRecordTypes array of address record types 
     *  @return the address form 
     *  @throws org.osid.NullArgumentException <code> addressRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.AddressForm getAddressFormForCreate(org.osid.type.Type[] addressRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Address. </code> 
     *
     *  @param  addressForm the form for this <code> Address </code> 
     *  @return the new <code> Address </code> 
     *  @throws org.osid.IllegalStateException <code> addressForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> addressForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> addressForm </code> did 
     *          not originate from <code> getAddressFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.Address createAddress(org.osid.contact.AddressForm addressForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Addresses. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating an <code> Address </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not wish to offer update operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Address </code> modification is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateAddresses();


    /**
     *  Gets the address form for updating an existing address. A new address 
     *  form should be requested for each update transaction. 
     *
     *  @param  addressId the <code> Id </code> of the <code> Address </code> 
     *  @return the address form 
     *  @throws org.osid.NotFoundException <code> addressId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> addressId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.AddressForm getAddressFormForUpdate(org.osid.id.Id addressId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing address. 
     *
     *  @param  addressForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> addressForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> addressId </code> or 
     *          <code> addressForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> addressForm </code> did 
     *          not originate from <code> getAddressFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateAddress(org.osid.contact.AddressForm addressForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> Addresses </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting an <code> Address </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not wish to offer delete operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Address </code> deletion is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteAddresses();


    /**
     *  Deletes an <code> Address. </code> 
     *
     *  @param  addressId the <code> Id </code> of the <code> Address </code> 
     *          to remove 
     *  @throws org.osid.NotFoundException <code> addressId </code> not found 
     *  @throws org.osid.NullArgumentException <code> addressId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteAddress(org.osid.id.Id addressId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Addresses. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Address </code> aliasing is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageAddressAliases();


    /**
     *  Adds an <code> Id </code> to an <code> Address </code> for the purpose 
     *  of creating compatibility. The primary <code> Id </code> of the <code> 
     *  Address </code> is determined by the provider. The new <code> Id 
     *  </code> performs as an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another address, it is reassigned to the given 
     *  address <code> Id. </code> 
     *
     *  @param  addressId the <code> Id </code> of an <code> Address </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> addressId </code> not found 
     *  @throws org.osid.NullArgumentException <code> addressId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasAddress(org.osid.id.Id addressId, org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
