//
// org.osid.contact.AddressBookAdminSession
//
//     The OSID Java specification for org.osid.contact.AddressBookAdminSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.contact;


/**
 *  <p>This session creates, updates, and deletes <code> AddressBooks. </code> 
 *  The data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create an 
 *  <code> AddressBook, </code> an <code> AddressBookForm </code> is requested 
 *  using <code> getAddressBookFormForCreate() </code> specifying the desired 
 *  record <code> Types </code> or none if no record <code> Types </code> are 
 *  needed. The returned <code> AddressBookForm </code> will indicate that it 
 *  is to be used with a create operation and can be used to examine metdata 
 *  or validate data prior to creation. Once the <code> AddressBookForm 
 *  </code> is submiited to a create operation, it cannot be reused with 
 *  another create operation unless the first operation was unsuccessful. Each 
 *  <code> AddressBookForm </code> corresponds to an attempted transaction. 
 *  </p> 
 *  
 *  <p> For updates, <code> AddressBookForms </code> are requested to the 
 *  <code> AddressBook </code> <code> Id </code> that is to be updated using 
 *  <code> getAddressBookFormForUpdate(). </code> Similarly, the <code> 
 *  AddressBookForm </code> has metadata about the data that can be updated 
 *  and it can perform validation before submitting the update. The <code> 
 *  AddressBookForm </code> can only be used once for a successful update and 
 *  cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> AddressBooks. </code> </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface AddressBookAdminSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can create <code> AddressBooks. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating an <code> AddressBook </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not wish to offer create operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> AddressBook </code> creation is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAddressBooks();


    /**
     *  Tests if this user can create a single <code> AddressBook </code> 
     *  using the desired record types. While <code> 
     *  ContactManager.getAddressBookRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> AddressBook. </code> 
     *  Providing an empty array tests if an <code> AddressBook </code> can be 
     *  created with no records. 
     *
     *  @param  addressBookRecordTypes array of address book types 
     *  @return <code> true </code> if <code> AddressBook </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> addressBookRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAddressBookWithRecordTypes(org.osid.type.Type[] addressBookRecordTypes);


    /**
     *  Gets the address book form for creating new address books. A new form 
     *  should be requested for each create transaction. 
     *
     *  @param  addressBookRecordTypes array of address book types 
     *  @return the address book form 
     *  @throws org.osid.NullArgumentException <code> addressBookRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.AddressBookForm getAddressBookFormForCreate(org.osid.type.Type[] addressBookRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> AddressBook. </code> 
     *
     *  @param  addressBookForm the form for this <code> AddressBook </code> 
     *  @return the new <code> AddressBook </code> 
     *  @throws org.osid.IllegalStateException <code> addressBookForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> addressBookForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> addressBookForm </code> 
     *          did not originate from <code> getAddressBookFormForCreate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.AddressBook createAddressBook(org.osid.contact.AddressBookForm addressBookForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> AddressBooks. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating an <code> AddressBook </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not wish to offer update operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> AddressBook </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateAddressBooks();


    /**
     *  Gets the address book form for updating an existing address book. A 
     *  new address book form should be requested for each update transaction. 
     *
     *  @param  addressBookId the <code> Id </code> of the <code> AddressBook 
     *          </code> 
     *  @return the address book form 
     *  @throws org.osid.NotFoundException <code> addressBookId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> addressBookId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.AddressBookForm getAddressBookFormForUpdate(org.osid.id.Id addressBookId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing address book. 
     *
     *  @param  addressBookForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> addressBookForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> addressBookId </code> or 
     *          <code> addressBookForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> addressBookForm </code> 
     *          did not originate from <code> getAddressBookFormForUpdate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateAddressBook(org.osid.contact.AddressBookForm addressBookForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> AddressBooks </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting an <code> AddressBook </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not wish to offer delete operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> AddressBook </code> deletion is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteAddressBooks();


    /**
     *  Deletes an <code> AddressBook. </code> 
     *
     *  @param  addressBookId the <code> Id </code> of the <code> AddressBook 
     *          </code> to remove 
     *  @throws org.osid.NotFoundException <code> addressBookId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> addressBookId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteAddressBook(org.osid.id.Id addressBookId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  AddressBooks. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> AddressBook </code> aliasing is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageAddressBookAliases();


    /**
     *  Adds an <code> Id </code> to an <code> AddressBook </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> AddressBook </code> is determined by the provider. The new 
     *  <code> Id </code> performs as an alias to the primary <code> Id. 
     *  </code> If the alias is a pointer to another addressBook, it is 
     *  reassigned to the given address book <code> Id. </code> 
     *
     *  @param  addressBookId the <code> Id </code> of an <code> AddressBook 
     *          </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> addressBookId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> addressBookId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasAddressBook(org.osid.id.Id addressBookId, 
                                 org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
