//
// org.osid.contact.AddressBookQueryInspector
//
//     The OSID Java specification for org.osid.contact.AddressBookQueryInspector.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.contact;


/**
 *  <p>This is the query inspector for examining address book queries. Each 
 *  method specifies an <code> AND </code> term while multiple invocations of 
 *  the same method produce a nested <code> OR. </code> </p>
 */

public interface AddressBookQueryInspector
    extends org.osid.OsidCatalogQueryInspector {


    /**
     *  Gets the contact <code> Id </code> terms. 
     *
     *  @return the contact <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getContactIdTerms();


    /**
     *  Gets the contact terms. 
     *
     *  @return the contact terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.ContactQueryInspector[] getContactTerms();


    /**
     *  Gets the address <code> Id </code> terms. 
     *
     *  @return the address <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getAddressIdTerms();


    /**
     *  Gets the address terms. 
     *
     *  @return the address terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.AddressQueryInspector[] getAddressTerms();


    /**
     *  Gets the ancestor address book <code> Id </code> terms. 
     *
     *  @return the ancestor address book <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getAncestorAddressBookIdTerms();


    /**
     *  Gets the ancestor address book terms. 
     *
     *  @return the ancestor address book terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.AddressBookQueryInspector[] getAncestorAddressBookTerms();


    /**
     *  Gets the descendant address book <code> Id </code> terms. 
     *
     *  @return the descendant address book <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getDescendantAddressBookIdTerms();


    /**
     *  Gets the descendant address book terms. 
     *
     *  @return the descendant address book terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.AddressBookQueryInspector[] getDescendantAddressBookTerms();


    /**
     *  Gets the query inspector record corresponding to the given <code> 
     *  AddressBook </code> record <code> Type. </code> 
     *
     *  @param  addressBookRecordType an address book record type 
     *  @return the address book query inspector record 
     *  @throws org.osid.NullArgumentException <code> addressBookRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(addressBookRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.records.AddressBookQueryInspectorRecord getAddressBookQueryInspectorRecord(org.osid.type.Type addressBookRecordType)
        throws org.osid.OperationFailedException;
}
