//
// org.osid.contact.AddressBookSearchSession
//
//     The OSID Java specification for org.osid.contact.AddressBookSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.contact;


/**
 *  <p>This session provides methods for searching <code> AddressBook </code> 
 *  objects. The search query is constructed using the <code> 
 *  AddressBookQuery. </code> The address book record <code> Type </code> also 
 *  specifies the record for the address book query. </p> 
 *  
 *  <p> <code> getAddressBooksByQuery() </code> is the basic search method and 
 *  returns a list of <code> AddressBook </code> elements. A more advanced 
 *  search may be performed with <code> getAddressBooksBySearch(). </code> It 
 *  accepts an <code> AddressBookSearch </code> in addition to the query for 
 *  the purpose of specifying additional options affecting the entire search, 
 *  such as ordering. <code> getAddressBooksBySearch() </code> returns an 
 *  <code> AddressBookSearchResults </code> that can be used to access the 
 *  resulting <code> AddressBookList </code> or be used to perform a search 
 *  within the result set through <code> AddressBookSearch. </code> </p> 
 *  
 *  <p> AddressBooks may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> 
 *  AddressBookQuery. </code> The returns in this session may not be cast 
 *  directly to these interfaces. </p>
 */

public interface AddressBookSearchSession
    extends org.osid.contact.AddressBookQuerySession {


    /**
     *  Gets an address book search. 
     *
     *  @return the address book search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.AddressBookSearch getAddressBookSearch();


    /**
     *  Gets an address book search order. The <code> AddressBookSearchOrder 
     *  </code> is supplied to an <code> AddressBookSearch </code> to specify 
     *  the ordering of results. 
     *
     *  @return the address book search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.AddressBookSearchOrder getAddressBookSearchOrder();


    /**
     *  Gets the search results matching the given search. 
     *
     *  @param  addressBookQuery the address book query 
     *  @param  addressBookSearch the address book search 
     *  @return the address book search results 
     *  @throws org.osid.NullArgumentException <code> addressBookQuery </code> 
     *          or <code> address books earch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> addressBookQuery </code> 
     *          or <code> address books earch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.AddressBookSearchResults getAddressBooksBySearch(org.osid.contact.AddressBookQuery addressBookQuery, 
                                                                             org.osid.contact.AddressBookSearch addressBookSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an address book query from an inspector. The inspector is 
     *  available from an <code> AddressBookSearchResults. </code> 
     *
     *  @param  addressBookQueryInspector an address book query inspector 
     *  @return the address book query 
     *  @throws org.osid.NullArgumentException <code> 
     *          addressBookQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> addressBookQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.AddressBookQuery getAddressBookQueryFromInspector(org.osid.contact.AddressBookQueryInspector addressBookQueryInspector);
}
