//
// org.osid.contact.ContactSearchSession
//
//     The OSID Java specification for org.osid.contact.ContactSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.contact;


/**
 *  <p>This session provides methods for searching <code> Contact </code> 
 *  objects. The search query is constructed using the <code> ContactQuery. 
 *  </code> The contact record <code> Type </code> also specifies the record 
 *  for the contact query. </p> 
 *  
 *  <p> <code> getContactsByQuery() </code> is the basic search method and 
 *  returns a list of <code> AddressBook </code> elements. A more advanced 
 *  search may be performed with <code> getContactsBySearch(). </code> It 
 *  accepts a <code> ContactSearch </code> in addition to the query for the 
 *  purpose of specifying additional options affecting the entire search, such 
 *  as ordering. <code> getContactsBySearch() </code> returns a <code> 
 *  ContactSearchResults </code> that can be used to access the resulting 
 *  <code> ContactList </code> or be used to perform a search within the 
 *  result set through <code> ContactSearch. </code> </p> 
 *  
 *  <p> Contacts may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> ContactQuery. </code> 
 *  The returns in this session may not be cast directly to these interfaces. 
 *  </p>
 */

public interface ContactSearchSession
    extends org.osid.contact.ContactQuerySession {


    /**
     *  Gets a contact search. 
     *
     *  @return the contact search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.ContactSearch getContactSearch();


    /**
     *  Gets a contact search order. The <code> ContactSearchOrder </code> is 
     *  supplied to a <code> ContactSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the contact search order interface 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.ContactSearchOrder getContactSearchOrder();


    /**
     *  Gets the search results matching the given search. 
     *
     *  @param  contactQuery the contact query 
     *  @param  contactSearch the contact search 
     *  @return the contact search results 
     *  @throws org.osid.NullArgumentException <code> contactQuery </code> or 
     *          <code> contactSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> contactQuery </code> or 
     *          <code> contactSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.ContactSearchResults getContactsBySearch(org.osid.contact.ContactQuery contactQuery, 
                                                                     org.osid.contact.ContactSearch contactSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a contact query from an inspector. The inspector is available 
     *  from a <code> ContactSearchResults. </code> 
     *
     *  @param  contactQueryInspector a contact query inspector 
     *  @return the contact query 
     *  @throws org.osid.NullArgumentException <code> contactQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> contactQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.ContactQuery getContactQueryFromInspector(org.osid.contact.ContactQueryInspector contactQueryInspector);
}
