//
// org.osid.contact.ContactSession
//
//     The OSID Java specification for org.osid.contact.ContactSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.contact;


/**
 *  <p>This session defines methods for retrieving contacts. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> isolated address book view: All contact methods in this session 
 *      operate, retrieve and pertain to contacts defined explicitly in the 
 *      current address book. Using an isolated view is useful for managing 
 *      contacts with the <code> ContactAdminSession. </code> </li> 
 *      <li> federated address book view: All contact lookup methods in this 
 *      session operate, retrieve and pertain to all contacts defined in this 
 *      address book and any other address books implicitly available in this 
 *      address book through address book inheritence. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedAddressBookView() </code> and <code> 
 *  useIsolatedAddressBookView() </code> behave as a radio group and one 
 *  should be selected before invoking any lookup methods. This session is 
 *  always in comparative mode. </p>
 */

public interface ContactSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> AddressBook </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> AddressBook Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAddressBookId();


    /**
     *  Gets the <code> AddressBook </code> associated with this session. 
     *
     *  @return the address book 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.AddressBook getAddressBook()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can lookup contacts. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer these operations. 
     *
     *  @return <code> false </code> if contact lookup methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canGetContacts();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include contacts in address books which are children of this address 
     *  book in the address book hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedAddressBookView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this address book only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedAddressBookView();


    /**
     *  Gets a list of all current available contacts corresponding to a 
     *  reference <code> Id </code> sorted from highlest to lowest priority. 
     *
     *  @param  referenceId the <code> Id </code> of the reference 
     *  @return the returned <code> ContactList </code> 
     *  @throws org.osid.NullArgumentException <code> referenceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.ContactList getAvailableContacts(org.osid.id.Id referenceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all current available contacts for a reference and by contact 
     *  genus <code> Type </code> sorted from highest to lowest priority. 
     *
     *  @param  referenceId the <code> Id </code> of the reference 
     *  @param  contactGenusType a contact genus <code> Type </code> 
     *  @return a list of contacts 
     *  @throws org.osid.NullArgumentException <code> referenceId </code> or 
     *          <code> contactGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.ContactList getAvailableContactsByGenusType(org.osid.id.Id referenceId, 
                                                                        org.osid.type.Type contactGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
