//
// org.osid.contact.rules.ContactEnablerNotificationSession
//
//     The OSID Java specification for org.osid.contact.rules.ContactEnablerNotificationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.contact.rules;


/**
 *  <p>This session defines methods to receive notifications on adds/changes 
 *  to <code> ContactEnabler </code> objects in this <code> AddressBook. 
 *  </code> This also includes existing <code> ContactEnablers </code> that 
 *  may appear or disappear due to changes in the <code> AddressBook </code> 
 *  hierarchy, This session is intended for consumers needing to synchronize 
 *  their state with this service without the use of polling. Notifications 
 *  are cancelled when this session is closed. </p> 
 *  
 *  <p> The two views defined in this session correspond to the views in the 
 *  <code> ContactEnablerLookupSession. </code> </p>
 */

public interface ContactEnablerNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> AddressBook </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> AddressBook Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAddressBookId();


    /**
     *  Gets the <code> AddressBook </code> associated with this session. 
     *
     *  @return the address book 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.AddressBook getAddressBook()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can register for <code> ContactEnabler </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForContactEnablerNotifications();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include enablers in address books which are children of this address 
     *  book in the address book hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedAddressBookView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts notifications to this address book only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedAddressBookView();


    /**
     *  Reliable notifications are desired. In reliable mode, notifications 
     *  are to be acknowledged using <code> 
     *  acknowledgeContactEnablerNotification() </code> . 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void reliableContactEnablerNotifications();


    /**
     *  Unreliable notifications are desired. In unreliable mode, 
     *  notifications do not need to be acknowledged. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void unreliableContactEnablerNotifications();


    /**
     *  Acknowledge a contact enabler notification. 
     *
     *  @param  notificationId the <code> Id </code> of the notification 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void acknowledgeContactEnablerNotification(org.osid.id.Id notificationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new contact enablers. <code> 
     *  ContactEnablerReceiver.newContactEnablers() </code> is invoked when a 
     *  new <code> ContactEnabler </code> appears in this address book. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewContactEnablers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated contact enablers. <code> 
     *  ContactEnablerReceiver.changedContactEnablers() </code> is invoked 
     *  when a contact enabler in this address book is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedContactEnablers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated contact enabler. <code> 
     *  ProvisionableReceiver.changedContactEnablers() </code> is invoked when 
     *  the specified contact enabler in this address book is changed. 
     *
     *  @param  contactEnablerId the <code> Id </code> of the <code> 
     *          ContactEnabler </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> contactEnablerId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedContactEnabler(org.osid.id.Id contactEnablerId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted contact enablers. <code> 
     *  ContactEnablerReceiver.deletedContactEnablers() </code> is invoked 
     *  when a contact enabler is deleted or removed from this address book. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedContactEnablers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted contact enabler. <code> 
     *  ContactEnablerReceiver.deletedContactEnablers() </code> is invoked 
     *  when the specified contact enabler is deleted or removed from this 
     *  address book. 
     *
     *  @param  contactEnablerId the <code> Id </code> of the <code> 
     *          ContactEnabler </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> contactEnablerId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedContactEnabler(org.osid.id.Id contactEnablerId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
