//
// org.osid.contact.rules.ContactEnablerRuleApplicationSession
//
//     The OSID Java specification for org.osid.contact.rules.ContactEnablerRuleApplicationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.contact.rules;


/**
 *  <p>This session provides methods to apply <code> ContactEnablers </code> 
 *  to <code> Contacts. </code> A <code> Contact </code> with multiple <code> 
 *  ContactEnablers </code> means any positive rule evaluation across the 
 *  enablers result in an effective <code> Contact. </code> </p>
 */

public interface ContactEnablerRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> AddressBook </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> AddressBook Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAddressBookId();


    /**
     *  Gets the <code> AddressBook </code> associated with this session. 
     *
     *  @return the address book 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.AddressBook getAddressBook()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter contact enabler/contact mappings. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignContactEnablers();


    /**
     *  Adds an existing <code> ContactEnabler </code> to a <code> Contact. 
     *  </code> 
     *
     *  @param  contactEnablerId the <code> Id </code> of the <code> 
     *          ContactEnabler </code> 
     *  @param  contactId the <code> Id </code> of the <code> Contact </code> 
     *  @throws org.osid.AlreadyExistsException <code> contactEnablerId 
     *          </code> is already applied to <code> contactId </code> 
     *  @throws org.osid.NotFoundException <code> contactEnablerId </code> or 
     *          <code> contactId </code> not found 
     *  @throws org.osid.NullArgumentException <code> contactEnablerId </code> 
     *          or <code> contactId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignContactEnablerToContact(org.osid.id.Id contactEnablerId, 
                                              org.osid.id.Id contactId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> ContactEnabler </code> from a <code> Contact. </code> 
     *
     *  @param  contactEnablerId the <code> Id </code> of the <code> 
     *          ContactEnabler </code> 
     *  @param  contactId the <code> Id </code> of the <code> Contact </code> 
     *  @throws org.osid.NotFoundException <code> contactEnablerId </code> or 
     *          <code> contactId </code> not found or <code> contactEnablerId 
     *          </code> is not applied to <code> contactId </code> 
     *  @throws org.osid.NullArgumentException <code> contactEnablerId </code> 
     *          or <code> contactId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignContactEnablerFromContact(org.osid.id.Id contactEnablerId, 
                                                  org.osid.id.Id contactId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> ContactEnablers. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known sequencing operations will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> ContactEnabler </code> ordering 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceContactEnablers();


    /**
     *  Reorders contact enablers for a contact by moving the specified 
     *  contact enabler in front of a reference contact enabler. 
     *
     *  @param  contactEnablerId the <code> Id </code> of a <code> 
     *          ContactEnabler </code> 
     *  @param  contactId the <code> Id </code> of a <code> Contact </code> 
     *  @param  referenceId the reference contact enabler <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> contactEnabelrId, contactId, 
     *          </code> or <code> referenceId </code> not found or, <code> 
     *          contactEnablerId </code> or <code> referenceId </code> not 
     *          related to <code> contactId </code> 
     *  @throws org.osid.NullArgumentException <code> contactEnablerId, 
     *          contactId, </code> or <code> referenceId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveContactEnablerAhead(org.osid.id.Id contactEnablerId, 
                                        org.osid.id.Id contactId, 
                                        org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders contact enablers for a contact by moving the specified 
     *  contact enabler behind a reference contact enabler. 
     *
     *  @param  contactEnablerId the <code> Id </code> of a <code> 
     *          ContactEnabler </code> 
     *  @param  contactId the <code> Id </code> of a <code> Contact </code> 
     *  @param  referenceId the reference contact enabler <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> contactEnabelrId, contactId, 
     *          </code> or <code> referenceId </code> not found or, <code> 
     *          contactEnablerId </code> or <code> referenceId </code> not 
     *          related to <code> contactId </code> 
     *  @throws org.osid.NullArgumentException <code> contactEnablerId, 
     *          contactId, </code> or <code> referenceId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveContactEnablerBehind(org.osid.id.Id contactEnablerId, 
                                         org.osid.id.Id contactId, 
                                         org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of contact enablers for a contact. 
     *
     *  @param  contactEnablerId the <code> Ids </code> for a set of <code> 
     *          ContactEnablers </code> 
     *  @param  contactId the <code> Id </code> of a <code> Contact </code> 
     *  @throws org.osid.NotFoundException <code> contactId </code> not found 
     *          or, a <code> contactEnablerId </code> not related to <code> 
     *          contactId </code> 
     *  @throws org.osid.NullArgumentException <code> contactEnablerIds 
     *          </code> or <code> contactId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderContactEnablers(org.osid.id.Id[] contactEnablerId, 
                                     org.osid.id.Id contactId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
