//
// org.osid.contact.rules.ContactEnablerRuleLookupSession
//
//     The OSID Java specification for org.osid.contact.rules.ContactEnablerRuleLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.contact.rules;


/**
 *  <p>This session provides methods to retrieve <code> ContactEnabler </code> 
 *  to <code> Contact </code> mappings. A <code> Contact </code> with multiple 
 *  <code> ContactEnablers </code> means any positive rule evaluation across 
 *  the enablers result in an enabled <code> Contact. </code> </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated address book view: All methods in this session operate, 
 *      retrieve and pertain contact enablers defined explicitly in the 
 *      current address book </li> 
 *      <li> federated address book view: All methods in this session operate, 
 *      retrieve and pertain to all contact enablers defined in this address 
 *      book and any other contact enablers implicitly available in this 
 *      address book through address book inheritence. </li> 
 *  </ul>
 *  
 */

public interface ContactEnablerRuleLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> AddressBook </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> AddressBook Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAddressBookId();


    /**
     *  Gets the <code> AddressBook </code> associated with this session. 
     *
     *  @return the address book 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.AddressBook getAddressBook()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform lookups of contact enabler/contact 
     *  mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known lookup 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if looking up mappings is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupContactEnablerRules();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeContactEnablerRuleView();


    /**
     *  A complete view of the <code> ContactEnabler </code> and <code> 
     *  Contact </code> returns is desired. Methods will return what is 
     *  requested or result in an error. This view is used when greater 
     *  precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryContactEnablerRuleView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include contact enablers in address books which are children of this 
     *  address book in the address book hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedAddressBookView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this address book only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedAddressBookView();


    /**
     *  Gets the <code> ContactEnabler Id </code> associated with a <code> 
     *  Contact. </code> 
     *
     *  @param   contactId <code> Id </code> of the <code> Contact </code> 
     *  @return the contact enabler <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> contactId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> contactId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getContactEnablerIdsForContact(org.osid.id.Id  contactId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> ContactEnabler </code> associated with a <code> 
     *  Contact. </code> 
     *
     *  @param  contactId <code> Id </code> of the <code> Contact </code> 
     *  @return the contact enablers 
     *  @throws org.osid.NotFoundException <code> contactId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> contactId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.rules.ContactEnablerList getContactEnablersForContact(org.osid.id.Id contactId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> COntact </code> <code> Ids </code> mapped to a <code> 
     *  ContactEnabler. </code> 
     *
     *  @param  contactEnablerId <code> Id </code> of a <code> ContactEnabler 
     *          </code> 
     *  @return list of contact <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> contactEnablerId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> contactEnablerId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getContactIdsForContactEnabler(org.osid.id.Id contactEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Contacts </code> mapped to a <code> ContactEnabler. 
     *  </code> 
     *
     *  @param  contactEnablerId <code> Id </code> of a <code> ContactEnabler 
     *          </code> 
     *  @return list of contacts 
     *  @throws org.osid.NotFoundException <code> contactEnablerId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> contactEnablerId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.ContactList getContactsForContactEnabler(org.osid.id.Id contactEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
