//
// org.osid.control.Action
//
//     The OSID Java specification for org.osid.control.Action.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control;


/**
 *  <p>An <code> Action </code> executes a <code> Scene, Setting, </code> 
 *  another <code> ActionGroup, </code> or other <code> Rule </code> . An 
 *  <code> Action </code> is also an <code> OsidRule </code> that may or may 
 *  not be active. </p>
 */

public interface Action
    extends org.osid.OsidRule,
            org.osid.Subjugateable {


    /**
     *  Gets the action group <code> Id </code> for this action. 
     *
     *  @return the action group <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getActionGroupId();


    /**
     *  Gets the action group for this action. 
     *
     *  @return the action group 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.ActionGroup getActionGroup()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the delay before proceeding with execution. 
     *
     *  @return the delay 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Duration getDelay();


    /**
     *  Tests if this action blocks further actions until complete. 
     *
     *  @return <code> true </code> if blocking, <code> false </code> if 
     *          subsequent actions can begin before this action completes 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isBlocking();


    /**
     *  Tests if this rule executes a scene. If <code> executesActionGroup() 
     *  </code> is <code> true, </code> <code> hasRule(), executesScene(), 
     *  executesSetting(), </code> and <code> executesMatchingSetting() 
     *  </code> must be <code> false. </code> 
     *
     *  @return <code> true </code> if this is a scene execution, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean executesActionGroup();


    /**
     *  Gets the action group <code> Id </code> to execute. 
     *
     *  @return the action group <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> executesActionGroup() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getNextActionGroupId();


    /**
     *  Gets the action group to execute, 
     *
     *  @return the action group 
     *  @throws org.osid.IllegalStateException <code> executesActionGroup() 
     *          </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.ActionGroup getNextActionGroup()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this rule executes a scene. If <code> executesScene() </code> 
     *  is <code> true, </code> <code> hasRule(), executesActionGroup(), 
     *  executesSetting(), </code> and <code> executesMatchingSetting() 
     *  </code> must be <code> false. </code> 
     *
     *  @return <code> true </code> if this is a scene execution, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean executesScene();


    /**
     *  Gets the scene <code> Id. </code> 
     *
     *  @return the scene <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> executesScene() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getSceneId();


    /**
     *  Gets the scene. 
     *
     *  @return the scene 
     *  @throws org.osid.IllegalStateException <code> executesScene() </code> 
     *          is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.Scene getScene()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this rule executes a setting. If <code> executesSetting() 
     *  </code> is <code> true, </code> <code> hasRule(), 
     *  executesActionGroup(), executesScene(), </code> and <code> 
     *  executesMatchingSetting() </code> must be <code> false. </code> 
     *
     *  @return <code> true </code> if this is a setting execution, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean executesSetting();


    /**
     *  Gets the setting <code> Id. </code> 
     *
     *  @return the setting <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> executesSetting() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getSettingId();


    /**
     *  Gets the setting. 
     *
     *  @return the setting 
     *  @throws org.osid.IllegalStateException <code> executesSetting() 
     *          </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.Setting getSetting()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this rule executes a matching setting. If <code> 
     *  executesMatchingSetting() </code> is <code> true, </code> <code> 
     *  hasRule(), </code> <code> executesScene(), executesActionGroup(), 
     *  </code> and <code> executesSetting() </code> must be <code> false. 
     *  </code> 
     *
     *  @return <code> true </code> if this is a setting execution, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean executesMatchingSetting();


    /**
     *  Gets the matching controller <code> Id. </code> 
     *
     *  @return the controller <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> 
     *          executesMatchingSetting() </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getMatchingControllerId();


    /**
     *  Gets the matching controller. 
     *
     *  @return the controller 
     *  @throws org.osid.IllegalStateException <code> 
     *          executesMatchingSetting() </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.Controller getMatchingController()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the factor by which the matching amount differs. A factor of 1 
     *  matches the amount of the matching controller. 
     *
     *  @return the factor 
     *  @throws org.osid.IllegalStateException <code> 
     *          executesMatchingSetting() </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getMatchingAmountFactor();


    /**
     *  Gets the factor by which the matching transition rate differs. A 
     *  factor of 1 matches the ramp rate of the matching controller. 
     *
     *  @return the factor 
     *  @throws org.osid.IllegalStateException <code> 
     *          executesMatchingSetting() </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getMatchingRateFactor();


    /**
     *  Gets the action record corresponding to the given <code> Action 
     *  </code> record <code> Type. </code> This method is used to retrieve an 
     *  object implementing the requested record. The <code> actionRecordType 
     *  </code> may be the <code> Type </code> returned in <code> 
     *  getRecordTypes() </code> or any of its parents in a <code> Type 
     *  </code> hierarchy where <code> hasRecordType(actionRecordType) </code> 
     *  is <code> true </code> . 
     *
     *  @param  actionRecordType the type of action record to retrieve 
     *  @return the action record 
     *  @throws org.osid.NullArgumentException <code> actionRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(actionRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.records.ActionRecord getActionRecord(org.osid.type.Type actionRecordType)
        throws org.osid.OperationFailedException;
}
