//
// org.osid.control.ActionForm
//
//     The OSID Java specification for org.osid.control.ActionForm.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control;


/**
 *  <p>This is the form for creating and updating actions. <code> </code> Like 
 *  all <code> OsidForm </code> objects, various data elements may be set here 
 *  for use in the create and update methods in the <code> 
 *  ActionGroupAdminSession. </code> For each data element that may be set, 
 *  metadata may be examined to provide display hints or data constraints. 
 *  </p>
 */

public interface ActionForm
    extends org.osid.OsidRuleForm,
            org.osid.OsidSubjugateableForm {


    /**
     *  Gets the metadata for the delay. 
     *
     *  @return metadata for the delay 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getDelayMetadata();


    /**
     *  Sets the delay. 
     *
     *  @param  delay the new delay 
     *  @throws org.osid.InvalidArgumentException <code> delay </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> delay </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setDelay(org.osid.calendaring.Duration delay);


    /**
     *  Removes the delay. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDelay();


    /**
     *  Gets the metadata for the blocking flag. 
     *
     *  @return metadata for the blocking flag 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getBlockingMetadata();


    /**
     *  Sets the blocking flag. 
     *
     *  @param  blocking <code> true </code> if blocking, <code> false </code> 
     *          if unblocking 
     *  @throws org.osid.InvalidArgumentException <code> blocking </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setBlocking(boolean blocking);


    /**
     *  Removes the blocking flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBlocking();


    /**
     *  Gets the metadata for the action group to be executed. 
     *
     *  @return metadata for the action group 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getNextActionGroupMetadata();


    /**
     *  Sets the next action group. 
     *
     *  @param  actionGroupId the new action group 
     *  @throws org.osid.InvalidArgumentException <code> actionGroupId </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> actionGroupId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setNextActionGroup(org.osid.id.Id actionGroupId);


    /**
     *  Removes the next action group. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearNextActionGroup();


    /**
     *  Gets the metadata for the scene. 
     *
     *  @return metadata for the scene 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getSceneMetadata();


    /**
     *  Sets the scene. 
     *
     *  @param  sceneId the new scene 
     *  @throws org.osid.InvalidArgumentException <code> sceneId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> sceneId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setScene(org.osid.id.Id sceneId);


    /**
     *  Removes the scene. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearScene();


    /**
     *  Gets the metadata for the setting. 
     *
     *  @return metadata for the setting 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getSettingMetadata();


    /**
     *  Sets the setting. 
     *
     *  @param  settingId the new setting 
     *  @throws org.osid.InvalidArgumentException <code> settingId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> settingId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setSetting(org.osid.id.Id settingId);


    /**
     *  Removes the setting. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSetting();


    /**
     *  Gets the <code> ActionFormRecord </code> corresponding to the given 
     *  action record <code> Type. </code> 
     *
     *  @param  actionRecordType an action record type 
     *  @return the action form record 
     *  @throws org.osid.NullArgumentException <code> actionRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(actionRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.records.ActionFormRecord getActionFormRecord(org.osid.type.Type actionRecordType)
        throws org.osid.OperationFailedException;
}
