//
// org.osid.control.ActionGroupSearchSession
//
//     The OSID Java specification for org.osid.control.ActionGroupSearchSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control;


/**
 *  <p>This session provides methods for searching among <code> ActionGroup 
 *  </code> objects. The search query is constructed using the <code> 
 *  ActionGroupQuery. </code> </p> 
 *  
 *  <p> <code> getActionGroupsByQuery() </code> is the basic search method and 
 *  returns a list of <code> ActionGroups. </code> A more advanced search may 
 *  be performed with <code> getActionGroupsBySearch(). </code> It accepts an 
 *  <code> ActionGroupSearch </code> in addition to the query for the purpose 
 *  of specifying additional options affecting the entire search, such as 
 *  ordering. <code> getActionGroupsBySearch() </code> returns an <code> 
 *  ActionGroupSearchResults </code> that can be used to access the resulting 
 *  <code> ActionGroupList </code> or be used to perform a search within the 
 *  result set through <code> ActionGroupSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated system view: searches include action groups in systems 
 *      of which this system is an ancestor in the system hierarchy </li> 
 *      <li> isolated system view: searches are restricted to action groups in 
 *      this system </li> 
 *  </ul>
 *  
 *  
 *  <p> ActionGroups may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> 
 *  ActionGroupQuery. </code> </p>
 */

public interface ActionGroupSearchSession
    extends org.osid.control.ActionGroupQuerySession {


    /**
     *  Gets an action group search. 
     *
     *  @return the action group search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.ActionGroupSearch getActionGroupSearch();


    /**
     *  Gets an action group search order. The <code> ActionGroupSearchOrder 
     *  </code> is supplied to an <code> ActionGroupSearch </code> to specify 
     *  the ordering of results. 
     *
     *  @return the action group search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.ActionGroupSearchOrder getActionGroupSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  actuionGroupQuery the action group query 
     *  @param  actionGroupSearch the action group search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> actuionGroupQuery 
     *          </code> or <code> actionGroupSearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> actuionGroupQuery </code> 
     *          or <code> actionGroupSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.ActionGroupSearchResults getActionGroupsBySearch(org.osid.control.ActionGroupQuery actuionGroupQuery, 
                                                                             org.osid.control.ActionGroupSearch actionGroupSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an action group query from an inspector. The inspector is 
     *  available from an <code> ActionGroupSearchResults. </code> 
     *
     *  @param  actuionGroupQueryInspector an action group query inspector 
     *  @return the action group query 
     *  @throws org.osid.NullArgumentException <code> 
     *          actuionGroupQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          actuionGroupQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.ActionGroupQuery getActionGroupQueryFromInspector(org.osid.control.ActionGroupQueryInspector actuionGroupQueryInspector);
}
