//
// org.osid.control.ActionQueryInspector
//
//     The OSID Java specification for org.osid.control.ActionQueryInspector.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control;


/**
 *  <p>This is the query inspector for examining action queries. </p>
 */

public interface ActionQueryInspector
    extends org.osid.OsidRuleQueryInspector,
            org.osid.OsidSubjugateableQueryInspector {


    /**
     *  Gets the action group <code> Id </code> query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getActionGroupIdTerms();


    /**
     *  Gets the action group query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.ActionGroupQueryInspector[] getActionGroupTerms();


    /**
     *  Gets the delay query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DurationRangeTerm[] getDelayTerms();


    /**
     *  Gets the blocking query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.BooleanTerm[] getBlockingTerms();


    /**
     *  Gets the action group <code> Id </code> query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getNextActionGroupIdTerms();


    /**
     *  Gets the action group query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.ActionGroupQueryInspector[] getNextActionGroupTerms();


    /**
     *  Gets the scene <code> Id </code> query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getSceneIdTerms();


    /**
     *  Gets the scene query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.SceneQueryInspector[] getSceneTerms();


    /**
     *  Gets the setting <code> Id </code> query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getSettingIdTerms();


    /**
     *  Gets the setting query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.SettingQueryInspector[] getSettingTerms();


    /**
     *  Gets the action query inspector record corresponding to the given 
     *  <code> Action </code> record <code> Type. </code> 
     *
     *  @param  actionRecordType an action record type 
     *  @return the action query inspector record 
     *  @throws org.osid.NullArgumentException <code> actionRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(actionRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.records.ActionQueryInspectorRecord getActionQueryInspectorRecord(org.osid.type.Type actionRecordType)
        throws org.osid.OperationFailedException;
}
