//
// org.osid.control.ControlProfile
//
//     The OSID Java specification for org.osid.control.ControlProfile.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control;


/**
 *  <p>The control profile describes the interoperability among control 
 *  services. </p>
 */

public interface ControlProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any trigger federation is exposed. Federation is exposed when 
     *  a specific trigger may be identified, selected and used to create a 
     *  lookup or admin session. Federation is not exposed when a set of 
     *  triggers appears as a single trigger. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if looking up devices is supported. 
     *
     *  @return <code> true </code> if device lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDeviceLookup();


    /**
     *  Tests if querying devices is supported. 
     *
     *  @return <code> true </code> if device query is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDeviceQuery();


    /**
     *  Tests if searching devices is supported. 
     *
     *  @return <code> true </code> if device search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDeviceSearch();


    /**
     *  Tests if a device administrative service is supported. 
     *
     *  @return <code> true </code> if device administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDeviceAdmin();


    /**
     *  Tests if a device <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if device notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDeviceNotification();


    /**
     *  Tests if a device system lookup service is supported. 
     *
     *  @return <code> true </code> if a device system lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDeviceSystem();


    /**
     *  Tests if a device system assignment service is supported. 
     *
     *  @return <code> true </code> if a device to system assignment service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDeviceSystemAssignment();


    /**
     *  Tests if a device smart system service is supported. 
     *
     *  @return <code> true </code> if an v smart system service is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDeviceSmartSystem();


    /**
     *  Tests if returning devices is supported. 
     *
     *  @return <code> true </code> if returning devices is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDeviceReturn();


    /**
     *  Tests if looking up controllers is supported. 
     *
     *  @return <code> true </code> if controller lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsControllerLookup();


    /**
     *  Tests if querying controllers is supported. 
     *
     *  @return <code> true </code> if controller query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsControllerQuery();


    /**
     *  Tests if searching controllers is supported. 
     *
     *  @return <code> true </code> if controller search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsControllerSearch();


    /**
     *  Tests if controller administrative service is supported. 
     *
     *  @return <code> true </code> if controller administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsControllerAdmin();


    /**
     *  Tests if a controller notification service is supported. 
     *
     *  @return <code> true </code> if controller notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsControllerNotification();


    /**
     *  Tests if a controller trigger lookup service is supported. 
     *
     *  @return <code> true </code> if a controller trigger lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsControllerTrigger();


    /**
     *  Tests if a controller trigger service is supported. 
     *
     *  @return <code> true </code> if controller to trigger assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsControllerTriggerAssignment();


    /**
     *  Tests if a controller smart trigger lookup service is supported. 
     *
     *  @return <code> true </code> if a controller smart trigger service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsControllerSmartTrigger();


    /**
     *  Tests if looking up inputs is supported. 
     *
     *  @return <code> true </code> if input lookup is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInputLookup();


    /**
     *  Tests if querying inputs is supported. 
     *
     *  @return <code> true </code> if input query is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInputQuery();


    /**
     *  Tests if searching inputs is supported. 
     *
     *  @return <code> true </code> if input search is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInputSearch();


    /**
     *  Tests if an input administrative service is supported. 
     *
     *  @return <code> true </code> if input administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInputAdmin();


    /**
     *  Tests if an input <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if input notification is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInputNotification();


    /**
     *  Tests if an input system lookup service is supported. 
     *
     *  @return <code> true </code> if an input system lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInputSystem();


    /**
     *  Tests if an input system assignment service is supported. 
     *
     *  @return <code> true </code> if an input to system assignment service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInputSystemAssignment();


    /**
     *  Tests if an input smart system service is supported. 
     *
     *  @return <code> true </code> if a smart system service is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInputSmartSystem();


    /**
     *  Tests if looking up settings is supported. 
     *
     *  @return <code> true </code> if setting lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSettingLookup();


    /**
     *  Tests if querying settings is supported. 
     *
     *  @return <code> true </code> if setting query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSettingQuery();


    /**
     *  Tests if searching settings is supported. 
     *
     *  @return <code> true </code> if setting search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSettingSearch();


    /**
     *  Tests if setting <code> </code> administrative service is supported. 
     *
     *  @return <code> true </code> if setting administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSettingAdmin();


    /**
     *  Tests if a setting <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if setting notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSettingNotification();


    /**
     *  Tests if a setting system lookup service is supported. 
     *
     *  @return <code> true </code> if a setting system lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSettingSystem();


    /**
     *  Tests if a setting system assignment service is supported. 
     *
     *  @return <code> true </code> if a setting to system assignment service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSettingSystemAssignment();


    /**
     *  Tests if a setting smart system service is supported. 
     *
     *  @return <code> true </code> if a setting smart system service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSettingSmartSystem();


    /**
     *  Tests if looking up scenes is supported. 
     *
     *  @return <code> true </code> if scene lookup is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSceneLookup();


    /**
     *  Tests if querying scenes is supported. 
     *
     *  @return <code> true </code> if scene query is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSceneQuery();


    /**
     *  Tests if searching scenes is supported. 
     *
     *  @return <code> true </code> if scene search is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSceneSearch();


    /**
     *  Tests if scene <code> </code> administrative service is supported. 
     *
     *  @return <code> true </code> if scene administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSceneAdmin();


    /**
     *  Tests if a scene <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if scene notification is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSceneNotification();


    /**
     *  Tests if a scene system lookup service is supported. 
     *
     *  @return <code> true </code> if a scene system lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSceneSystem();


    /**
     *  Tests if a scene system assignment service is supported. 
     *
     *  @return <code> true </code> if a scene to system assignment service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSceneSystemAssignment();


    /**
     *  Tests if a scene smart system service is supported. 
     *
     *  @return <code> true </code> if a scene smart system service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSceneSmartSystem();


    /**
     *  Tests if looking up triggers is supported. 
     *
     *  @return <code> true </code> if trigger lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTriggerLookup();


    /**
     *  Tests if querying triggers is supported. 
     *
     *  @return <code> true </code> if a trigger query service is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTriggerQuery();


    /**
     *  Tests if searching triggers is supported. 
     *
     *  @return <code> true </code> if trigger search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTriggerSearch();


    /**
     *  Tests if trigger administrative service is supported. 
     *
     *  @return <code> true </code> if trigger administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTriggerAdmin();


    /**
     *  Tests if a trigger <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if trigger notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTriggerNotification();


    /**
     *  Tests if a trigger system lookup service is supported. 
     *
     *  @return <code> true </code> if a trigger system lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTriggerSystem();


    /**
     *  Tests if a trigger system service is supported. 
     *
     *  @return <code> true </code> if trigger to system assignment service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTriggerSystemAssignment();


    /**
     *  Tests if a trigger smart system lookup service is supported. 
     *
     *  @return <code> true </code> if a trigger smart system service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTriggerSmartSystem();


    /**
     *  Tests if looking up action groups is supported. 
     *
     *  @return <code> true </code> if action group lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActionGroupLookup();


    /**
     *  Tests if querying action groups is supported. 
     *
     *  @return <code> true </code> if an action group query service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActionGroupQuery();


    /**
     *  Tests if searching action groups is supported. 
     *
     *  @return <code> true </code> if action group search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActionGroupSearch();


    /**
     *  Tests if action group administrative service is supported. 
     *
     *  @return <code> true </code> if action group administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActionGroupAdmin();


    /**
     *  Tests if an action group <code> </code> notification service is 
     *  supported. 
     *
     *  @return <code> true </code> if action group notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActionGroupNotification();


    /**
     *  Tests if an action group system lookup service is supported. 
     *
     *  @return <code> true </code> if an action group system lookup service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActionGroupSystem();


    /**
     *  Tests if an action group system service is supported. 
     *
     *  @return <code> true </code> if action group to system assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActionGroupSystemAssignment();


    /**
     *  Tests if an action group smart system lookup service is supported. 
     *
     *  @return <code> true </code> if an action group smart system service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActionGroupSmartSystem();


    /**
     *  Tests if looking up systems is supported. 
     *
     *  @return <code> true </code> if system lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSystemLookup();


    /**
     *  Tests if querying systems is supported. 
     *
     *  @return <code> true </code> if a system query service is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSystemQuery();


    /**
     *  Tests if searching systems is supported. 
     *
     *  @return <code> true </code> if system search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSystemSearch();


    /**
     *  Tests if system administrative service is supported. 
     *
     *  @return <code> true </code> if system administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSystemAdmin();


    /**
     *  Tests if a system <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if system notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSystemNotification();


    /**
     *  Tests for the availability of a system hierarchy traversal service. 
     *
     *  @return <code> true </code> if system hierarchy traversal is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsSystemHierarchy();


    /**
     *  Tests for the availability of a system hierarchy design service. 
     *
     *  @return <code> true </code> if system hierarchy design is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSystemHierarchyDesign();


    /**
     *  Tests for the availability of a control batch service. 
     *
     *  @return <code> true </code> if control batch service is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsControlBatch();


    /**
     *  Tests for the availability of a control rules service. 
     *
     *  @return <code> true </code> if control rules service is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsControlRules();


    /**
     *  Gets the supported <code> Device </code> record types. 
     *
     *  @return a list containing the supported <code> Device </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getDeviceRecordTypes();


    /**
     *  Tests if the given <code> Device </code> record type is supported. 
     *
     *  @param  deviceRecordType a <code> Type </code> indicating a <code> 
     *          Device </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> deviceRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDeviceRecordType(org.osid.type.Type deviceRecordType);


    /**
     *  Gets the supported <code> Device </code> search types. 
     *
     *  @return a list containing the supported <code> Device </code> search 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getDeviceSearchRecordTypes();


    /**
     *  Tests if the given <code> Device </code> search type is supported. 
     *
     *  @param  deviceSearchRecordType a <code> Type </code> indicating a 
     *          <code> Device </code> search type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> effiortSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDeviceSearchRecordType(org.osid.type.Type deviceSearchRecordType);


    /**
     *  Gets the supported <code> DeviceReturn </code> record types. 
     *
     *  @return a list containing the supported <code> DeviceReturn </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getDeviceReturnRecordTypes();


    /**
     *  Tests if the given <code> DeviceReturn </code> record type is 
     *  supported. 
     *
     *  @param  deviceReturnRecordType a <code> Type </code> indicating a 
     *          <code> DeviceReturn </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> deviceReturnRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDeviceReturnRecordType(org.osid.type.Type deviceReturnRecordType);


    /**
     *  Gets the supported <code> Controller </code> record types. 
     *
     *  @return a list containing the supported <code> Controller </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getControllerRecordTypes();


    /**
     *  Tests if the given <code> Controller </code> record type is supported. 
     *
     *  @param  controllerRecordType a <code> Type </code> indicating a <code> 
     *          Controller </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> controllerRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsControllerRecordType(org.osid.type.Type controllerRecordType);


    /**
     *  Gets the supported <code> Controller </code> search record types. 
     *
     *  @return a list containing the supported <code> Controller </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getControllerSearchRecordTypes();


    /**
     *  Tests if the given <code> Controller </code> search record type is 
     *  supported. 
     *
     *  @param  controllerSearchRecordType a <code> Type </code> indicating a 
     *          <code> Controller </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          controllerSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsControllerSearchRecordType(org.osid.type.Type controllerSearchRecordType);


    /**
     *  Gets the supported <code> Input </code> record types. 
     *
     *  @return a list containing the supported <code> Input </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getInputRecordTypes();


    /**
     *  Tests if the given <code> Input </code> record type is supported. 
     *
     *  @param  inputRecordType a <code> Type </code> indicating an <code> 
     *          Input </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> inputRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInputRecordType(org.osid.type.Type inputRecordType);


    /**
     *  Gets the supported <code> Input </code> search types. 
     *
     *  @return a list containing the supported <code> Input </code> search 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getInputSearchRecordTypes();


    /**
     *  Tests if the given <code> Input </code> search type is supported. 
     *
     *  @param  inputSearchRecordType a <code> Type </code> indicating an 
     *          <code> Input </code> search type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> inputSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInputSearchRecordType(org.osid.type.Type inputSearchRecordType);


    /**
     *  Gets the supported <code> Setting </code> record types. 
     *
     *  @return a list containing the supported <code> Setting </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSettingRecordTypes();


    /**
     *  Tests if the given <code> Setting </code> record type is supported. 
     *
     *  @param  settingRecordType a <code> Type </code> indicating a <code> 
     *          Setting </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> settingRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSettingRecordType(org.osid.type.Type settingRecordType);


    /**
     *  Gets the supported <code> Setting </code> search types. 
     *
     *  @return a list containing the supported <code> Setting </code> search 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSettingSearchRecordTypes();


    /**
     *  Tests if the given <code> Setting </code> search type is supported. 
     *
     *  @param  settingSearchRecordType a <code> Type </code> indicating a 
     *          <code> Setting </code> search type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> settingSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSettingSearchRecordType(org.osid.type.Type settingSearchRecordType);


    /**
     *  Gets the supported <code> Scene </code> record types. 
     *
     *  @return a list containing the supported <code> Scene </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSceneRecordTypes();


    /**
     *  Tests if the given <code> Scene </code> record type is supported. 
     *
     *  @param  sceneRecordType a <code> Type </code> indicating a <code> 
     *          Scene </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> sceneRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSceneRecordType(org.osid.type.Type sceneRecordType);


    /**
     *  Gets the supported <code> Scene </code> search types. 
     *
     *  @return a list containing the supported <code> Scene </code> search 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSceneSearchRecordTypes();


    /**
     *  Tests if the given <code> Scene </code> search type is supported. 
     *
     *  @param  sceneSearchRecordType a <code> Type </code> indicating a 
     *          <code> Scene </code> search type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> sceneSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSceneSearchRecordType(org.osid.type.Type sceneSearchRecordType);


    /**
     *  Gets the supported <code> Trigger </code> record types. 
     *
     *  @return a list containing the supported <code> Trigger </code> types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getTriggerRecordTypes();


    /**
     *  Tests if the given <code> Trigger </code> record type is supported. 
     *
     *  @param  triggerRecordType a <code> Type </code> indicating a <code> 
     *          Trigger </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> triggerRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTriggerRecordType(org.osid.type.Type triggerRecordType);


    /**
     *  Gets the supported <code> Trigger </code> search record types. 
     *
     *  @return a list containing the supported <code> Trigger </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getTriggerSearchRecordTypes();


    /**
     *  Tests if the given <code> Trigger </code> search record type is 
     *  supported. 
     *
     *  @param  triggerSearchRecordType a <code> Type </code> indicating a 
     *          <code> Trigger </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> triggerSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTriggerSearchRecordType(org.osid.type.Type triggerSearchRecordType);


    /**
     *  Gets the supported <code> ActionGroup </code> record types. 
     *
     *  @return a list containing the supported <code> ActionGroup </code> 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getActionGroupRecordTypes();


    /**
     *  Tests if the given <code> ActionGroup </code> record type is 
     *  supported. 
     *
     *  @param  actionGroupRecordType a <code> Type </code> indicating an 
     *          <code> ActionGroup </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> actionGroupRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActionGroupRecordType(org.osid.type.Type actionGroupRecordType);


    /**
     *  Gets the supported <code> ActionGroup </code> search record types. 
     *
     *  @return a list containing the supported <code> ActionGroup </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getActionGroupSearchRecordTypes();


    /**
     *  Tests if the given <code> ActionGroup </code> search record type is 
     *  supported. 
     *
     *  @param  actionGroupSearchRecordType a <code> Type </code> indicating 
     *          an <code> ActionGroup </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          actionGroupSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActionGroupSearchRecordType(org.osid.type.Type actionGroupSearchRecordType);


    /**
     *  Gets the supported <code> Action </code> record types. 
     *
     *  @return a list containing the supported <code> Action </code> types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getActionRecordTypes();


    /**
     *  Tests if the given <code> Action </code> record type is supported. 
     *
     *  @param  actionRecordType a <code> Type </code> indicating an <code> 
     *          Action </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> actionRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActionRecordType(org.osid.type.Type actionRecordType);


    /**
     *  Gets the supported <code> System </code> record types. 
     *
     *  @return a list containing the supported <code> System </code> types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSystemRecordTypes();


    /**
     *  Tests if the given <code> System </code> record type is supported. 
     *
     *  @param  systemRecordType a <code> Type </code> indicating a <code> 
     *          System </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> systemRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSystemRecordType(org.osid.type.Type systemRecordType);


    /**
     *  Gets the supported <code> System </code> search record types. 
     *
     *  @return a list containing the supported <code> System </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSystemSearchRecordTypes();


    /**
     *  Tests if the given <code> System </code> search record type is 
     *  supported. 
     *
     *  @param  systemSearchRecordType a <code> Type </code> indicating a 
     *          <code> System </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> systemSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSystemSearchRecordType(org.osid.type.Type systemSearchRecordType);
}
