//
// org.osid.control.ControllerForm
//
//     The OSID Java specification for org.osid.control.ControllerForm.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control;


/**
 *  <p>This is the form for creating and updating <code> Controllers. </code> 
 *  Like all <code> OsidForm </code> objects, various data elements may be set 
 *  here for use in the create and update methods in the <code> 
 *  ControllerAdminSession. </code> For each data element that may be set, 
 *  metadata may be examined to provide display hints or data constraints. 
 *  Some data may be automatically derived from the controller segments. </p>
 */

public interface ControllerForm
    extends org.osid.OsidObjectForm,
            org.osid.OsidOperableForm {


    /**
     *  Gets the metadata for the address. 
     *
     *  @return metadata for the address 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getAddressMetadata();


    /**
     *  Sets the address. 
     *
     *  @param  address the new address 
     *  @throws org.osid.InvalidArgumentException <code> address </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> address </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setAddress(String address);


    /**
     *  Removes the address. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAddress();


    /**
     *  Gets the metadata for the model. 
     *
     *  @return metadata for the model 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getModelMetadata();


    /**
     *  Sets the model. 
     *
     *  @param  modelId the new model 
     *  @throws org.osid.InvalidArgumentException <code> modelId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> modelId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setModel(org.osid.id.Id modelId);


    /**
     *  Removes the model. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearModel();


    /**
     *  Gets the metadata for the version. 
     *
     *  @return metadata for the version 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getVersionMetadata();


    /**
     *  Sets the version. 
     *
     *  @param  version the new version 
     *  @throws org.osid.InvalidArgumentException <code> version </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> version </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setVersion(org.osid.installation.Version version);


    /**
     *  Removes the version. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearVersion();


    /**
     *  Gets the metadata for the toggle capability. 
     *
     *  @return metadata for the toggle 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getToggleableMetadata();


    /**
     *  Sets the toggleable capability. 
     *
     *  @param  toggle the new toggle flag 
     *  @throws org.osid.InvalidArgumentException <code> toggle </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setToggleable(boolean toggle);


    /**
     *  Removes the toggle. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearToggleable();


    /**
     *  Gets the metadata for the variable capability. 
     *
     *  @return metadata for the variable 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getVariableMetadata();


    /**
     *  Sets the variable capability. 
     *
     *  @param  variable the new variable flag 
     *  @throws org.osid.InvalidArgumentException <code> variable </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setVariable(boolean variable);


    /**
     *  Removes the variable flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearVariable();


    /**
     *  Gets the metadata for the variable by percentage capability. 
     *
     *  @return metadata for the percentage 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getVariableByPercentageMetadata();


    /**
     *  Sets the variable bt percentage capability. 
     *
     *  @param  percentage the new percentage flag 
     *  @throws org.osid.InvalidArgumentException <code> percentage </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setVariablePercentage(boolean percentage);


    /**
     *  Removes the variable by percentage flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearVariablePercentage();


    /**
     *  Gets the metadata for the minimum variable amount. 
     *
     *  @return metadata for the minimum variable amount 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getVariableMinimumMetadata();


    /**
     *  Sets the minimum variable amount. 
     *
     *  @param  amount the new minimum variable amount 
     *  @throws org.osid.InvalidArgumentException <code> amount </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> amount </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setVariableMinimum(java.math.BigDecimal amount);


    /**
     *  Removes the minimum variable amount. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearVariableMinimum();


    /**
     *  Gets the metadata for the maximum variable amount. 
     *
     *  @return metadata for the maximum variable amount 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getVariableMaximumMetadata();


    /**
     *  Sets the maximum variable amount. 
     *
     *  @param  amount the new maximum variable amount 
     *  @throws org.osid.InvalidArgumentException <code> amount </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> amount </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setVariableMaximum(java.math.BigDecimal amount);


    /**
     *  Removes the maximum variable amount. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearVariableMaximum();


    /**
     *  Gets the metadata for the discreet states. 
     *
     *  @return metadata for the discreet states 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getDiscreetStatesMetadata();


    /**
     *  Sets the maximum variable amount. 
     *
     *  @param  stateIds the new discreet states 
     *  @throws org.osid.InvalidArgumentException <code> stateIds </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> stateIds </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setDiscreetStates(org.osid.id.Id[] stateIds);


    /**
     *  Removes the discreet states. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDiscreetStates();


    /**
     *  Gets the <code> ControllerFormRecord </code> corresponding to the 
     *  given controller record <code> Type. </code> 
     *
     *  @param  controllerRecordType a controller record type 
     *  @return the controller form record 
     *  @throws org.osid.NullArgumentException <code> controllerRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(controllerRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.records.ControllerFormRecord getControllerFormRecord(org.osid.type.Type controllerRecordType)
        throws org.osid.OperationFailedException;
}
