//
// org.osid.control.ControllerLookupSession
//
//     The OSID Java specification for org.osid.control.ControllerLookupSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control;


/**
 *  <p>This session provides methods for retrieving <code> Controllers. 
 *  </code> The <code> Controller </code> represents a set of actions <code> . 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated system view: All controller methods in this session 
 *      operate, retrieve and pertain to controllers defined explicitly in the 
 *      current system. Using an isolated view is useful for managing <code> 
 *      Controllers </code> with the <code> ControllerAdminSession. </code> 
 *      </li> 
 *      <li> federated system view: All controller methods in this session 
 *      operate, retrieve and pertain to all controllers defined in this 
 *      system and any other controllers implicitly available in this system 
 *      through system inheritence. </li> 
 *      <li> active controller view: active controllers are returned from 
 *      methods in this session </li> 
 *      <li> any status controller view: active and inactive controllers are 
 *      returned from methods in this session </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedSystemView() </code> and <code> 
 *  useIsolatedSystemView() </code> behave as a radio group and one should be 
 *  selected before invoking the methods in this session. </p>
 */

public interface ControllerLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> System </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> System Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getSystemId();


    /**
     *  Gets the <code> System </code> associated with this session. 
     *
     *  @return the system 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.System getSystem()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Controller </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupControllers();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeControllerView();


    /**
     *  A complete view of the <code> ControllerConstrainer </code> returns is 
     *  desired. Methods will return what is requested or result in an error. 
     *  This view is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryControllerView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include controller constrainers in systems which are children of this 
     *  system in the system hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedSystemView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this system only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedSystemView();


    /**
     *  Only active controllers are returned from methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveControllerView();


    /**
     *  Borth active and inactive controllers are returned from methods in 
     *  this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusControllerView();


    /**
     *  Gets the <code> Controller </code> specified by its <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Controller </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> Controller </code> and retained for 
     *  compatibility. 
     *  
     *  In active mode, controllers are returned that are currently active. In 
     *  any status mode, active and inactive controllers are returned. 
     *
     *  @param  controllerId <code> Id </code> of the <code> Controller 
     *          </code> 
     *  @return the controller 
     *  @throws org.osid.NotFoundException <code> controllerId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> controllerId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.control.Controller getController(org.osid.id.Id controllerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ControllerList </code> corresponding to the given <code> 
     *  IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  controllers specified in the <code> Id </code> list, in the order of 
     *  the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Controllers </code> may be omitted from the list 
     *  and may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In active mode, controllers are returned that are currently active. In 
     *  any status mode, active and inactive controllers are returned. 
     *
     *  @param  controllerIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Controller </code> list 
     *  @throws org.osid.NotFoundException an <code> Id </code> was not found 
     *  @throws org.osid.NullArgumentException <code> controllerIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.ControllerList getControllersByIds(org.osid.id.IdList controllerIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ControllerList </code> corresponding to the given 
     *  controller genus <code> Type </code> which does not include 
     *  controllers of genus types derived from the specified <code> Type. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  controllers or an error results. Otherwise, the returned list may 
     *  contain only those controllers that are accessible through this 
     *  session. 
     *  
     *  In active mode, controllers are returned that are currently active. In 
     *  any status mode, active and inactive controllers are returned. 
     *
     *  @param  controllerGenusType a controller genus type 
     *  @return the returned <code> Controller </code> list 
     *  @throws org.osid.NullArgumentException <code> controllerGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.ControllerList getControllersByGenusType(org.osid.type.Type controllerGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ControllerList </code> corresponding to the given 
     *  controller genus <code> Type </code> and include any additional 
     *  controllers with genus types derived from the specified <code> Type. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  controllers or an error results. Otherwise, the returned list may 
     *  contain only those controllers that are accessible through this 
     *  session. 
     *  
     *  In active mode, controllers are returned that are currently active. In 
     *  any status mode, active and inactive controllers are returned. 
     *
     *  @param  controllerGenusType a controller genus type 
     *  @return the returned <code> Controller </code> list 
     *  @throws org.osid.NullArgumentException <code> controllerGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.ControllerList getControllersByParentGenusType(org.osid.type.Type controllerGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ControllerList </code> containing the given controller 
     *  record <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  controllers or an error results. Otherwise, the returned list may 
     *  contain only those controllers that are accessible through this 
     *  session. 
     *  
     *  In active mode, controllers are returned that are currently active. In 
     *  any status mode, active and inactive controllers are returned. 
     *
     *  @param  controllerRecordType a controller record type 
     *  @return the returned <code> Controller </code> list 
     *  @throws org.osid.NullArgumentException <code> controllerRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.ControllerList getControllersByRecordType(org.osid.type.Type controllerRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ControllerList </code> with the given address. <code> 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  controllers or an error results. Otherwise, the returned list may 
     *  contain only those controllers that are accessible through this 
     *  session. 
     *  
     *  In active mode, controllers are returned that are currently active. In 
     *  any status mode, active and inactive controllers are returned. 
     *
     *  @param  address a controller address 
     *  @return the returned <code> Controller </code> list 
     *  @throws org.osid.NullArgumentException <code> address </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.ControllerList getControllersByAddress(String address)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Controllers. </code> 
     *  
     *  In plenary mode, the returned list contains all known controllers or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  controllers that are accessible through this session. 
     *  
     *  In active mode, controllers are returned that are currently active. In 
     *  any status mode, active and inactive controllers are returned. 
     *
     *  @return a list of <code> Controllers </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.ControllerList getControllers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
