//
// org.osid.control.ControllerSearchSession
//
//     The OSID Java specification for org.osid.control.ControllerSearchSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control;


/**
 *  <p>This session provides methods for searching among <code> Controller 
 *  </code> objects. The search query is constructed using the <code> 
 *  ControlleryQuery. </code> </p> 
 *  
 *  <p> <code> getControllersByQuery() </code> is the basic search method and 
 *  returns a list of <code> Controllers. </code> A more advanced search may 
 *  be performed with <code> getControllersBySearch(). </code> It accepts a 
 *  <code> ControllerSearch </code> in addition to the query for the purpose 
 *  of specifying additional options affecting the entire search, such as 
 *  ordering. <code> getControllersBySearch() </code> returns a <code> 
 *  ControllerSearchResults </code> that can be used to access the resulting 
 *  <code> ControllerList </code> or be used to perform a search within the 
 *  result set through <code> ControllerSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated trigger view: searches include controllers in triggers 
 *      of which this trigger is an ancestor in the trigger hierarchy </li> 
 *      <li> isolated trigger view: searches are restricted to controllers in 
 *      this trigger </li> 
 *  </ul>
 *  
 *  
 *  <p> Controllers may have a controller record indicated by their respective 
 *  record types. The controller record is accessed via the <code> 
 *  ControllerQuery. </code> </p>
 */

public interface ControllerSearchSession
    extends org.osid.control.ControllerQuerySession {


    /**
     *  Gets a controller search. 
     *
     *  @return the controller search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.ControllerSearch getControllerSearch();


    /**
     *  Gets a controller search order. The <code> ControllerSearchOrder 
     *  </code> is supplied to a <code> ControllerSearch </code> to specify 
     *  the ordering of results. 
     *
     *  @return the controller search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.ControllerSearchOrder getControllerSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  controllerQuery the controller query 
     *  @param  controllerSearch the controller search 
     *  @return the controller search results 
     *  @throws org.osid.NullArgumentException <code> controllerQuery </code> 
     *          or <code> controllerSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> controllerQuery </code> 
     *          or <code> controllerSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.ControllerSearchResults getControllersBySearch(org.osid.control.ControllerQuery controllerQuery, 
                                                                           org.osid.control.ControllerSearch controllerSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a controller query from an inspector. The inspector is available 
     *  from a <code> ControllerSearchResults. </code> 
     *
     *  @param  controllerQueryInspector a controller query inspector 
     *  @return the controller query 
     *  @throws org.osid.NullArgumentException <code> controllerQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> controllerQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.ControllerQuery getControllerQueryFromInspector(org.osid.control.ControllerQueryInspector controllerQueryInspector);
}
