//
// org.osid.control.InputAdminSession
//
//     The OSID Java specification for org.osid.control.InputAdminSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control;


/**
 *  <p>This session creates, updates, and deletes <code> Inputs. </code> The 
 *  data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Input, </code> a <code> InputForm </code> is requested using <code> 
 *  getInputFormForCreate() </code> specifying the desired device, controller, 
 *  and record <code> Types </code> or none if no record <code> Types </code> 
 *  are needed. The returned <code> InputForm </code> will indicate that it is 
 *  to be used with a create operation and can be used to examine metdata or 
 *  validate data prior to creation. Once the <code> InputForm </code> is 
 *  submiited to a create operation, it cannot be reused with another create 
 *  operation unless the first operation was unsuccessful. Each <code> 
 *  InputForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> InputForms </code> are requested to the <code> 
 *  Input </code> <code> Id </code> that is to be updated using <code> 
 *  getInputFormForUpdate(). </code> Similarly, the <code> InputForm </code> 
 *  has metadata about the data that can be updated and it can perform 
 *  validation before submitting the update. The <code> InputForm </code> can 
 *  only be used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Inputs. </code> To unmap a <code> 
 *  Input </code> from the current <code> System, </code> the <code> 
 *  InputSystemAssignmentSession </code> should be used. These delete 
 *  operations attempt to remove the <code> Input </code> itself thus removing 
 *  it from all known <code> System </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface InputAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> System </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> System Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getSystemId();


    /**
     *  Gets the <code> System </code> associated with this session. 
     *
     *  @return the system 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.System getSystem()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> Inputs. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> Input </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer create operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Input </code> creation is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateInputs();


    /**
     *  Tests if this user can create a single <code> Input </code> using the 
     *  desired record types. While <code> 
     *  ControlManager.getInputRecordTypes() </code> can be used to examine 
     *  which records are supported, this method tests which record(s) are 
     *  required for creating a specific <code> Input. </code> Providing an 
     *  empty array tests if a <code> Input </code> can be created with no 
     *  records. 
     *
     *  @param  inputRecordTypes array of input record types 
     *  @return <code> true </code> if <code> Input </code> creation using the 
     *          specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> inputRecordTypes </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateInputWithRecordTypes(org.osid.type.Type[] inputRecordTypes);


    /**
     *  Gets the input form for creating new inputs. A new form should be 
     *  requested for each create transaction. 
     *
     *  @param  deviceId a device <code> Id </code> 
     *  @param  controllerId a controller <code> Id </code> 
     *  @param  inputRecordTypes array of input record types 
     *  @return the input form 
     *  @throws org.osid.NotFoundException <code> deviceId </code> or <code> 
     *          controllerId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> deviceId, controllerId, 
     *          </code> or <code> inputRecordTypes </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.InputForm getInputFormForCreate(org.osid.id.Id deviceId, 
                                                            org.osid.id.Id controllerId, 
                                                            org.osid.type.Type[] inputRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Input. </code> 
     *
     *  @param  inputForm the form for this <code> Input </code> 
     *  @return the new <code> Input </code> 
     *  @throws org.osid.IllegalStateException <code> inputForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> inputForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> inputForm </code> did not 
     *          originate from <code> getInputFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.Input createInput(org.osid.control.InputForm inputForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Inputs. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> Input </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer update operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Input </code> modification is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateInputs();


    /**
     *  Gets the input form for updating an existing input. A new input form 
     *  should be requested for each update transaction. 
     *
     *  @param  inputId the <code> Id </code> of the <code> Input </code> 
     *  @return the input form 
     *  @throws org.osid.NotFoundException <code> inputId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> inputId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.InputForm getInputFormForUpdate(org.osid.id.Id inputId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing input. 
     *
     *  @param  inputForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> inputForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> inputForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> inputForm </code> did not 
     *          originate from <code> getInputFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateInput(org.osid.control.InputForm inputForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> Inputs. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> Input </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer delete operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Input </code> deletion is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteInputs();


    /**
     *  Deletes a <code> Input. </code> 
     *
     *  @param  inputId the <code> Id </code> of the <code> Input </code> to 
     *          remove 
     *  @throws org.osid.NotFoundException <code> inputId </code> not found 
     *  @throws org.osid.NullArgumentException <code> inputId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteInput(org.osid.id.Id inputId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Inputs. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Input </code> aliasing is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageInputAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Input </code> for the purpose of 
     *  creating compatibility. The primary <code> Id </code> of the <code> 
     *  Input </code> is determined by the provider. The new <code> Id </code> 
     *  performs as an alias to the primary <code> Id. </code> If the alias is 
     *  a pointer to another input, it is reassigned to the given input <code> 
     *  Id. </code> 
     *
     *  @param  inputId the <code> Id </code> of a <code> Input </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> inputId </code> not found 
     *  @throws org.osid.NullArgumentException <code> inputId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasInput(org.osid.id.Id inputId, org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
