//
// org.osid.control.SceneSearchSession
//
//     The OSID Java specification for org.osid.control.SceneSearchSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control;


/**
 *  <p>This session provides methods for searching among <code> Scene </code> 
 *  objects. The search query is constructed using the <code> SceneQuery. 
 *  </code> </p> 
 *  
 *  <p> <code> getScenesByQuery() </code> is the basic search method and 
 *  returns a list of <code> Scenes. </code> A more advanced search may be 
 *  performed with <code> getScenesBySearch(). </code> It accepts an <code> 
 *  SceneSearch </code> in addition to the query for the purpose of specifying 
 *  additional options affecting the entire search, such as ordering. <code> 
 *  getScenesBySearch() </code> returns an <code> SceneSearchResults </code> 
 *  that can be used to access the resulting <code> SceneList </code> or be 
 *  used to perform a search within the result set through <code> SceneSearch. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated system view: searches include scenes in systems of 
 *      which this system is an ancestor in the system hierarchy </li> 
 *      <li> isolated system view: searches are restricted to scenes in this 
 *      system </li> 
 *  </ul>
 *  
 *  
 *  <p> Scenes may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> SceneQuery. </code> 
 *  </p>
 */

public interface SceneSearchSession
    extends org.osid.control.SceneQuerySession {


    /**
     *  Gets a scene search. 
     *
     *  @return the scene search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.SceneSearch getSceneSearch();


    /**
     *  Gets a scene search order. The <code> SceneSearchOrder </code> is 
     *  supplied to a <code> SceneSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the scene search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.SceneSearchOrder getSceneSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  sceneQuery the scene query 
     *  @param  sceneSearch the scene search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> sceneQuery </code> or 
     *          <code> sceneSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> sceneQuery </code> or 
     *          <code> sceneSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.SceneSearchResults getScenesBySearch(org.osid.control.SceneQuery sceneQuery, 
                                                                 org.osid.control.SceneSearch sceneSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a scene query from an inspector. The inspector is available from 
     *  a <code> SceneSearchResults. </code> 
     *
     *  @param  sceneQueryInspector a scene query inspector 
     *  @return the scene query 
     *  @throws org.osid.NullArgumentException <code> sceneQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> sceneQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.SceneQuery getSceneQueryFromInspector(org.osid.control.SceneQueryInspector sceneQueryInspector);
}
