//
// org.osid.control.SettingQuery
//
//     The OSID Java specification for org.osid.control.SettingQuery.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control;


/**
 *  <p>This is the query for searching settings. Each method match specifies 
 *  an <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface SettingQuery
    extends org.osid.OsidObjectQuery,
            org.osid.OsidSubjugateableQuery {


    /**
     *  Sets the controller <code> Id </code> for this query. 
     *
     *  @param  controllerId the controller <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> controllerId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchControllerId(org.osid.id.Id controllerId, boolean match);


    /**
     *  Clears the controller <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearControllerIdTerms();


    /**
     *  Tests if a <code> ControllerQuery </code> is available. 
     *
     *  @return <code> true </code> if a controller query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsControllerQuery();


    /**
     *  Gets the query for a <code> InputQntry. </code> Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @return the controller query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsControllerQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsControllerQuery() </code> is <code> true. </code> 
     */

    public org.osid.control.ControllerQuery getControllerQuery();


    /**
     *  Clears the controller query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearControllerTerms();


    /**
     *  Matches on settings. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchOn(boolean match);


    /**
     *  Clears the on query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOnTerms();


    /**
     *  Matches off settings. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchOff(boolean match);


    /**
     *  Clears the off query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOffTerms();


    /**
     *  Matches variable percentages between the given range inclusive. 
     *
     *  @param  start start of range 
     *  @param  end end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> start </code> is 
     *          greater than <code> end </code> 
     *  @throws org.osid.NullArgumentException <code> start or end </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchVariablePercentage(java.math.BigDecimal start, 
                                        java.math.BigDecimal end, 
                                        boolean match);


    /**
     *  Matches any variable percentages. 
     *
     *  @param  match <code> true </code> to match settings with variable 
     *          percentages, <code> false </code> to match settings with no 
     *          variable percentages 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyVariablePercentage(boolean match);


    /**
     *  Clears the variable percentages query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearVariablePercentageTerms();


    /**
     *  Matches variable amount between the given range inclusive. 
     *
     *  @param  start start of range 
     *  @param  end end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> start </code> is 
     *          greater than <code> end </code> 
     *  @throws org.osid.NullArgumentException <code> start or end </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchVariableAmount(java.math.BigDecimal start, 
                                    java.math.BigDecimal end, boolean match);


    /**
     *  Matches any variable amount. 
     *
     *  @param  match <code> true </code> to match settings with variable 
     *          amounts, <code> false </code> to match settings with no 
     *          variable amounts 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyVariableAmount(boolean match);


    /**
     *  Clears the variable amount query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearVariableAmountTerms();


    /**
     *  Sets the state <code> Id </code> for this query. 
     *
     *  @param  stateId the state <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> stateId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDiscreetStateId(org.osid.id.Id stateId, boolean match);


    /**
     *  Clears the state <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDiscreetStateIdTerms();


    /**
     *  Tests if a <code> StateQuery </code> is available. 
     *
     *  @return <code> true </code> if a state query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDiscreetStateQuery();


    /**
     *  Gets the query for a <code> State. </code> Multiple retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @return the state query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDiscreetStateQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDiscreetStateQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.process.StateQuery getDiscreetStateQuery();


    /**
     *  Matches any discreet states. 
     *
     *  @param  match <code> true </code> to match settings with discreet 
     *          states, <code> false </code> to match settings with no 
     *          discreet states 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDiscreetState(boolean match);


    /**
     *  Clears the state query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDiscreetStateTerms();


    /**
     *  Matches ramp rates between the given range inclusive. 
     *
     *  @param  start start of range 
     *  @param  end end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> start </code> is 
     *          greater than <code> end </code> 
     *  @throws org.osid.NullArgumentException <code> start or end </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRampRate(org.osid.calendaring.Duration start, 
                              org.osid.calendaring.Duration end, boolean match);


    /**
     *  Matches any ramp rate. 
     *
     *  @param  match <code> true </code> to match settings with ramp rates, 
     *          <code> false </code> to match settings with no ramp rates 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRampRate(boolean match);


    /**
     *  Clears the ramp rate query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRampRateTerms();


    /**
     *  Sets the system <code> Id </code> for this query to match controllers 
     *  assigned to systems. 
     *
     *  @param  systemId the system <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSystemId(org.osid.id.Id systemId, boolean match);


    /**
     *  Clears the system <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSystemIdTerms();


    /**
     *  Tests if a <code> SystemQuery </code> is available. 
     *
     *  @return <code> true </code> if a system query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSystemQuery();


    /**
     *  Gets the query for a system. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the system query 
     *  @throws org.osid.UnimplementedException <code> supportsSystemQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSystemQuery() </code> is <code> true. </code> 
     */

    public org.osid.control.SystemQuery getSystemQuery();


    /**
     *  Clears the system query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSystemTerms();


    /**
     *  Gets the query record corresponding to the given <code> Setting 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @param  settingRecordType a setting record type 
     *  @return the setting query record 
     *  @throws org.osid.NullArgumentException <code> settingRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(settingRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.records.SettingQueryRecord getSettingQueryRecord(org.osid.type.Type settingRecordType)
        throws org.osid.OperationFailedException;
}
