//
// org.osid.control.SystemHierarchySession
//
//     The OSID Java specification for org.osid.control.SystemHierarchySession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control;


/**
 *  <p>This session defines methods for traversing a hierarchy of <code> 
 *  System </code> objects. Each node in the hierarchy is a unique <code> 
 *  System. </code> The hierarchy may be traversed recursively to establish 
 *  the tree structure through <code> getParentSystems() </code> and <code> 
 *  getChildSystems(). </code> To relate these <code> Ids </code> to another 
 *  OSID, <code> getSystemNodes() </code> can be used for retrievals that can 
 *  be used for bulk lookups in other OSIDs. Any <code> System </code> 
 *  available in the Control OSID is known to this hierarchy but does not 
 *  appear in the hierarchy traversal until added as a root system or a child 
 *  of another system. </p> 
 *  
 *  <p> A user may not be authorized to traverse the entire hierarchy. Parts 
 *  of the hierarchy may be made invisible through omission from the returns 
 *  of <code> getParentSystems() </code> or <code> getChildSystems() </code> 
 *  in lieu of a <code> PERMISSION_DENIED </code> error that may disrupt the 
 *  traversal through authorized deviceways. </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative system view: system elements may be silently omitted 
 *      or re-ordered </li> 
 *      <li> plenary system view: provides a complete set or is an error 
 *      condition </li> 
 *  </ul>
 *  
 */

public interface SystemHierarchySession
    extends org.osid.OsidSession {


    /**
     *  Gets the hierarchy <code> Id </code> associated with this session. 
     *
     *  @return the hierarchy <code> Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getSystemHierarchyId();


    /**
     *  Gets the hierarchy associated with this session. 
     *
     *  @return the hierarchy associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hierarchy.Hierarchy getSystemHierarchy()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform hierarchy queries. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations. 
     *
     *  @return <code> false </code> if hierarchy traversal methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAccessSystemHierarchy();


    /**
     *  The returns from the system methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeSystemView();


    /**
     *  A complete view of the <code> Systems </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenarySystemView();


    /**
     *  Gets the root system <code> Ids </code> in this hierarchy. 
     *
     *  @return the root system <code> Ids </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getRootSystemIds()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the root system in the system hierarchy. A system with no parents 
     *  is an orphan. While all system <code> Ids </code> are known to the 
     *  hierarchy, an orphan does not appear in the hierarchy unless 
     *  explicitly added as a root system or child of another system. 
     *
     *  @return the root systems 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.control.SystemList getRootSystems()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if the <code> System </code> has any parents. 
     *
     *  @param  systemId a system <code> Id </code> 
     *  @return <code> true </code> if the system has parents, f <code> alse 
     *          </code> otherwise 
     *  @throws org.osid.NotFoundException <code> systemId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasParentSystems(org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if an <code> Id </code> is a direct parent of system. 
     *
     *  @param  id an <code> Id </code> 
     *  @param  systemId the <code> Id </code> of a system 
     *  @return <code> true </code> if this <code> id </code> is a parent of 
     *          <code> systemId, </code> f <code> alse </code> otherwise 
     *  @throws org.osid.NotFoundException <code> systemId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> id </code> or <code> 
     *          systemId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If <code> id </code> not found return <code> false. </code> 
     */

    public boolean isParentOfSystem(org.osid.id.Id id, org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the parent <code> Ids </code> of the given system. 
     *
     *  @param  systemId a system <code> Id </code> 
     *  @return the parent <code> Ids </code> of the system 
     *  @throws org.osid.NotFoundException <code> systemId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getParentSystemIds(org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the parents of the given system. 
     *
     *  @param  systemId the <code> Id </code> to query 
     *  @return the parents of the system 
     *  @throws org.osid.NotFoundException <code> systemId </code> not found 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.SystemList getParentSystems(org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if an <code> Id </code> is an ancestor of a system. 
     *
     *  @param  id an <code> Id </code> 
     *  @param  systemId the <code> Id </code> of a system 
     *  @return <code> tru </code> e if this <code> id </code> is an ancestor 
     *          of <code> systemId, </code> <code> false </code> otherwise 
     *  @throws org.osid.NotFoundException <code> systemId </code> not found 
     *  @throws org.osid.NullArgumentException <code> systemId </code> or 
     *          <code> id </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If <code> id </code> not found return <code> false. </code> 
     */

    public boolean isAncestorOfSystem(org.osid.id.Id id, 
                                      org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if a system has any children. 
     *
     *  @param  systemId a system <code> Id </code> 
     *  @return <code> true </code> if the <code> systemId </code> has 
     *          children, <code> false </code> otherwise 
     *  @throws org.osid.NotFoundException <code> systemId </code> not found 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasChildSystems(org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if a system is a direct child of another. 
     *
     *  @param  id an <code> Id </code> 
     *  @param  systemId the <code> Id </code> of a system 
     *  @return <code> true </code> if the <code> id </code> is a child of 
     *          <code> systemId, </code> <code> false </code> otherwise 
     *  @throws org.osid.NotFoundException <code> systemId </code> not found 
     *  @throws org.osid.NullArgumentException <code> id </code> or <code> 
     *          systemId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If <code> id </code> not found return <code> false. </code> 
     */

    public boolean isChildOfSystem(org.osid.id.Id id, org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the child <code> Ids </code> of the given system. 
     *
     *  @param  systemId the <code> Id </code> to query 
     *  @return the children of the system 
     *  @throws org.osid.NotFoundException <code> systemId </code> not found 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getChildSystemIds(org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the children of the given system. 
     *
     *  @param  systemId the <code> Id </code> to query 
     *  @return the children of the system 
     *  @throws org.osid.NotFoundException <code> systemId </code> not found 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.SystemList getChildSystems(org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if an <code> Id </code> is a descendant of a system. 
     *
     *  @param  id an <code> Id </code> 
     *  @param  systemId the <code> Id </code> of a system 
     *  @return <code> true </code> if the <code> id </code> is a descendant 
     *          of the <code> systemId, </code> <code> false </code> otherwise 
     *  @throws org.osid.NotFoundException <code> systemId </code> not found 
     *  @throws org.osid.NullArgumentException <code> id </code> or <code> 
     *          systemId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If <code> id </code> is not found return <code> false. </code> 
     */

    public boolean isDescendantOfSystem(org.osid.id.Id id, 
                                        org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a portion of the hierarchy for the given system. 
     *
     *  @param  systemId the <code> Id </code> to query 
     *  @param  ancestorLevels the maximum number of ancestor levels to 
     *          include. A value of 0 returns no parents in the system. 
     *  @param  descendantLevels the maximum number of descendant levels to 
     *          include. A value of 0 returns no children in the system. 
     *  @param  includeSiblings <code> true </code> to include the siblings of 
     *          the given system, <code> false </code> to omit the siblings 
     *  @return a system node 
     *  @throws org.osid.NotFoundException <code> systemId </code> not found 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hierarchy.Node getSystemNodeIds(org.osid.id.Id systemId, 
                                                    long ancestorLevels, 
                                                    long descendantLevels, 
                                                    boolean includeSiblings)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a portion of the hierarchy for the given system. 
     *
     *  @param  systemId the <code> Id </code> to query 
     *  @param  ancestorLevels the maximum number of ancestor levels to 
     *          include. A value of 0 returns no parents in the hierarchy. 
     *  @param  descendantLevels the maximum number of descendant levels to 
     *          include. A value of 0 returns no children in the hierarchy. 
     *  @param  includeSiblings <code> true </code> to include the siblings of 
     *          the given system, <code> false </code> to omit the siblings 
     *  @return a system node 
     *  @throws org.osid.NotFoundException <code> systemId </code> not found 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.SystemNode getSystemNodes(org.osid.id.Id systemId, 
                                                      long ancestorLevels, 
                                                      long descendantLevels, 
                                                      boolean includeSiblings)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
