//
// org.osid.control.SystemQuery
//
//     The OSID Java specification for org.osid.control.SystemQuery.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control;


/**
 *  <p>This is the query for searching systems. Each method match specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface SystemQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Sets the device <code> Id </code> for this query to match systems that 
     *  have a related device. 
     *
     *  @param  deviceId a device <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for negative match 
     *  @throws org.osid.NullArgumentException <code> deviceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDeviceId(org.osid.id.Id deviceId, boolean match);


    /**
     *  Clears the device <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDeviceIdTerms();


    /**
     *  Tests if a <code> DeviceQuery </code> is available. 
     *
     *  @return <code> true </code> if a device query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDeviceQuery();


    /**
     *  Gets the query for a device. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the device query 
     *  @throws org.osid.UnimplementedException <code> supportsDeviceQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDeviceQuery() </code> is <code> true. </code> 
     */

    public org.osid.control.DeviceQuery getDeviceQuery();


    /**
     *  Matches systems that have any device. 
     *
     *  @param  match <code> true </code> to match systems with any device, 
     *          <code> false </code> to match systems with no device 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDevice(boolean match);


    /**
     *  Clears the device query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDeviceTerms();


    /**
     *  Sets the controller <code> Id </code> for this query. 
     *
     *  @param  controllerId the controller <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> controllerId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchControllerId(org.osid.id.Id controllerId, boolean match);


    /**
     *  Clears the controller <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearControllerIdTerms();


    /**
     *  Tests if a <code> ControllerQuery </code> is available. 
     *
     *  @return <code> true </code> if a controller query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsControllerQuery();


    /**
     *  Gets the query for a controller. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the controller query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsControllerQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsControllerQuery() </code> is <code> true. </code> 
     */

    public org.osid.control.ControllerQuery getControllerQuery();


    /**
     *  Matches systems with any controller. 
     *
     *  @param  match <code> true </code> to match systems with any 
     *          controller, <code> false </code> to match systems with no 
     *          controller 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyController(boolean match);


    /**
     *  Clears the controller query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearControllerTerms();


    /**
     *  Sets the input <code> Id </code> for this query. 
     *
     *  @param  inputId the input <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> inputId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchInputId(org.osid.id.Id inputId, boolean match);


    /**
     *  Clears the input <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearInputIdTerms();


    /**
     *  Tests if an <code> InputQuery </code> is available. 
     *
     *  @return <code> true </code> if an input query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInputQuery();


    /**
     *  Gets the query for an input. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the input query 
     *  @throws org.osid.UnimplementedException <code> supportsInputQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInputQuery() </code> is <code> true. </code> 
     */

    public org.osid.control.InputQuery getInputQuery();


    /**
     *  Matches systems with any input. 
     *
     *  @param  match <code> true </code> to match systems with any input, 
     *          <code> false </code> to match systems with no inputs 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyInput(boolean match);


    /**
     *  Clears the input query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearInputTerms();


    /**
     *  Sets the setting <code> Id </code> for this query. 
     *
     *  @param  settingId the setting <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> settingId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSettingId(org.osid.id.Id settingId, boolean match);


    /**
     *  Clears the setting <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSettingIdTerms();


    /**
     *  Tests if a <code> SettingQuery </code> is available. 
     *
     *  @return <code> true </code> if a setting query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSettingQuery();


    /**
     *  Gets the query for a setting. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the setting query 
     *  @throws org.osid.UnimplementedException <code> supportsSettingQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSettingQuery() </code> is <code> true. </code> 
     */

    public org.osid.control.SettingQuery getSettingQuery();


    /**
     *  Matches systems with any setting. 
     *
     *  @param  match <code> true </code> to match systems with any setting, 
     *          <code> false </code> to match systems with no settings 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnySetting(boolean match);


    /**
     *  Clears the setting query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSettingTerms();


    /**
     *  Sets the scene <code> Id </code> for this query. 
     *
     *  @param  sceneId the scene <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> sceneId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSceneId(org.osid.id.Id sceneId, boolean match);


    /**
     *  Clears the scene <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSceneIdTerms();


    /**
     *  Tests if a <code> SceneQuery </code> is available. 
     *
     *  @return <code> true </code> if a scene query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSceneQuery();


    /**
     *  Gets the query for a scene. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the scene query 
     *  @throws org.osid.UnimplementedException <code> supportsSceneQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSceneQuery() </code> is <code> true. </code> 
     */

    public org.osid.control.SceneQuery getSceneQuery();


    /**
     *  Matches systems with any scene. 
     *
     *  @param  match <code> true </code> to match systems with any scene, 
     *          <code> false </code> to match systems with no scenes 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyScene(boolean match);


    /**
     *  Clears the scene query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSceneTerms();


    /**
     *  Sets the trigger <code> Id </code> for this query. 
     *
     *  @param  triggerId the trigger <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> triggerId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchTriggerId(org.osid.id.Id triggerId, boolean match);


    /**
     *  Clears the trigger <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTriggerIdTerms();


    /**
     *  Tests if a <code> TriggerQuery </code> is available. 
     *
     *  @return <code> true </code> if a trigger query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTriggerQuery();


    /**
     *  Gets the query for a trigger. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the trigger query 
     *  @throws org.osid.UnimplementedException <code> supportsTriggerQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTriggerQuery() </code> is <code> true. </code> 
     */

    public org.osid.control.TriggerQuery getTriggerQuery();


    /**
     *  Matches systems with any trigger. 
     *
     *  @param  match <code> true </code> to match systems with any trigger, 
     *          <code> false </code> to match systems with no trigger 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyTrigger(boolean match);


    /**
     *  Clears the trigger query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTriggerTerms();


    /**
     *  Sets the action group <code> Id </code> for this query. 
     *
     *  @param  actionGroupId the action group <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> actionGroupId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchActionGroupId(org.osid.id.Id actionGroupId, boolean match);


    /**
     *  Clears the action group <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearActionGroupIdTerms();


    /**
     *  Tests if an <code> ActionGroup </code> is available. 
     *
     *  @return <code> true </code> if an action group query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActionGroupQuery();


    /**
     *  Gets the query for an action group. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the action group query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActionGroupQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActionGroupQuery() </code> is <code> true. </code> 
     */

    public org.osid.control.ActionGroupQuery getActionGroupQuery();


    /**
     *  Matches systems with any action group. 
     *
     *  @param  match <code> true </code> to match systems with any action 
     *          group, <code> false </code> to match systems with no action 
     *          groups 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyActionGroup(boolean match);


    /**
     *  Clears the action group query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearActionGroupTerms();


    /**
     *  Sets the system <code> Id </code> for this query to match systems that 
     *  have the specified system as an ancestor. 
     *
     *  @param  systemId a system <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for negative match 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorSystemId(org.osid.id.Id systemId, boolean match);


    /**
     *  Clears the ancestor system <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorSystemIdTerms();


    /**
     *  Tests if a <code> SystemQuery </code> is available. 
     *
     *  @return <code> true </code> if a system query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorSystemQuery();


    /**
     *  Gets the query for a system. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the system query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorSystemQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorSystemQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.SystemQuery getAncestorSystemQuery();


    /**
     *  Matches systems with any ancestor. 
     *
     *  @param  match <code> true </code> to match systems with any ancestor, 
     *          <code> false </code> to match root systems 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorSystem(boolean match);


    /**
     *  Clears the ancestor system query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorSystemTerms();


    /**
     *  Sets the system <code> Id </code> for this query to match systems that 
     *  have the specified system as a descendant. 
     *
     *  @param  systemId a system <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for negative match 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantSystemId(org.osid.id.Id systemId, boolean match);


    /**
     *  Clears the descendant system <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantSystemIdTerms();


    /**
     *  Tests if a <code> SystemQuery </code> is available. 
     *
     *  @return <code> true </code> if a system query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantSystemQuery();


    /**
     *  Gets the query for a system/ Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the system query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantSystemQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantSystemQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.SystemQuery getDescendantSystemQuery();


    /**
     *  Matches systems with any descendant. 
     *
     *  @param  match <code> true </code> to match systems with any 
     *          descendant, <code> false </code> to match leaf systems 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantSystem(boolean match);


    /**
     *  Clears the descendant system query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantSystemTerms();


    /**
     *  Gets the system query record corresponding to the given <code> System 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @param  systemRecordType a system record type 
     *  @return the system query record 
     *  @throws org.osid.NullArgumentException <code> systemRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(systemRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.records.SystemQueryRecord getSystemQueryRecord(org.osid.type.Type systemRecordType)
        throws org.osid.OperationFailedException;
}
