//
// org.osid.control.SystemReceiver
//
//     The OSID Java specification for org.osid.control.SystemReceiver.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control;


/**
 *  <p>The system receiver is the consumer supplied interface for receiving 
 *  notifications pertaining to new, updated or deleted <code> System </code> 
 *  objects. </p>
 */

public interface SystemReceiver
    extends org.osid.OsidReceiver {


    /**
     *  The callback for notifications of new systems. 
     *
     *  @param  notificationId the notification <code> Id </code> 
     *  @param  systemIds the <code> Ids </code> of the new <code> Systems 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newSystems(org.osid.id.Id notificationId, 
                           org.osid.id.IdList systemIds);


    /**
     *  The callback for notification of updated system. 
     *
     *  @param  notificationId the notification <code> Id </code> 
     *  @param  systemIds the <code> Ids </code> of the updated <code> Systems 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void changedSystems(org.osid.id.Id notificationId, 
                               org.osid.id.IdList systemIds);


    /**
     *  The callback for notification of deleted systems. 
     *
     *  @param  notificationId the notification <code> Id </code> 
     *  @param  systemIds the <code> Ids </code> of the deleted <code> Systems 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedSystems(org.osid.id.Id notificationId, 
                               org.osid.id.IdList systemIds);


    /**
     *  The callback for notifications of changes to children of system 
     *  hierarchy nodes. 
     *
     *  @param  notificationId the notification <code> Id </code> 
     *  @param  systemIds the <code> Ids </code> of the <code> Systems </code> 
     *          whose children have changed 
     *  @compliance mandatory This method must be implemented. 
     */

    public void changedChildOfSystems(org.osid.id.Id notificationId, 
                                      org.osid.id.IdList systemIds);
}
