//
// org.osid.control.TriggerSearchSession
//
//     The OSID Java specification for org.osid.control.TriggerSearchSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control;


/**
 *  <p>This session provides methods for searching among <code> Trigger 
 *  </code> objects. The search query is constructed using the <code> 
 *  TriggerQuery. </code> </p> 
 *  
 *  <p> <code> getTriggersByQuery() </code> is the basic search method and 
 *  returns a list of <code> Triggers. </code> A more advanced search may be 
 *  performed with <code> getTriggersBySearch(). </code> It accepts a <code> 
 *  TriggerSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getTriggersBySearch() </code> returns a <code> 
 *  TriggerSearchResults </code> that can be used to access the resulting 
 *  <code> TriggerList </code> or be used to perform a search within the 
 *  result set through <code> TriggerSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated system view: searches include triggers in systems of 
 *      which this system is an ancestor in the system hierarchy </li> 
 *      <li> isolated system view: searches are restricted to triggers in this 
 *      system </li> 
 *  </ul>
 *  
 *  
 *  <p> Triggers may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> TriggerQuery. </code> 
 *  </p>
 */

public interface TriggerSearchSession
    extends org.osid.control.TriggerQuerySession {


    /**
     *  Gets a trigger search. 
     *
     *  @return the trigger search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.TriggerSearch getTriggerSearch();


    /**
     *  Gets a trigger search order. The <code> TriggerSearchOrder </code> is 
     *  supplied to a <code> TriggerSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the trigger search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.TriggerSearchOrder getTriggerSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  triggerQuery the trigger query 
     *  @param  triggerSearch the trigger search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> triggerQuery </code> or 
     *          <code> triggerSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> triggerQuery </code> or 
     *          <code> triggerSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.TriggerSearchResults getTriggersBySearch(org.osid.control.TriggerQuery triggerQuery, 
                                                                     org.osid.control.TriggerSearch triggerSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a trigger query from an inspector. The inspector is available 
     *  from a <code> TriggerSearchResults. </code> 
     *
     *  @param  triggerQueryInspector a trigger query inspector 
     *  @return the trigger query 
     *  @throws org.osid.NullArgumentException <code> triggerQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> triggerQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.TriggerQuery getTriggerQueryFromInspector(org.osid.control.TriggerQueryInspector triggerQueryInspector);
}
