//
// org.osid.control.batch.ActionGroupBatchAdminSession
//
//     The OSID Java specification for org.osid.control.batch.ActionGroupBatchAdminSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control.batch;


/**
 *  <p>This session creates, updates, and deletes <code> ActionGroups </code> 
 *  in bulk. The data for create and update is provided by the consumer via 
 *  the form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create an 
 *  <code> ActionGroup, </code> an <code> ActionGroupForm </code> is requested 
 *  using <code> getActionGroupFormsForCreate() </code> specifying the desired 
 *  record <code> Types </code> or none if no record <code> Types </code> are 
 *  needed. Each of the returned <code> ActionGroupForms </code> will indicate 
 *  that it is to be used with a create operation and can be used to examine 
 *  metdata or validate data prior to creation. Once an <code> ActionGroupForm 
 *  </code> is submiited to a create operation, it cannot be reused with 
 *  another create operation unless the first operation was unsuccessful. Each 
 *  <code> ActionGroupForm </code> corresponds to an attempted transaction. 
 *  </p> 
 *  
 *  <p> The <code> ActionGroupForms </code> returned from <code> 
 *  getActionGroupFormsForCreate() </code> may be linked to the originating 
 *  request through the peer <code> Ids </code> of the <code> ActionGroupForm. 
 *  </code> In the case where there may be duplicates, any <code> 
 *  ActionGroupForm </code> of the same peer <code> Ids </code> may be used 
 *  for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> ActionGroupForm </code> are submitted for 
 *  create, a <code> CreateActionGroup </code> is returned for each <code> 
 *  ActionGroupForm, </code> although the ordering is not defined. Only errors 
 *  that pertain to the entire create operation are returned from <code> 
 *  createActionGroups(), </code> errors specific to an individual <code> 
 *  ActionGroupForm </code> are indicated in the corresponding <code> 
 *  CreateActionGroup. </code> <code> CreateActionGroups </code> may be linked 
 *  to the originating <code> ActionGroupForm </code> through the <code> 
 *  ActionGroupForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> ActionGroupForms </code> are requested to the 
 *  <code> ActionGroup </code> <code> Id </code> that is to be updated using 
 *  <code> getActionGroupFormsForUpdate() </code> where the reference <code> 
 *  Id </code> in the <code> ActionGroupForm </code> may be used to link the 
 *  request. Similarly, the <code> ActionGroupForm </code> has metadata about 
 *  the data that can be updated and it can perform validation before 
 *  submitting the update. The <code> ActionGroupForm </code> can only be used 
 *  once for a successful update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> ActionGroupForms </code> are submitted for 
 *  update, an <code> UpdateActionGroup </code> is returned for each <code> 
 *  ActionGroupForm, </code> although the ordering is not defined. Only errors 
 *  that pertain to the entire update operation are returned from <code> 
 *  updateActionGroups(), </code> errors specific to an individual <code> 
 *  ActionGroupForm </code> are indicated in the corresponding <code> 
 *  UpdateActionGroup. </code> <code> UpdateActionGroups </code> may be linked 
 *  to the originating <code> ActionGroupForm </code> through the <code> 
 *  ActionGroupForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> ActionGroups </code> in bulk. To 
 *  unmap an <code> ActionGroup </code> from the current <code> System, 
 *  </code> the <code> ActionGroupSystemAssignmentSession </code> should be 
 *  used. These delete operations attempt to remove the <code> ActionGroup 
 *  </code> itself thus removing it from all known <code> System </code> 
 *  catalogs. Bulk delete operations return the results in <code> 
 *  DeleteActionGroups. </code> </p>
 */

public interface ActionGroupBatchAdminSession
    extends org.osid.control.ActionGroupAdminSession {


    /**
     *  Gets the action group forms for creating a bunch of new action groups. 
     *
     *  @param  n the number of forms to retrieve 
     *  @param  actionGroupRecordTypes array of action group record types to 
     *          be included in each create operation or an empty list if none 
     *  @return the action group forms 
     *  @throws org.osid.NullArgumentException <code> actionGroupRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.batch.ActionGroupBatchFormList getActionGroupFormsForCreate(long n, 
                                                                                        org.osid.type.Type[] actionGroupRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> ActionGroups. </code> This method returns 
     *  an error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateActionGroup </code> . 
     *
     *  @param  actionGroupForms the action group forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> actionGroupForms </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createActionGroups(org.osid.control.batch.ActionGroupBatchFormList actionGroupForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the action group forms for updating an existing set of action 
     *  groups. A new action group form should be requested for each update 
     *  transaction. 
     *
     *  @param  actionGroupIds the <code> Ids </code> of the <code> 
     *          ActionGroup </code> 
     *  @return the action group form 
     *  @throws org.osid.NotFoundException an <code> actionGroupId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> actionGroupIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.batch.ActionGroupBatchFormList getActionGroupFormsForUpdate(org.osid.id.IdList actionGroupIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing action groups. This method returns an error if the 
     *  entire operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateActionGroup </code> . 
     *
     *  @param  actionGroupForms the form containing the elements to be 
     *          updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> actionGroupForms </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateActionGroups(org.osid.control.batch.ActionGroupBatchFormList actionGroupForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> ActionGroups </code> in this <code> System. </code> 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllActionGroups()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes action groups for the given <code> Ids. </code> 
     *
     *  @param  actionGroupIds the <code> Ids </code> of the action groups to 
     *          delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> actionGroupIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteActionGroups(org.osid.id.IdList actionGroupIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to an <code> ActionGroup </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> ActionGroup </code> is determined by the provider. The new 
     *  <code> Id </code> is an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another action group, it is reassigned to the 
     *  given action group <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasActionGroups(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the action forms for creating a bunch of new actions. A form is 
     *  retrieved for each action group. 
     *
     *  @param  actionGroupIds list of action groups 
     *  @param  actionRecordTypes array of action record types to be included 
     *          in each create operation or an empty list if none 
     *  @return the action forms 
     *  @throws org.osid.NotFoundException an <code> actionGroupId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> actionGroupIds </code> 
     *          or <code> actionRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.batch.ActionBatchFormList getActionFormsForCreate(org.osid.id.IdList actionGroupIds, 
                                                                              org.osid.type.Type[] actionRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Actions. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateAction </code> . 
     *
     *  @param  actionForms the action forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> actionForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createActions(org.osid.control.batch.ActionBatchFormList actionForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the action forms for updating an existing set of actions. A new 
     *  action form should be requested for each update transaction. 
     *
     *  @param  actionIds the <code> Ids </code> of the <code> Action </code> 
     *  @return the action form 
     *  @throws org.osid.NotFoundException a <code> actionId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> actionIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.batch.ActionBatchFormList getActionFormsForUpdate(org.osid.id.IdList actionIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing actions. This method returns an error if the entire 
     *  operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateAction </code> . 
     *
     *  @param  actionForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> actionForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateActions(org.osid.control.batch.ActionBatchFormList actionForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Actions </code> in this <code> Control. </code> 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllActions()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes actions for the given <code> Ids. </code> 
     *
     *  @param  actionIds the <code> Ids </code> of the actions to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> actionIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteActions(org.osid.id.IdList actionIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes actions for the given <code> ActionGroup. </code> 
     *
     *  @param  actionGroupId an action group <code> Id </code> 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> actionGroupId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteActionsForActionGroup(org.osid.id.Id actionGroupId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Action </code> for the purpose 
     *  of creating compatibility. The primary <code> Id </code> of the <code> 
     *  Action </code> is determined by the provider. The new <code> Id 
     *  </code> is an alias to the primary <code> Id. </code> If the alias is 
     *  a pointer to another action, it is reassigned to the given action 
     *  <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasActions(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
