//
// org.osid.control.batch.SceneBatchAdminSession
//
//     The OSID Java specification for org.osid.control.batch.SceneBatchAdminSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Scenes </code> in 
 *  bulk. The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Scene, </code> a <code> SceneForm </code> is requested using <code> 
 *  getSceneFormsForCreate() </code> specifying the desired record <code> 
 *  Types </code> or none if no record <code> Types </code> are needed. Each 
 *  of the returned <code> SceneForms </code> will indicate that it is to be 
 *  used with a create operation and can be used to examine metdata or 
 *  validate data prior to creation. Once a <code> SceneForm </code> is 
 *  submiited to a create operation, it cannot be reused with another create 
 *  operation unless the first operation was unsuccessful. Each <code> 
 *  SceneForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> SceneForms </code> returned from <code> 
 *  getSceneFormsForCreate() </code> may be linked to the originating request 
 *  through the peer <code> Ids </code> of the <code> SceneForm. </code> In 
 *  the case where there may be duplicates, any <code> SceneForm </code> of 
 *  the same peer <code> Ids </code> may be used for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> SceneForm </code> are submitted for create, a 
 *  <code> CreateScene </code> is returned for each <code> SceneForm, </code> 
 *  although the ordering is not defined. Only errors that pertain to the 
 *  entire create operation are returned from <code> createScenes(), </code> 
 *  errors specific to an individual <code> SceneForm </code> are indicated in 
 *  the corresponding <code> CreateScene. </code> <code> CreateScenes </code> 
 *  may be linked to the originating <code> SceneForm </code> through the 
 *  <code> SceneForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> SceneForms </code> are requested to the <code> 
 *  Scene </code> <code> Id </code> that is to be updated using <code> 
 *  getSceneFormsForUpdate() </code> where the reference <code> Id </code> in 
 *  the <code> SceneForm </code> may be used to link the request. Similarly, 
 *  the <code> SceneForm </code> has metadata about the data that can be 
 *  updated and it can perform validation before submitting the update. The 
 *  <code> SceneForm </code> can only be used once for a successful update and 
 *  cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> SceneForms </code> are submitted for update, an 
 *  <code> UpdateScene </code> is returned for each <code> SceneForm, </code> 
 *  although the ordering is not defined. Only errors that pertain to the 
 *  entire update operation are returned from <code> updateScenes(), </code> 
 *  errors specific to an individual <code> SceneForm </code> are indicated in 
 *  the corresponding <code> UpdateScene. </code> <code> UpdateScenes </code> 
 *  may be linked to the originating <code> SceneForm </code> through the 
 *  <code> SceneForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> Scenes </code> in bulk. To unmap a 
 *  <code> Scene </code> from the current <code> System, </code> the <code> 
 *  SceneSystemAssignmentSession </code> should be used. These delete 
 *  operations attempt to remove the <code> Scene </code> itself thus removing 
 *  it from all known <code> System </code> catalogs. Bulk delete operations 
 *  return the results in <code> DeleteScenes. </code> </p>
 */

public interface SceneBatchAdminSession
    extends org.osid.control.SceneAdminSession {


    /**
     *  Gets the scene forms for creating a bunch of new scenes. 
     *
     *  @param  n the number of forms to retrieve 
     *  @param  sceneRecordTypes array of scene record types to be included in 
     *          each create operation or an empty list if none 
     *  @return the scene forms 
     *  @throws org.osid.NullArgumentException <code> peers </code> or <code> 
     *          sceneRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.batch.SceneBatchFormList getSceneFormsForCreate(long n, 
                                                                            org.osid.type.Type[] sceneRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Scenes. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateScene </code> . 
     *
     *  @param  sceneForms the scene forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> sceneForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createScenes(org.osid.control.batch.SceneBatchFormList sceneForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the scene forms for updating an existing set of scenes. A new 
     *  scene form should be requested for each update transaction. 
     *
     *  @param  sceneIds the <code> Ids </code> of the <code> Scene </code> 
     *  @return the scene form 
     *  @throws org.osid.NotFoundException a <code> sceneId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> sceneIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.batch.SceneBatchFormList getSceneFormsForUpdate(org.osid.id.IdList sceneIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing scenes. This method returns an error if the entire 
     *  operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateScene </code> . 
     *
     *  @param  sceneForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> sceneForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateScenes(org.osid.control.batch.SceneBatchFormList sceneForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Scenes </code> in this <code> System. </code> 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllScenes()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes scenes for the given <code> Ids. </code> 
     *
     *  @param  sceneIds the <code> Ids </code> of the scenes to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> sceneIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteScenes(org.osid.id.IdList sceneIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Scene </code> for the purpose of 
     *  creating compatibility. The primary <code> Id </code> of the <code> 
     *  Scene </code> is determined by the provider. The new <code> Id </code> 
     *  is an alias to the primary <code> Id. </code> If the alias is a 
     *  pointer to another scene, it is reassigned to the given scene <code> 
     *  Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasScenes(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
