/**
 * <p>The Open Service Interface Definitions for the org.osid.control
 * service.</p>
 * 
 * <p>The Control OSID manages control systems. A system is comprised o <code> 
 * f Devices </code> whose <code> Controllers </code> are the control points. 
 * <code> Devices </code> have various <code> Input </code> mechanisms to 
 * command the <code> Controllers. </code> </p> 
 * <h4> Device </h4> 
 * 
 * <p> A <code> Device </code> represents some piece of visible equipment in a 
 * system. Example <code> Devices </code> are joysticks, yokes, and control 
 * panels. </p> 
 * <h4> Controller </h4> 
 * 
 * <p> A <code> Controller </code> is an <code> Operable </code> manages a 
 * specific responder in a system such as a model railroad gate, an airplane 
 * rudder, or the volume of a stereo. The management of a <code> Controller 
 * </code> includes on/off, variable amount values, or a set of States. A 
 * <code> Controller </code> is a black box. The Control OSID does not 
 * describe or manage system responders or how a Controller performs its 
 * tasks. </p> 
 * 
 * <p> </p> 
 * <h4> Inputs </h4> 
 * 
 * <p> An <code> Input </code> is an <code> OsidRelationship </code> between a 
 * <code> Device </code> and a <code> Controller. </code> A yoke may have 
 * several <code> Inputs. </code> One <code> Input </code> for push-pull that 
 * commands the <code> Controller </code> for the elevator, another <code> 
 * Input </code> for turning that commands the <code> Controller </code> for 
 * the ailerons, and another <code> Input </code> that commands the <code> 
 * Controller </code> for enabling and disabling auto-pilot. </p> 
 * <h4> Settings </h4> 
 * 
 * <p> A <code> Setting </code> captures fixed setting values for a <code> 
 * Controller. </code> A <code> Controller </code> for a sound system volume 
 * may have a variable amount <code> Setting </code> for LOUD and another 
 * variable amount <code> Setting </code> for SOFT. <code> Settings </code> 
 * are the basic building blocks for <code> Scenes. </code> </p> 
 * <h4> Scenes </h4> 
 * 
 * <p> A <code> Scen </code> e is a set of <code> Settings. </code> While a 
 * <code> Setting </code> is a value for a single <code> Controller, </code> 
 * <code> Scenes </code> apply values across a bunch of <code> Controllers. 
 * </code> Executing a movie theater <code> Scene </code> may set the light 
 * <code> Controllers </code> to dim values, close the curtains, and set the 
 * sound system vilume. </p> 
 * <h4> Triggers </h4> 
 * 
 * <p> <code> Triggers </code> are <code> OsidRules </code> used to perform 
 * actions in response to a value or state change in a <code> Controller. 
 * </code> <code> Triggers </code> have two parts. One part of the <code> 
 * Trigger </code> is the event listening criteria (fan turned on, light 
 * changed brightness). The second part of a <code> Trigger </code> is the 
 * execution that is to be performed when the event criteria is true. The 
 * <code> OsidRule </code> may encapsulate more complex event criteria. </p> 
 * 
 * <p> An example <code> Trigger </code> is when the motion sensor <code> 
 * Controller </code> is turned "on," the <code> Trigger </code> executes a 
 * <code> Setting </code> or a <code> Scene </code> that turns on the porch 
 * light. </p> 
 * 
 * <p> <code> Triggers </code> may execute <code> Scenes </code> or <code> 
 * Settings </code> directly. This is the simpler approach but does not allow 
 * for other rules or conditionals not expressable by a set of critera. <code> 
 * Triggers </code> may also execute <code> ActionGroups. </code> </p> 
 * <h4> Actions and ActionGroups </h4> 
 * 
 * <p> <code> ActionGroups </code> are a set of <code> Actions. </code> <code> 
 * Actions </code> are <code> OsidRules </code> to be executed. Built-in rules 
 * execute <code> Settings </code> or <code> Scenes. </code> These <code> 
 * OsidRules </code> may reference other actions or behaviors not directly 
 * described in the <code> Action. </code> </p> 
 * <h4> Settings, Scenes, and Actions </h4> 
 * 
 * <p> A <code> Setting </code> is a single state or value for a specific 
 * <code> Controller </code> used to build <code> Scenes </code> but may also 
 * be directly executed by a <code> Trigger </code> or <code> Action. </code> 
 * </p> 
 * 
 * <p> <code> Scenes </code> are a set of <code> Settings </code> used to set 
 * the state or values of multiple <code> Controllers </code> simultaneously 
 * and provide reusability of clusters of <code> Settings. </code> </p> 
 * 
 * <p> <code> ActionGroups </code> may be used with <code> Triggers </code> to 
 * achieve the same effect as a <code> Setting. </code> The difference between 
 * a set of <code> Actions </code> and a <code> Setting </code> are the 
 * presence of rules in the <code> Actions. </code> These rules may determine 
 * which <code> Actions </code> within an <code> ActionGroup </code> apply at 
 * tha time within a context. As such, each evaluation across an <code> 
 * ActionGroup </code> may result in different sets of executed <code> Actions 
 * </code> unlike <code> Scenes </code> whose complete set of <code> Settings 
 * </code> are known up front and may be thought of as a multicast group. </p> 
 * <h4> System Cataloging </h4> 
 * 
 * <p> All <code> Devices, </code> <code> Inputs, </code> <code> Controllers, 
 * </code> <code> Settings, </code> <code> Scenes, </code> <code> Triggers 
 * </code> , and <code> ActionGroups </code> may be organized into 
 * federateable <code> OsidCatalogs </code> called <code> Systems. </code> 
 * </p> 
 * <h4> Sub Packages </h4> 
 * 
 * <p> The Control OSID includes a Control Rules OSID for managing rules amd a 
 * Control Batch OSID for managing <code> Devices, </code> <code> Inputs, 
 * </code> <code> Controllers, </code> <code> Scenes, </code> <code> Settings, 
 * </code> <code> Triggers, </code> and <code> ActionGroups </code> in bulk. 
 * </p>
 * 
 * <br/><hr/><br/>
 * 
 * <p>Copyright &copy; 2013 Ingenescus. All Rights Reserved. </p>
 * 
 * <p>This Work is being provided by the copyright holder(s) subject to the 
 * following license. By obtaining, using and/or copying this Work, you agree 
 * that you have read, understand, and will comply with the following terms 
 * and conditions. </p> 
 * 
 * <p> Permission to use, copy and distribute unmodified versions of this 
 * Work, for any purpose, without fee or royalty is hereby granted, provided 
 * that you include the above copyright notices and the terms of this license 
 * on ALL copies of the Work or portions thereof. </p> 
 * 
 * <p> You may nodify or create Derivatives of this Work only for your 
 * internal purposes. You shall not distribute or transfer any such Derivative 
 * of this Work to any location or to any third party. For the purposes of 
 * this license, "Derivative" shall mean any derivative of the Work as defined 
 * in the United States Copyright Act of 1976, such as a translation or 
 * modification. </p> 
 * 
 * <p> This Work and the information contained herein is provided on an "AS 
 * IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT 
 * NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR 
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT 
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN 
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN 
 * CONNECTION WITH THE WORK OR THE USE OR OTHER DEALINGS IN THE WORK. </p> 
 * 
 * <p> The export of software employing encryption technology may require a 
 * specific license from the United States Government. It is the 
 * responsibility of any person or organization contemplating export to obtain 
 * such a license before exporting this Work. </p>
 */

package org.osid.control;
