//
// org.osid.control.rules.ControlRulesProfile
//
//     The OSID Java specification for org.osid.control.rules.ControlRulesProfile.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control.rules;


/**
 *  <p>The control rules profile describes the interoperability among control 
 *  rules services. </p>
 */

public interface ControlRulesProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any broker federation is exposed. Federation is exposed when 
     *  a specific broker may be identified, selected and used to create a 
     *  lookup or admin session. Federation is not exposed when a set of 
     *  brokers appears as a single broker. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if looking up device enablers is supported. 
     *
     *  @return <code> true </code> if device enabler lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDeviceEnablerLookup();


    /**
     *  Tests if querying device enablers is supported. 
     *
     *  @return <code> true </code> if device enabler query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDeviceEnablerQuery();


    /**
     *  Tests if searching device enablers is supported. 
     *
     *  @return <code> true </code> if device enabler search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDeviceEnablerSearch();


    /**
     *  Tests if a device enabler administrative service is supported. 
     *
     *  @return <code> true </code> if device enabler administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDeviceEnablerAdmin();


    /**
     *  Tests if a device enabler notification service is supported. 
     *
     *  @return <code> true </code> if device enabler notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDeviceEnablerNotification();


    /**
     *  Tests if a device enabler system lookup service is supported. 
     *
     *  @return <code> true </code> if a device enabler system lookup service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDeviceEnablerSystem();


    /**
     *  Tests if a device enabler system service is supported. 
     *
     *  @return <code> true </code> if device enabler system assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDeviceEnablerSystemAssignment();


    /**
     *  Tests if a device enabler system lookup service is supported. 
     *
     *  @return <code> true </code> if a device enabler system service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDeviceEnablerSmartSystem();


    /**
     *  Tests if looking up input enablers is supported. 
     *
     *  @return <code> true </code> if input enabler lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInputEnablerLookup();


    /**
     *  Tests if querying input enablers is supported. 
     *
     *  @return <code> true </code> if input enabler query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInputEnablerQuery();


    /**
     *  Tests if searching input enablers is supported. 
     *
     *  @return <code> true </code> if input enabler search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInputEnablerSearch();


    /**
     *  Tests if an input enabler administrative service is supported. 
     *
     *  @return <code> true </code> if input enabler administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInputEnablerAdmin();


    /**
     *  Tests if an input enabler notification service is supported. 
     *
     *  @return <code> true </code> if input enabler notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInputEnablerNotification();


    /**
     *  Tests if an input enabler system lookup service is supported. 
     *
     *  @return <code> true </code> if an input enabler system lookup service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInputEnablerSystem();


    /**
     *  Tests if an input enabler system service is supported. 
     *
     *  @return <code> true </code> if input enabler system assignment service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInputEnablerSystemAssignment();


    /**
     *  Tests if an input enabler system lookup service is supported. 
     *
     *  @return <code> true </code> if an input enabler system service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInputEnablerSmartSystem();


    /**
     *  Tests if an input enabler rule lookup service is supported. 
     *
     *  @return <code> true </code> if an processor enabler rule lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInputEnablerRuleLookup();


    /**
     *  Tests if an input enabler rule application service is supported. 
     *
     *  @return <code> true </code> if input enabler rule application service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInputEnablerRuleApplication();


    /**
     *  Tests if looking up trigger enablers is supported. 
     *
     *  @return <code> true </code> if trigger enabler lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTriggerEnablerLookup();


    /**
     *  Tests if querying trigger enablers is supported. 
     *
     *  @return <code> true </code> if trigger enabler query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTriggerEnablerQuery();


    /**
     *  Tests if searching trigger enablers is supported. 
     *
     *  @return <code> true </code> if trigger enabler search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTriggerEnablerSearch();


    /**
     *  Tests if a trigger enabler administrative service is supported. 
     *
     *  @return <code> true </code> if trigger enabler administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTriggerEnablerAdmin();


    /**
     *  Tests if a trigger enabler notification service is supported. 
     *
     *  @return <code> true </code> if trigger enabler notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTriggerEnablerNotification();


    /**
     *  Tests if a trigger enabler system lookup service is supported. 
     *
     *  @return <code> true </code> if a trigger enabler system lookup service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTriggerEnablerSystem();


    /**
     *  Tests if a trigger enabler system service is supported. 
     *
     *  @return <code> true </code> if trigger enabler system assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTriggerEnablerSystemAssignment();


    /**
     *  Tests if a trigger enabler system lookup service is supported. 
     *
     *  @return <code> true </code> if a trigger enabler system service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTriggerEnablerSmartSystem();


    /**
     *  Tests if a trigger enabler rule lookup service is supported. 
     *
     *  @return <code> true </code> if a trigger enabler rule lookup service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTriggerEnablerRuleLookup();


    /**
     *  Tests if a trigger enabler rule application service is supported. 
     *
     *  @return <code> true </code> if trigger enabler rule application 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTriggerEnablerRuleApplication();


    /**
     *  Tests if looking up action enablers is supported. 
     *
     *  @return <code> true </code> if action enabler lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActionEnablerLookup();


    /**
     *  Tests if querying action enablers is supported. 
     *
     *  @return <code> true </code> if action enabler query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActionEnablerQuery();


    /**
     *  Tests if searching action enablers is supported. 
     *
     *  @return <code> true </code> if action enabler search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActionEnablerSearch();


    /**
     *  Tests if an action enabler administrative service is supported. 
     *
     *  @return <code> true </code> if action enabler administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActionEnablerAdmin();


    /**
     *  Tests if an action enabler notification service is supported. 
     *
     *  @return <code> true </code> if action enabler notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActionEnablerNotification();


    /**
     *  Tests if an action enabler system lookup service is supported. 
     *
     *  @return <code> true </code> if an action enabler system lookup service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActionEnablerSystem();


    /**
     *  Tests if an action enabler system service is supported. 
     *
     *  @return <code> true </code> if action enabler system assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActionEnablerSystemAssignment();


    /**
     *  Tests if an action enabler system lookup service is supported. 
     *
     *  @return <code> true </code> if an action enabler system service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActionEnablerSmartSystem();


    /**
     *  Gets the supported <code> DeviceEnabler </code> record types. 
     *
     *  @return a list containing the supported <code> DeviceEnabler </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getDeviceEnablerRecordTypes();


    /**
     *  Tests if the given <code> DeviceEnabler </code> record type is 
     *  supported. 
     *
     *  @param  deviceEnablerRecordType a <code> Type </code> indicating a 
     *          <code> DeviceEnabler </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> deviceEnablerRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDeviceEnablerRecordType(org.osid.type.Type deviceEnablerRecordType);


    /**
     *  Gets the supported <code> DeviceEnabler </code> search record types. 
     *
     *  @return a list containing the supported <code> DeviceEnabler </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getDeviceEnablerSearchRecordTypes();


    /**
     *  Tests if the given <code> DeviceEnabler </code> search record type is 
     *  supported. 
     *
     *  @param  deviceEnablerSearchRecordType a <code> Type </code> indicating 
     *          a <code> DeviceEnabler </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          deviceEnablerSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDeviceEnablerSearchRecordType(org.osid.type.Type deviceEnablerSearchRecordType);


    /**
     *  Gets the supported <code> InputEnabler </code> record types. 
     *
     *  @return a list containing the supported <code> InputEnabler </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getInputEnablerRecordTypes();


    /**
     *  Tests if the given <code> InputEnabler </code> record type is 
     *  supported. 
     *
     *  @param  inputEnablerRecordType a <code> Type </code> indicating an 
     *          <code> InputEnabler </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> inputEnablerRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInputEnablerRecordType(org.osid.type.Type inputEnablerRecordType);


    /**
     *  Gets the supported <code> InputEnabler </code> search record types. 
     *
     *  @return a list containing the supported <code> InputEnabler </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getInputEnablerSearchRecordTypes();


    /**
     *  Tests if the given <code> InputEnabler </code> search record type is 
     *  supported. 
     *
     *  @param  inputEnablerSearchRecordType a <code> Type </code> indicating 
     *          an <code> InputEnabler </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          inputEnablerSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInputEnablerSearchRecordType(org.osid.type.Type inputEnablerSearchRecordType);


    /**
     *  Gets the supported <code> TriggerEnabler </code> record types. 
     *
     *  @return a list containing the supported <code> TriggerEnabler </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getTriggerEnablerRecordTypes();


    /**
     *  Tests if the given <code> TriggerEnabler </code> record type is 
     *  supported. 
     *
     *  @param  triggerEnablerRecordType a <code> Type </code> indicating a 
     *          <code> TriggerEnabler </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> triggerEnablerRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTriggerEnablerRecordType(org.osid.type.Type triggerEnablerRecordType);


    /**
     *  Gets the supported <code> TriggerEnabler </code> search record types. 
     *
     *  @return a list containing the supported <code> TriggerEnabler </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getTriggerEnablerSearchRecordTypes();


    /**
     *  Tests if the given <code> TriggerEnabler </code> search record type is 
     *  supported. 
     *
     *  @param  triggerEnablerSearchRecordType a <code> Type </code> 
     *          indicating a <code> TriggerEnabler </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          triggerEnablerSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTriggerEnablerSearchRecordType(org.osid.type.Type triggerEnablerSearchRecordType);


    /**
     *  Gets the supported <code> ActionEnabler </code> record types. 
     *
     *  @return a list containing the supported <code> ActionEnabler </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getActionEnablerRecordTypes();


    /**
     *  Tests if the given <code> ActionEnabler </code> record type is 
     *  supported. 
     *
     *  @param  actionEnablerRecordType a <code> Type </code> indicating an 
     *          <code> ActionEnabler </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> actionEnablerRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActionEnablerRecordType(org.osid.type.Type actionEnablerRecordType);


    /**
     *  Gets the supported <code> ActionEnabler </code> search record types. 
     *
     *  @return a list containing the supported <code> ActionEnabler </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getActionEnablerSearchRecordTypes();


    /**
     *  Tests if the given <code> ActionEnabler </code> search record type is 
     *  supported. 
     *
     *  @param  actionEnablerSearchRecordType a <code> Type </code> indicating 
     *          an <code> ActionEnabler </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          actionEnablerSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActionEnablerSearchRecordType(org.osid.type.Type actionEnablerSearchRecordType);
}
