//
// org.osid.control.rules.ControlRulesProxyManager
//
//     The OSID Java specification for org.osid.control.rules.ControlRulesProxyManager.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control.rules;


/**
 *  <p>The control rules proxy manager provides access to control rules 
 *  sessions and provides interoperability tests for various aspects of this 
 *  service. Methods in this manager pass a <code> Proxy </code> for passing 
 *  information from server environments. The sessions included in this 
 *  manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> DeviceEnablerLookupSession: </code> a session to retrieve 
 *      device enablers </li> 
 *      <li> <code> DeviceEnablerQuerySession: </code> a session to query for 
 *      device enablers </li> 
 *      <li> <code> DeviceEnablerSearchSession: </code> a session to search 
 *      for device enablers </li> 
 *      <li> <code> DeviceEnablerAdminSession: </code> a session to create and 
 *      delete device enablers </li> 
 *      <li> <code> DeviceEnablerNotificationSession: </code> a session to 
 *      receive notifications pertaining to device enabler changes </li> 
 *      <li> <code> DeviceEnablerSystemSession: </code> a session to look up 
 *      device enabler system mappings </li> 
 *      <li> <code> DeviceEnablerSystemAssignmentSession: </code> a session to 
 *      manage device enabler to system mappings </li> 
 *      <li> <code> DeviceEnablerSmartSystemSession: </code> a session to 
 *      manage dynamic systems of device enablers </li> 
 *      <li> <code> DeviceEnablerRuleLookupSession: </code> a session to look 
 *      up device enabler mappings </li> 
 *      <li> <code> DeviceEnablerRuleApplicationSession: </code> a session to 
 *      apply device enablers </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> InputEnablerLookupSession: </code> a session to retrieve 
 *      input enablers </li> 
 *      <li> <code> InputEnablerQuerySession: </code> a session to query for 
 *      input enablers </li> 
 *      <li> <code> InputEnablerSearchSession: </code> a session to search for 
 *      input enablers </li> 
 *      <li> <code> InputEnablerAdminSession: </code> a session to create and 
 *      delete input enablers </li> 
 *      <li> <code> InputEnablerNotificationSession: </code> a session to 
 *      receive notifications pertaining to input enabler changes </li> 
 *      <li> <code> InputEnablerSystemSession: </code> a session to look up 
 *      input enabler system mappings </li> 
 *      <li> <code> InputEnablerSystemAssignmentSession: </code> a session to 
 *      manage input enabler to system mappings </li> 
 *      <li> <code> InputEnablerSmartSystemSession: </code> a session to 
 *      manage dynamic systems of input enablers </li> 
 *      <li> <code> InputEnablerRuleLookupSession: </code> a session to look 
 *      up input enabler mappings </li> 
 *      <li> <code> InputEnablerRuleApplicationSession: </code> a session to 
 *      apply input enablers </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> TriggerEnablerLookupSession: </code> a session to retrieve 
 *      trigger enablers </li> 
 *      <li> <code> TriggerEnablerQuerySession: </code> a session to query for 
 *      trigger enablers </li> 
 *      <li> <code> TriggerEnablerSearchSession: </code> a session to search 
 *      for trigger enablers </li> 
 *      <li> <code> TriggerEnablerAdminSession: </code> a session to create 
 *      and delete trigger enablers </li> 
 *      <li> <code> TriggerEnablerNotificationSession: </code> a session to 
 *      receive notifications pertaining to trigger enabler changes </li> 
 *      <li> <code> TriggerEnablerSystemSession: </code> a session to look up 
 *      trigger enabler system mappings </li> 
 *      <li> <code> TriggerEnablerSystemAssignmentSession: </code> a session 
 *      to manage trigger enabler to system mappings </li> 
 *      <li> <code> TriggerEnablerSmartSystemSession: </code> a session to 
 *      manage dynamic systems of trigger enablers </li> 
 *      <li> <code> TriggerEnableRuleLookupSession: </code> a session to look 
 *      up trigger enabler mappings </li> 
 *      <li> <code> TriggerEnablerRuleApplicationSession: </code> a session to 
 *      apply trigger enablers </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> ActionEnablerLookupSession: </code> a session to retrieve 
 *      action enablers </li> 
 *      <li> <code> ActionEnablerQuerySession: </code> a session to query for 
 *      action enablers </li> 
 *      <li> <code> ActionEnablerSearchSession: </code> a session to search 
 *      for action enablers </li> 
 *      <li> <code> ActionEnablerAdminSession: </code> a session to create and 
 *      delete action enablers </li> 
 *      <li> <code> ActionEnablerNotificationSession: </code> a session to 
 *      receive notifications pertaining to action enabler changes </li> 
 *      <li> <code> ActionEnablerSystemSession: </code> a session to look up 
 *      action enabler system mappings </li> 
 *      <li> <code> ActionEnablerSystemAssignmentSession: </code> a session to 
 *      manage action enabler to system mappings </li> 
 *      <li> <code> ActionEnablerSmartSystemSession: </code> a session to 
 *      manage dynamic systems of action enablers </li> 
 *      <li> <code> ActionEnableRuleLookupSession: </code> a session to look 
 *      up action enabler mappings </li> 
 *      <li> <code> ActionEnablerRuleApplicationSession: </code> a session to 
 *      apply action enablers </li> 
 *  </ul>
 *  
 */

public interface ControlRulesProxyManager
    extends org.osid.OsidProxyManager,
            org.osid.control.rules.ControlRulesProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the device enabler 
     *  lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> DeviceEnablerLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDeviceEnablerLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDeviceEnablerLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.DeviceEnablerLookupSession getDeviceEnablerLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the device enabler 
     *  lookup service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @param  proxy a proxy 
     *  @return a <code> DeviceEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no System found by the given Id 
     *  @throws org.osid.NullArgumentException <code> systemId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDeviceEnablerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDeviceEnablerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.DeviceEnablerLookupSession getDeviceEnablerLookupSessionForSystem(org.osid.id.Id systemId, 
                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the device enabler 
     *  query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> DeviceEnablerQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDeviceEnablerQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDeviceEnablerQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.DeviceEnablerQuerySession getDeviceEnablerQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the device enabler 
     *  query service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @param  proxy a proxy 
     *  @return a <code> DeviceEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no System found by the given Id 
     *  @throws org.osid.NullArgumentException <code> systemId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDeviceEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDeviceEnablerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.DeviceEnablerQuerySession getDeviceEnablerQuerySessionForSystem(org.osid.id.Id systemId, 
                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the device enabler 
     *  search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> DeviceEnablerSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDeviceEnablerSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDeviceEnablerSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.DeviceEnablerSearchSession getDeviceEnablerSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the device 
     *  enablers earch service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @param  proxy a proxy 
     *  @return a <code> DeviceEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no System found by the given Id 
     *  @throws org.osid.NullArgumentException <code> systemId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDeviceEnablerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDeviceEnablerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.DeviceEnablerSearchSession getDeviceEnablerSearchSessionForSystem(org.osid.id.Id systemId, 
                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the device enabler 
     *  administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> DeviceEnablerAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDeviceEnablerAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDeviceEnablerAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.DeviceEnablerAdminSession getDeviceEnablerAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the device enabler 
     *  administration service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @param  proxy a proxy 
     *  @return a <code> DeviceEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no System found by the given Id 
     *  @throws org.osid.NullArgumentException <code> systemId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDeviceEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDeviceEnablerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.DeviceEnablerAdminSession getDeviceEnablerAdminSessionForSystem(org.osid.id.Id systemId, 
                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the device enabler 
     *  notification service. 
     *
     *  @param  deviceEnablerReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> DeviceEnablerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> deviceEnablerReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDeviceEnablerNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDeviceEnablerNotification() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.control.rules.DeviceEnablerNotificationSession getDeviceEnablerNotificationSession(org.osid.control.rules.DeviceEnablerReceiver deviceEnablerReceiver, 
                                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the device enabler 
     *  notification service for the given system. 
     *
     *  @param  deviceEnablerReceiver the notification callback 
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @param  proxy a proxy 
     *  @return a <code> DeviceEnablerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no system found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> deviceEnablerReceiver, 
     *          systemId, </code> or <code> proxy </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDeviceEnablerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDeviceEnablerNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.DeviceEnablerNotificationSession getDeviceEnablerNotificationSessionForSystem(org.osid.control.rules.DeviceEnablerReceiver deviceEnablerReceiver, 
                                                                                                                org.osid.id.Id systemId, 
                                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup device enabler/system 
     *  mappings for device enablers. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> DeviceEnablerSystemSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDeviceEnablerSystem() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDeviceEnablerSystem() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.DeviceEnablerSystemSession getDeviceEnablerSystemSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning device 
     *  enablers to systems. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> DeviceEnablerSystemAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDeviceEnablerSystemAssignment() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDeviceEnablerSystemAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.control.rules.DeviceEnablerSystemAssignmentSession getDeviceEnablerSystemAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage device enabler smart 
     *  systems. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @param  proxy a proxy 
     *  @return a <code> DeviceEnablerSmartSystemSession </code> 
     *  @throws org.osid.NotFoundException no System found by the given Id 
     *  @throws org.osid.NullArgumentException <code> systemId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDeviceEnablerSmartSystem() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDeviceEnablerSmartSystem() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.DeviceEnablerSmartSystemSession getDeviceEnablerSmartSystemSession(org.osid.id.Id systemId, 
                                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the device enabler 
     *  mapping lookup service . 
     *
     *  @param  proxy a proxy 
     *  @return a <code> DeviceEnablerRuleLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDeviceEnablerRuleLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDeviceEnablerRuleLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.DeviceEnablerRuleLookupSession getDeviceEnablerRuleLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the device enabler 
     *  mapping lookup service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @param  proxy a proxy 
     *  @return a <code> DeviceEnablerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no System found by the given Id 
     *  @throws org.osid.NullArgumentException <code> systemId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDeviceEnablerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDeviceEnablerRuleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.DeviceEnablerRuleLookupSession getDeviceEnablerRuleLookupSessionForSystem(org.osid.id.Id systemId, 
                                                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the device enabler 
     *  assignment service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> DeviceEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDeviceEnablerRuleApplication() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDeviceEnablerRuleApplication() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.control.rules.DeviceEnablerRuleApplicationSession getDeviceEnablerRuleApplicationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the device enabler 
     *  assignment service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @param  proxy a proxy 
     *  @return a <code> DeviceEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no System found by the given Id 
     *  @throws org.osid.NullArgumentException <code> systemId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDeviceEnablerRuleApplication() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDeviceEnablerRuleApplication() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.DeviceEnablerRuleApplicationSession getDeviceEnablerRuleApplicationSessionForSystem(org.osid.id.Id systemId, 
                                                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the input enabler 
     *  lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> InputEnablerLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInputEnablerLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInputEnablerLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.InputEnablerLookupSession getInputEnablerLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the input enabler 
     *  lookup service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @param  proxy a proxy 
     *  @return an <code> InputEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no System found by the given Id 
     *  @throws org.osid.NullArgumentException <code> systemId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInputEnablerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInputEnablerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.InputEnablerLookupSession getInputEnablerLookupSessionForSystem(org.osid.id.Id systemId, 
                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the input enabler 
     *  query service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> InputEnablerQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInputEnablerQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInputEnablerQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.InputEnablerQuerySession getInputEnablerQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the input enabler 
     *  query service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @param  proxy a proxy 
     *  @return an <code> InputEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no System found by the given Id 
     *  @throws org.osid.NullArgumentException <code> systemId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInputEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInputEnablerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.InputEnablerQuerySession getInputEnablerQuerySessionForSystem(org.osid.id.Id systemId, 
                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the input enabler 
     *  search service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> InputEnablerSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInputEnablerSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInputEnablerSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.InputEnablerSearchSession getInputEnablerSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the input enablers 
     *  earch service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @param  proxy a proxy 
     *  @return an <code> InputEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no System found by the given Id 
     *  @throws org.osid.NullArgumentException <code> systemId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInputEnablerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInputEnablerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.InputEnablerSearchSession getInputEnablerSearchSessionForSystem(org.osid.id.Id systemId, 
                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the input enabler 
     *  administration service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> InputEnablerAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInputEnablerAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInputEnablerAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.InputEnablerAdminSession getInputEnablerAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the input enabler 
     *  administration service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @param  proxy a proxy 
     *  @return an <code> InputEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no System found by the given Id 
     *  @throws org.osid.NullArgumentException <code> systemId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInputEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInputEnablerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.InputEnablerAdminSession getInputEnablerAdminSessionForSystem(org.osid.id.Id systemId, 
                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the input enabler 
     *  notification service. 
     *
     *  @param  deviceProcessoEnablerReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return an <code> InputEnablerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          deviceProcessoEnablerReceiver </code> or <code> proxy </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInputEnablerNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInputEnablerNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.InputEnablerNotificationSession getInputEnablerNotificationSession(org.osid.control.rules.InputEnablerReceiver deviceProcessoEnablerReceiver, 
                                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the input enabler 
     *  notification service for the given system. 
     *
     *  @param  deviceProcessoEnablerReceiver the notification callback 
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @param  proxy a proxy 
     *  @return an <code> InputEnablerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no system found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          deviceProcessoEnablerReceiver, systemId, </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInputEnablerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInputEnablerNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.InputEnablerNotificationSession getInputEnablerNotificationSessionForSystem(org.osid.control.rules.InputEnablerReceiver deviceProcessoEnablerReceiver, 
                                                                                                              org.osid.id.Id systemId, 
                                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup input enabler/system 
     *  mappings for input enablers. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> InputEnablerSystemSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInputEnablerSystem() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInputEnablerSystem() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.InputEnablerSystemSession getInputEnablerSystemSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning input 
     *  enablers to systems. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> InputEnablerSystemAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInputEnablerSystemAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInputEnablerSystemAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.control.rules.InputEnablerSystemAssignmentSession getInputEnablerSystemAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage input enabler smart 
     *  systems. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @param  proxy a proxy 
     *  @return an <code> InputEnablerSmartSystemSession </code> 
     *  @throws org.osid.NotFoundException no System found by the given Id 
     *  @throws org.osid.NullArgumentException <code> systemId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInputEnablerSmartSystem() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInputEnablerSmartSystem() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.InputEnablerSmartSystemSession getInputEnablerSmartSystemSession(org.osid.id.Id systemId, 
                                                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the input enabler 
     *  mapping lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> InputEnablerRuleLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInputEnablerRuleLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInputEnablerRuleLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.InputEnablerRuleLookupSession getInputEnablerRuleLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the input enabler 
     *  mapping lookup service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @param  proxy a proxy 
     *  @return an <code> InputEnablerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no System found by the given Id 
     *  @throws org.osid.NullArgumentException <code> systemId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInputEnablerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInputEnablerRuleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.InputEnablerRuleLookupSession getInputEnablerRuleLookupSessionForSystem(org.osid.id.Id systemId, 
                                                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the input enabler 
     *  assignment service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> InputEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInputEnablerRuleApplication() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInputEnablerRuleApplication() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.control.rules.InputEnablerRuleApplicationSession getInputEnablerRuleApplicationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the input enabler 
     *  assignment service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @param  proxy a proxy 
     *  @return an <code> InputEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no System found by the given Id 
     *  @throws org.osid.NullArgumentException <code> systemId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInputEnablerRuleApplication() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInputEnablerRuleApplication() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.InputEnablerRuleApplicationSession getInputEnablerRuleApplicationSessionForSystem(org.osid.id.Id systemId, 
                                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the trigger 
     *  enabler lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> TriggerEnablerLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTriggerEnablerLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTriggerEnablerLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.TriggerEnablerLookupSession getTriggerEnablerLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the trigger 
     *  enabler lookup service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @param  proxy a proxy 
     *  @return a <code> TriggerEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no System found by the given Id 
     *  @throws org.osid.NullArgumentException <code> systemId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTriggerEnablerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTriggerEnablerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.TriggerEnablerLookupSession getTriggerEnablerLookupSessionForSystem(org.osid.id.Id systemId, 
                                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the trigger 
     *  enabler query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> TriggerEnablerQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTriggerEnablerQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTriggerEnablerQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.TriggerEnablerQuerySession getTriggerEnablerQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the trigger 
     *  enabler query service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @param  proxy a proxy 
     *  @return a <code> TriggerEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no System found by the given Id 
     *  @throws org.osid.NullArgumentException <code> systemId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTriggerEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTriggerEnablerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.TriggerEnablerQuerySession getTriggerEnablerQuerySessionForSystem(org.osid.id.Id systemId, 
                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the trigger 
     *  enabler search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> TriggerEnablerSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTriggerEnablerSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTriggerEnablerSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.TriggerEnablerSearchSession getTriggerEnablerSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the trigger 
     *  enablers earch service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @param  proxy a proxy 
     *  @return a <code> TriggerEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no System found by the given Id 
     *  @throws org.osid.NullArgumentException <code> systemId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTriggerEnablerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTriggerEnablerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.TriggerEnablerSearchSession getTriggerEnablerSearchSessionForSystem(org.osid.id.Id systemId, 
                                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the trigger 
     *  enabler administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> TriggerEnablerAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTriggerEnablerAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTriggerEnablerAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.TriggerEnablerAdminSession getTriggerEnablerAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the trigger 
     *  enabler administration service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @param  proxy a proxy 
     *  @return a <code> TriggerEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no System found by the given Id 
     *  @throws org.osid.NullArgumentException <code> systemId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTriggerEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTriggerEnablerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.TriggerEnablerAdminSession getTriggerEnablerAdminSessionForSystem(org.osid.id.Id systemId, 
                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the trigger 
     *  enabler notification service. 
     *
     *  @param  triggerEnablerReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> TriggerEnablerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> triggerEnablerReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTriggerEnablerNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTriggerEnablerNotification() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.control.rules.TriggerEnablerNotificationSession getTriggerEnablerNotificationSession(org.osid.control.rules.TriggerEnablerReceiver triggerEnablerReceiver, 
                                                                                                         org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the trigger 
     *  enabler notification service for the given system. 
     *
     *  @param  triggerEnablerReceiver the notification callback 
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @param  proxy a proxy 
     *  @return a <code> TriggerEnablerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no system found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> triggerEnablerReceiver, 
     *          systemId, </code> or <code> proxy </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTriggerEnablerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTriggerEnablerNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.TriggerEnablerNotificationSession getTriggerEnablerNotificationSessionForSystem(org.osid.control.rules.TriggerEnablerReceiver triggerEnablerReceiver, 
                                                                                                                  org.osid.id.Id systemId, 
                                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup trigger enabler/system 
     *  mappings for trigger enablers. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> TriggerEnablerSystemSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTriggerEnablerSystem() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTriggerEnablerSystem() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.TriggerEnablerSystemSession getTriggerEnablerSystemSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning trigger 
     *  enablers to systems. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> TriggerEnablerSystemAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTriggerEnablerSystemAssignment() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTriggerEnablerSystemAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.control.rules.TriggerEnablerSystemAssignmentSession getTriggerEnablerSystemAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage trigger enabler smart 
     *  systems. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @param  proxy a proxy 
     *  @return a <code> TriggerEnablerSmartSystemSession </code> 
     *  @throws org.osid.NotFoundException no System found by the given Id 
     *  @throws org.osid.NullArgumentException <code> systemId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTriggerEnablerSmartSystem() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTriggerEnablerSmartSystem() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.control.rules.TriggerEnablerSmartSystemSession getTriggerEnablerSmartSystemSession(org.osid.id.Id systemId, 
                                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the trigger 
     *  enabler mapping lookup service . 
     *
     *  @param  proxy a proxy 
     *  @return a <code> TriggerEnablerRuleLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTriggerEnablerRuleLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTriggerEnablerRuleLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.TriggerEnablerRuleLookupSession getTriggerEnablerRuleLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the trigger 
     *  enabler mapping lookup service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @param  proxy a proxy 
     *  @return a <code> TriggerEnablerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no System found by the given Id 
     *  @throws org.osid.NullArgumentException <code> systemId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTriggerEnablerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTriggerEnablerRuleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.TriggerEnablerRuleLookupSession getTriggerEnablerRuleLookupSessionForSystem(org.osid.id.Id systemId, 
                                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the trigger 
     *  enabler assignment service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> TriggerEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTriggerEnablerRuleApplication() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTriggerEnablerRuleApplication() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.control.rules.TriggerEnablerRuleApplicationSession getTriggerEnablerRuleApplicationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the trigger 
     *  enabler assignment service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @param  proxy a proxy 
     *  @return a <code> TriggerEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no System found by the given Id 
     *  @throws org.osid.NullArgumentException <code> systemId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTriggerEnablerRuleApplication() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTriggerEnablerRuleApplication() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.TriggerEnablerRuleApplicationSession getTriggerEnablerRuleApplicationSessionForSystem(org.osid.id.Id systemId, 
                                                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the action enabler 
     *  lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> ActionEnablerLookupSession </code> 
     *  @throws org.osid.NullArgumentException an <code> 
     *          ActionEnablerLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActionEnablerLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActionEnablerLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.ActionEnablerLookupSession getActionEnablerLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the action enabler 
     *  lookup service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @param  proxy a proxy 
     *  @return an <code> ActionEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> System </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> systemId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActionEnablerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActionEnablerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.ActionEnablerLookupSession getActionEnablerLookupSessionForSystem(org.osid.id.Id systemId, 
                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the action enabler 
     *  query service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> ActionEnablerQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActionEnablerQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActionEnablerQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.ActionEnablerQuerySession getActionEnablerQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the action enabler 
     *  query service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @param  proxy a proxy 
     *  @return an <code> ActionEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> System </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> systemId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActionEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActionEnablerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.ActionEnablerQuerySession getActionEnablerQuerySessionForSystem(org.osid.id.Id systemId, 
                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the action enabler 
     *  search service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> ActionEnablerSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActionEnablerSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActionEnablerSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.ActionEnablerSearchSession getActionEnablerSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the action 
     *  enablers earch service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @param  proxy a proxy 
     *  @return an <code> ActionEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> System </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> systemId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActionEnablerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActionEnablerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.ActionEnablerSearchSession getActionEnablerSearchSessionForSystem(org.osid.id.Id systemId, 
                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the action enabler 
     *  administration service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> ActionEnablerAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActionEnablerAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActionEnablerAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.ActionEnablerAdminSession getActionEnablerAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the action enabler 
     *  administration service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @param  proxy a proxy 
     *  @return an <code> ActionEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> System </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> systemId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActionEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActionEnablerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.ActionEnablerAdminSession getActionEnablerAdminSessionForSystem(org.osid.id.Id systemId, 
                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the action enabler 
     *  notification service. 
     *
     *  @param  actionEnablerReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return an <code> ActionEnablerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> actionEnablerReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActionEnablerNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActionEnablerNotification() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.control.rules.ActionEnablerNotificationSession getActionEnablerNotificationSession(org.osid.control.rules.ActionEnablerReceiver actionEnablerReceiver, 
                                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the action enabler 
     *  notification service for the given system. 
     *
     *  @param  actionEnablerReceiver the notification callback 
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @param  proxy a proxy 
     *  @return an <code> ActionEnablerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no system found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> actionEnablerReceiver, 
     *          systemId </code> or <code> proxy </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActionEnablerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActionEnablerNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.ActionEnablerNotificationSession getActionEnablerNotificationSessionForSystem(org.osid.control.rules.ActionEnablerReceiver actionEnablerReceiver, 
                                                                                                                org.osid.id.Id systemId, 
                                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup action enabler/system 
     *  mappings for action enablers. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> ActionEnablerSystemSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActionEnablerSystem() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActionEnablerSystem() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.ActionEnablerSystemSession getActionEnablerSystemSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning action 
     *  enablers to systems. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> ActionEnablerSystemAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActionEnablerSystemAssignment() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActionEnablerSystemAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.control.rules.ActionEnablerSystemAssignmentSession getActionEnablerSystemAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage action enabler smart 
     *  systems. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @param  proxy a proxy 
     *  @return an <code> ActionEnablerSmartSystemSession </code> 
     *  @throws org.osid.NotFoundException no <code> System </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> systemId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActionEnablerSmartSystem() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActionEnablerSmartSystem() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.ActionEnablerSmartSystemSession getActionEnablerSmartSystemSession(org.osid.id.Id systemId, 
                                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the action enabler 
     *  mapping lookup service . 
     *
     *  @param  proxy a proxy 
     *  @return an <code> ActionEnablerRuleLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActionEnablerRuleLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActionEnablerRuleLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.ActionEnablerRuleLookupSession getActionEnablerRuleLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the action enabler 
     *  mapping lookup service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @param  proxy a proxy 
     *  @return an <code> ActionEnablerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> System </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> systemId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActionEnablerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActionEnablerRuleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.ActionEnablerRuleLookupSession getActionEnablerRuleLookupSessionForSystem(org.osid.id.Id systemId, 
                                                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the action enabler 
     *  assignment service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> ActionEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActionEnablerRuleApplication() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActionEnablerRuleApplication() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.control.rules.ActionEnablerRuleApplicationSession getActionEnablerRuleApplicationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the action enabler 
     *  assignment service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @param  proxy a proxy 
     *  @return an <code> ActionEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> System </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActionEnablerRuleApplication() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActionEnablerRuleApplication() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.control.rules.ActionEnablerRuleApplicationSession getActionEnablerRuleApplicationSessionForSystem(org.osid.id.Id systemId, 
                                                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;
}
