//
// org.osid.control.rules.DeviceEnablerRuleApplicationSession
//
//     The OSID Java specification for org.osid.control.rules.DeviceEnablerRuleApplicationSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control.rules;


/**
 *  <p>This session provides methods to apply <code> DeviceEnablers </code> to 
 *  <code> Devices. </code> A <code> Device </code> with multiple <code> 
 *  DeviceEnablers </code> means any positive rule evaluation across the 
 *  enablers result in an active <code> Device. </code> </p>
 */

public interface DeviceEnablerRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> System </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> System Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getSystemId();


    /**
     *  Gets the <code> System </code> associated with this session. 
     *
     *  @return the system 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.System getSystem()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter device enabler/device mappings. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignDeviceEnablers();


    /**
     *  Adds an existing <code> DeviceEnabler </code> to a <code> Device. 
     *  </code> 
     *
     *  @param  deviceEnablerId the <code> Id </code> of the <code> 
     *          DeviceEnabler </code> 
     *  @param  deviceId the <code> Id </code> of the <code> Device </code> 
     *  @throws org.osid.AlreadyExistsException <code> deviceEnablerId </code> 
     *          already applied to <code> deviceId </code> 
     *  @throws org.osid.NotFoundException <code> deviceEnablerId </code> or 
     *          <code> deviceId </code> not found 
     *  @throws org.osid.NullArgumentException <code> deviceEnablerId </code> 
     *          or <code> deviceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignDeviceEnablerToDevice(org.osid.id.Id deviceEnablerId, 
                                            org.osid.id.Id deviceId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> DeviceEnabler </code> from a <code> Device. </code> 
     *
     *  @param  deviceEnablerId the <code> Id </code> of the <code> 
     *          DeviceEnabler </code> 
     *  @param  deviceId the <code> Id </code> of the <code> Device </code> 
     *  @throws org.osid.NotFoundException <code> deviceEnablerId </code> or 
     *          <code> deviceId </code> not found or <code> deviceEnablerId 
     *          </code> not applied to <code> deviceId </code> 
     *  @throws org.osid.NullArgumentException <code> deviceEnablerId </code> 
     *          or <code> deviceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignDeviceEnablerFromDevice(org.osid.id.Id deviceEnablerId, 
                                                org.osid.id.Id deviceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> DeviceEnablers. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known sequencing operations will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> DeviceEnabler </code> ordering 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceDeviceEnablers();


    /**
     *  Reorders device enablers for a device by moving the specified device 
     *  enabler in front of a reference device enabler. 
     *
     *  @param  deviceEnablerId the <code> Id </code> of a <code> 
     *          DeviceEnabler </code> 
     *  @param  deviceId the <code> Id </code> of a <code> Device </code> 
     *  @param  referenceId the reference device enabler <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> deviceEnablerId, deviceId, 
     *          </code> or <code> referenceId </code> not found or, <code> 
     *          deviceEnablerId </code> or <code> referenceId </code> not 
     *          related to <code> deviceId </code> 
     *  @throws org.osid.NullArgumentException <code> deviceEnablerId, 
     *          deviceId, </code> or <code> referenceId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveDeviceEnablerAhead(org.osid.id.Id deviceEnablerId, 
                                       org.osid.id.Id deviceId, 
                                       org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders device enablers for a device by moving the specified device 
     *  enabler behind a reference device enabler. 
     *
     *  @param  deviceEnablerId the <code> Id </code> of a <code> 
     *          DeviceEnabler </code> 
     *  @param  deviceId the <code> Id </code> of a <code> Device </code> 
     *  @param  referenceId the reference device enabler <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> deviceEnablerId, deviceId, 
     *          </code> or <code> referenceId </code> not found or, <code> 
     *          deviceEnablerId </code> or <code> referenceId </code> not 
     *          related to <code> deviceId </code> 
     *  @throws org.osid.NullArgumentException <code> deviceEnablerId, 
     *          deviceId, </code> or <code> referenceId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveDeviceEnablerBehind(org.osid.id.Id deviceEnablerId, 
                                        org.osid.id.Id deviceId, 
                                        org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of device enablers for a device. 
     *
     *  @param  deviceEnablerIds the <code> Ids </code> for a set of <code> 
     *          DeviceEnablers </code> 
     *  @param  deviceId the <code> Id </code> of a <code> Device </code> 
     *  @throws org.osid.NotFoundException <code> deviceConstraienrId </code> 
     *          not found or, a <code> deviceEnablerId </code> not related to 
     *          <code> deviceId </code> 
     *  @throws org.osid.NullArgumentException <code> deviceEnablerIds </code> 
     *          or <code> deviceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderDeviceEnablers(org.osid.id.Id[] deviceEnablerIds, 
                                    org.osid.id.Id deviceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
