//
// org.osid.control.rules.InputEnablerSearch
//
//     The OSID Java specification for org.osid.control.rules.InputEnablerSearch.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control.rules;


/**
 *  <p>The search interface for governing input enabler searches. </p>
 */

public interface InputEnablerSearch
    extends org.osid.OsidSearch {


    /**
     *  Execute this search among the given list of input enablers. 
     *
     *  @param  inputEnablerIds list of input enablers 
     *  @throws org.osid.NullArgumentException <code> inputEnablerIds </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void searchAmongInputEnablers(org.osid.id.IdList inputEnablerIds);


    /**
     *  Specify an ordering to the search results. 
     *
     *  @param  inputEnablerSearchOrder input enabler search order 
     *  @throws org.osid.NullArgumentException <code> inputEnablerSearchOrder 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> inputEnablerSearchOrder 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderInputEnablerResults(org.osid.control.rules.InputEnablerSearchOrder inputEnablerSearchOrder);


    /**
     *  Gets the input enabler search record corresponding to the given input 
     *  enabler search record <code> Type. </code> This method is used to 
     *  retrieve an object implementing the requested record. 
     *
     *  @param  inputEnablerSearchRecordType an input enabler search record 
     *          type 
     *  @return the input enabler search record 
     *  @throws org.osid.NullArgumentException <code> 
     *          inputEnablerSearchRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(inputEnablerSearchRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.rules.records.InputEnablerSearchRecord getInputEnablerSearchRecord(org.osid.type.Type inputEnablerSearchRecordType)
        throws org.osid.OperationFailedException;
}
