//
// org.osid.control.rules.TriggerEnablerAdminSession
//
//     The OSID Java specification for org.osid.control.rules.TriggerEnablerAdminSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control.rules;


/**
 *  <p>This session creates and removes trigger enablers. The data for create 
 *  and update is provided via the <code> TriggerEnablerForm. </code> </p>
 */

public interface TriggerEnablerAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> System </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> System Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getSystemId();


    /**
     *  Gets the <code> System </code> associated with this session. 
     *
     *  @return the system 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.System getSystem()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create trigger enablers. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known creating a <code> TriggerEnabler </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer create operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> TriggerEnabler </code> creation 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateTriggerEnabler();


    /**
     *  Tests if this user can create a single <code> TriggerEnabler </code> 
     *  using the desired record types. While <code> 
     *  OfferingRulesManager.getTriggerEnablerRecordTypes() </code> can be 
     *  used to examine which records are supported, this method tests which 
     *  record(s) are required for creating a specific <code> TriggerEnabler. 
     *  </code> Providing an empty array tests if a <code> TriggerEnabler 
     *  </code> can be created with no records. 
     *
     *  @param  triggerEnablerRecordTypes array of trigger enabler record 
     *          types 
     *  @return <code> true </code> if <code> TriggerEnabler </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          triggerEnablerRecordTypes </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateTriggerEnablerWithRecordTypes(org.osid.type.Type[] triggerEnablerRecordTypes);


    /**
     *  Gets the trigger enabler form for creating new trigger enablers. A new 
     *  form should be requested for each create transaction. 
     *
     *  @param  triggerEnablerRecordTypes array of trigger enabler record 
     *          types 
     *  @return the trigger enabler form 
     *  @throws org.osid.NullArgumentException <code> 
     *          triggerEnablerRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.rules.TriggerEnablerForm getTriggerEnablerFormForCreate(org.osid.type.Type[] triggerEnablerRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> TriggerEnabler. </code> 
     *
     *  @param  triggerEnablerForm the form for this <code> TriggerEnabler 
     *          </code> 
     *  @return the new <code> TriggerEnabler </code> 
     *  @throws org.osid.IllegalStateException <code> triggerEnablerForm 
     *          </code> already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> triggerEnablerForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> triggerEnablerForm did 
     *          not originate from getTriggerEnablerFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.rules.TriggerEnabler createTriggerEnabler(org.osid.control.rules.TriggerEnablerForm triggerEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update trigger enablers. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known updating a <code> TriggerEnabler </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer update operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> TriggerEnabler </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateTriggerEnablers();


    /**
     *  Gets the trigger enabler form for updating an existing trigger 
     *  enabler. A new trigger enabler form should be requested for each 
     *  update transaction. 
     *
     *  @param  triggerEnablerId the <code> Id </code> of the <code> 
     *          TriggerEnabler </code> 
     *  @return the trigger enabler form 
     *  @throws org.osid.NotFoundException <code> triggerEnablerId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> triggerEnablerId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.rules.TriggerEnablerForm getTriggerEnablerFormForUpdate(org.osid.id.Id triggerEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing trigger enabler. 
     *
     *  @param  triggerEnablerForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> triggerEnablerForm 
     *          </code> already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> triggerEnablerForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> triggerEnablerForm 
     *          </code> did not originate from <code> 
     *          getTriggerEnablerFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateTriggerEnabler(org.osid.control.rules.TriggerEnablerForm triggerEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete trigger enablers. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known deleting a <code> TriggerEnabler </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer delete operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> TriggerEnabler </code> deletion 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteTriggerEnablers();


    /**
     *  Deletes a <code> TriggerEnabler. </code> 
     *
     *  @param  triggerEnablerId the <code> Id </code> of the <code> 
     *          TriggerEnabler </code> to remove 
     *  @throws org.osid.NotFoundException <code> triggerEnablerId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> triggerEnablerId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteTriggerEnabler(org.osid.id.Id triggerEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for trigger 
     *  enablers. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> TriggerEnabler </code> aliasing 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageTriggerEnablerAliases();


    /**
     *  Adds an <code> Id </code> to a <code> TriggerEnabler </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> TriggerEnabler </code> is determined by the provider. The 
     *  new <code> Id </code> performs as an alias to the primary <code> Id 
     *  </code> . If the alias is a pointer to another trigger enabler. it is 
     *  reassigned to the given trigger enabler <code> Id. </code> 
     *
     *  @param  triggerEnablerId the <code> Id </code> of a <code> 
     *          TriggerEnabler </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> triggerEnablerId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> triggerEnablerId </code> 
     *          or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasTriggerEnabler(org.osid.id.Id triggerEnablerId, 
                                    org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
