//
// org.osid.control.rules.TriggerEnablerRuleApplicationSession
//
//     The OSID Java specification for org.osid.control.rules.TriggerEnablerRuleApplicationSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control.rules;


/**
 *  <p>This session provides methods to apply <code> TriggerEnablers </code> 
 *  to <code> Triggers. </code> A <code> Trigger </code> with multiple <code> 
 *  TriggerEnablers </code> means any positive rule evaluation across the 
 *  enablers result in an effective <code> Trigger. </code> </p>
 */

public interface TriggerEnablerRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> System </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> System Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getSystemId();


    /**
     *  Gets the <code> System </code> associated with this session. 
     *
     *  @return the system 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.System getSystem()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter trigger enabler/trigger mappings. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignTriggerEnablers();


    /**
     *  Adds an existing <code> TriggerEnabler </code> to a <code> Trigger. 
     *  </code> 
     *
     *  @param  triggerEnablerId the <code> Id </code> of the <code> 
     *          TriggerEnabler </code> 
     *  @param  triggerId the <code> Id </code> of the <code> Trigger </code> 
     *  @throws org.osid.AlreadyExistsException <code> triggerEnablerId 
     *          </code> already applied to <code> triggerId </code> 
     *  @throws org.osid.NotFoundException <code> triggerEnablerId </code> or 
     *          <code> triggerId </code> not found 
     *  @throws org.osid.NullArgumentException <code> triggerEnablerId </code> 
     *          or <code> triggerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignTriggerEnablerToTrigger(org.osid.id.Id triggerEnablerId, 
                                              org.osid.id.Id triggerId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> TriggerEnabler </code> from a <code> Trigger. </code> 
     *
     *  @param  triggerEnablerId the <code> Id </code> of the <code> 
     *          TriggerEnabler </code> 
     *  @param  triggerId the <code> Id </code> of the <code> Trigger </code> 
     *  @throws org.osid.NotFoundException <code> triggerEnablerId </code> or 
     *          <code> triggerId </code> not found or <code> triggerEnablerId 
     *          </code> not applied to <code> triggerId </code> 
     *  @throws org.osid.NullArgumentException <code> triggerEnablerId </code> 
     *          or <code> triggerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignTriggerEnablerFromTrigger(org.osid.id.Id triggerEnablerId, 
                                                  org.osid.id.Id triggerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> TriggerEnablers. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known sequencing operations will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> TriggerEnabler </code> ordering 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceTriggerEnablers();


    /**
     *  Reorders trigger enablers for a trigger by moving the specified 
     *  trigger enabler in front of a reference trigger enabler. 
     *
     *  @param  triggerEnablerId the <code> Id </code> of a <code> 
     *          TriggerEnabler </code> 
     *  @param  triggerId the <code> Id </code> of a <code> Trigger </code> 
     *  @param  referenceId the reference trigger enabler <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> triggerEnablerId, triggerId, 
     *          </code> or <code> referenceId </code> not found or, <code> 
     *          triggerEnablerId </code> or <code> referenceId </code> not 
     *          related to <code> triggerId </code> 
     *  @throws org.osid.NullArgumentException <code> triggerEnablerId, 
     *          triggerId, </code> or <code> referenceId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveTriggerEnablerAhead(org.osid.id.Id triggerEnablerId, 
                                        org.osid.id.Id triggerId, 
                                        org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders trigger enablers for a device by moving the specified trigger 
     *  enabler behind a reference trigger enabler. 
     *
     *  @param  triggerEnablerId the <code> Id </code> of a <code> 
     *          TriggerEnabler </code> 
     *  @param  triggerId the <code> Id </code> of a <code> Trigger </code> 
     *  @param  referenceId the reference trigger enabler <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> triggerEnablerId, triggerId, 
     *          </code> or <code> referenceId </code> not found or, <code> 
     *          triggerEnablerId </code> or <code> referenceId </code> not 
     *          related to <code> triggerId </code> 
     *  @throws org.osid.NullArgumentException <code> triggerEnablerId, 
     *          triggerId, </code> or <code> referenceId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveTriggerEnablerBehind(org.osid.id.Id triggerEnablerId, 
                                         org.osid.id.Id triggerId, 
                                         org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of trigger enablers for a trigger. 
     *
     *  @param  triggerEnablerIds the <code> Ids </code> for a set of <code> 
     *          TriggerEnablers </code> 
     *  @param  triggerId the <code> Id </code> of a <code> Trigger </code> 
     *  @throws org.osid.NotFoundException <code> triggerId </code> not found 
     *          or, a <code> triggerEnablerId </code> not related to <code> 
     *          triggerId </code> 
     *  @throws org.osid.NullArgumentException <code> triggerEnablerIds 
     *          </code> or <code> triggerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderTriggerEnablers(org.osid.id.Id[] triggerEnablerIds, 
                                     org.osid.id.Id triggerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
