//
// org.osid.control.rules.TriggerEnablerSmartSystemSession
//
//     The OSID Java specification for org.osid.control.rules.TriggerEnablerSmartSystemSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control.rules;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  systems. A <code> TriggerEnablerQuery </code> can be retrieved from this 
 *  session and mapped to this <code> System </code> to create a virtual 
 *  collection of trigger enablers. The trigger enablers may be sequenced 
 *  using the <code> TriggerEnablerSearchOrder </code> from this session. </p> 
 *  
 *  <p> This <code> System </code> has a default query that matches any 
 *  trigger enabler and a default search order that specifies no sequencing. 
 *  The queries may be examined using a <code> TriggerEnablerQueryInspector. 
 *  </code> The query may be modified by converting the inspector back to a 
 *  <code> TriggerEnablerQuery. </code> </p>
 */

public interface TriggerEnablerSmartSystemSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> System </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> System Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getSystemId();


    /**
     *  Gets the <code> System </code> associated with this session. 
     *
     *  @return the system 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.System getSystem()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart systems. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart system management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartSystems();


    /**
     *  Gets a trigger enabler query. 
     *
     *  @return the trigger enabler query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.rules.TriggerEnablerQuery getTriggerEnablerQuery();


    /**
     *  Gets a trigger enabler search order. 
     *
     *  @return the trigger enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.rules.TriggerEnablerSearchOrder getTriggerEnablerSearchOrder();


    /**
     *  Applies a trigger enabler query to this system. 
     *
     *  @param  triggerEnablerQuery the trigger enabler query 
     *  @throws org.osid.NullArgumentException <code> triggerEnablerQuery 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> triggerEnablerQuery 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyTriggerEnablerQuery(org.osid.control.rules.TriggerEnablerQuery triggerEnablerQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a trigger enabler query inspector for this system. 
     *
     *  @return the trigger enabler query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.rules.TriggerEnablerQueryInspector inspectTriggerEnablerQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a trigger enabler search order to this system. 
     *
     *  @param  triggerEnablerSearchOrder the trigger enabler search order 
     *  @throws org.osid.NullArgumentException <code> 
     *          triggerEnablerSearchOrder </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> triggerEnablerSearchOrder 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyTriggerEnablerSequencing(org.osid.control.rules.TriggerEnablerSearchOrder triggerEnablerSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a trigger enabler query from an inspector. 
     *
     *  @param  triggerEnablerQueryInspector a trigger enabler query inspector 
     *  @return the trigger enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          triggerEnablerQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          triggerEnablerQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.rules.TriggerEnablerQuery getTriggerEnablerQueryFromInspector(org.osid.control.rules.TriggerEnablerQueryInspector triggerEnablerQueryInspector);
}
