//
// org.osid.course.Activity
//
//     The OSID Java specification for org.osid.course.Activity.
//
// Copyright (C) 2002-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course;


/**
 *  <p>An <code> Activity </code> represents a recurring activity of a course 
 *  offering. </p>
 */

public interface Activity
    extends org.osid.OsidRelationship,
            org.osid.Subjugateable {


    /**
     *  Gets the activity unit <code> Id </code> associated with this 
     *  activity. 
     *
     *  @return the activity unit <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getActivityUnitId();


    /**
     *  Gets the activity unit associated with this activity. 
     *
     *  @return the activity unit 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.ActivityUnit getActivityUnit()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the course offering <code> Id </code> associated with this 
     *  activity. 
     *
     *  @return the course offering <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCourseOfferingId();


    /**
     *  Gets the course offering associated with this activity. 
     *
     *  @return the course offering 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseOffering getCourseOffering()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of the <code> Term </code> of this 
     *  offering. 
     *
     *  @return the <code> Term </code> <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getTermId();


    /**
     *  Gets the <code> Term </code> of this offering. 
     *
     *  @return the term 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.Term getTerm()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this is a an implicit or explicit activity. 
     *
     *  @return <code> true </code> if this is an implicit activity, <code> 
     *          false </code> if an explicit activity 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isImplicit();


    /**
     *  Gets the schedule <code> Ids </code> associated with this activity. 
     *
     *  @return the schedule <code> Ids </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getScheduleIds();


    /**
     *  Gets the schedules associated with this activity. 
     *
     *  @return the schedules 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.ScheduleList getSchedules()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the superseding activity <code> Ids </code> whose sessions 
     *  override sessions of this activity. 
     *
     *  @return the superseding activity <code> Ids </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getSupersedingActivityIds();


    /**
     *  Gets the superseding activities whose sessions that override sessions 
     *  of this activity. 
     *
     *  @return the superseding activities 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.ActivityList getSupersedingActivities()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the specific meeting times added to this activity. 
     *
     *  @return a list of specific meeting times 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.MeetingTimeList getSpecificMeetingTimes();


    /**
     *  Gets the blackout dates for this activity. Activitiy sessions 
     *  overlapping with the time intervals do not appear in the series. 
     *
     *  @return the exceptions to the scheduled activity 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTimeIntervalList getBlackouts();


    /**
     *  Gets the instructor <code> Ids. </code> If each activity has its own 
     *  instructor, the headlining instructors may be returned. 
     *
     *  @return the instructor <code> Ids </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getInstructorIds();


    /**
     *  Gets the instructors. If each activity has its own instructor, the 
     *  headlining instructors may be returned. 
     *
     *  @return the sponsors 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceList getInstructors()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if registration is required. 
     *
     *  @return <code> true </code> if this is a registration is required, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean requiresRegistration();


    /**
     *  Gets the minimum number of students this activity can have. 
     *
     *  @return the minimum seats 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getMinimumSeats();


    /**
     *  Tests if seating is limited. 
     *
     *  @return <code> true </code> if this is a seating is limited, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isSeatingLimited();


    /**
     *  Gets the maximum number of students this activity can accommodate. 
     *
     *  @return the maximum seats 
     *  @throws org.osid.IllegalStateException <code> isSeatingLimited() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getMaximumSeats();


    /**
     *  Gets the total time required for this activity. 
     *
     *  @return the total effort 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Duration getTotalTargetEffort();


    /**
     *  Tests if this is a contact activity. 
     *
     *  @return <code> true </code> if this is a contact activity, <code> 
     *          false </code> if an independent activity 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isContact();


    /**
     *  Gets the total contact time for this activity. 
     *
     *  @return the total effort 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Duration getTotalTargetContactTime();


    /**
     *  Gets the total individual time required for this activity. 
     *
     *  @return the total individual effort 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Duration getTotalTargetIndividualEffort();


    /**
     *  Tests if this activity is recurring. 
     *
     *  @return <code> true </code> if this activity is recurring, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isRecurringWeekly();


    /**
     *  Gets the time required for this recurring effort on a weekly basis. 
     *
     *  @return the weekly time 
     *  @throws org.osid.IllegalStateException <code> isRecurringWeekly() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Duration getWeeklyEffort();


    /**
     *  Gets the weekly contact time for ths activity. 
     *
     *  @return the weekly time 
     *  @throws org.osid.IllegalStateException <code> isRecurringWeekly() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Duration getWeeklyContactTime();


    /**
     *  Gets the weekly individual time for ths activity. 
     *
     *  @return the weekly time 
     *  @throws org.osid.IllegalStateException <code> isRecurringWeekly() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Duration getWeeklyIndividualEffort();


    /**
     *  Gets the activity record corresponding to the given <code> Activity 
     *  </code> record <code> Type. </code> This method is used to retrieve an 
     *  object implementing the requested record. The <code> 
     *  activityRecordType </code> may be the <code> Type </code> returned in 
     *  <code> getRecordTypes() </code> or any of its parents in a <code> Type 
     *  </code> hierarchy where <code> hasRecordType(activityRecordType) 
     *  </code> is <code> true </code> . 
     *
     *  @param  activityRecordType the type of activity record to retrieve 
     *  @return the activity record 
     *  @throws org.osid.NullArgumentException <code> activityRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(activityRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.records.ActivityRecord getActivityRecord(org.osid.type.Type activityRecordType)
        throws org.osid.OperationFailedException;
}
