//
// org.osid.course.ActivityForm
//
//     The OSID Java specification for org.osid.course.ActivityForm.
//
// Copyright (C) 2002-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course;


/**
 *  <p>This is the form for creating and updating <code> Activities. </code> 
 *  Like all <code> OsidForm </code> objects, various data elements may be set 
 *  here for use in the create and update methods in the <code> 
 *  ActivityAdminSession. </code> For each data element that may be set, 
 *  metadata may be examined to provide display hints or data constraints. 
 *  </p>
 */

public interface ActivityForm
    extends org.osid.OsidRelationshipForm,
            org.osid.OsidSubjugateableForm {


    /**
     *  Gets the metadata for the instructors. 
     *
     *  @return metadata for the instructors 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getInstructorsMetadata();


    /**
     *  Sets the instructors. 
     *
     *  @param  resourceIds the new instructors 
     *  @throws org.osid.InvalidArgumentException <code> instructorIds </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> instructorIds </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setInstructors(org.osid.id.Id[] resourceIds);


    /**
     *  Removes the instructors. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearInstructors();


    /**
     *  Gets the metadata for the minimum seats. 
     *
     *  @return metadata for the minimum seats 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getMinimumSeatsMetadata();


    /**
     *  Sets the minimum seating count. 
     *
     *  @param  seats the new minimum seats 
     *  @throws org.osid.InvalidArgumentException <code> seats </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setMinimumSeats(long seats);


    /**
     *  Removes the minimum seats. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMinimumSeats();


    /**
     *  Gets the metadata for the maximum seats. 
     *
     *  @return metadata for the maximum seats 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getMaximumSeatsMetadata();


    /**
     *  Sets the maximum seating count. 
     *
     *  @param  seats the new maximum seats 
     *  @throws org.osid.InvalidArgumentException <code> seats </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setMaximumSeats(long seats);


    /**
     *  Removes the maximum seats. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMaximumSeats();


    /**
     *  Gets the metadata for the total effort. The amount may be calculated 
     *  from the other data. 
     *
     *  @return metadata for the total effort 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getTotalEffortMatadata();


    /**
     *  Sets the total effort. 
     *
     *  @param  time the new total effort 
     *  @throws org.osid.InvalidArgumentException <code> time </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> time </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setTotalTargetEffort(org.osid.calendaring.Duration time);


    /**
     *  Removes the total effort. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTotalTargetEffort();


    /**
     *  Gets the metadata for the contact flag. 
     *
     *  @return metadata for the contact 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getContactMetadata();


    /**
     *  Sets the contact flag. 
     *
     *  @param  contact the new contact flag 
     *  @throws org.osid.InvalidArgumentException <code> contact </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setContact(boolean contact);


    /**
     *  Removes the contact flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearContact();


    /**
     *  Gets the metadata for the total contact time. 
     *
     *  @return metadata for the total contact time 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getTotalTargetContactTimeMetadata();


    /**
     *  Sets the total contact time. 
     *
     *  @param  time the new total contact time 
     *  @throws org.osid.InvalidArgumentException <code> time </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> time </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setTotalTargetContactTime(org.osid.calendaring.Duration time);


    /**
     *  Removes the total contact time. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTotalTargetContactTime();


    /**
     *  Gets the metadata for the total individual effort. The amount may be 
     *  calculated from the other data. 
     *
     *  @return metadata for the total individual effort 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getTotalTargetIndividualEffortMetadata();


    /**
     *  Sets the total individual effort. 
     *
     *  @param  time the new total individual effort 
     *  @throws org.osid.InvalidArgumentException <code> time </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> time </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setTotalTargetIndividualEffort(org.osid.calendaring.Duration time);


    /**
     *  Removes the total individual effort. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTotalTargetIndividualEffort();


    /**
     *  Gets the metadata for the recurring weekly flag. 
     *
     *  @return metadata for the contact 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getRecurringWeeklyMetadata();


    /**
     *  Sets the recurring weekly flag. 
     *
     *  @param  recurring the new recurring weekly flag 
     *  @throws org.osid.InvalidArgumentException <code> recurring </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setRecurringWeekly(boolean recurring);


    /**
     *  Removes the recurring weekly flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRecurringWeekly();


    /**
     *  Gets the metadata for the weekly effort. The amount may be calculated 
     *  from the other data. 
     *
     *  @return metadata for the weekly effort 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getWeeklyEffortMetadata();


    /**
     *  Sets the weekly effort. 
     *
     *  @param  time the new weekly effort 
     *  @throws org.osid.InvalidArgumentException <code> time </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> time </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setWeeklyEffort(org.osid.calendaring.Duration time);


    /**
     *  Removes the weekly effort. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearWeeklyEffort();


    /**
     *  Gets the metadata for the weekly contact time. 
     *
     *  @return metadata for the weekly contact time 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getWeeklyContactTimeMetadata();


    /**
     *  Sets the weekly contact time. 
     *
     *  @param  time the new weekly contact time 
     *  @throws org.osid.InvalidArgumentException <code> time </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> time </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setWeeklyContactTime(org.osid.calendaring.Duration time);


    /**
     *  Removes the weekly contact time. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearWeeklyContactTime();


    /**
     *  Gets the metadata for the weekly individual effort. The amount may be 
     *  calculated from the other data. 
     *
     *  @return metadata for the weekly individual effort 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getWeeklyIndividualEffortMetadata();


    /**
     *  Sets the weekly individual effort. 
     *
     *  @param  time the new weekly individual effort 
     *  @throws org.osid.InvalidArgumentException <code> time </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> time </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setWeeklyIndividualEffort(org.osid.calendaring.Duration time);


    /**
     *  Removes the weekly individual effort. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearWeeklyIndividualEffort();


    /**
     *  Gets the <code> ActivityFormRecord </code> corresponding to the given 
     *  activity record <code> Type. </code> 
     *
     *  @param  activityRecordType an activity record type 
     *  @return the activity form record 
     *  @throws org.osid.NullArgumentException <code> activityRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(activityRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.records.ActivityFormRecord getActivityFormRecord(org.osid.type.Type activityRecordType)
        throws org.osid.OperationFailedException;
}
