//
// org.osid.course.ActivityQuery
//
//     The OSID Java specification for org.osid.course.ActivityQuery.
//
// Copyright (C) 2002-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course;


/**
 *  <p>This is the query for searching activities. Each method match specifies 
 *  an <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface ActivityQuery
    extends org.osid.OsidRelationshipQuery,
            org.osid.OsidSubjugateableQuery {


    /**
     *  Matches an activity that is implicitly generated. 
     *
     *  @param  match <code> true </code> to match activities implicitly 
     *          generated, <code> false </code> to match activities explicitly 
     *          defined 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchImplicit(boolean match);


    /**
     *  Clears the implcit terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearImplicitTerms();


    /**
     *  Sets the activity unit <code> Id </code> for this query. 
     *
     *  @param  activityUnitId an activity unit <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> activityUnitId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchActivityUnitId(org.osid.id.Id activityUnitId, 
                                    boolean match);


    /**
     *  Clears the activity unit <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearActivityUnitIdTerms();


    /**
     *  Tests if an <code> ActivityUnitQuery </code> is available. 
     *
     *  @return <code> true </code> if an activity unit query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityUnitQuery();


    /**
     *  Gets the query for an activity unit. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the activity unit query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActivityUnitQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityUnitQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.ActivityUnitQuery getActivityUnitQuery();


    /**
     *  Clears the activity unit terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearActivityUnitTerms();


    /**
     *  Sets the course offering <code> Id </code> for this query. 
     *
     *  @param  courseOfferingId a course offering <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> courseOfferingId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCourseOfferingId(org.osid.id.Id courseOfferingId, 
                                      boolean match);


    /**
     *  Clears the course offering <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCourseOfferingIdTerms();


    /**
     *  Tests if a <code> CourseOfferingQuery </code> is available. 
     *
     *  @return <code> true </code> if a course offering query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseOfferingQuery();


    /**
     *  Gets the query for a coure offering. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the course offering query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCourseOfferingQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCourseOfferingQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.CourseOfferingQuery getCourseOfferingQuery();


    /**
     *  Clears the course offering terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCourseOfferingTerms();


    /**
     *  Sets the term <code> Id </code> for this query to match course 
     *  offerings that have a related term. 
     *
     *  @param  termId a term <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> termId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchTermId(org.osid.id.Id termId, boolean match);


    /**
     *  Clears the term <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTermIdTerms();


    /**
     *  Tests if a <code> TermQuery </code> is available. 
     *
     *  @return <code> true </code> if a term query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTermQuery();


    /**
     *  Gets the query for a reporting term. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the term query 
     *  @throws org.osid.UnimplementedException <code> supportsTermQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTermQuery() </code> is <code> true. </code> 
     */

    public org.osid.course.TermQuery getTermQuery();


    /**
     *  Clears the term terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTermTerms();


    /**
     *  Matches activities where the given time falls within a denormalized 
     *  meeting time inclusive. 
     *
     *  @param  date a date 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMeetingTime(org.osid.calendaring.DateTime date, 
                                 boolean match);


    /**
     *  Clears the meeting time terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMeetingTimeTerms();


    /**
     *  Matches activities with any denormalized meeting time within the given 
     *  date range inclusive. 
     *
     *  @param  start a start date 
     *  @param  end an end date 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> start </code> is 
     *          greater than <code> end </code> 
     *  @throws org.osid.NullArgumentException <code> start </code> or <code> 
     *          end </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMeetingTimeInclusive(org.osid.calendaring.DateTime start, 
                                          org.osid.calendaring.DateTime end, 
                                          boolean match);


    /**
     *  Clears the meeting time inclusive terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMeetingTimeInclusiveTerms();


    /**
     *  Matches activities with any meeting location. 
     *
     *  @param  locationId a location <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> locationId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMeetingLocationId(org.osid.id.Id locationId, 
                                       boolean match);


    /**
     *  Clears the location <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMeetingLocationIdTerms();


    /**
     *  Tests if a <code> LocationQuery </code> is available. 
     *
     *  @return <code> true </code> if a location query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMeetingLocationQuery();


    /**
     *  Gets the query for a location. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the location query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsMeetingLocationQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMeetingLocationQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.mapping.LocationQuery getMeetingLocationQuery();


    /**
     *  Clears the location <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMeetingLocationTerms();


    /**
     *  Sets the schedule <code> Id </code> for this query. 
     *
     *  @param  scheduleId a schedule <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> scheduleId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchScheduleId(org.osid.id.Id scheduleId, boolean match);


    /**
     *  Clears the schedule <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearScheduleIdTerms();


    /**
     *  Tests if a <code> ScheduleQuery </code> is available. 
     *
     *  @return <code> true </code> if a schedule query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsScheduleQuery();


    /**
     *  Gets the query for a schedule. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the schedule query 
     *  @throws org.osid.UnimplementedException <code> supportsScheduleQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsScheduleQuery() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.ScheduleQuery getScheduleQuery();


    /**
     *  Matches an activity that has any schedule. 
     *
     *  @param  match <code> true </code> to match activitiies with any 
     *          schedule, <code> false </code> to match activitiies with no 
     *          schedule 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnySchedule(boolean match);


    /**
     *  Clears the schedule terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearScheduleTerms();


    /**
     *  Sets the superseding activity <code> Id </code> for this query. 
     *
     *  @param  activityId a superseding activity <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> activityId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSupersedingActivityId(org.osid.id.Id activityId, 
                                           boolean match);


    /**
     *  Clears the superseding activity <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSupersedingActivityIdTerms();


    /**
     *  Tests if an <code> ActivityQuery </code> is available. 
     *
     *  @return <code> true </code> if a superseding activity query is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSupersedingActivityQuery();


    /**
     *  Gets the query for a superseding activity. Multiple retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @return the superseding activity query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSupersedingActivityQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSupersedingActivityQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.ActivityQuery getSupersedingActivityQuery();


    /**
     *  Matches an activity that has any superseding activity. 
     *
     *  @param  match <code> true </code> to match activitiies with any 
     *          superseding activity, <code> false </code> to match 
     *          activitiies with no superseding activities 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnySupersedingActivity(boolean match);


    /**
     *  Clears the superseding activity terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSupersedingActivityTerms();


    /**
     *  Matches activities with specific dates between the given range 
     *  inclusive. 
     *
     *  @param  start start date 
     *  @param  end end date 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> end </code> is less 
     *          than <code> start </code> 
     *  @throws org.osid.NullArgumentException <code> start </code> or <code> 
     *          end </code> is <code> zero </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSpecificMeetingTime(org.osid.calendaring.DateTime start, 
                                         org.osid.calendaring.DateTime end, 
                                         boolean match);


    /**
     *  Matches an activity that has any specific date. 
     *
     *  @param  match <code> true </code> to match activitiies with any 
     *          specific date, <code> false </code> to match activitiies with 
     *          no specific dates 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnySpecificMeetingTime(boolean match);


    /**
     *  Clears the specific date terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSpecificMeetingTimeTerms();


    /**
     *  Matches activities containing the given blackout date. 
     *
     *  @param  date a date 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBlackout(org.osid.calendaring.DateTime date, 
                              boolean match);


    /**
     *  Matches an activity that has any blackout. 
     *
     *  @param  match <code> true </code> to match activitiies with any 
     *          blackout, <code> false </code> to match activitiies with no 
     *          blackouts 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyBlackout(boolean match);


    /**
     *  Clears all blackout terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBlackoutTerms();


    /**
     *  Matches activities with blackouts within the given date range 
     *  inclousive. 
     *
     *  @param  start a start date 
     *  @param  end an end date 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> start </code> is 
     *          greater than <code> end </code> 
     *  @throws org.osid.NullArgumentException <code> star </code> t or <code> 
     *          end </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBlackoutInclusive(org.osid.calendaring.DateTime start, 
                                       org.osid.calendaring.DateTime end, 
                                       boolean match);


    /**
     *  Clears all blackout inclusive terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBlackoutInclusiveTerms();


    /**
     *  Sets the resource <code> Id </code> for this query to match course 
     *  offerings that have an instructor. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchInstructorId(org.osid.id.Id resourceId, boolean match);


    /**
     *  Clears the instructor <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearInstructorIdTerms();


    /**
     *  Tests if a <code> ResourceQuery </code> is available. 
     *
     *  @return <code> true </code> if a resource query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInstructorQuery();


    /**
     *  Gets the query for an instructor. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return a resource query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInstructorQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInstructorQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceQuery getInstructorQuery();


    /**
     *  Matches course offerings that have any instructor. 
     *
     *  @param  match <code> true </code> to match course offerings with any 
     *          instructor, <code> false </code> to match course offerings 
     *          with no instructors 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyInstructor(boolean match);


    /**
     *  Clears the instructor terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearInstructorTerms();


    /**
     *  Matches activities with a minimum seating between the given numbers 
     *  inclusive. 
     *
     *  @param  min low number 
     *  @param  max high number 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> max </code> is less 
     *          than <code> min </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMinimumSeats(long min, long max, boolean match);


    /**
     *  Matches activities with any minimum seating assigned. 
     *
     *  @param  match <code> true </code> to match activities with any minimum 
     *          seating, <code> false </code> to match activities with no 
     *          minimum seating 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyMinimumSeats(boolean match);


    /**
     *  Clears the minimum seating terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMinimumSeatsTerms();


    /**
     *  Matches activities with a maximum seating between the given numbers 
     *  inclusive. 
     *
     *  @param  min low number 
     *  @param  max high number 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> max </code> is less 
     *          than <code> min </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMaximumSeats(long min, long max, boolean match);


    /**
     *  Matches activities with any maximum seating assigned. 
     *
     *  @param  match <code> true </code> to match activities with any maximum 
     *          seating, <code> false </code> to match activities with no 
     *          maximum seating 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyMaximumSeats(boolean match);


    /**
     *  Clears the maximum seating terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMaximumSeatsTerms();


    /**
     *  Matches activities with a total effort between the given durations 
     *  inclusive. 
     *
     *  @param  min low range 
     *  @param  max high range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> max </code> is less 
     *          than <code> min </code> 
     *  @throws org.osid.NullArgumentException <code> min </code> or <code> 
     *          max </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchTotalTargetEffort(org.osid.calendaring.Duration min, 
                                       org.osid.calendaring.Duration max, 
                                       boolean match);


    /**
     *  Matches an activity that has any total effort assigned. 
     *
     *  @param  match <code> true </code> to match activities with any total 
     *          effort, <code> false </code> to match activities with no total 
     *          effort 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyTotalTargetEffort(boolean match);


    /**
     *  Clears the total effort terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTotalTargetEffortTerms();


    /**
     *  Matches activities that are contact activities. 
     *
     *  @param  match <code> true </code> to match activities that have 
     *          contact, <code> false </code> to match activities with no 
     *          contact 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchContact(boolean match);


    /**
     *  Clears the contact terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearContactTerms();


    /**
     *  Matches activities with a total contact time between the given 
     *  durations inclusive. 
     *
     *  @param  min low range 
     *  @param  max high range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> max </code> is less 
     *          than <code> min </code> 
     *  @throws org.osid.NullArgumentException <code> min </code> or <code> 
     *          max </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchTotalTargetContactTime(org.osid.calendaring.Duration min, 
                                            org.osid.calendaring.Duration max, 
                                            boolean match);


    /**
     *  Matches an activity that has any total contact assigned. 
     *
     *  @param  match <code> true </code> to match activities with any total 
     *          contatc, <code> false </code> to match activities with no 
     *          total contact 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyTotalTargetContactTime(boolean match);


    /**
     *  Clears the total contact terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTotalTargetContactTimeTerms();


    /**
     *  Matches activities with a individual effort between the given 
     *  durations inclusive. 
     *
     *  @param  min low range 
     *  @param  max high range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> max </code> is less 
     *          than <code> min </code> 
     *  @throws org.osid.NullArgumentException <code> min </code> or <code> 
     *          max </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchTotalTargetIndividualEffort(org.osid.calendaring.Duration min, 
                                                 org.osid.calendaring.Duration max, 
                                                 boolean match);


    /**
     *  Matches an activity that has any individual effort assigned. 
     *
     *  @param  match <code> true </code> to match activities with any 
     *          individual effort, <code> false </code> to match activities 
     *          with no individual effort 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyTotalTargetIndividualEffort(boolean match);


    /**
     *  Clears the individual effort terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTotalTargetIndividualEffortTerms();


    /**
     *  Matches activities that recur weekly. 
     *
     *  @param  match <code> true </code> to match activities that recur 
     *          weekly, <code> false </code> to match activities with no 
     *          weekly recurrance 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRecurringWeekly(boolean match);


    /**
     *  Clears the recurring weekly terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRecurringWeeklyTerms();


    /**
     *  Matches activities with a weekly effort between the given durations 
     *  inclusive. 
     *
     *  @param  min low range 
     *  @param  max high range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> max </code> is less 
     *          than <code> min </code> 
     *  @throws org.osid.NullArgumentException <code> min </code> or <code> 
     *          max </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchWeeklyEffort(org.osid.calendaring.Duration min, 
                                  org.osid.calendaring.Duration max, 
                                  boolean match);


    /**
     *  Matches an activity that has any weekly effort assigned. 
     *
     *  @param  match <code> true </code> to match activities with any weekly 
     *          effort, <code> false </code> to match activities with no 
     *          weekly effort 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyWeeklyEffort(boolean match);


    /**
     *  Clears the weekly effort terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearWeeklyEffortTerms();


    /**
     *  Matches activities with a weekly contact time between the given 
     *  durations inclusive. 
     *
     *  @param  min low range 
     *  @param  max high range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> max </code> is less 
     *          than <code> min </code> 
     *  @throws org.osid.NullArgumentException <code> min </code> or <code> 
     *          max </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchWeeklyContactTime(org.osid.calendaring.Duration min, 
                                       org.osid.calendaring.Duration max, 
                                       boolean match);


    /**
     *  Matches an activity that has any weekly contact time assigned. 
     *
     *  @param  match <code> true </code> to match activities with any weekly 
     *          contact time, <code> false </code> to match activities with no 
     *          weekly contact time 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyWeeklyContactTime(boolean match);


    /**
     *  Clears the weekly contact time terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearWeeklyContactTimeTerms();


    /**
     *  Matches activities with a weekly individual effort between the given 
     *  durations inclusive. 
     *
     *  @param  min low range 
     *  @param  max high range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> max </code> is less 
     *          than <code> min </code> 
     *  @throws org.osid.NullArgumentException <code> min </code> or <code> 
     *          max </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchWeeklyIndividualEffort(org.osid.calendaring.Duration min, 
                                            org.osid.calendaring.Duration max, 
                                            boolean match);


    /**
     *  Matches an activity that has any weekly individual effort assigned. 
     *
     *  @param  match <code> true </code> to match activities with any weekly 
     *          individual effort, <code> false </code> to match activities 
     *          with no weekly individual effort 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyWeeklyIndividualEffort(boolean match);


    /**
     *  Clears the weekly individual effort terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearWeeklyIndividualEffortTerms();


    /**
     *  Sets the course catalog <code> Id </code> for this query to match 
     *  activities assigned to course catalogs. 
     *
     *  @param  courseCatalogId the course catalog <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCourseCatalogId(org.osid.id.Id courseCatalogId, 
                                     boolean match);


    /**
     *  Clears the course catalog <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCourseCatalogIdTerms();


    /**
     *  Tests if a <code> CourseCatalogQuery </code> is available. 
     *
     *  @return <code> true </code> if a course catalog query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseCatalogQuery();


    /**
     *  Gets the query for a course catalog. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the course catalog query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCourseCatalogQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCourseCatalogQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.CourseCatalogQuery getCourseCatalogQuery();


    /**
     *  Clears the course catalog terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCourseCatalogTerms();


    /**
     *  Gets the activity query record corresponding to the given <code> 
     *  Activity </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  activityRecordType an activity record type 
     *  @return the activity query record 
     *  @throws org.osid.NullArgumentException <code> activityRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(activityRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.records.ActivityQueryRecord getActivityQueryRecord(org.osid.type.Type activityRecordType)
        throws org.osid.OperationFailedException;
}
