//
// org.osid.course.ActivitySearchSession
//
//     The OSID Java specification for org.osid.course.ActivitySearchSession.
//
// Copyright (C) 2002-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course;


/**
 *  <p>This session provides methods for searching among <code> Activity 
 *  </code> objects. The search query is constructed using the <code> 
 *  ActivityQuery. </code> </p> 
 *  
 *  <p> <code> getActivitiesByQuery() </code> is the basic search method and 
 *  returns a list of <code> Activitys. </code> A more advanced search may be 
 *  performed with <code> getActivitysBySearch(). </code> It accepts an <code> 
 *  ActivitySearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getActivitiesBySearch() </code> returns an <code> 
 *  ActivitySearchResults </code> that can be used to access the resulting 
 *  <code> ActivityList </code> or be used to perform a search within the 
 *  result set through <code> ActivitySearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated course catalog view: searches include activities in 
 *      course catalogs of which this course catalog is an ancestor in the 
 *      course catalog hierarchy </li> 
 *      <li> isolated course catalog view: searches are restricted to 
 *      activities in this course catalog </li> 
 *  </ul>
 *  
 *  
 *  <p> Activities may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> ActivityQuery. 
 *  </code> </p>
 */

public interface ActivitySearchSession
    extends org.osid.course.ActivityQuerySession {


    /**
     *  Gets an activity search. 
     *
     *  @return the activity search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.ActivitySearch getActivitySearch();


    /**
     *  Gets an activity search order. The <code> ActivitySearchOrder </code> 
     *  is supplied to an <code> ActivitySearch </code> to specify the 
     *  ordering of results. 
     *
     *  @return the activity search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.ActivitySearchOrder getActivitySearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  activityQuery the activity query 
     *  @param  activitySearch the activity search 
     *  @return the activity search results 
     *  @throws org.osid.NullArgumentException <code> activityQuery </code> or 
     *          <code> activitySearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> activityQuery </code> or 
     *          <code> activitySearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.ActivitySearchResults getActivitiesBySearch(org.osid.course.ActivityQuery activityQuery, 
                                                                       org.osid.course.ActivitySearch activitySearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an activity query from an inspector. The inspector is available 
     *  from an <code> ActivitySearchResults. </code> 
     *
     *  @param  activityQueryInspector an activity query inspector 
     *  @return the activity query 
     *  @throws org.osid.NullArgumentException <code> activityQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> activityQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.ActivityQuery getActivityQueryFromInspector(org.osid.course.ActivityQueryInspector activityQueryInspector);
}
