//
// org.osid.course.ActivityUnitLookupSession
//
//     The OSID Java specification for org.osid.course.ActivityUnitLookupSession.
//
// Copyright (C) 2002-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course;


/**
 *  <p>This session defines methods for retrieving activity units. An <code> 
 *  ActivityUnit </code> is derived from a <code> Course </code> and maps to 
 *  an offering time and registered students. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated course catalog view: All activity unit methods in this 
 *      session operate, retrieve and pertain to activity units defined 
 *      explicitly in the current course catalog. Using an isolated view is 
 *      useful for managing <code> ActivityUnits </code> with the <code> 
 *      ActivityUnitAdminSession. </code> </li> 
 *      <li> federated course catalog view: All activity unit lookup methods 
 *      in this session operate, retrieve and pertain to all activity units 
 *      defined in this course catalog and any other activity units implicitly 
 *      available in this course catalog through course catalog inheritence. 
 *      </li> 
 *      <li> active activity unit view: All activity unit lookup methods 
 *      return activity units which are active. </li> 
 *      <li> any active activity unit view: Activity units of any active or 
 *      inactive status are returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedCourseCatalogView() </code> and <code> 
 *  useIsolatedCourseCatalogView() </code> behave as a radio group and one 
 *  should be selected before invoking any lookup methods. </p> 
 *  
 *  <p> Activity units may have an additional records indicated by their 
 *  respective record types. The record may not be accessed through a cast of 
 *  the <code> ActivityUnit. </code> </p>
 */

public interface ActivityUnitLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> CourseCatalog </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> CourseCatalog Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCourseCatalogId();


    /**
     *  Gets the <code> CourseCatalog </code> associated with this session. 
     *
     *  @return the course catalog 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseCatalog getCourseCatalog()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> ActivityUnit </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupActivityUnits();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeActivityUnitView();


    /**
     *  A complete view of the <code> ActivityUnit </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryActivityUnitView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include activity units in catalogs which are children of this catalog 
     *  in the course catalog hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCourseCatalogView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this course catalog only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCourseCatalogView();


    /**
     *  Only active activity units are returned by methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveActivityUnitView();


    /**
     *  All activity units of any active or inactive status are returned by 
     *  methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusActivityUnitView();


    /**
     *  Gets the <code> ActivityUnit </code> specified by its <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  ActivityUnit </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> ActivityUnit </code> and retained for 
     *  compatibility. 
     *  
     *  In active mode, activity units are returned that are currently active. 
     *  In any status mode, active and inactive activity units are returned. 
     *
     *  @param  activityUnitId the <code> Id </code> of the <code> 
     *          ActivityUnit </code> to retrieve 
     *  @return the returned <code> ActivityUnit </code> 
     *  @throws org.osid.NotFoundException no <code> ActivityUnit </code> 
     *          found with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> activityUnitId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.ActivityUnit getActivityUnit(org.osid.id.Id activityUnitId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ActivityUnitList </code> corresponding to the given 
     *  <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  activity units specified in the <code> Id </code> list, in the order 
     *  of the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> ActivityUnits </code> may be omitted from the list 
     *  and may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In active mode, activity units are returned that are currently active. 
     *  In any status mode, active and inactive activity units are returned. 
     *
     *  @param  activityUnitIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> ActivityUnit </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> activityUnitIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.ActivityUnitList getActivityUnitsByIds(org.osid.id.IdList activityUnitIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ActivityUnitList </code> corresponding to the given 
     *  activity unit genus <code> Type </code> which does not include 
     *  activity units of types derived from the specified <code> Type </code> 
     *  . 
     *  
     *  In plenary mode, the returned list contains all known activity units 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those activity units that are accessible through this session. 
     *  
     *  In active mode, activity units are returned that are currently active. 
     *  In any status mode, active and inactive activity units are returned. 
     *
     *  @param  activityUnitGenusType an activity unit genus type 
     *  @return the returned <code> ActivityUnit </code> list 
     *  @throws org.osid.NullArgumentException <code> activityUnitGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.ActivityUnitList getActivityUnitsByGenusType(org.osid.type.Type activityUnitGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ActivityUnitList </code> corresponding to the given 
     *  activity unit genus <code> Type </code> and include any additional 
     *  activity units with genus types derived from the specified <code> 
     *  Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  activity units or an error results. Otherwise, the returned list may 
     *  contain only those activity units that are accessible through this 
     *  session. 
     *  
     *  In active mode, activity units are returned that are currently active. 
     *  In any status mode, active and inactive activity units are returned. 
     *
     *  @param  activityUnitGenusType an activity unit genus type 
     *  @return the returned <code> ActivityUnit </code> list 
     *  @throws org.osid.NullArgumentException <code> activityUnitGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.ActivityUnitList getActivityUnitsByParentGenusType(org.osid.type.Type activityUnitGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ActivityUnitList </code> containing the given activity 
     *  unit record <code> Type. </code> 
     *  
     *  In plenary mode, the returned list contains all known activity units 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those activity units that are accessible through this session. 
     *  
     *  In active mode, activity units are returned that are currently active. 
     *  In any status mode, active and inactive activity units are returned. 
     *
     *  @param  activityUnitRecordType an activity unit record type 
     *  @return the returned <code> ActivityUnit </code> list 
     *  @throws org.osid.NullArgumentException <code> activityUnitRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.ActivityUnitList getActivityUnitsByRecordType(org.osid.type.Type activityUnitRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ActivityUnitList </code> for the given course. 
     *  
     *  In plenary mode, the returned list contains all known activity units 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those activity units that are accessible through this session. 
     *  
     *  In active mode, activity units are returned that are currently active. 
     *  In any status mode, active and inactive activity units are returned. 
     *
     *  @param  courseId a course <code> Id </code> 
     *  @return the returned <code> ActivityUnit </code> list 
     *  @throws org.osid.NullArgumentException <code> courseId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.ActivityUnitList getActivityUnitsForCourse(org.osid.id.Id courseId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> ActivityUnits. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  activity units or an error results. Otherwise, the returned list may 
     *  contain only those activity units that are accessible through this 
     *  session. 
     *  
     *  In active mode, activity units are returned that are currently active. 
     *  In any status mode, active and inactive activity units are returned. 
     *
     *  @return a list of <code> ActivityUnits </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.ActivityUnitList getActivityUnits()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
