//
// org.osid.course.ActivityUnitQuery
//
//     The OSID Java specification for org.osid.course.ActivityUnitQuery.
//
// Copyright (C) 2002-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course;


/**
 *  <p>This is the query for searching activity units. Each method match 
 *  specifies an <code> AND </code> term while multiple invocations of the 
 *  same method produce a nested <code> OR. </code> </p>
 */

public interface ActivityUnitQuery
    extends org.osid.OsidObjectQuery,
            org.osid.OsidOperableQuery,
            org.osid.OsidSubjugateableQuery {


    /**
     *  Sets the course <code> Id </code> for this query to match activity 
     *  units that have a related course. 
     *
     *  @param  courseId a course <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> courseId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCourseId(org.osid.id.Id courseId, boolean match);


    /**
     *  Clears the course <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCourseIdTerms();


    /**
     *  Tests if a <code> CourseQuery </code> is available. 
     *
     *  @return <code> true </code> if a course query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseQuery();


    /**
     *  Gets the query for a course. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the course query 
     *  @throws org.osid.UnimplementedException <code> supportsCourseQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCourseQuery() </code> is <code> true. </code> 
     */

    public org.osid.course.CourseQuery getCourseQuery();


    /**
     *  Clears the course terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCourseTerms();


    /**
     *  Matches activity units with a total effort between the given durations 
     *  inclusive. 
     *
     *  @param  min low range 
     *  @param  max high range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> max </code> is less 
     *          than <code> min </code> 
     *  @throws org.osid.NullArgumentException <code> min </code> or <code> 
     *          max </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchTotalTargetEffort(org.osid.calendaring.Duration min, 
                                       org.osid.calendaring.Duration max, 
                                       boolean match);


    /**
     *  Matches an activity unit that has any total effort assigned. 
     *
     *  @param  match <code> true </code> to match activity units with any 
     *          total effort, <code> false </code> to match activity units 
     *          with no total effort 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyTotalTargetEffort(boolean match);


    /**
     *  Clears the total effort terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTotalTargetEffortTerms();


    /**
     *  Matches activity units that are contact activities. 
     *
     *  @param  match <code> true </code> to match activity units that have 
     *          contact, <code> false </code> to match activity units with no 
     *          contact 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchContact(boolean match);


    /**
     *  Clears the contact terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearContactTerms();


    /**
     *  Matches activity units with a total contact time between the given 
     *  durations inclusive. 
     *
     *  @param  min low range 
     *  @param  max high range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> max </code> is less 
     *          than <code> min </code> 
     *  @throws org.osid.NullArgumentException <code> min </code> or <code> 
     *          max </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchTotalTargetContactTime(org.osid.calendaring.Duration min, 
                                            org.osid.calendaring.Duration max, 
                                            boolean match);


    /**
     *  Matches an activity unit that has any total contact assigned. 
     *
     *  @param  match <code> true </code> to match activity units with any 
     *          total contatc, <code> false </code> to match activity units 
     *          with no total contact 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyTotalTargetContactTime(boolean match);


    /**
     *  Clears the total contact terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTotalTargetContactTimeTerms();


    /**
     *  Matches activity units with a individual effort between the given 
     *  durations inclusive. 
     *
     *  @param  min low range 
     *  @param  max high range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> max </code> is less 
     *          than <code> min </code> 
     *  @throws org.osid.NullArgumentException <code> min </code> or <code> 
     *          max </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchTotalTargetIndividualEffort(org.osid.calendaring.Duration min, 
                                                 org.osid.calendaring.Duration max, 
                                                 boolean match);


    /**
     *  Matches an activity unit that has any individual effort assigned. 
     *
     *  @param  match <code> true </code> to match activity units with any 
     *          individual effort, <code> false </code> to match activity 
     *          units with no individual effort 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyTotalTargetIndividualEffort(boolean match);


    /**
     *  Clears the individual effort terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTotalTargetIndividualEffortTerms();


    /**
     *  Matches activity units that recur weekly. 
     *
     *  @param  match <code> true </code> to match activity units that recur 
     *          weekly, <code> false </code> to match activity units with no 
     *          weekly recurrance 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRecurringWeekly(boolean match);


    /**
     *  Clears the recurring weekly terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRecurringWeeklyTerms();


    /**
     *  Matches activity units with a weekly effort between the given 
     *  durations inclusive. 
     *
     *  @param  min low range 
     *  @param  max high range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> max </code> is less 
     *          than <code> min </code> 
     *  @throws org.osid.NullArgumentException <code> min </code> or <code> 
     *          max </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchWeeklyEffort(org.osid.calendaring.Duration min, 
                                  org.osid.calendaring.Duration max, 
                                  boolean match);


    /**
     *  Matches an activity unit that has any weekly effort assigned. 
     *
     *  @param  match <code> true </code> to match activity units with any 
     *          weekly effort, <code> false </code> to match activity units 
     *          with no weekly effort 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyWeeklyEffort(boolean match);


    /**
     *  Clears the weekly effort terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearWeeklyEffortTerms();


    /**
     *  Matches activity units with a weekly contact time between the given 
     *  durations inclusive. 
     *
     *  @param  min low range 
     *  @param  max high range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> max </code> is less 
     *          than <code> min </code> 
     *  @throws org.osid.NullArgumentException <code> min </code> or <code> 
     *          max </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchWeeklyContactTime(org.osid.calendaring.Duration min, 
                                       org.osid.calendaring.Duration max, 
                                       boolean match);


    /**
     *  Matches an activity unit that has any weekly contact time assigned. 
     *
     *  @param  match <code> true </code> to match activity units with any 
     *          weekly contact time, <code> false </code> to match activity 
     *          units with no weekly contact time 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyWeeklyContactTime(boolean match);


    /**
     *  Clears the weekly contact time terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearWeeklyContactTimeTerms();


    /**
     *  Matches activity units with a weekly individual effort between the 
     *  given durations inclusive. 
     *
     *  @param  min low range 
     *  @param  max high range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> max </code> is less 
     *          than <code> min </code> 
     *  @throws org.osid.NullArgumentException <code> min </code> or <code> 
     *          max </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchWeeklyIndividualEffort(org.osid.calendaring.Duration min, 
                                            org.osid.calendaring.Duration max, 
                                            boolean match);


    /**
     *  Matches an activity unit that has any weekly individual effort 
     *  assigned. 
     *
     *  @param  match <code> true </code> to match activity units with any 
     *          weekly individual effort, <code> false </code> to match 
     *          activity units with no weekly individual effort 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyWeeklyIndividualEffort(boolean match);


    /**
     *  Clears the weekly individual effort terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearWeeklyIndividualEffortTerms();


    /**
     *  Sets the objective <code> Id </code> for this query. 
     *
     *  @param  objectiveId an objective <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> objectiveId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchLearningObjectiveId(org.osid.id.Id objectiveId, 
                                         boolean match);


    /**
     *  Clears the objective <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLearningObjectiveIdTerms();


    /**
     *  Tests if a <code> ObjectiveQuery </code> is available. 
     *
     *  @return <code> true </code> if an objective query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLearningObjectiveQuery();


    /**
     *  Gets the query for a learning objective. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return an objective query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsLearningObjectiveQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLearningObjectiveQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.learning.ObjectiveQuery getLearningObjectiveQuery();


    /**
     *  Matches activity units that have any learning objective. 
     *
     *  @param  match <code> true </code> to match activity units with any 
     *          learning objective, <code> false </code> to match activity 
     *          units with no learning objectives 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyLearningObjective(boolean match);


    /**
     *  Clears the learning objective terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLearningObjectiveTerms();


    /**
     *  Sets the activity <code> Id </code> for this query to match activity 
     *  units that have a related activity. 
     *
     *  @param  activityId an activity <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> activityId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchActivityId(org.osid.id.Id activityId, boolean match);


    /**
     *  Clears the activity <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearActivityIdTerms();


    /**
     *  Tests if an <code> ActivityQuery </code> is available. 
     *
     *  @return <code> true </code> if an activity query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityQuery();


    /**
     *  Gets the query for an activity. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the activity query 
     *  @throws org.osid.UnimplementedException <code> supportsActivityQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityQuery() </code> is <code> true. </code> 
     */

    public org.osid.course.ActivityQuery getActivityQuery();


    /**
     *  Matches activity units that have any activity. 
     *
     *  @param  match <code> true </code> to match activity units with any 
     *          activity. <code> false </code> to match activity units with no 
     *          activity 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyActivity(boolean match);


    /**
     *  Clears the activity terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearActivityTerms();


    /**
     *  Sets the course catalog <code> Id </code> for this query to match 
     *  courses assigned to course catalogs. 
     *
     *  @param  courseCatalogId the course catalog <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCourseCatalogId(org.osid.id.Id courseCatalogId, 
                                     boolean match);


    /**
     *  Clears the course catalog <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCourseCatalogIdTerms();


    /**
     *  Tests if a <code> CourseCatalogQuery </code> is available. 
     *
     *  @return <code> true </code> if a course catalog query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseCatalogQuery();


    /**
     *  Gets the query for a course catalog. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the course catalog query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCourseCatalogQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCourseCatalogQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.CourseCatalogQuery getCourseCatalogQuery();


    /**
     *  Clears the course catalog terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCourseCatalogTerms();


    /**
     *  Gets the activity unit query record corresponding to the given <code> 
     *  Course </code> record <code> Type. </code> Multiple record retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @param  activityUnitRecordType an activity unit record type 
     *  @return the activity unit query record 
     *  @throws org.osid.NullArgumentException <code> activityUnitRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(activityUnitRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.records.ActivityUnitQueryRecord getActivityUnitQueryRecord(org.osid.type.Type activityUnitRecordType)
        throws org.osid.OperationFailedException;
}
