//
// org.osid.course.ActivityUnitSearchSession
//
//     The OSID Java specification for org.osid.course.ActivityUnitSearchSession.
//
// Copyright (C) 2002-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course;


/**
 *  <p>This session provides methods for searching among <code> ActivityUnit 
 *  </code> objects. The search query is constructed using the <code> 
 *  ActivityUnitQuery. </code> </p> 
 *  
 *  <p> <code> getActivityUnitsByQuery() </code> is the basic search method 
 *  and returns a list of <code> ActivityUnits. </code> A more advanced search 
 *  may be performed with <code> getActivityUnitsBySearch(). </code> It 
 *  accepts an <code> ActivityUnitSearch </code> in addition to the query for 
 *  the purpose of specifying additional options affecting the entire search, 
 *  such as ordering. <code> getActivityUnitsBySearch() </code> returns an 
 *  <code> ActivityUnitSearchResults </code> that can be used to access the 
 *  resulting <code> ActivityUnitList </code> or be used to perform a search 
 *  within the result set through <code> ActivityUnitSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated course catalog view: searches include activity units in 
 *      course catalogs of which this course catalog is an ancestor in the 
 *      course catalog hierarchy </li> 
 *      <li> isolated course catalog view: searches are restricted to activity 
 *      units in this course catalog </li> 
 *  </ul>
 *  
 *  
 *  <p> Activity Units may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> 
 *  ActivityUnitQuery. </code> </p>
 */

public interface ActivityUnitSearchSession
    extends org.osid.course.ActivityUnitQuerySession {


    /**
     *  Gets an activity unit search. 
     *
     *  @return the activity unit search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.ActivityUnitSearch getActivityUnitSearch();


    /**
     *  Gets an activity search order. The <code> ActivityUnitSearchOrder 
     *  </code> is supplied to an <code> ActivityUnitSearch </code> to specify 
     *  the ordering of results. 
     *
     *  @return the activity unit search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.ActivityUnitSearchOrder getActivityUnitSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  activityUnitQuery the activity unit query 
     *  @param  activityUnitSearch the activity unit search 
     *  @return the activity unit search results 
     *  @throws org.osid.NullArgumentException <code> activityUnitQuery 
     *          </code> or <code> activityUnitSearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> activityUnitQuery </code> 
     *          or <code> activityUnitSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.ActivityUnitSearchResults getActivityUnitsBySearch(org.osid.course.ActivityUnitQuery activityUnitQuery, 
                                                                              org.osid.course.ActivityUnitSearch activityUnitSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an activity unit query from an inspector. The inspector is 
     *  available from an <code> ActivityUnitSearchResults. </code> 
     *
     *  @param  activityUnitQueryInspector an activity unit query inspector 
     *  @return the activity unit query 
     *  @throws org.osid.NullArgumentException <code> 
     *          activityUnitQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          activityUnitQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.ActivityUnitQuery getActivityUnitQueryFromInspector(org.osid.assessment.ItemQueryInspector activityUnitQueryInspector);
}
