//
// org.osid.course.ActivityUnitSmartCourseCatalogSession
//
//     The OSID Java specification for org.osid.course.ActivityUnitSmartCourseCatalogSession.
//
// Copyright (C) 2002-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. An <code> ActivityUnitQuery </code> can be retrieved from this 
 *  session and mapped to this <code> CoursOfferingeCatalog </code> to create 
 *  a virtual collection of <code> ActivityUnits. </code> The activity units 
 *  may be sequenced using the <code> ActivityUnitSearchOrder </code> from 
 *  this session. </p> 
 *  
 *  <p> This <code> CourseCatalog </code> has a default query that matches any 
 *  activity unit and a default search order that specifies no sequencing. The 
 *  queries may be examined using an <code> ActivityUnitQueryInspector. 
 *  </code> The query may be modified by converting the inspector back to an 
 *  <code> ActivityUnitQuery. </code> </p>
 */

public interface ActivityUnitSmartCourseCatalogSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> CourseCatalog </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> CourseCatalog Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCourseCatalogId();


    /**
     *  Gets the <code> CourseCatalog </code> associated with this session. 
     *
     *  @return the course catalog 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseCatalog getCourseCatalog()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart course catalogs. A return of true 
     *  does not guarantee successful assessment. A return of false indicates 
     *  that it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart course catalog management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartCourseCatalogs();


    /**
     *  Gets an activity unit query. 
     *
     *  @return the activity unit query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.ActivityUnitQuery getActivityUnitQuery();


    /**
     *  Gets an activity unit search order. 
     *
     *  @return the activity unit search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.ActivityUnitSearchOrder getActivityUnitSearchOrder();


    /**
     *  Applies an activity unit query to this course catalog. 
     *
     *  @param  activityUnitQuery the activity unit query 
     *  @throws org.osid.NullArgumentException <code> activityUnitQuery 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> activityUnitQuery </code> 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyActivityUnitQuery(org.osid.course.ActivityUnitQuery activityUnitQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an activity unit query inspector for this course catalog. 
     *
     *  @return the activity unit query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.ActivityUnitQueryInspector inspectActivityUnitQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies an activity unit search order to this course catalog. 
     *
     *  @param  activityUnitSearchOrder the activity unit search order 
     *  @throws org.osid.NullArgumentException <code> activityUnitSearchOrder 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> activityUnitSearchOrder 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyActivityUnitSequencing(org.osid.course.ActivityUnitSearchOrder activityUnitSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an activity unit query from an inspector. 
     *
     *  @param  activityUnitQueryInspector a query inspector 
     *  @return the activity unit query 
     *  @throws org.osid.NullArgumentException <code> 
     *          activityUnitQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          activityUnitQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.ActivityUnitQuery getActivityUnitQueryFromInspector(org.osid.course.ActivityUnitQueryInspector activityUnitQueryInspector);
}
