//
// org.osid.course.Course
//
//     The OSID Java specification for org.osid.course.Course.
//
// Copyright (C) 2002-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course;


/**
 *  <p>A <code> Course </code> represents a canonical course that manages the 
 *  curriculum of learning units. A <code> Course </code> is composed of 
 *  <code> ActivityUnits </code> that manage the details of the curriculum and 
 *  instantiated for offering through the creation of a <code> CourseOffering. 
 *  </code> </p>
 */

public interface Course
    extends org.osid.OsidObject,
            org.osid.Operable {


    /**
     *  Gets the formal title of this course. It may be the same as the 
     *  display name or it may be used to more formally label the course. A 
     *  display name might be Physics 102 where the title is Introduction to 
     *  Electromagentism. 
     *
     *  @return the course title 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getTitle();


    /**
     *  Gets the course number which is a label generally used to index the 
     *  course in a catalog, such as T101 or 16.004. 
     *
     *  @return the course number 
     *  @compliance mandatory This method must be implemented. 
     */

    public String getNumber();


    /**
     *  Tests if this course has sponsors. 
     *
     *  @return <code> true </code> if this course has sponsors, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasSponsors();


    /**
     *  Gets the sponsor <code> Ids. </code> 
     *
     *  @return the sponsor <code> Ids </code> 
     *  @throws org.osid.IllegalStateException <code> hasSponsors() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getSponsorIds();


    /**
     *  Gets the sponsors. 
     *
     *  @return the sponsors 
     *  @throws org.osid.IllegalStateException <code> hasSponsors() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceList getSponsors()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the credits in which this course can be offered. The credits are 
     *  expressed as <code> Grades. </code> 
     *
     *  @return the grade <code> Ids </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getCreditAmountIds();


    /**
     *  Gets the credits in which this course can be offered. The credits are 
     *  expressed as <code> Grades. </code> 
     *
     *  @return the credits 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeList getCreditAmounts()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the an informational string for the course prerequisites. 
     *
     *  @return the course prerequisites 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getPrerequisitesInfo();


    /**
     *  Tests if this course has <code> Requisites </code> for the course 
     *  prerequisites. 
     *
     *  @return <code> true </code> if this course has prerequisites <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasPrerequisites();


    /**
     *  Gets the requisite <code> Ids </code> for the course prerequisites. 
     *
     *  @return the requisite <code> Ids </code> 
     *  @throws org.osid.IllegalStateException <code> hasPrerequisites() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getPrerequisiteIds();


    /**
     *  Gets the requisites for the course prerequisites. Each <code> 
     *  Requisite </code> is an <code> AND </code> term such that all <code> 
     *  Requisites </code> must be true for the prerequisites to be satisifed. 
     *
     *  @return the requisites 
     *  @throws org.osid.IllegalStateException <code> hasPrerequisites() 
     *          </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.RequisiteList getPrerequisites()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the grade level <code> Ids </code> of this course. Multiple 
     *  levels may exist for different systems. 
     *
     *  @return the returned list of grade level <code> Ids </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getLevelIds();


    /**
     *  Gets the grade levels of this course. Multiple levels may exist for 
     *  different systems. 
     *
     *  @return the returned list of grade levels 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeList getLevels()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this course is graded. 
     *
     *  @return <code> true </code> if this course is graded, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isGraded();


    /**
     *  Gets the various grading option <code> Ids </code> available to 
     *  register in this course. 
     *
     *  @return the returned list of grading option <code> Ids </code> 
     *  @throws org.osid.IllegalStateException <code> isGraded() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getGradingOptionIds();


    /**
     *  Gets the various grading options available to register in this course. 
     *
     *  @return the returned list of grading options 
     *  @throws org.osid.IllegalStateException <code> isGraded() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeSystemList getGradingOptions()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this course has associated learning objectives. 
     *
     *  @return <code> true </code> if this course has a learning objective, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasLearningObjectives();


    /**
     *  Gets the overall learning objective <code> Ids </code> for this 
     *  course. 
     *
     *  @return <code> Ids </code> of the <code> l </code> earning objectives 
     *  @throws org.osid.IllegalStateException <code> hasLearningObjectives() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.id.IdList getLearningObjectiveIds();


    /**
     *  Gets the overall learning objectives for this course. 
     *
     *  @return the learning objectives 
     *  @throws org.osid.IllegalStateException <code> hasLearningObjectives() 
     *          </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveList getLearningObjectives()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the course record corresponding to the given <code> Course 
     *  </code> record <code> Type. </code> This method is used to retrieve an 
     *  object implementing the requested record. The <code> courseRecordType 
     *  </code> may be the <code> Type </code> returned in <code> 
     *  getRecordTypes() </code> or any of its parents in a <code> Type 
     *  </code> hierarchy where <code> hasRecordType(courseRecordType) </code> 
     *  is <code> true </code> . 
     *
     *  @param  courseRecordType the type of course record to retrieve 
     *  @return the course record 
     *  @throws org.osid.NullArgumentException <code> courseRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(courseRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.records.CourseRecord getCourseRecord(org.osid.type.Type courseRecordType)
        throws org.osid.OperationFailedException;
}
