//
// org.osid.course.CourseCatalogNotificationSession
//
//     The OSID Java specification for org.osid.course.CourseCatalogNotificationSession.
//
// Copyright (C) 2002-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course;


/**
 *  <p>This session defines methods to receive notifications on adds/changes 
 *  to <code> CourseCatalog </code> objects. This session is intended for 
 *  consumers needing to synchronize their state with this service without the 
 *  use of polling. Notifications are cancelled when this sess </p>
 */

public interface CourseCatalogNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can register for <code> CourseCatalog </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForCourseCatalogNotifications();


    /**
     *  Reliable notifications are desired. In reliable mode, notifications 
     *  are to be acknowledged using <code> 
     *  acknowledgeCourseCatalogNotification() </code> . 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void reliableCourseCatalogNotifications();


    /**
     *  Unreliable notifications are desired. In unreliable mode, 
     *  notifications do not need to be acknowledged. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void unreliableCourseCatalogNotifications();


    /**
     *  Acknowledge a course catalog notification. 
     *
     *  @param  notificationId the <code> Id </code> of the notification 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void acknowledgeCourseCatalogNotification(org.osid.id.Id notificationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new course catalogs. <code> 
     *  CourseCatalogReceiver.newCourseCatalogs() </code> is invoked when a 
     *  new <code> CourseCatalog </code> is created. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewCourseCatalogs()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated course catalogs. <code> 
     *  CourseCatalogReceiver.changedCourseCatalogs() </code> is invoked when 
     *  a course catalog is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedCourseCatalogs()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated course catalog. <code> 
     *  CourseCatalogReceiver.changedCourseCatalogs() </code> is invoked when 
     *  the specified course catalog is changed. 
     *
     *  @param  courseCatalogId the Id of the <code> CourseCatalog </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedCourseCatalog(org.osid.id.Id courseCatalogId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted course catalogs. <code> 
     *  CourseCatalogReceiver.deletedCourseCatalogs() </code> is invoked when 
     *  a course catalog is deleted. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedCourseCatalogs()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted course catalog. <code> 
     *  CourseCatalogReceiver.deletedCourseCatalogs() </code> is invoked when 
     *  the specified course catalog is deleted. 
     *
     *  @param  courseCatalogId the Id of the <code> CourseCatalog </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedCourseCatalog(org.osid.id.Id courseCatalogId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated course catalog hierarchy 
     *  structure. <code> CourseCataloReceiver.changedChildOfCourseCatalos() 
     *  </code> is invoked when a node experiences a change in its children. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedCourseCatalogHierarchy()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated course catalog hierarchy 
     *  structure. <code> CourseCataloReceiver.changedChildOfCourseCatalos() 
     *  </code> is invoked when the specified node or any of its ancestors 
     *  experiences a change in its children. 
     *
     *  @param  courseCatalogId the <code> Id </code> of the <code> 
     *          CourseCatalo </code> node to monitor 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedCourseCatalogHierarchyForAncestors(org.osid.id.Id courseCatalogId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated course catalog hierarchy 
     *  structure. <code> CourseCatalogReceiver.changedChildOfCourseCatalos() 
     *  </code> is invoked when the specified node or any of its descendants 
     *  experiences a change in its children. 
     *
     *  @param  courseCatalogId the <code> Id </code> of the <code> 
     *          CourseCatalo </code> node to monitor 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedCourseCatalogHierarchyForDescendants(org.osid.id.Id courseCatalogId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
