//
// org.osid.course.CourseOffering
//
//     The OSID Java specification for org.osid.course.CourseOffering.
//
// Copyright (C) 2002-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course;


/**
 *  <p>A <code> CourseOffering </code> represents a learning unit offered 
 *  duing a <code> Term. </code> Scheduling information of a <code> 
 *  CourseOffering </code> is maintained at the <code> Activity </code> level 
 *  resulting in a composite <code> RecurringEvent. </code> A separate <code> 
 *  Calendar </code> of activities can be made available through orchestration 
 *  of the Calendaring OSID. </p>
 */

public interface CourseOffering
    extends org.osid.OsidRelationship {


    /**
     *  Gets the canonical course <code> Id </code> associated with this 
     *  course offering. 
     *
     *  @return the course <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCourseId();


    /**
     *  Gets the canonical course associated with this course offering. 
     *
     *  @return the course 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.Course getCourse()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of the <code> Term </code> of this 
     *  offering. 
     *
     *  @return the <code> Term </code> <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getTermId();


    /**
     *  Gets the <code> Term </code> of this offering. 
     *
     *  @return the term 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.Term getTerm()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the formal title of this course. It may be the same as the 
     *  display name or it may be used to more formally label the course. A 
     *  display name might be Physics 102 where the title is Introduction to 
     *  Electromagentism. 
     *
     *  @return the course title 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getTitle();


    /**
     *  Gets the course number which is a label generally used to index the 
     *  course offering in a catalog, such as T101 or 16.004. 
     *
     *  @return the course number 
     *  @compliance mandatory This method must be implemented. 
     */

    public String getNumber();


    /**
     *  Gets the instructor <code> Ids. </code> If each activity has its own 
     *  instructor, the headlining instructors may be returned. 
     *
     *  @return the instructor <code> Ids </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getInstructorIds();


    /**
     *  Gets the instructors. If each activity has its own instructor, the 
     *  headlining instructors may be returned. 
     *
     *  @return the sponsors 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceList getInstructors()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this course has sponsors. 
     *
     *  @return <code> true </code> if this course has sponsors, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasSponsors();


    /**
     *  Gets the sponsor <code> Ids. </code> 
     *
     *  @return the sponsor <code> Ids </code> 
     *  @throws org.osid.IllegalStateException <code> hasSponsors() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getSponsorIds();


    /**
     *  Gets the sponsors. 
     *
     *  @return the sponsors 
     *  @throws org.osid.IllegalStateException <code> hasSponsors() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceList getSponsors()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the credits in which this course can be registered. The credits 
     *  are expressed as <code> Grades. </code> 
     *
     *  @return the grade <code> Ids </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getCreditAmountIds();


    /**
     *  Gets the credits in which this course can be registered. The credits 
     *  are expressed as <code> Grades. </code> 
     *
     *  @return the credits 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeList getCreditAmounts()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this course offering is graded. 
     *
     *  @return <code> true </code> if this course is graded, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isGraded();


    /**
     *  Gets the various grading option <code> Ids </code> available to 
     *  register in this course. 
     *
     *  @return the returned list of grading option <code> Ids </code> 
     *  @throws org.osid.IllegalStateException <code> isGraded() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getGradingOptionIds();


    /**
     *  Gets the various grading options available to register in this course. 
     *
     *  @return the returned list of grading options 
     *  @throws org.osid.IllegalStateException <code> isGraded() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeSystemList getGradingOptions()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this course offering requires advanced registration. 
     *
     *  @return <code> true </code> if this course requires advance 
     *          registration, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean requiresRegistration();


    /**
     *  Gets the minimum number of students this offering can have. 
     *
     *  @return the minimum seats 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getMinimumSeats();


    /**
     *  Tests if this course offering has limited seating. 
     *
     *  @return <code> true </code> if this seating is limited, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isSeatingLimited();


    /**
     *  Gets the maximum number of students this offering can have. 
     *
     *  @return the maximum seats 
     *  @throws org.osid.IllegalStateException <code> isSeatingLimited() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getMaximumSeats();


    /**
     *  Gets an external resource, such as a class web site, associated with 
     *  this offering. 
     *
     *  @return a URL string 
     *  @compliance mandatory This method must be implemented. 
     */

    public String getURL();


    /**
     *  Gets the an informational string for the course offering schedule. 
     *
     *  @return the schedule info 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getScheduleInfo();


    /**
     *  Tests if a calendaring event is available for this course offering 
     *  with the schedule details. 
     *
     *  @return <code> true </code> if this course is graded, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasEvent();


    /**
     *  Gets the calendaring event <code> Id. </code> 
     *
     *  @return the event <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> hasEvent() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getEventId();


    /**
     *  Gets the calendaring event with the schedule details. 
     *
     *  @return an event 
     *  @throws org.osid.IllegalStateException <code> hasEvent() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Event getEvent()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the course offering record corresponding to the given <code> 
     *  CourseOffering </code> record <code> Type. </code> This method is used 
     *  to retrieve an object implementing the requested record. The <code> 
     *  courseOfferingRecordType </code> may be the <code> Type </code> 
     *  returned in <code> getRecordTypes() </code> or any of its parents in a 
     *  <code> Type </code> hierarchy where <code> 
     *  hasRecordType(courseOfferingRecordType) </code> is <code> true </code> 
     *  . 
     *
     *  @param  courseOfferingRecordType the type of course offering record to 
     *          retrieve 
     *  @return the course offering record 
     *  @throws org.osid.NullArgumentException <code> courseOfferingRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(courseOfferingRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.records.CourseOfferingRecord getCourseOfferingRecord(org.osid.type.Type courseOfferingRecordType)
        throws org.osid.OperationFailedException;
}
