//
// org.osid.course.CourseOfferingAdminSession
//
//     The OSID Java specification for org.osid.course.CourseOfferingAdminSession.
//
// Copyright (C) 2002-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course;


/**
 *  <p>This session creates, updates, and deletes <code> CourseOfferings. 
 *  </code> The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  CourseOffering, </code> a <code> CourseOfferingForm </code> is requested 
 *  using <code> getCourseOfferingFormForCreate() </code> specifying the 
 *  desired course, term, and record <code> Types </code> or none if no record 
 *  <code> Types </code> are needed. The returned <code> CourseOfferingForm 
 *  </code> will indicate that it is to be used with a create operation and 
 *  can be used to examine metdata or validate data prior to creation. Once 
 *  the <code> CourseOfferingForm </code> is submiited to a create operation, 
 *  it cannot be reused with another create operation unless the first 
 *  operation was unsuccessful. Each <code> CourseOfferingForm </code> 
 *  corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> CourseOfferingForms </code> are requested to the 
 *  <code> CourseOffering </code> <code> Id </code> that is to be updated 
 *  using <code> getCourseOfferingFormForUpdate(). </code> Similarly, the 
 *  <code> CourseOfferingForm </code> has metadata about the data that can be 
 *  updated and it can perform validation before submitting the update. The 
 *  <code> CourseOfferingForm </code> can only be used once for a successful 
 *  update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> CourseOfferings. </code> To unmap 
 *  a <code> CourseOffering </code> from the current <code> CourseCatalog, 
 *  </code> the <code> CourseOfferingCourseCatalogAssignmentSession </code> 
 *  should be used. These delete operations attempt to remove the <code> 
 *  CourseOffering </code> itself thus removing it from all known <code> 
 *  CourseCatalog </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface CourseOfferingAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> CourseCatalog </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> CourseCatalog Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCourseCatalogId();


    /**
     *  Gets the <code> CourseCatalog </code> associated with this session. 
     *
     *  @return the course catalog 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseCatalog getCourseCatalog()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> CourseOfferings. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> CourseOffering </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer create operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> CourseOffering </code> creation 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateCourseOfferings();


    /**
     *  Tests if this user can create a single <code> CourseOffering </code> 
     *  using the desired record types. While <code> 
     *  CourseManager.getCourseOfferingRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> CourseOffering. </code> 
     *  Providing an empty array tests if a <code> CourseOffering </code> can 
     *  be created with no records. 
     *
     *  @param  courseOfferingRecordTypes array of course offering record 
     *          types 
     *  @return <code> true </code> if <code> CourseOffering </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          courseOfferingRecordTypes </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateCourseOfferingWithRecordTypes(org.osid.type.Type[] courseOfferingRecordTypes);


    /**
     *  Gets the course form for creating new course offerings. A new form 
     *  should be requested for each create transaction. 
     *
     *  @param  courseId the Id of the associated Course 
     *  @param  termId the Id of the associated Term 
     *  @param  courseOfferingRecordTypes array of course offering record 
     *          types 
     *  @return the course offering form 
     *  @throws org.osid.NotFoundException <code> courseId </code> or <code> 
     *          termId </code> not found 
     *  @throws org.osid.NullArgumentException <code> courseId, termId </code> 
     *          or <code> courseOfferingRecordTypes </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseOfferingForm getCourseOfferingFormForCreate(org.osid.id.Id courseId, 
                                                                             org.osid.id.Id termId, 
                                                                             org.osid.type.Type[] courseOfferingRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> CourseOffering. </code> 
     *
     *  @param  courseOfferingForm the form for this <code> CourseOffering 
     *          </code> 
     *  @return the new <code> CourseOffering </code> 
     *  @throws org.osid.IllegalStateException <code> courseOfferingForm 
     *          </code> already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> courseOfferingForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> activityForm did not 
     *          originate from getCourseOfferingFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseOffering createCourseOffering(org.osid.course.CourseOfferingForm courseOfferingForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> CourseOfferings. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> CourseOffering </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer update operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> CourseOffering </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateCourseOfferings();


    /**
     *  Gets the course offering form for updating an existing course 
     *  offering. A new course offering form should be requested for each 
     *  update transaction. 
     *
     *  @param  courseOfferingId the <code> Id </code> of the <code> 
     *          CourseOffering </code> 
     *  @return the course offering form 
     *  @throws org.osid.NotFoundException <code> courseOfferingId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> courseOfferingId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseOfferingForm getCourseOfferingFormForUpdate(org.osid.id.Id courseOfferingId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing course offering. 
     *
     *  @param  courseOfferingForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> courseOfferingForm 
     *          </code> already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> courseOfferingForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> activityForm did not 
     *          originate from getCourseOfferingFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateCourseOffering(org.osid.course.CourseOfferingForm courseOfferingForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> CourseOfferings. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> CourseOffering </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer delete operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> CourseOffering </code> deletion 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteCourseOfferings();


    /**
     *  Deletes a <code> CourseOffering. </code> 
     *
     *  @param  courseOfferingId the <code> Id </code> of the <code> 
     *          CourseOffering </code> to remove 
     *  @throws org.osid.NotFoundException <code> courseOfferingId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> courseOfferingId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteCourseOffering(org.osid.id.Id courseOfferingId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  CourseOfferings. </code> A return of true does not guarantee 
     *  successful authorization. A return of false indicates that it is known 
     *  changing an alias will result in a <code> PERMISSION_DENIED. </code> 
     *  This is intended as a hint to an application that may opt not to offer 
     *  alias operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> CourseOffering </code> aliasing 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageCourseOfferingAliases();


    /**
     *  Adds an <code> Id </code> to a <code> CourseOffering </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Course </code> is determined by the provider. The new 
     *  <code> Id </code> performs as an alias to the primary <code> Id. 
     *  </code> If the alias is a pointer to another course offering, it is 
     *  reassigned to the given course offering <code> Id. </code> 
     *
     *  @param  courseOfferingId the <code> Id </code> of a <code> 
     *          CourseOffering </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is in 
     *          use as a primary <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> courseOfferingId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> courseOfferingId </code> 
     *          or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasCourseOffering(org.osid.id.Id courseOfferingId, 
                                    org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
