//
// org.osid.course.CourseOfferingForm
//
//     The OSID Java specification for org.osid.course.CourseOfferingForm.
//
// Copyright (C) 2002-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course;


/**
 *  <p>This is the form for creating and updating <code> CourseOfferings. 
 *  </code> Like all <code> OsidForm </code> objects, various data elements 
 *  may be set here for use in the create and update methods in the <code> 
 *  CourseOfferingAdminSession. </code> For each data element that may be set, 
 *  metadata may be examined to provide display hints or data constraints. 
 *  </p>
 */

public interface CourseOfferingForm
    extends org.osid.OsidRelationshipForm {


    /**
     *  Gets the metadata for a course title. 
     *
     *  @return metadata for the title 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getTitleMetadata();


    /**
     *  Sets the title. 
     *
     *  @param  title the new title 
     *  @throws org.osid.InvalidArgumentException <code> title </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> title </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setTitle(String title);


    /**
     *  Removes the title. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTitle();


    /**
     *  Gets the metadata for a course number. 
     *
     *  @return metadata for the course number 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getNumberMetadata();


    /**
     *  Sets the course number. 
     *
     *  @param  number the new course number 
     *  @throws org.osid.InvalidArgumentException <code> number </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> number </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setNumber(String number);


    /**
     *  Removes the course number. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearNumber();


    /**
     *  Gets the metadata for the instructors. 
     *
     *  @return metadata for the instructors 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getInstructorsMetadata();


    /**
     *  Sets the instructors. 
     *
     *  @param  resourceIds the new instructors 
     *  @throws org.osid.InvalidArgumentException <code> instructorIds </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> instructorIds </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setInstructors(org.osid.id.Id[] resourceIds);


    /**
     *  Removes the instructors. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearInstructors();


    /**
     *  Gets the metadata for the sponsors. 
     *
     *  @return metadata for the sponsors 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getSponsorsMetadata();


    /**
     *  Sets the sponsors. 
     *
     *  @param  sponsorIds the new sponsors 
     *  @throws org.osid.InvalidArgumentException <code> sponsorIds </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> sponsorIds </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setSponsors(org.osid.id.Id[] sponsorIds);


    /**
     *  Removes the sponsors. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSponsors();


    /**
     *  Gets the metadata for the credits. 
     *
     *  @return metadata for the credit scale 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getCreditsMetadata();


    /**
     *  Sets the credits. 
     *
     *  @param  gradeIds the new credit levels 
     *  @throws org.osid.InvalidArgumentException <code> gradeIds </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> gradeIds </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setCredits(org.osid.id.Id[] gradeIds);


    /**
     *  Removes the credits. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCredits();


    /**
     *  Gets the metadata for the grading options. 
     *
     *  @return metadata for the prerequisite information 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getGradingOptionsMetadata();


    /**
     *  Sets the grading options. 
     *
     *  @param  gradeSystemIds the new grading options 
     *  @throws org.osid.InvalidArgumentException <code> gradeSystemIds 
     *          </code> is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> gradeSystemIds </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setGradingOptions(org.osid.id.Id[] gradeSystemIds);


    /**
     *  Removes the grading options. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGradingOptions();


    /**
     *  Gets the metadata for requires registration flag. 
     *
     *  @return metadata for registration flag 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getRequiresRegistrationMetadata();


    /**
     *  Sets the requires registration flag. 
     *
     *  @param  requiresRegistration the new registration flag 
     *  @throws org.osid.InvalidArgumentException <code> requiresRegistration 
     *          </code> is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setRequiresRegistration(boolean requiresRegistration);


    /**
     *  Removes the requires registration flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRequiresRegistration();


    /**
     *  Gets the metadata for the minimum seats. 
     *
     *  @return metadata for the minimum seats 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getMinimumSeatsMetadata();


    /**
     *  Sets the minimum seating count. 
     *
     *  @param  seats the new minimum seats 
     *  @throws org.osid.InvalidArgumentException <code> seats </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setMinimumSeats(long seats);


    /**
     *  Removes the minimum seats. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMinimumSeats();


    /**
     *  Gets the metadata for the maximum seats. 
     *
     *  @return metadata for the maximum seats 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getMaximumSeatsMetadata();


    /**
     *  Sets the maximum seating count. 
     *
     *  @param  seats the new maximum seats 
     *  @throws org.osid.InvalidArgumentException <code> seats </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setMaximumSeats(long seats);


    /**
     *  Removes the maximum seats. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMaximumSeats();


    /**
     *  Gets the metadata for a class url. 
     *
     *  @return metadata for the url 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getURLMetadata();


    /**
     *  Sets the url for a class web site. 
     *
     *  @param  url the new url 
     *  @throws org.osid.InvalidArgumentException <code> url </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> url </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setURL(String url);


    /**
     *  Removes the url. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearURL();


    /**
     *  Gets the metadata for a schedule informatoin string. 
     *
     *  @return metadata for the schedule information 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getScheduleInfoMetadata();


    /**
     *  Sets the schedule information. This information may be derived from 
     *  the schedule and not settable here. 
     *
     *  @param  scheduleInfo the new schedule info 
     *  @throws org.osid.InvalidArgumentException <code> scheduleInfo </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> scheduleInfo </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setScheduleInfo(String scheduleInfo);


    /**
     *  Removes the schedule info. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearScheduleInfo();


    /**
     *  Gets the metadata for manually linking an event. 
     *
     *  @return metadata for the event 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getEventMetadata();


    /**
     *  Sets the event. This information may be derived from the activity 
     *  schedules. 
     *
     *  @param  eventId the new event 
     *  @throws org.osid.InvalidArgumentException <code> eventId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> eventId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setEvent(org.osid.id.Id eventId);


    /**
     *  Removes the event. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEvent();


    /**
     *  Gets the <code> CourseOfferingFormRecord </code> corresponding to the 
     *  given course offering record <code> Type. </code> 
     *
     *  @param  courseOfferingRecordType a course offering record type 
     *  @return the course offering form record 
     *  @throws org.osid.NullArgumentException <code> courseOfferingRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(courseOfferingRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.records.CourseOfferingFormRecord getCourseOfferingFormRecord(org.osid.type.Type courseOfferingRecordType)
        throws org.osid.OperationFailedException;
}
