//
// org.osid.course.CourseOfferingLookupSession
//
//     The OSID Java specification for org.osid.course.CourseOfferingLookupSession.
//
// Copyright (C) 2002-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course;


/**
 *  <p>This session defines methods for retrieving course offerings. A <code> 
 *  CourseOffering </code> is a scheduled course listed in a course catalog. A 
 *  <code> CourseOffering </code> is derived from a <code> Course </code> and 
 *  maps to an offering time and registered students. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated course catalog view: All course offering methods in this 
 *      session operate, retrieve and pertain to course offerings defined 
 *      explicitly in the current course catalog. Using an isolated view is 
 *      useful for managing <code> CourseOfferings </code> with the <code> 
 *      CourseOfferingAdminSession. </code> </li> 
 *      <li> federated course catalog view: All course offering lookup methods 
 *      in this session operate, retrieve and pertain to all course offerings 
 *      defined in this course catalog and any other courses implicitly 
 *      available in this course catalog through course catalog inheritence. 
 *      </li> 
 *      <li> effective course offering view: All course offering lookup 
 *      methods return course offerings where the current date falls within 
 *      the effective dates inclusive. </li> 
 *      <li> any effective course offering view: Course offerings of any 
 *      effective or expired status are returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedCourseCatalogView() </code> and <code> 
 *  useIsolatedCourseCatalogView() </code> behave as a radio group and one 
 *  should be selected before invoking any lookup methods. </p> 
 *  
 *  <p> Courses may have an additional records indicated by their respective 
 *  record types. The record may not be accessed through a cast of the <code> 
 *  Course. </code> </p>
 */

public interface CourseOfferingLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> CourseCatalog </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> CourseCatalog Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCourseCatalogId();


    /**
     *  Gets the <code> CourseCatalog </code> associated with this session. 
     *
     *  @return the course catalog 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseCatalog getCourseCatalog()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> CourseOffering </code> lookups. 
     *  A return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupCourseOfferings();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeCourseOfferingView();


    /**
     *  A complete view of the <code> CourseOffering </code> returns is 
     *  desired. Methods will return what is requested or result in an error. 
     *  This view is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryCourseOfferingView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include course offerings in catalogs which are children of this 
     *  catalog in the course catalog hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCourseCatalogView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this course catalog only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCourseCatalogView();


    /**
     *  All course offering methods return course offerings where the current 
     *  date falls within the effective dates inclusive. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useEffectiveCourseOfferingView();


    /**
     *  All methods return course offerings of any effective or expired 
     *  status. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyEffectiveCourseOfferingView();


    /**
     *  Gets the <code> CourseOffering </code> specified by its <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  CourseOffering </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> Course </code> and retained for compatibility. 
     *  
     *  In effective mode, course offerings are returned where the current 
     *  date falls within the effective dates inclusive. In any effective 
     *  mode, effective and expired course offerings are returned. 
     *
     *  @param  courseOfferingId the <code> Id </code> of the <code> 
     *          CourseOffering </code> to retrieve 
     *  @return the returned <code> CourseOffering </code> 
     *  @throws org.osid.NotFoundException no <code> CourseOffering </code> 
     *          found with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> courseOfferingId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseOffering getCourseOffering(org.osid.id.Id courseOfferingId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CourseOfferingList </code> corresponding to the given 
     *  <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  course offerings specified in the <code> Id </code> list, in the order 
     *  of the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> CourseOfferings </code> may be omitted from the 
     *  list and may present the elements in any order including returning a 
     *  unique set. 
     *  
     *  In effective mode, course offerings are returned where the current 
     *  date falls within the effective dates inclusive. In any effective 
     *  mode, effective and expired course offerings are returned. 
     *
     *  @param  courseOfferingIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> CourseOffering </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> courseOfferingIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseOfferingList getCourseOfferingsByIds(org.osid.id.IdList courseOfferingIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CourseOfferingList </code> corresponding to the given 
     *  course offering genus <code> Type </code> which does not include 
     *  course offerings of types derived from the specified <code> Type. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  course offerings or an error results. Otherwise, the returned list may 
     *  contain only those course offerings that are accessible through this 
     *  session. 
     *  
     *  In effective mode, course offerings are returned where the current 
     *  date falls within the effective dates inclusive. In any effective 
     *  mode, effective and expired course offerings are returned. 
     *
     *  @param  courseOfferingGenusType a course offering genus type 
     *  @return the returned <code> CourseOffering </code> list 
     *  @throws org.osid.NullArgumentException <code> courseOfferingGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseOfferingList getCourseOfferingsByGenusType(org.osid.type.Type courseOfferingGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CourseOfferingList </code> corresponding to the given 
     *  course genus <code> Type </code> and include any additional course 
     *  offerings with genus types derived from the specified <code> Type. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  course offerings or an error results. Otherwise, the returned list may 
     *  contain only those course offerings that are accessible through this 
     *  session. 
     *  
     *  In effective mode, course offerings are returned where the current 
     *  date falls within the effective dates inclusive. In any effective 
     *  mode, effective and expired course offerings are returned. 
     *
     *  @param  courseOfferingGenusType a course offering genus type 
     *  @return the returned <code> CourseOffering </code> list 
     *  @throws org.osid.NullArgumentException <code> courseOfferingGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseOfferingList getCourseOfferingsByParentGenusType(org.osid.type.Type courseOfferingGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CourseOfferingList </code> containing the given course 
     *  offering record <code> Type. </code> 
     *  
     *  In plenary mode, the returned list contains all known courses or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  course offerings that are accessible through this session. 
     *  
     *  In effective mode, course offerings are returned where the current 
     *  date falls within the effective dates inclusive. In any effective 
     *  mode, effective and expired course offerings are returned. 
     *
     *  @param  courseOfferingRecordType a course offering record type 
     *  @return the returned <code> CourseOffering </code> list 
     *  @throws org.osid.NullArgumentException <code> courseOfferingRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseOfferingList getCourseOfferingsByRecordType(org.osid.type.Type courseOfferingRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> CourseOfferings </code> effective within the given 
     *  date range inclusive. 
     *  
     *  In plenary mode, the returned list contains all known course offerings 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those course offerings that are accessible through this session. 
     *  
     *  In effective mode, course offerings are returned where the current 
     *  date falls within the effective dates inclusive. In any effective 
     *  mode, effective and expired course offerings are returned. 
     *
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return a list of <code> CourseOfferings </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseOfferingList getCourseOfferingsOnDate(org.osid.calendaring.DateTime from, 
                                                                       org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> CourseOfferings </code> associated with a given <code> 
     *  Course. </code> 
     *  
     *  In plenary mode, the returned list contains all known course offerings 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those course offerings that are accessible through this session. 
     *  
     *  In effective mode, course offerings are returned where the current 
     *  date falls within the effective dates inclusive. In any effective 
     *  mode, effective and expired course offerings are returned. 
     *
     *  @param  courseId a course <code> Id </code> 
     *  @return a list of <code> CourseOfferings </code> 
     *  @throws org.osid.NullArgumentException <code> courseId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseOfferingList getCourseOfferingsForCourse(org.osid.id.Id courseId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> CourseOffering </code> s for a course and effective 
     *  within the given date range inclusive. 
     *  
     *  In plenary mode, the returned list contains all known course offerings 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those course offerings that are accessible through this session. 
     *  
     *  In effective mode, course offerings are returned where the current 
     *  date falls within the effective dates inclusive. In any effective 
     *  mode, effective and expired course offerings are returned. 
     *
     *  @param  courseId a course <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return a list of <code> CourseOfferings </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> courseId, from, </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseOfferingList getCourseOfferingsForCourseOnDate(org.osid.id.Id courseId, 
                                                                                org.osid.calendaring.DateTime from, 
                                                                                org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> CourseOfferings </code> associated for a given <code> 
     *  Term. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  course offerings or an error results. Otherwise, the returned list may 
     *  contain only those course offerings that are accessible through this 
     *  session. 
     *  
     *  In effective mode, course offerings are returned where the current 
     *  date falls within the effective dates inclusive. In any effective 
     *  mode, effective and expired course offerings are returned. 
     *
     *  @param  termId a term <code> Id </code> 
     *  @return a list of <code> CourseOfferings </code> 
     *  @throws org.osid.NullArgumentException <code> termId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseOfferingList getCourseOfferingsForTerm(org.osid.id.Id termId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> CourseOfferings </code> for a term and effective 
     *  within the given date range inclusive. 
     *  
     *  In plenary mode, the returned list contains all known course offerings 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those course offerings that are accessible through this session. 
     *  
     *  In effective mode, course offerings are returned where the current 
     *  date falls within the effective dates inclusive. In any effective 
     *  mode, effective and expired course offerings are returned. 
     *
     *  @param  termId a term <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return a list of <code> CourseOfferings </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> termId, from, </code> or 
     *          <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseOfferingList getCourseOfferingsForTermOnDate(org.osid.id.Id termId, 
                                                                              org.osid.calendaring.DateTime from, 
                                                                              org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> CourseOfferings </code> associated with a given <code> 
     *  Term </code> and <code> Course. </code> 
     *  
     *  In plenary mode, the returned list contains all known course offerings 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those course offerings that are accessible through this session. 
     *  
     *  In effective mode, course offerings are returned where the current 
     *  date falls within the effective dates inclusive. In any effective 
     *  mode, effective and expired course offerings are returned. 
     *
     *  @param  courseId a course <code> Id </code> 
     *  @param  termId a term <code> Id </code> 
     *  @return a list of <code> CourseOfferings </code> 
     *  @throws org.osid.NullArgumentException <code> courseId </code> or 
     *          <code> termId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseOfferingList getCourseOfferingsForCourseAndTerm(org.osid.id.Id courseId, 
                                                                                 org.osid.id.Id termId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> CourseOffering </code> s for a course, term, and 
     *  effective within the given date range inclusive. 
     *  
     *  In plenary mode, the returned list contains all known course offerings 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those course offerings that are accessible through this session. 
     *  
     *  In effective mode, course offerings are returned where the current 
     *  date falls within the effective dates inclusive. In any effective 
     *  mode, effective and expired course offerings are returned. 
     *
     *  @param  courseId a course <code> Id </code> 
     *  @param  termId a term <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return a list of <code> CourseOfferings </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> courseId, termId, from, 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseOfferingList getCourseOfferingsForCourseAndTermOnDate(org.osid.id.Id courseId, 
                                                                                       org.osid.id.Id termId, 
                                                                                       org.osid.calendaring.DateTime from, 
                                                                                       org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> CourseOfferings ny number and </code> associated with 
     *  a given <code> Term. </code> 
     *  
     *  In plenary mode, the returned list contains all known course offerings 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those course offerings that are accessible through this session. 
     *  
     *  In effective mode, course offerings are returned where the current 
     *  date falls within the effective dates inclusive. In any effective 
     *  mode, effective and expired course offerings are returned. 
     *
     *  @param  termId a term <code> Id </code> 
     *  @param  number a course offering number 
     *  @return a list of <code> CourseOfferings </code> 
     *  @throws org.osid.NullArgumentException <code> termId </code> or <code> 
     *          number </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseOfferingList getCourseOfferingsByNumberForTerm(org.osid.id.Id termId, 
                                                                                String number)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> CourseOfferings. </code> 
     *  
     *  In plenary mode, the returned list contains all known course offerings 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those courses that are accessible through this session. 
     *  
     *  In effective mode, course offerings are returned where the current 
     *  date falls within the effective dates inclusive. In any effective 
     *  mode, effective and expired course offerings are returned. 
     *
     *  @return a list of <code> CourseOfferings </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseOfferingList getCourseOfferings()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
