//
// org.osid.course.CourseOfferingQueryInspector
//
//     The OSID Java specification for org.osid.course.CourseOfferingQueryInspector.
//
// Copyright (C) 2002-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course;


/**
 *  <p>The query inspectors provide a means of accessing the match terms of a 
 *  query. These interfaces are used to examine the actual query terms used in 
 *  a search or that may be used to create a smart catalog. Query inspectors 
 *  may be converted to <code> OsidQuery </code> interfaces for reuse or 
 *  modification in the search sessions. </p>
 */

public interface CourseOfferingQueryInspector
    extends org.osid.OsidRelationshipQueryInspector {


    /**
     *  Gets the course <code> Id </code> query terms. 
     *
     *  @return the course <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getCourseIdTerms();


    /**
     *  Gets the course query terms. 
     *
     *  @return the course query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseQueryInspector[] getCourseTerms();


    /**
     *  Gets the term <code> Id </code> query terms. 
     *
     *  @return the term <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getTermIdTerms();


    /**
     *  Gets the term query terms. 
     *
     *  @return the term query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.TermQueryInspector[] getTermTerms();


    /**
     *  Gets the title query terms. 
     *
     *  @return the title query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.StringTerm[] getTitleTerms();


    /**
     *  Gets the bumber query terms. 
     *
     *  @return the number query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.StringTerm[] getNumberTerms();


    /**
     *  Gets the instructor <code> Id </code> query terms. 
     *
     *  @return the instructor <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getInstructorIdTerms();


    /**
     *  Gets the instructor query terms. 
     *
     *  @return the instructor query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceQueryInspector[] getInstructorTerms();


    /**
     *  Gets the sponsor <code> Id </code> query terms. 
     *
     *  @return the sponsor <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getSponsorIdTerms();


    /**
     *  Gets the sponsor query terms. 
     *
     *  @return the sponsor query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceQueryInspector[] getSponsorTerms();


    /**
     *  Gets the grade system <code> Id </code> query terms. 
     *
     *  @return the grade system <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getCreditAmountIdTerms();


    /**
     *  Gets the grade system query terms. 
     *
     *  @return the grade system query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeQueryInspector[] getCreditAmountTerms();


    /**
     *  Gets the grade system <code> Id </code> query terms. 
     *
     *  @return the grade system <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getGradingOptionIdTerms();


    /**
     *  Gets the grade system query terms. 
     *
     *  @return the grade system terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeSystemQueryInspector[] getGradingOptionTerms();


    /**
     *  Gets the requires registration query terms. 
     *
     *  @return the requires registration query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.BooleanTerm[] getRequiresRegistrationTerms();


    /**
     *  Gets the minimum seats query terms. 
     *
     *  @return the minimum seats query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.CardinalRangeTerm[] getMinimumSeatsTerms();


    /**
     *  Gets the maximum seats query terms. 
     *
     *  @return the maximum seats query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.CardinalRangeTerm[] getMaximumSeatsTerms();


    /**
     *  Gets the url query terms. 
     *
     *  @return the url query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.StringTerm[] getURLTerms();


    /**
     *  Gets the scheudle info query terms. 
     *
     *  @return the schedule info query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.StringTerm[] getScheduleInfoTerms();


    /**
     *  Gets the event <code> Id </code> query terms. 
     *
     *  @return the event <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getEventIdTerms();


    /**
     *  Gets the event query terms. 
     *
     *  @return the event terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.EventQueryInspector[] getEventTerms();


    /**
     *  Gets the activity <code> Id </code> query terms. 
     *
     *  @return the activity <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getActivityIdTerms();


    /**
     *  Gets the activity query terms. 
     *
     *  @return the activity query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.ActivityQueryInspector[] getActivityTerms();


    /**
     *  Gets the course catalog <code> Id </code> query terms. 
     *
     *  @return the course catalog <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getCourseCatalogIdTerms();


    /**
     *  Gets the course catalog query terms. 
     *
     *  @return the course catalog query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseCatalogQueryInspector[] getCourseCatalogTerms();


    /**
     *  Gets the course offering query inspector record corresponding to the 
     *  given <code> CourseOffering </code> record <code> Type. </code> 
     *  Multiple record retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  courseOfferingRecordType a course offering record type 
     *  @return the course offering query inspector record 
     *  @throws org.osid.NullArgumentException <code> courseOfferingRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(courseOfferingRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.records.CourseOfferingQueryInspectorRecord getCourseOfferingQueryInspectorRecord(org.osid.type.Type courseOfferingRecordType)
        throws org.osid.OperationFailedException;
}
