//
// org.osid.course.CourseOfferingSearchSession
//
//     The OSID Java specification for org.osid.course.CourseOfferingSearchSession.
//
// Copyright (C) 2002-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course;


/**
 *  <p>This session provides methods for searching among <code> CourseOffering 
 *  </code> objects. The search query is constructed using the <code> 
 *  CourseOfferingQuery. </code> </p> 
 *  
 *  <p> <code> getCourseOfferingsByQuery() </code> is the basic search method 
 *  and returns a list of <code> CourseOfferings. </code> A more advanced 
 *  search may be performed with <code> getCourseOfferingsBySearch(). </code> 
 *  It accepts a <code> CourseOfferingSearch </code> in addition to the query 
 *  for the purpose of specifying additional options affecting the entire 
 *  search, such as ordering. <code> getCourseOfferingsBySearch() </code> 
 *  returns a <code> CourseOfferingSearchResults </code> that can be used to 
 *  access the resulting <code> CourseOfferingList </code> or be used to 
 *  perform a search within the result set through <code> 
 *  CourseOfferingSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated course catalog view: searches include course offerings 
 *      in course catalogs of which this course catalog is an ancestor in the 
 *      course catalog hierarchy </li> 
 *      <li> isolated course catalog view: searches are restricted to course 
 *      offerings in this course catalog </li> 
 *  </ul>
 *  
 *  
 *  <p> Course Offerings may have a query record indicated by their respective 
 *  record types. The queryrecord is accessed via the <code> 
 *  CourseOfferingQuery. </code> </p>
 */

public interface CourseOfferingSearchSession
    extends org.osid.course.CourseOfferingQuerySession {


    /**
     *  Gets a course offering search. 
     *
     *  @return the course offering search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseOfferingSearch getCourseOfferingSearch();


    /**
     *  Gets a course offering search order. The <code> 
     *  CourseOfferingSearchOrder </code> is supplied to a <code> 
     *  CourseOfferingSearch </code> to specify the ordering of results. 
     *
     *  @return the course offering search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseOfferingSearchOrder getCourseOfferingSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  courseOfferingQuery the course offering query 
     *  @param  courseOfferingSearch the course offering search 
     *  @return the course offering search results 
     *  @throws org.osid.NullArgumentException <code> courseOfferingQuery 
     *          </code> or <code> courseOfferingSearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> courseOfferingQuery 
     *          </code> or <code> courseOfferingSearch </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseOfferingSearchResults getCourseOfferingsBySearch(org.osid.course.CourseOfferingQuery courseOfferingQuery, 
                                                                                  org.osid.course.CourseOfferingSearch courseOfferingSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a course offering query from an inspector. The inspector is 
     *  available from a <code> CourseOfferingSearchResults. </code> 
     *
     *  @param  courseOfferingQueryInspector a course offering query inspector 
     *  @return the course offering query 
     *  @throws org.osid.NullArgumentException <code> 
     *          courseOfferingQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          courseOfferingQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseOfferingQuery getCourseOfferingQueryFromInspector(org.osid.assessment.ItemQueryInspector courseOfferingQueryInspector);
}
