//
// org.osid.course.CourseProfile
//
//     The OSID Java specification for org.osid.course.CourseProfile.
//
// Copyright (C) 2002-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course;


/**
 *  <p>The course profile describes the interoperability among course 
 *  management services. </p>
 */

public interface CourseProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any course catalog federation is exposed. Federation is 
     *  exposed when a specific course catalog may be identified, selected and 
     *  used to create a lookup or admin session. Federation is not exposed 
     *  when a set of catalogs appears as a single catalog. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if looking up courses is supported. 
     *
     *  @return <code> true </code> if course lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseLookup();


    /**
     *  Tests if querying courses is supported. 
     *
     *  @return <code> true </code> if course query is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseQuery();


    /**
     *  Tests if searching courses is supported. 
     *
     *  @return <code> true </code> if course search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseSearch();


    /**
     *  Tests if course <code> </code> administrative service is supported. 
     *
     *  @return <code> true </code> if course administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseAdmin();


    /**
     *  Tests if a course <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if course notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseNotification();


    /**
     *  Tests if a course cataloging service is supported. 
     *
     *  @return <code> true </code> if course cataloging is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseCourseCatalog();


    /**
     *  Tests if a course cataloging service is supported. A course cataloging 
     *  service maps courses to catalogs. 
     *
     *  @return <code> true </code> if course cataloging is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseCourseCatalogAssignment();


    /**
     *  Tests if a course smart course catalog session is available. 
     *
     *  @return <code> true </code> if a course smart course catalog session 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseSmartCourseCatalog();


    /**
     *  Tests if looking up activity units is supported. 
     *
     *  @return <code> true </code> if activity unit lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityUnitLookup();


    /**
     *  Tests if querying activity units is supported. 
     *
     *  @return <code> true </code> if activity unit query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityUnitQuery();


    /**
     *  Tests if searching activity units is supported. 
     *
     *  @return <code> true </code> if activity unit search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityUnitSearch();


    /**
     *  Tests if an activity unit <code> </code> administrative service is 
     *  supported. 
     *
     *  @return <code> true </code> if activity unit administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityUnitAdmin();


    /**
     *  Tests if an activity unit <code> </code> notification service is 
     *  supported. 
     *
     *  @return <code> true </code> if activity unit notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityUnitNotification();


    /**
     *  Tests if an activity unit cataloging service is supported. 
     *
     *  @return <code> true </code> if activity unit catalog is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityUnitCourseCatalog();


    /**
     *  Tests if an activity unit cataloging service is supported. A 
     *  cataloging service maps activity units to catalogs. 
     *
     *  @return <code> true </code> if activity unit cataloging is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityUnitCourseCatalogAssignment();


    /**
     *  Tests if an activity unit smart course catalog session is available. 
     *
     *  @return <code> true </code> if an activity unit smart course catalog 
     *          session is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityUnitSmartCourseCatalog();


    /**
     *  Tests if looking up course offerings is supported. 
     *
     *  @return <code> true </code> if course offering lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseOfferingLookup();


    /**
     *  Tests if querying course offerings is supported. 
     *
     *  @return <code> true </code> if course offering query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseOfferingQuery();


    /**
     *  Tests if searching course offerings is supported. 
     *
     *  @return <code> true </code> if course offering search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseOfferingSearch();


    /**
     *  Tests if course <code> </code> offering <code> </code> administrative 
     *  service is supported. 
     *
     *  @return <code> true </code> if course offering administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseOfferingAdmin();


    /**
     *  Tests if a course offering <code> </code> notification service is 
     *  supported. 
     *
     *  @return <code> true </code> if course offering notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseOfferingNotification();


    /**
     *  Tests if a course offering cataloging service is supported. 
     *
     *  @return <code> true </code> if course offering catalog is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseOfferingCourseCatalog();


    /**
     *  Tests if a course offering cataloging service is supported. A 
     *  cataloging service maps course offerings to catalogs. 
     *
     *  @return <code> true </code> if course offering cataloging is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseOfferingCourseCatalogAssignment();


    /**
     *  Tests if a course offering smart course catalog session is available. 
     *
     *  @return <code> true </code> if a course offering smart course catalog 
     *          session is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseOfferingSmartCourseCatalog();


    /**
     *  Tests if looking up activities is supported. 
     *
     *  @return <code> true </code> if activity lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityLookup();


    /**
     *  Tests if querying activities is supported. 
     *
     *  @return <code> true </code> if activity query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityQuery();


    /**
     *  Tests if searching activities is supported. 
     *
     *  @return <code> true </code> if activity search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivitySearch();


    /**
     *  Tests if activity administrative service is supported. 
     *
     *  @return <code> true </code> if activity administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityAdmin();


    /**
     *  Tests if an activity <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if activity notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityNotification();


    /**
     *  Tests if an activity cataloging service is supported. 
     *
     *  @return <code> true </code> if activity catalog is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityCourseCatalog();


    /**
     *  Tests if an activity cataloging service is supported. A cataloging 
     *  service maps activities to catalogs. 
     *
     *  @return <code> true </code> if activity cataloging is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityCourseCatalogAssignment();


    /**
     *  Tests if an activity smart course catalog session is available. 
     *
     *  @return <code> true </code> if an activity smart course catalog 
     *          session is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivitySmartCourseCatalog();


    /**
     *  Tests if unravelling activities is supported. 
     *
     *  @return <code> true </code> if unravelling activities is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityUnravelling();


    /**
     *  Tests if looking up terms is supported. 
     *
     *  @return <code> true </code> if term lookup is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTermLookup();


    /**
     *  Tests if querying terms is supported. 
     *
     *  @return <code> true </code> if term query is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTermQuery();


    /**
     *  Tests if searching terms is supported. 
     *
     *  @return <code> true </code> if term search is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTermSearch();


    /**
     *  Tests if term <code> </code> administrative service is supported. 
     *
     *  @return <code> true </code> if term administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTermAdmin();


    /**
     *  Tests if a term <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if term notification is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTermNotification();


    /**
     *  Tests if term <code> </code> hierarchy traversal service is supported. 
     *
     *  @return <code> true </code> if term hierarchy is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTermHierarchy();


    /**
     *  Tests if a term <code> </code> hierarchy design service is supported. 
     *
     *  @return <code> true </code> if term hierarchy design is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTermHierarchyDesign();


    /**
     *  Tests if a term cataloging service is supported. 
     *
     *  @return <code> true </code> if term catalog is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTermCourseCatalog();


    /**
     *  Tests if a term cataloging service is supported. A cataloging service 
     *  maps terms to catalogs. 
     *
     *  @return <code> true </code> if term cataloging is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTermCourseCatalogAssignment();


    /**
     *  Tests if a term smart course catalog session is available. 
     *
     *  @return <code> true </code> if a term smart course catalog session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTermSmartCourseCatalog();


    /**
     *  Tests if looking up course catalogs is supported. 
     *
     *  @return <code> true </code> if course catalog lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseCatalogLookup();


    /**
     *  Tests if searching course catalogs is supported. 
     *
     *  @return <code> true </code> if course catalog search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseCatalogSearch();


    /**
     *  Tests if querying course catalogs is supported. 
     *
     *  @return <code> true </code> if course catalog query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseCatalogQuery();


    /**
     *  Tests if course catalog administrative service is supported. 
     *
     *  @return <code> true </code> if course catalog administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseCatalogAdmin();


    /**
     *  Tests if a course catalog <code> </code> notification service is 
     *  supported. 
     *
     *  @return <code> true </code> if course catalog notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseCatalogNotification();


    /**
     *  Tests for the availability of a course catalog hierarchy traversal 
     *  service. 
     *
     *  @return <code> true </code> if course catalog hierarchy traversal is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsCourseCatalogHierarchy();


    /**
     *  Tests for the availability of a course catalog hierarchy design 
     *  service. 
     *
     *  @return <code> true </code> if course catalog hierarchy design is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseCatalogHierarchyDesign();


    /**
     *  Tests for the availability of a course batch service. 
     *
     *  @return <code> true </code> if a course batch service is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseBatch();


    /**
     *  Tests for the availability of a course program service. 
     *
     *  @return <code> true </code> if a course program service is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseProgram();


    /**
     *  Tests for the availability of a course registration service. 
     *
     *  @return <code> true </code> if a course registration service is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseRegistration();


    /**
     *  Tests for the availability of a course requisite service. 
     *
     *  @return <code> true </code> if a course requisite service is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseRequisite();


    /**
     *  Tests for the availability of a course syllabus service. 
     *
     *  @return <code> true </code> if a course syllabus service is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseSyllabus();


    /**
     *  Tests for the availability of a course plan service. 
     *
     *  @return <code> true </code> if a course plan service is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCoursePlan();


    /**
     *  Tests for the availability of a course chronicle service. 
     *
     *  @return <code> true </code> if a course chronicle service is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseChronicle();


    /**
     *  Gets the supported <code> Course </code> record types. 
     *
     *  @return a list containing the supported <code> Course </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCourseRecordTypes();


    /**
     *  Tests if the given <code> Course </code> record type is supported. 
     *
     *  @param  courseRecordType a <code> Type </code> indicating a <code> 
     *          Course </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> courseRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseRecordType(org.osid.type.Type courseRecordType);


    /**
     *  Gets the supported <code> Course </code> search record types. 
     *
     *  @return a list containing the supported <code> Course </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCourseSearchRecordTypes();


    /**
     *  Tests if the given <code> Course </code> search record type is 
     *  supported. 
     *
     *  @param  courseSearchRecordType a <code> Type </code> indicating a 
     *          <code> Course </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> courseSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseSearchRecordType(org.osid.type.Type courseSearchRecordType);


    /**
     *  Gets the supported <code> ActivityUnit </code> record types. 
     *
     *  @return a list containing the supported <code> ActivityUnit </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getActivityUnitRecordTypes();


    /**
     *  Tests if the given <code> ActivityUnit </code> record type is 
     *  supported. 
     *
     *  @param  activityUnitRecordType a <code> Type </code> indicating an 
     *          <code> ActivityUnit </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> activityUnitRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityUnitRecordType(org.osid.type.Type activityUnitRecordType);


    /**
     *  Gets the supported <code> ActivityUnit </code> search record types. 
     *
     *  @return a list containing the supported <code> ActivityUnit </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getActivityUnitSearchRecordTypes();


    /**
     *  Tests if the given <code> ActivityUnit </code> search record type is 
     *  supported. 
     *
     *  @param  activityUnitSearchRecordType a <code> Type </code> indicating 
     *          an <code> ActivityUnit </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          activityUnitSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityUnitSearchRecordType(org.osid.type.Type activityUnitSearchRecordType);


    /**
     *  Gets the supported <code> CourseOffering </code> record types. 
     *
     *  @return a list containing the supported <code> CourseOffering </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCourseOfferingRecordTypes();


    /**
     *  Tests if the given <code> CourseOffering </code> record type is 
     *  supported. 
     *
     *  @param  courseOfferingRecordType a <code> Type </code> indicating an 
     *          <code> CourseOffering </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> courseOfferingRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseOfferingRecordType(org.osid.type.Type courseOfferingRecordType);


    /**
     *  Gets the supported <code> CourseOffering </code> search record types. 
     *
     *  @return a list containing the supported <code> CourseOffering </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCourseOfferingSearchRecordTypes();


    /**
     *  Tests if the given <code> CourseOffering </code> search record type is 
     *  supported. 
     *
     *  @param  courseOfferingSearchRecordType a <code> Type </code> 
     *          indicating an <code> CourseOffering </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          courseOfferingSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseOfferingSearchRecordType(org.osid.type.Type courseOfferingSearchRecordType);


    /**
     *  Gets the supported <code> Activity </code> record types. 
     *
     *  @return a list containing the supported <code> Activity </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getActivityRecordTypes();


    /**
     *  Tests if the given <code> Activity </code> record type is supported. 
     *
     *  @param  activityRecordType a <code> Type </code> indicating an <code> 
     *          Activity </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> activityRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityRecordType(org.osid.type.Type activityRecordType);


    /**
     *  Gets the supported <code> Activity </code> search record types. 
     *
     *  @return a list containing the supported <code> Activity </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getActivitySearchRecordTypes();


    /**
     *  Tests if the given <code> Activity </code> search record type is 
     *  supported. 
     *
     *  @param  activitySearchRecordType a <code> Type </code> indicating an 
     *          <code> Activity </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> activitySearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivitySearchRecordType(org.osid.type.Type activitySearchRecordType);


    /**
     *  Gets the supported <code> Term </code> record types. 
     *
     *  @return a list containing the supported <code> Term </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getTermRecordTypes();


    /**
     *  Tests if the given <code> Term </code> record type is supported. 
     *
     *  @param  termRecordType a <code> Type </code> indicating a <code> Term 
     *          </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> termRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTermRecordType(org.osid.type.Type termRecordType);


    /**
     *  Gets the supported <code> Term </code> search record types. 
     *
     *  @return a list containing the supported <code> Term </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getTermSearchRecordTypes();


    /**
     *  Tests if the given <code> Term </code> search record type is 
     *  supported. 
     *
     *  @param  termSearchRecordType a <code> Type </code> indicating a <code> 
     *          Term </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> termSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTermSearchRecordType(org.osid.type.Type termSearchRecordType);


    /**
     *  Gets the supported <code> CourseCatalog </code> record types. 
     *
     *  @return a list containing the supported <code> CourseCatalog </code> 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCourseCatalogRecordTypes();


    /**
     *  Tests if the given <code> CourseCatalog </code> record type is 
     *  supported. 
     *
     *  @param  courseCatalogRecordType a <code> Type </code> indicating an 
     *          <code> CourseCatalog </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> courseCatalogRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseCatalogRecordType(org.osid.type.Type courseCatalogRecordType);


    /**
     *  Gets the supported <code> CourseCatalog </code> search record types. 
     *
     *  @return a list containing the supported <code> CourseCatalog </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCourseCatalogSearchRecordTypes();


    /**
     *  Tests if the given <code> CourseCatalog </code> search record type is 
     *  supported. 
     *
     *  @param  courseCatalogSearchRecordType a <code> Type </code> indicating 
     *          an <code> CourseCatalog </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          courseCatalogSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseCatalogSearchRecordType(org.osid.type.Type courseCatalogSearchRecordType);
}
