//
// org.osid.course.CourseQuery
//
//     The OSID Java specification for org.osid.course.CourseQuery.
//
// Copyright (C) 2002-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course;


/**
 *  <p>This is the query for searching courses. Each method match specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface CourseQuery
    extends org.osid.OsidObjectQuery,
            org.osid.OsidOperableQuery {


    /**
     *  Adds a title for this query. 
     *
     *  @param  title title string to match 
     *  @param  stringMatchType the string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> title </code> not of 
     *          <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> title </code> or <code> 
     *          stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchTitle(String title, org.osid.type.Type stringMatchType, 
                           boolean match);


    /**
     *  Matches a title that has any value. 
     *
     *  @param  match <code> true </code> to match courses with any title, 
     *          <code> false </code> to match courses with no title 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyTitle(boolean match);


    /**
     *  Clears the title terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTitleTerms();


    /**
     *  Adds a course number for this query. 
     *
     *  @param  number course number string to match 
     *  @param  stringMatchType the string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> number </code> not of 
     *          <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> number </code> or <code> 
     *          stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchNumber(String number, org.osid.type.Type stringMatchType, 
                            boolean match);


    /**
     *  Matches a course number that has any value. 
     *
     *  @param  match <code> true </code> to match courses with any number, 
     *          <code> false </code> to match courses with no title 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyNumber(boolean match);


    /**
     *  Clears the number terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearNumberTerms();


    /**
     *  Sets the resource <code> Id </code> for this query to match courses 
     *  that have a sponsor. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSponsorId(org.osid.id.Id resourceId, boolean match);


    /**
     *  Clears the sponsor <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSponsorIdTerms();


    /**
     *  Tests if a <code> ResourceQuery </code> is available. 
     *
     *  @return <code> true </code> if a resource query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSponsorQuery();


    /**
     *  Gets the query for a sponsor. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return a resource query 
     *  @throws org.osid.UnimplementedException <code> supportsSponsorQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSponsorQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceQuery getSponsorQuery();


    /**
     *  Matches courses that have any sponsor. 
     *
     *  @param  match <code> true </code> to match courses with any sponsor, 
     *          <code> false </code> to match courses with no sponsors 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnySponsor(boolean match);


    /**
     *  Clears the sponsor terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSponsorTerms();


    /**
     *  Sets the grade <code> Id </code> for this query to match courses with 
     *  a credit amount. 
     *
     *  @param  gradeId a grade <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> gradeId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCreditAmountId(org.osid.id.Id gradeId, boolean match);


    /**
     *  Clears the grade system <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCreditAmountIdTerms();


    /**
     *  Tests if a <code> GradeQuery </code> is available. 
     *
     *  @return <code> true </code> if a grade system query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCreditAmountQuery();


    /**
     *  Gets the query for a credit amount. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return a grade query 
     *  @throws org.osid.UnimplementedException <code> supportsCreditQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCreditQuery() </code> is <code> true. </code> 
     */

    public org.osid.grading.GradeQuery getCreditAmountQuery();


    /**
     *  Matches courses that have any credits. 
     *
     *  @param  match <code> true </code> to match courses with any credits 
     *          <code> false </code> to match courses with no credits 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCreditAmount(boolean match);


    /**
     *  Clears the credit terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCreditAmountTerms();


    /**
     *  Matches courses with the prerequisites informational string. 
     *
     *  @param  prereqInfo prerequisite informational string to match 
     *  @param  stringMatchType the string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> prereqInfo </code> 
     *          not of <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> prereqInfo </code> or 
     *          <code> stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchPrerequisitesInfo(String prereqInfo, 
                                       org.osid.type.Type stringMatchType, 
                                       boolean match);


    /**
     *  Matches a course that has any prerequisite information assigned. 
     *
     *  @param  match <code> true </code> to match courses with any 
     *          prerequisite information, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyPrerequisitesInfo(boolean match);


    /**
     *  Clears the prerequisite info terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPrerequisitesInfoTerms();


    /**
     *  Sets the requisite <code> Id </code> for this query. 
     *
     *  @param  requisiteId a requisite <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> requisiteId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchPrerequisitesId(org.osid.id.Id requisiteId, boolean match);


    /**
     *  Clears the requisite <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPrerequisitesIdTerms();


    /**
     *  Tests if a <code> RequisiteQuery </code> is available. 
     *
     *  @return <code> true </code> if a requisite query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPrerequisitesQuery();


    /**
     *  Gets the query for a requisite. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return a prerequisites query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPrerequisitesQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPrerequisitesQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.requisite.RequisiteQuery getPrerequisitesQuery();


    /**
     *  Matches courses that have any prerequisites. 
     *
     *  @param  match <code> true </code> to match courses with any 
     *          prerequisites, <code> false </code> to match courses with no 
     *          prerequisites 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyPrerequisites(boolean match);


    /**
     *  Clears the prerequisites terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPrerequisitesTerms();


    /**
     *  Sets the grade <code> Id </code> for this query. 
     *
     *  @param  gradeId a grade <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> gradeId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchLevelId(org.osid.id.Id gradeId, boolean match);


    /**
     *  Clears the grade <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLevelIdTerms();


    /**
     *  Tests if a <code> GradeQuery </code> is available. 
     *
     *  @return <code> true </code> if a grade query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLevelQuery();


    /**
     *  Gets the query for a grade level. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return a grade query 
     *  @throws org.osid.UnimplementedException <code> supportsLevelQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLevelQuery() </code> is <code> true. </code> 
     */

    public org.osid.grading.GradeQuery getLevelQuery();


    /**
     *  Matches courses that have any grade level. 
     *
     *  @param  match <code> true </code> to match courses with any level, 
     *          <code> false </code> to match courses with no level 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyLevel(boolean match);


    /**
     *  Clears the level terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLevelTerms();


    /**
     *  Sets the grade system <code> Id </code> for this query. 
     *
     *  @param  gradeSystemId a grade system <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> gradeSystemId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchGradingOptionId(org.osid.id.Id gradeSystemId, 
                                     boolean match);


    /**
     *  Clears the grade system <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGradingOptionIdTerms();


    /**
     *  Tests if a <code> GradeSystemQuery </code> is available. 
     *
     *  @return <code> true </code> if a grade system query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradingOptionQuery();


    /**
     *  Gets the query for a grading option. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return a grade system query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradingOptionQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradingOptionQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.grading.GradeSystemQuery getGradingOptionQuery();


    /**
     *  Matches courses that have any grading option. 
     *
     *  @param  match <code> true </code> to match courses with any grading 
     *          option, <code> false </code> to match courses with no grading 
     *          options 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyGradingOption(boolean match);


    /**
     *  Clears the grading option terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGradingOptionTerms();


    /**
     *  Sets the objective <code> Id </code> for this query. 
     *
     *  @param  objectiveId an objective <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> objectiveId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchLearningObjectiveId(org.osid.id.Id objectiveId, 
                                         boolean match);


    /**
     *  Clears the objective <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLearningObjectiveIdTerms();


    /**
     *  Tests if a <code> ObjectiveQuery </code> is available. 
     *
     *  @return <code> true </code> if an objective query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLearningObjectiveQuery();


    /**
     *  Gets the query for a learning objective. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return an objective query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsLearningObjectiveQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLearningObjectiveQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.learning.ObjectiveQuery getLearningObjectiveQuery();


    /**
     *  Matches courses that have any learning objective. 
     *
     *  @param  match <code> true </code> to match courses with any learning 
     *          objective, <code> false </code> to match courses with no 
     *          learning objectives 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyLearningObjective(boolean match);


    /**
     *  Clears the learning objective terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLearningObjectiveTerms();


    /**
     *  Sets the course offering <code> Id </code> for this query to match 
     *  courses that have a related course offering. 
     *
     *  @param  courseOfferingId a course offering <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> courseOfferingId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchActivityUnitId(org.osid.id.Id courseOfferingId, 
                                    boolean match);


    /**
     *  Clears the activity unit <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearActivityUnitIdTerms();


    /**
     *  Tests if a <code> ActivityUnitQuery </code> is available. 
     *
     *  @return <code> true </code> if a activity unit query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityUnitQuery();


    /**
     *  Gets the query for an activity unit. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the activity unit query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActivityUnitQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityUnitQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.ActivityUnitQuery getActivityUnitQuery();


    /**
     *  Matches courses that have any course offering. 
     *
     *  @param  match <code> true </code> to match courses with any related 
     *          activity unit, <code> false </code> to match courses with no 
     *          activity units 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyActivityUnit(boolean match);


    /**
     *  Clears the activity unit terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearActivityUnitTerms();


    /**
     *  Sets the course offering <code> Id </code> for this query to match 
     *  courses that have a related course offering. 
     *
     *  @param  courseOfferingId a course offering <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> courseOfferingId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCourseOfferingId(org.osid.id.Id courseOfferingId, 
                                      boolean match);


    /**
     *  Clears the course offering <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCourseOfferingIdTerms();


    /**
     *  Tests if a <code> CourseOfferingQuery </code> is available. 
     *
     *  @return <code> true </code> if a course offering query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseOfferingQuery();


    /**
     *  Gets the query for a course offering. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the course offering query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCourseOfferingQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCourseOfferingQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.CourseOfferingQuery getCourseOfferingQuery();


    /**
     *  Matches courses that have any course offering. 
     *
     *  @param  match <code> true </code> to match courses with any course 
     *          offering, <code> false </code> to match courses with no course 
     *          offering 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCourseOffering(boolean match);


    /**
     *  Clears the course offering terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCourseOfferingTerms();


    /**
     *  Sets the course catalog <code> Id </code> for this query to match 
     *  courses assigned to course catalogs. 
     *
     *  @param  courseCatalogId the course catalog <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCourseCatalogId(org.osid.id.Id courseCatalogId, 
                                     boolean match);


    /**
     *  Clears the course catalog <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCourseCatalogIdTerms();


    /**
     *  Tests if a <code> CourseCatalogQuery </code> is available. 
     *
     *  @return <code> true </code> if a course catalog query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseCatalogQuery();


    /**
     *  Gets the query for a course catalog. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the course catalog query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCourseCatalogQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCourseCatalogQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.CourseCatalogQuery getCourseCatalogQuery();


    /**
     *  Clears the course catalog terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCourseCatalogTerms();


    /**
     *  Gets the course query record corresponding to the given <code> Course 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @param  courseRecordType a course record type 
     *  @return the course query record 
     *  @throws org.osid.NullArgumentException <code> courseRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(courseRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.records.CourseQueryRecord getCourseQueryRecord(org.osid.type.Type courseRecordType)
        throws org.osid.OperationFailedException;
}
