//
// org.osid.course.CourseSearchSession
//
//     The OSID Java specification for org.osid.course.CourseSearchSession.
//
// Copyright (C) 2002-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course;


/**
 *  <p>This session provides methods for searching among <code> Course </code> 
 *  objects. The search query is constructed using the <code> CourseQuery. 
 *  </code> </p> 
 *  
 *  <p> <code> getCoursesByQuery() </code> is the basic search method and 
 *  returns a list of <code> Courses. </code> A more advanced search may be 
 *  performed with <code> getCoursesBySearch(). </code> It accepts a <code> 
 *  CourseSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getCoursesBySearch() </code> returns a <code> 
 *  CourseSearchResults </code> that can be used to access the resulting 
 *  <code> CourseList </code> or be used to perform a search within the result 
 *  set through <code> CourseSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated course catalog view: searches include courses in course 
 *      catalogs of which this course catalog is an ancestor in the course 
 *      catalog hierarchy </li> 
 *      <li> isolated course catalog view: searches are restricted to courses 
 *      in this course catalog </li> 
 *  </ul>
 *  
 *  
 *  <p> Courses may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> CourseQuery. </code> 
 *  </p>
 */

public interface CourseSearchSession
    extends org.osid.course.CourseQuerySession {


    /**
     *  Gets a course search. 
     *
     *  @return the course search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseSearch getCourseSearch();


    /**
     *  Gets a course search order. The <code> CourseSearchOrder </code> is 
     *  supplied to a <code> CourseSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the course search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseSearchOrder getCourseSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  courseQuery the course query 
     *  @param  courseSearch the course search 
     *  @return the course search results 
     *  @throws org.osid.NullArgumentException <code> courseQuery </code> or 
     *          <code> courseSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> courseQuery </code> or 
     *          <code> courseSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseSearchResults getCoursesBySearch(org.osid.course.CourseQuery courseQuery, 
                                                                  org.osid.course.CourseSearch courseSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a course query from an inspector. The inspector is available from 
     *  a <code> CourseSearchResults. </code> 
     *
     *  @param  courseQueryInspector a course query inspector 
     *  @return the course query 
     *  @throws org.osid.NullArgumentException <code> courseQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> courseQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseQuery getCourseQueryFromInspector(org.osid.course.CourseQueryInspector courseQueryInspector);
}
