//
// org.osid.course.TermQuery
//
//     The OSID Java specification for org.osid.course.TermQuery.
//
// Copyright (C) 2002-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course;


/**
 *  <p>This is the query for searching terms. Each method match specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface TermQuery
    extends org.osid.OsidObjectQuery,
            org.osid.OsidFederateableQuery {


    /**
     *  Adds a display label for this query. 
     *
     *  @param  label label string to match 
     *  @param  stringMatchType the label match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> label </code> not of 
     *          <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> label </code> or <code> 
     *          stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDisplayLabel(String label, 
                                  org.osid.type.Type stringMatchType, 
                                  boolean match);


    /**
     *  Matches a display label that has any value. 
     *
     *  @param  match <code> true </code> to match courses with any label, 
     *          <code> false </code> to match assets with no title 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDisplayLabel(boolean match);


    /**
     *  Clears the display label query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDisplayLabelTerms();


    /**
     *  Matches the open date between the given range inclusive. 
     *
     *  @param  low low date range 
     *  @param  high high date range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> high </code> is less 
     *          than <code> low </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchOpenDate(org.osid.calendaring.DateTime low, 
                              org.osid.calendaring.DateTime high, 
                              boolean match);


    /**
     *  Matches a term that has any open date assigned. 
     *
     *  @param  match <code> true </code> to match terms with any open date, 
     *          <code> false </code> to match terms with no open date 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyOpenDate(boolean match);


    /**
     *  Clears the open date query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOpenDateTerms();


    /**
     *  Matches the registration start date between the given range inclusive. 
     *
     *  @param  low low date range 
     *  @param  high high date range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> high </code> is less 
     *          than <code> low </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRegistrationStart(org.osid.calendaring.DateTime low, 
                                       org.osid.calendaring.DateTime high, 
                                       boolean match);


    /**
     *  Matches a term that has any registration start date assigned. 
     *
     *  @param  match <code> true </code> to match terms with any registration 
     *          start date, <code> false </code> to match terms with no 
     *          registration start date 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRegistrationStart(boolean match);


    /**
     *  Clears the registration start date query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRegistrationStartTerms();


    /**
     *  Matches the registration end date between the given range inclusive. 
     *
     *  @param  low low date range 
     *  @param  high high date range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> high </code> is less 
     *          than <code> low </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRegistrationEnd(org.osid.calendaring.DateTime low, 
                                     org.osid.calendaring.DateTime high, 
                                     boolean match);


    /**
     *  Matches a term that has any registration end date assigned. 
     *
     *  @param  match <code> true </code> to match terms with any registration 
     *          end date, <code> false </code> to match terms with no 
     *          registration end date 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRegistrationEnd(boolean match);


    /**
     *  Clears the registration end date query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRegistrationEndTerms();


    /**
     *  Matches the registration period that incudes the given date. 
     *
     *  @param  date a date 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRegistrationPeriod(org.osid.calendaring.DateTime date, 
                                        boolean match);


    /**
     *  Clears the registration period query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRegistrationPeriodTerms();


    /**
     *  Matches the registration period duration between the given range 
     *  inclusive. 
     *
     *  @param  low low duration range 
     *  @param  high high duration range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> high </code> is less 
     *          than <code> low </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRegistrationDuration(org.osid.calendaring.Duration low, 
                                          org.osid.calendaring.Duration high, 
                                          boolean match);


    /**
     *  Clears the registration period duration query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRegistrationDurationTerms();


    /**
     *  Matches the class start date between the given range inclusive. 
     *
     *  @param  low low date range 
     *  @param  high high date range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> high </code> is less 
     *          than <code> low </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchClassesStart(org.osid.calendaring.DateTime low, 
                                  org.osid.calendaring.DateTime high, 
                                  boolean match);


    /**
     *  Matches a term that has any class start date assigned. 
     *
     *  @param  match <code> true </code> to match terms with any class start 
     *          date, <code> false </code> to match terms with no class start 
     *          date 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyClassesStart(boolean match);


    /**
     *  Clears the class start date query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearClassesStartTerms();


    /**
     *  Matches the class end date between the given range inclusive. 
     *
     *  @param  low low date range 
     *  @param  high high date range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> high </code> is less 
     *          than <code> low </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchClassesEnd(org.osid.calendaring.DateTime low, 
                                org.osid.calendaring.DateTime high, 
                                boolean match);


    /**
     *  Matches a term that has any class end date assigned. 
     *
     *  @param  match <code> true </code> to match terms with any class end 
     *          date, <code> false </code> to match terms with no class end 
     *          date 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyClassesEnd(boolean match);


    /**
     *  Clears the class end date query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearClassesEndTerms();


    /**
     *  Matches the class period that incudes the given date. 
     *
     *  @param  date a date 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchClassesPeriod(org.osid.calendaring.DateTime date, 
                                   boolean match);


    /**
     *  Clears the class period query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearClassesPeriodTerms();


    /**
     *  Matches the classes period duration between the given range inclusive. 
     *
     *  @param  low low duration range 
     *  @param  high high duration range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> high </code> is less 
     *          than <code> low </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchClassesDuration(org.osid.calendaring.Duration low, 
                                     org.osid.calendaring.Duration high, 
                                     boolean match);


    /**
     *  Clears the classes period duration query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearClassesDurationTerms();


    /**
     *  Matches the add date between the given range inclusive. 
     *
     *  @param  low low date range 
     *  @param  high high date range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> high </code> is less 
     *          than <code> low </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAddDate(org.osid.calendaring.DateTime low, 
                             org.osid.calendaring.DateTime high, boolean match);


    /**
     *  Matches a term that has any add date assigned. 
     *
     *  @param  match <code> true </code> to match terms with any add date, 
     *          <code> false </code> to match terms with no add/drop date 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAddDate(boolean match);


    /**
     *  Clears the add date query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAddDateTerms();


    /**
     *  Matches the drop date between the given range inclusive. 
     *
     *  @param  low low date range 
     *  @param  high high date range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> high </code> is less 
     *          than <code> low </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDropDate(org.osid.calendaring.DateTime low, 
                              org.osid.calendaring.DateTime high, 
                              boolean match);


    /**
     *  Matches a term that has any drop date assigned. 
     *
     *  @param  match <code> true </code> to match terms with any drop date, 
     *          <code> false </code> to match terms with no add/drop date 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDropDate(boolean match);


    /**
     *  Clears the drop date query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDropDateTerms();


    /**
     *  Matches the final exam period start date between the given range 
     *  inclusive. 
     *
     *  @param  low low date range 
     *  @param  high high date range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> high </code> is less 
     *          than <code> low </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchFinalExamStart(org.osid.calendaring.DateTime low, 
                                    org.osid.calendaring.DateTime high, 
                                    boolean match);


    /**
     *  Matches a term that has any final exam period start date assigned. 
     *
     *  @param  match <code> true </code> to match terms with any final exam 
     *          start date, <code> false </code> to match terms with no final 
     *          exam start date 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyFinalExamStart(boolean match);


    /**
     *  Clears the final exam start date query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFinalExamStartTerms();


    /**
     *  Matches the final exam period end date between the given range 
     *  inclusive. 
     *
     *  @param  low low date range 
     *  @param  high high date range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> high </code> is less 
     *          than <code> low </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchFinalExamEnd(org.osid.calendaring.DateTime low, 
                                  org.osid.calendaring.DateTime high, 
                                  boolean match);


    /**
     *  Matches a term that has any final exam period end date assigned. 
     *
     *  @param  match <code> true </code> to match terms with any final exam 
     *          end date, <code> false </code> to match terms with no final 
     *          exam end date 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyFinalExamEnd(boolean match);


    /**
     *  Clears the final exam period end date query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFinalExamEndTerms();


    /**
     *  Matches the final exam period that incudes the given date. 
     *
     *  @param  date a date 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchFinalExamPeriod(org.osid.calendaring.DateTime date, 
                                     boolean match);


    /**
     *  Clears the final exam period query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFinalExamPeriodTerms();


    /**
     *  Matches the final exam period duration between the given range 
     *  inclusive. 
     *
     *  @param  low low duration range 
     *  @param  high high duration range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> high </code> is less 
     *          than <code> low </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchFinalExamDuration(org.osid.calendaring.Duration low, 
                                       org.osid.calendaring.Duration high, 
                                       boolean match);


    /**
     *  Clears the final exam period duration query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFinalExamDurationTerms();


    /**
     *  Matches the close date between the given range inclusive. 
     *
     *  @param  low low date range 
     *  @param  high high date range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> high </code> is less 
     *          than <code> low </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCloseDate(org.osid.calendaring.DateTime low, 
                               org.osid.calendaring.DateTime high, 
                               boolean match);


    /**
     *  Matches a term that has any close date assigned. 
     *
     *  @param  match <code> true </code> to match terms with any close date, 
     *          <code> false </code> to match terms with no close date 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCloseDate(boolean match);


    /**
     *  Clears the close date query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCloseDateTerms();


    /**
     *  Sets the term <code> Id </code> for this query to match terms that 
     *  have the specified term as an ancestor. 
     *
     *  @param  termId a term <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> termId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorTermId(org.osid.id.Id termId, boolean match);


    /**
     *  Clears the ancestor term <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorTermIdTerms();


    /**
     *  Tests if a <code> TermQuery </code> is available. 
     *
     *  @return <code> true </code> if a termency query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorTermQuery();


    /**
     *  Gets the query for a term. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the term query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorTermQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorTermQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.TermQuery getAncestorTermQuery();


    /**
     *  Matches terms with any ancestor. 
     *
     *  @param  match <code> true </code> to match terms with any ancestor, 
     *          <code> false </code> to match root terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorTerm(boolean match);


    /**
     *  Clears the ancestor term query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorTermTerms();


    /**
     *  Sets the term <code> Id </code> for this query to match terms that 
     *  have the specified term as a descendant. 
     *
     *  @param  termId a term <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> termId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantTermId(org.osid.id.Id termId, boolean match);


    /**
     *  Clears the descendant term <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantTermIdTerms();


    /**
     *  Tests if a <code> TermQuery </code> is available. 
     *
     *  @return <code> true </code> if a termency query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantTermQuery();


    /**
     *  Gets the query for a term. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the term query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantTermQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantTermQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.TermQuery getDescendantTermQuery();


    /**
     *  Matches terms with any descendant. 
     *
     *  @param  match <code> true </code> to match terms with any Ddscendant, 
     *          <code> false </code> to match leaf terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantTerm(boolean match);


    /**
     *  Clears the descendant term query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantTermTerms();


    /**
     *  Sets the course offering <code> Id </code> for this query to match 
     *  terms assigned to course offerings. 
     *
     *  @param  courseOfferingId the course offering <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> courseOfferingId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCourseOfferingId(org.osid.id.Id courseOfferingId, 
                                      boolean match);


    /**
     *  Clears the course offering <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCourseOfferingIdTerms();


    /**
     *  Tests if a <code> CourseOfferingQuery </code> is available. 
     *
     *  @return <code> true </code> if a course offering query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseOfferingQuery();


    /**
     *  Gets the query for a course offering. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the course offering query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCourseOfferingQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCourseOfferingQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.CourseOfferingQuery getCourseOfferingQuery();


    /**
     *  Matches courses that have any course offering. 
     *
     *  @param  match <code> true </code> to match terms with any course 
     *          offering, <code> false </code> to match terms with no course 
     *          offerings 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCourseOffering(boolean match);


    /**
     *  Clears the course offering query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCourseOfferingTerms();


    /**
     *  Sets the course catalog <code> Id </code> for this query to match 
     *  terms assigned to course catalogs. 
     *
     *  @param  courseCatalogId the course catalog <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCourseCatalogId(org.osid.id.Id courseCatalogId, 
                                     boolean match);


    /**
     *  Clears the course catalog <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCourseCatalogIdTerms();


    /**
     *  Tests if a <code> CourseCatalogQuery </code> is available. 
     *
     *  @return <code> true </code> if a course catalog query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseCatalogQuery();


    /**
     *  Gets the query for a course catalog. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the course catalog query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCourseCatalogQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCourseCatalogQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.CourseCatalogQuery getCourseCatalogQuery();


    /**
     *  Clears the course catalog query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCourseCatalogTerms();


    /**
     *  Gets the term query record corresponding to the given <code> Term 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @param  termRecordType a term record type 
     *  @return the term query record 
     *  @throws org.osid.NullArgumentException <code> termRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(termRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.records.TermQueryRecord getTermQueryRecord(org.osid.type.Type termRecordType)
        throws org.osid.OperationFailedException;
}
