//
// org.osid.course.TermQueryInspector
//
//     The OSID Java specification for org.osid.course.TermQueryInspector.
//
// Copyright (C) 2002-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course;


/**
 *  <p>The query inspectors provide a means of accessing the match terms of a 
 *  query. These interfaces are used to examine the actual query terms used in 
 *  a search or that may be used to create a smart catalog. Query inspectors 
 *  may be converted to <code> OsidQuery </code> interfaces for reuse or 
 *  modification in the search sessions. </p>
 */

public interface TermQueryInspector
    extends org.osid.OsidObjectQueryInspector,
            org.osid.OsidFederateableQueryInspector {


    /**
     *  Gets the display label query terms. 
     *
     *  @return the display labelquery terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.StringTerm[] getDisplayLabelTerms();


    /**
     *  Gets the open date query terms. 
     *
     *  @return the open date query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DateTimeRangeTerm[] getOpenDateTerms();


    /**
     *  Gets the registration start date query terms. 
     *
     *  @return the registration start date query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DateTimeRangeTerm[] getRegistrationStartTerms();


    /**
     *  Gets the registration end date query terms. 
     *
     *  @return the registration end date query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DateTimeRangeTerm[] getRegistrationEndTerms();


    /**
     *  Gets the registration period query terms. 
     *
     *  @return the registration period query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DateTimeRangeTerm[] getRegistrationPeriodTerms();


    /**
     *  Gets the registration duration query terms. 
     *
     *  @return the registration duration query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DurationRangeTerm[] getRegistrationDurationTerms();


    /**
     *  Gets the class start date query terms. 
     *
     *  @return the class start date query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DateTimeRangeTerm[] getClassesStartTerms();


    /**
     *  Gets the class end date query terms. 
     *
     *  @return the class end date query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DateTimeRangeTerm[] getClassesEndTerms();


    /**
     *  Gets the class period query terms. 
     *
     *  @return the class period query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DateTimeRangeTerm[] getClassesPeriodTerms();


    /**
     *  Gets the classes duration query terms. 
     *
     *  @return the classes duration query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DurationRangeTerm[] getClassesDurationTerms();


    /**
     *  Gets the add date query terms. 
     *
     *  @return the add date query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DateTimeRangeTerm[] getAddDateTerms();


    /**
     *  Gets the drop date query terms. 
     *
     *  @return the drop date query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DateTimeRangeTerm[] getDropDateTerms();


    /**
     *  Gets the final exam start date query terms. 
     *
     *  @return the final exam start date query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DateTimeRangeTerm[] getFinalExamStartTerms();


    /**
     *  Gets the final exam end date query terms. 
     *
     *  @return the final exam end date query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DateTimeRangeTerm[] getFinalExamEndTerms();


    /**
     *  Gets the final exam period query terms. 
     *
     *  @return the final exam period query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DateTimeRangeTerm[] getFinalExamPeriodTerms();


    /**
     *  Gets the final exam duration query terms. 
     *
     *  @return the final exam duration query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DurationRangeTerm[] getFinalExamDurationTerms();


    /**
     *  Gets the close date query terms. 
     *
     *  @return the close date query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DateTimeRangeTerm[] getCloseDateTerms();


    /**
     *  Gets the ancestor term <code> Id </code> query terms. 
     *
     *  @return the ancestor term <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getAncestorTermIdTerms();


    /**
     *  Gets the ancestor term query terms. 
     *
     *  @return the ancestor term terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.TermQueryInspector[] getAncestorTermTerms();


    /**
     *  Gets the descendant term <code> Id </code> query terms. 
     *
     *  @return the descendant term <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getDescendantTermIdTerms();


    /**
     *  Gets the descendant term query terms. 
     *
     *  @return the descendant term terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.TermQueryInspector[] getDescendantTermTerms();


    /**
     *  Gets the course offering <code> Id </code> query terms. 
     *
     *  @return the course offering <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getCourseOfferingIdTerms();


    /**
     *  Gets the course offering query terms. 
     *
     *  @return the course offering query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseOfferingQueryInspector[] getCourseOfferingTerms();


    /**
     *  Gets the course catalog <code> Id </code> query terms. 
     *
     *  @return the course catalog <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getCourseCatalogIdTerms();


    /**
     *  Gets the course catalog query terms. 
     *
     *  @return the course catalog query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseCatalogQueryInspector[] getCourseCatalogTerms();


    /**
     *  Gets the term query inspector record corresponding to the given <code> 
     *  Term </code> record <code> Type. </code> Multiple record retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @param  termRecordType a term record type 
     *  @return the term query inspector record 
     *  @throws org.osid.NullArgumentException <code> termRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(termRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.records.TermQueryInspectorRecord getTermQueryInspectorRecord(org.osid.type.Type termRecordType)
        throws org.osid.OperationFailedException;
}
