//
// org.osid.course.batch.ActivityBatchForm
//
//     The OSID Java specification for org.osid.course.batch.ActivityBatchForm.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.batch;


/**
 *  <p>This is the form for creating and updating activities in bulk. <code> 
 *  </code> Like all <code> OsidForm </code> objects, various data elements 
 *  may be set here for use in the create and update methods in the <code> 
 *  ActivityBatchAdminSession. </code> For each data element that may be set, 
 *  metadata may be examined to provide display hints or data constraints. 
 *  </p>
 */

public interface ActivityBatchForm
    extends org.osid.course.ActivityForm {


    /**
     *  Gets the <code> ActivityUnit </code> <code> Id </code> of the activity 
     *  if this is a create transaction. 
     *
     *  @return the activity unit <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> isForUpdate() </code> is 
     *          <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getActivityUnitId();


    /**
     *  Gets the <code> CourseOffering </code> <code> Id </code> of the 
     *  activity if this is a create transaction. 
     *
     *  @return the course offering <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> isForUpdate() </code> is 
     *          <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCourseOfferingId();


    /**
     *  Gets the term <code> Id </code> of the activity if this is a create 
     *  transaction. 
     *
     *  @return the term <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> isForUpdate() </code> is 
     *          <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getTermId();


    /**
     *  Gets the <code> Id </code> of the activity to be updated if this is an 
     *  update transaction. 
     *
     *  @return the activity <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> isForUpdate() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getActivityId();
}
