//
// org.osid.course.chronicle.AssessmentEntryAdminSession
//
//     The OSID Java specification for org.osid.course.chronicle.AssessmentEntryAdminSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.chronicle;


/**
 *  <p>This session creates, updates, and deletes <code> AssessmentEntries. 
 *  </code> The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create an 
 *  <code> AssessmentEntry, </code> an <code> AssessmentEntryForm </code> is 
 *  requested using <code> getAssessmentEntryFormForCreate() </code> 
 *  specifying the desired award, student, and record <code> Types </code> or 
 *  none if no record <code> Types </code> are needed. The returned <code> 
 *  AssessmentEntryForm </code> will indicate that it is to be used with a 
 *  create operation and can be used to examine metdata or validate data prior 
 *  to creation. Once the <code> AssessmentEntryForm </code> is submiited to a 
 *  create operation, it cannot be reused with another create operation unless 
 *  the first operation was unsuccessful. Each <code> AssessmentEntryForm 
 *  </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> AssessmentEntryForms </code> are requested to the 
 *  <code> AssessmentEntry </code> <code> Id </code> that is to be updated 
 *  using <code> getAssessmentEntryFormForUpdate(). </code> Similarly, the 
 *  <code> AssessmentEntryForm </code> has metadata about the data that can be 
 *  updated and it can perform validation before submitting the update. The 
 *  <code> AssessmentEntryForm </code> can only be used once for a successful 
 *  update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> AssessmentEntries. </code> To 
 *  unmap an <code> AssessmentEntry </code> from the current <code> 
 *  CourseCatalog, </code> the <code> 
 *  AssessmentEntryCourseCatalogAssignmentSession </code> should be used. 
 *  These delete operations attempt to remove the <code> AssessmentEntryForm 
 *  </code> itself thus removing it from all known <code> CourseCatalog 
 *  </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface AssessmentEntryAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> CourseCatalog </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> CourseCatalog Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCourseCatalogId();


    /**
     *  Gets the <code> CourseCatalog </code> associated with this session. 
     *
     *  @return the course catalog 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseCatalog getCourseCatalog()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> AssessmentEntries. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known creating an <code> AssessmentEntry 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer create 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> AssessmentEntry </code> 
     *          creation is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAssessmentEntries();


    /**
     *  Tests if this user can create a single <code> Porgram </code> using 
     *  the desired record types. While <code> 
     *  CourseChronicleManager.getAssessmentEntryRecordTypes() </code> can be 
     *  used to examine which records are supported, this method tests which 
     *  record(s) are required for creating a specific <code> AssessmentEntry. 
     *  </code> Providing an empty array tests if an <code> AssessmentEntry 
     *  </code> can be created with no records. 
     *
     *  @param  assessmentEntryRecordTypes array of assessment entry record 
     *          types 
     *  @return <code> true </code> if <code> AssessmentEntry </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          assessmentEntryRecordTypes </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAssessmentEntryWithRecordTypes(org.osid.type.Type[] assessmentEntryRecordTypes);


    /**
     *  Gets the assessment entry form for creating new assessment entries. A 
     *  new form should be requested for each create transaction. 
     *
     *  @param  assessmentId an assessment <code> Id </code> 
     *  @param  resourceId a student <code> Id </code> 
     *  @param  assessmentEntryRecordTypes array of assessment entry record 
     *          types 
     *  @return the assessment entry form 
     *  @throws org.osid.NotFoundException <code> assessmentId </code> or 
     *          <code> resourceId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> assessmentId, 
     *          resourceId, </code> or <code> assessmentEntryRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.AssessmentEntryForm getAssessmentEntryFormForCreate(org.osid.id.Id assessmentId, 
                                                                                         org.osid.id.Id resourceId, 
                                                                                         org.osid.type.Type[] assessmentEntryRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> AssessmentEntry. </code> 
     *
     *  @param  assessmentEntryForm the form for this <code> AssessmentEntry 
     *          </code> 
     *  @return the new <code> AssessmentEntry </code> 
     *  @throws org.osid.IllegalStateException <code> assessmentEntryForm 
     *          </code> already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> assessmentEntryForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> assessmentEntryForm 
     *          </code> did not originate from <code> 
     *          getAssessmentEntryFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.AssessmentEntry createAssessmentEntry(org.osid.course.chronicle.AssessmentEntryForm assessmentEntryForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> AssessmentEntries. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known updating an <code> AssessmentEntry 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer update 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> AssessmentEntry </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateAssessmentEntries();


    /**
     *  Gets the assessment entry form for updating an existing assessment 
     *  entry. A new assessment entry form should be requested for each update 
     *  transaction. 
     *
     *  @param  assessmentEntryId the <code> Id </code> of the <code> 
     *          AssessmentEntry </code> 
     *  @return the assessment entry form 
     *  @throws org.osid.NotFoundException <code> assessmentEntryId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> assessmentEntryId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.AssessmentEntryForm getAssessmentEntryFormForUpdate(org.osid.id.Id assessmentEntryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing assessment entry. 
     *
     *  @param  assessmentEntryForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> assessmentEntryForm 
     *          </code> already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> assessmentEntryForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> assessmentEntryForm 
     *          </code> did not originate from <code> 
     *          getAssessmentEntryFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateAssessmentEntry(org.osid.course.chronicle.AssessmentEntryForm assessmentEntryForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> AssessmentEntries. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known deleting an <code> AssessmentEntry 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer delete 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> AssessmentEntry </code> 
     *          deletion is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteAssessmentEntries();


    /**
     *  Tests if this user can delete a specified <code> AssessmentEntry. 
     *  </code> A return of true does not guarantee successful authorization. 
     *  A return of false indicates that it is known deleting the <code> 
     *  AssessmentEntry </code> will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer a delete operation to an unauthorized user for this 
     *  assessment entry. 
     *
     *  @param  assessmentEntryId the <code> Id </code> of the <code> 
     *          AssessmentEntry </code> 
     *  @return <code> false </code> if deletion of this <code> 
     *          AssessmentEntry </code> is not authorized, <code> true </code> 
     *          otherwise 
     *  @throws org.osid.NullArgumentException <code> assessmentEntryId 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If the <code> assessmentEntryId </code> is not found, then it 
     *          is acceptable to return false to indicate the lack of a delete 
     *          available. 
     */

    public boolean canDeleteAssessmentEntry(org.osid.id.Id assessmentEntryId);


    /**
     *  Deletes an <code> AssessmentEntry. </code> 
     *
     *  @param  assessmentEntryId the <code> Id </code> of the <code> 
     *          AssessmentEntry </code> to remove 
     *  @throws org.osid.NotFoundException <code> assessmentEntryId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> assessmentEntryId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteAssessmentEntry(org.osid.id.Id assessmentEntryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  AssessmentEntries. </code> A return of true does not guarantee 
     *  successful authorization. A return of false indicates that it is known 
     *  changing an alias will result in a <code> PERMISSION_DENIED. </code> 
     *  This is intended as a hint to an application that may opt not to offer 
     *  alias operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> AssessmentEntry </code> 
     *          aliasing is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageAssessmentEntryAliases();


    /**
     *  Adds an <code> Id </code> to an <code> AssessmentEntry </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> AssessmentEntry </code> is determined by the provider. The 
     *  new <code> Id </code> performs as an alias to the primary <code> Id. 
     *  </code> If the alias is a pointer to another assessment entry, it is 
     *  reassigned to the given assessment entry <code> Id. </code> 
     *
     *  @param  assessmentEntryId the <code> Id </code> of an <code> 
     *          AssessmentEntry </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is in 
     *          use as a primary <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> assessmentEntryId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> assessmentEntryId 
     *          </code> or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasAssessmentEntry(org.osid.id.Id assessmentEntryId, 
                                     org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
