//
// org.osid.course.chronicle.AssessmentEntryForm
//
//     The OSID Java specification for org.osid.course.chronicle.AssessmentEntryForm.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.chronicle;


/**
 *  <p>This is the form for creating and updating <code> AssessmentEntries. 
 *  </code> Like all <code> OsidForm </code> objects, various data elements 
 *  may be set here for use in the create and update methods in the <code> 
 *  ChronicleAdminSession. </code> For each data element that may be set, 
 *  metadata may be examined to provide display hints or data constraints. 
 *  </p>
 */

public interface AssessmentEntryForm
    extends org.osid.OsidRuleForm,
            org.osid.OsidAggregateableForm {


    /**
     *  Gets the metadata for the completed date. 
     *
     *  @return metadata for the completion date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getDateCompletedMetadata();


    /**
     *  Sets the completed date. 
     *
     *  @param  date the new completion date 
     *  @throws org.osid.InvalidArgumentException <code> date </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setDateCompleted(org.osid.calendaring.DateTime date);


    /**
     *  Clears the date completed. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDateCompleted();


    /**
     *  Gets the metadata for the program. 
     *
     *  @return metadata for the program 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getProgramMetadata();


    /**
     *  Sets the program. 
     *
     *  @param  programId the new program 
     *  @throws org.osid.InvalidArgumentException <code> programId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> programId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setProgram(org.osid.id.Id programId);


    /**
     *  Clears the program. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProgram();


    /**
     *  Gets the metadata for the course. 
     *
     *  @return metadata for the course 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getCourseMetadata();


    /**
     *  Sets the course. 
     *
     *  @param  courseId the new course 
     *  @throws org.osid.InvalidArgumentException <code> courseId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> courseId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setCourse(org.osid.id.Id courseId);


    /**
     *  Clears the course. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCourse();


    /**
     *  Gets the metadata for the grade. 
     *
     *  @return metadata for the grade 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getGradeMetadata();


    /**
     *  Sets the grade. 
     *
     *  @param  gradeId the new grade 
     *  @throws org.osid.InvalidArgumentException <code> gradeId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> gradeId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setGrade(org.osid.id.Id gradeId);


    /**
     *  Clears the grade. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGrade();


    /**
     *  Gets the metadata for the score system. 
     *
     *  @return metadata for the grade system 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getScoreScaleMetadata();


    /**
     *  Sets the score system. 
     *
     *  @param  gradeSystemId the new grade system 
     *  @throws org.osid.InvalidArgumentException <code> gradeSystemId </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> gradeSystemId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setScoreScale(org.osid.id.Id gradeSystemId);


    /**
     *  Clears the score system. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearScoreScale();


    /**
     *  Gets the metadata for the score. 
     *
     *  @return metadata for the score 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getScoreMetadata();


    /**
     *  Sets the score. 
     *
     *  @param  score the new score 
     *  @throws org.osid.InvalidArgumentException <code> score </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setScore(java.math.BigDecimal score);


    /**
     *  Clears the score. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearScore();


    /**
     *  Gets the <code> AssessmentlEntryFormRecord </code> corresponding to 
     *  the given assessment entry record <code> Type. </code> 
     *
     *  @param  assessmentEntryRecordType an assessment entry record type 
     *  @return the assessment entry form record 
     *  @throws org.osid.NullArgumentException <code> 
     *          assessmentEntryRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(assessmentEntryRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.records.AssessmentEntryFormRecord getAssessmentlEntryFormRecord(org.osid.type.Type assessmentEntryRecordType)
        throws org.osid.OperationFailedException;
}
