//
// org.osid.course.chronicle.AssessmentEntryQueryInspector
//
//     The OSID Java specification for org.osid.course.chronicle.AssessmentEntryQueryInspector.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.chronicle;


/**
 *  <p>The query inspectors provide a means of accessing the match terms of a 
 *  query. These interfaces are used to examine the actual query terms used in 
 *  a search or that may be used to create a smart catalog. Query inspectors 
 *  may be converted to <code> OsidQuery </code> interfaces for reuse or 
 *  modification in the search sessions. </p>
 */

public interface AssessmentEntryQueryInspector
    extends org.osid.OsidRelationshipQueryInspector {


    /**
     *  Gets the resource <code> Id </code> query terms. 
     *
     *  @return the resource <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getStudentIdTerms();


    /**
     *  Gets the student query terms. 
     *
     *  @return the resource query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceQueryInspector[] getStudentTerms();


    /**
     *  Gets the assessment <code> Id </code> query terms. 
     *
     *  @return the assessment <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getAssessmentIdTerms();


    /**
     *  Gets the assessment query terms. 
     *
     *  @return the assessment terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentQueryInspector[] getAssessmentTerms();


    /**
     *  Gets the completion date query terms. 
     *
     *  @return the date terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DateTimeRangeTerm[] getDateCompletedTerms();


    /**
     *  Gets the program <code> Id </code> query terms. 
     *
     *  @return the program <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getProgramIdTerms();


    /**
     *  Gets the program query terms. 
     *
     *  @return the program terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.ProgramQueryInspector[] getProgramTerms();


    /**
     *  Gets the course <code> Id </code> query terms. 
     *
     *  @return the course <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getCourseIdTerms();


    /**
     *  Gets the course query terms. 
     *
     *  @return the course terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseQueryInspector[] getCourseTerms();


    /**
     *  Gets the grade <code> Id </code> query terms. 
     *
     *  @return the grade <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getGradeIdTerms();


    /**
     *  Gets the grade query terms. 
     *
     *  @return the grade terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeQueryInspector[] getGradeTerms();


    /**
     *  Gets the grade system <code> Id </code> query terms. 
     *
     *  @return the grade system <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getScoreScaleIdTerms();


    /**
     *  Gets the grade system query terms. 
     *
     *  @return the grade system terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeSystemQueryInspector[] getScoreScaleTerms();


    /**
     *  Gets the score query terms. 
     *
     *  @return the score query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DecimalRangeTerm[] getScoreTerms();


    /**
     *  Gets the course catalog <code> Id </code> query terms. 
     *
     *  @return the course catalog <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getCourseCatalogIdTerms();


    /**
     *  Gets the course catalog query terms. 
     *
     *  @return the course catalog query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseCatalogQueryInspector[] getCourseCatalogTerms();


    /**
     *  Gets the assessment entry query inspector record corresponding to the 
     *  given <code> AssessmentEntry </code> record <code> Type. </code> 
     *  Multiple record retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  assessmentEntryRecordType an assessment entry record type 
     *  @return the assessment entry query inspector record 
     *  @throws org.osid.NullArgumentException <code> 
     *          assessmentEntryRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(assessmentEntryRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.records.AssessmentEntryQueryInspectorRecord getAssessmentEntryQueryInspectorRecord(org.osid.type.Type assessmentEntryRecordType)
        throws org.osid.OperationFailedException;
}
