//
// org.osid.course.chronicle.AssessmentEntrySearchSession
//
//     The OSID Java specification for org.osid.course.chronicle.AssessmentEntrySearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.chronicle;


/**
 *  <p>This session provides methods for searching among <code> 
 *  AssessmentEntries. </code> The search query is constructed using the 
 *  <code> AssessmentEntryQuery. </code> </p> 
 *  
 *  <p> <code> getAssessmentEntriesByQuery() </code> is the basic search 
 *  method and returns a list of <code> AssessmentEntries. </code> A more 
 *  advanced search may be performed with <code> 
 *  getAssessmentEntriesBySearch(). </code> It accepts an <code> 
 *  AssessmentEntrySearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getAssessmentEntriesBySearch() </code> returns an <code> 
 *  AssessmentEntrySearchResults </code> that can be used to access the 
 *  resulting <code> AssessmentEntryList </code> or be used to perform a 
 *  search within the result set through <code> AssessmentEntrySearch. </code> 
 *  </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated course catalog view: searches include assessment 
 *      entries in course catalogs of which this course catalog is an ancestor 
 *      in the course catalog hierarchy </li> 
 *      <li> isolated course catalog view: searches are restricted to courses 
 *      in this course catalog </li> 
 *  </ul>
 *  
 *  
 *  <p> AssessmentEntries may have a query record indicated by their 
 *  respective record types. The query record is accessed via the <code> 
 *  AssessmentEntryQuery. </code> </p>
 */

public interface AssessmentEntrySearchSession
    extends org.osid.course.chronicle.AssessmentEntryQuerySession {


    /**
     *  Gets an assessment entry search. 
     *
     *  @return the assessment entry search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.AssessmentEntrySearch getAssessmentEntrySearch();


    /**
     *  Gets an assessment entry search order. The <code> 
     *  AssessmentEntrySearchOrder </code> is supplied to an <code> 
     *  AssessmentEntrySearch </code> to specify the ordering of results. 
     *
     *  @return the assessment entry search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.AssessmentEntrySearchOrder getAssessmentEntrySearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  assessmentEntryQuery the assessment entry query 
     *  @param  assessmentEntrySearch the assessment entry search 
     *  @return the assessment entry search results 
     *  @throws org.osid.NullArgumentException <code> assessmentEntryQuery 
     *          </code> or <code> assessmentEntrySearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> assessmentEntryQuery 
     *          </code> or <code> AssessmentEntrySearch </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.AssessmentEntrySearchResults getAssessmentEntriesBySearch(org.osid.course.chronicle.AssessmentEntryQuery assessmentEntryQuery, 
                                                                                               org.osid.course.chronicle.AssessmentEntrySearch assessmentEntrySearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an assessment entry query from an inspector. The inspector is 
     *  available from an <code> AssessmentEntrySearchResults. </code> 
     *
     *  @param  assessmentEntryQueryInspector an assessment entry query 
     *          inspector 
     *  @return the assessment entry query 
     *  @throws org.osid.NullArgumentException <code> 
     *          assessmentEntryQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          assessmentEntryQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.AssessmentEntryQuery getAssessmentEntryQueryFromInspector(org.osid.course.chronicle.AssessmentEntryQueryInspector assessmentEntryQueryInspector);
}
