//
// org.osid.course.chronicle.CourseEntryCourseCatalogAssignmentSession
//
//     The OSID Java specification for org.osid.course.chronicle.CourseEntryCourseCatalogAssignmentSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.chronicle;


/**
 *  <p>This session provides methods to re-assign <code> CourseEntries </code> 
 *  to <code> CourseCatalogs. </code> A <code> CourseEntry </code> may appear 
 *  in multiple <code> CourseCatalogs </code> and removing the last reference 
 *  to a <code> CourseEntry </code> is the equivalent of deleting it. Each 
 *  <code> CourseCatalog </code> may have its own authorizations governing who 
 *  is allowed to operate on it. </p> 
 *  
 *  <p> Adding a reference of a <code> CourseEntry </code> to another <code> 
 *  CourseCatalog </code> is not a copy operation (eg: does not change its 
 *  <code> Id </code> ). </p>
 */

public interface CourseEntryCourseCatalogAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter course entry/course catalog mappings. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer assignment 
     *  operations to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignCourseEntries();


    /**
     *  Tests if this user can alter course entry/course catalog mappings. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @param  courseCatalogId the <code> Id </code> of the <code> 
     *          CourseCatalog </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignCourseEntryToCourseCatalog(org.osid.id.Id courseCatalogId);


    /**
     *  Gets a list of course catalogs including and under the given course 
     *  catalog node in which any course entry can be assigned. 
     *
     *  @param  courseCatalogId the <code> Id </code> of the <code> 
     *          CourseCatalog </code> 
     *  @return list of assignable course catalog <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableCourseCatalogIds(org.osid.id.Id courseCatalogId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of course catalogs including and under the given course 
     *  catalog node in which a specific course entry can be assigned. 
     *
     *  @param  courseCatalogId the <code> Id </code> of the <code> 
     *          CourseCatalog </code> 
     *  @param  courseEntryId the <code> Id </code> of the <code> CourseEntry 
     *          </code> 
     *  @return list of assignable course catalog <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          or <code> courseEntryId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableCourseCatalogIdsForCourseEntry(org.osid.id.Id courseCatalogId, 
                                                                          org.osid.id.Id courseEntryId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> CourseEntry </code> to a <code> CourseCatalog. 
     *  </code> 
     *
     *  @param  courseEntryId the <code> Id </code> of the <code> CourseEntry 
     *          </code> 
     *  @param  courseCatalogId the <code> Id </code> of the <code> 
     *          CourseCatalog </code> 
     *  @throws org.osid.AlreadyExistsException <code> courseEntryId </code> 
     *          is already assigned to <code> courseCatalogId </code> 
     *  @throws org.osid.NotFoundException <code> courseEntryId </code> or 
     *          <code> courseCatalogId </code> not found 
     *  @throws org.osid.NullArgumentException <code> courseEntryId </code> or 
     *          <code> courseCatalogId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignCourseEntryToCourseCatalog(org.osid.id.Id courseEntryId, 
                                                 org.osid.id.Id courseCatalogId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> CourseEntry </code> from a <code> CourseCatalog. 
     *  </code> 
     *
     *  @param  courseEntryId the <code> Id </code> of the <code> CourseEntry 
     *          </code> 
     *  @param  courseCatalogId the <code> Id </code> of the <code> 
     *          CourseCatalog </code> 
     *  @throws org.osid.NotFoundException <code> courseEntryId </code> or 
     *          <code> courseCatalogId </code> not found or <code> 
     *          courseEntryId </code> not assigned to <code> courseCatalogId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> courseEntryId </code> or 
     *          <code> courseCatalogId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignCourseEntryFromCourseCatalog(org.osid.id.Id courseEntryId, 
                                                     org.osid.id.Id courseCatalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Moves a <code> CourseEntry </code> from one <code> CourseCatalog 
     *  </code> to another. Mappings to other <code> CourseCatalogs </code> 
     *  are unaffected. 
     *
     *  @param  courseEntryId the <code> Id </code> of the <code> CourseEntry 
     *          </code> 
     *  @param  fromCourseCatalogId the <code> Id </code> of the current 
     *          <code> CourseCatalog </code> 
     *  @param  toCourseCatalogId the <code> Id </code> of the destination 
     *          <code> CourseCatalog </code> 
     *  @throws org.osid.NotFoundException <code> courseEntryId, 
     *          fromCourseCatalogId, </code> or <code> toCourseCatalogId 
     *          </code> not found or <code> courseEntryId </code> not mapped 
     *          to <code> fromCourseCatalogId </code> 
     *  @throws org.osid.NullArgumentException <code> courseEntryId, 
     *          fromCourseCatalogId, </code> or <code> toCourseCatalogId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void reassignCourseEntryToCourseCatalog(org.osid.id.Id courseEntryId, 
                                                   org.osid.id.Id fromCourseCatalogId, 
                                                   org.osid.id.Id toCourseCatalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
