//
// org.osid.course.chronicle.CourseEntryQuery
//
//     The OSID Java specification for org.osid.course.chronicle.CourseEntryQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.chronicle;


/**
 *  <p>This is the query for searching course entries. Each method match 
 *  specifies an <code> AND </code> term while multiple invocations of the 
 *  same method produce a nested <code> OR. </code> </p>
 */

public interface CourseEntryQuery
    extends org.osid.OsidRelationshipQuery {


    /**
     *  Sets the student <code> Id </code> for this query. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchStudentId(org.osid.id.Id resourceId, boolean match);


    /**
     *  Clears the student <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStudentIdTerms();


    /**
     *  Tests if a <code> StudentQuery </code> is available. 
     *
     *  @return <code> true </code> if a student query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStudentQuery();


    /**
     *  Gets the query for a student option. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return a student query 
     *  @throws org.osid.UnimplementedException <code> supportsStudentQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStudentQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceQuery getStudentQuery();


    /**
     *  Clears the student option terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStudentTerms();


    /**
     *  Sets the course <code> Id </code> for this query to match entries that 
     *  have an entry for the given course. 
     *
     *  @param  courseId a course <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> courseId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCourseId(org.osid.id.Id courseId, boolean match);


    /**
     *  Clears the course <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCourseIdTerms();


    /**
     *  Tests if a <code> CourseQuery </code> is available. 
     *
     *  @return <code> true </code> if a course query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseQuery();


    /**
     *  Gets the query for a course entry. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return a course query 
     *  @throws org.osid.UnimplementedException <code> supportsCourseQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCourseQuery() </code> is <code> true. </code> 
     */

    public org.osid.course.CourseQuery getCourseQuery();


    /**
     *  Clears the course terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCourseTerms();


    /**
     *  Sets the term <code> Id </code> for this query. 
     *
     *  @param  termId a term <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> termId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchTermId(org.osid.id.Id termId, boolean match);


    /**
     *  Clears the term <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTermIdTerms();


    /**
     *  Tests if a <code> TermQuery </code> is available. 
     *
     *  @return <code> true </code> if a term query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTermQuery();


    /**
     *  Gets the query for a term entry. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return a term query 
     *  @throws org.osid.UnimplementedException <code> supportsTermQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTermQuery() </code> is <code> true. </code> 
     */

    public org.osid.course.TermQuery getTermQuery();


    /**
     *  Clears the term terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTermTerms();


    /**
     *  Matches completed courses. 
     *
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchComplete(boolean match);


    /**
     *  Clears the complete terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCompleteTerms();


    /**
     *  Matches a credit scale <code> Id. </code> 
     *
     *  @param  gradeSystemId a grade system <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> gradeSystemId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCreditScaleId(org.osid.id.Id gradeSystemId, boolean match);


    /**
     *  Clears the grade system <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCreditScaleIdTerms();


    /**
     *  Tests if a <code> GradeSystemQuery </code> is available. 
     *
     *  @return <code> true </code> if a grade system query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCreditScaleQuery();


    /**
     *  Gets the query for a grade system. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return a grade system query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCreditScaleQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCreditScaleQuery() </code> is <code> true. </code> 
     */

    public org.osid.grading.GradeSystemQuery getCreditScaleQuery();


    /**
     *  Matches entries that have any credit scale. 
     *
     *  @param  match <code> true </code> to match entries with any credit 
     *          scale, <code> false </code> to match entries with no credit 
     *          scale 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCreditScale(boolean match);


    /**
     *  Clears the credit scale terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCreditScaleTerms();


    /**
     *  Matches earned credits between the given range inclusive. 
     *
     *  @param  from starting value 
     *  @param  to ending value 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCreditsEarned(java.math.BigDecimal from, 
                                   java.math.BigDecimal to, boolean match);


    /**
     *  Matches entries that have any earned credits. 
     *
     *  @param  match <code> true </code> to match entries with any earned 
     *          credits, <code> false </code> to match entries with no earned 
     *          credits 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCreditsEarned(boolean match);


    /**
     *  Clears the earned credits terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCreditsEarnedTerms();


    /**
     *  Matches a grade <code> Id. </code> 
     *
     *  @param  gradeId a grade <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> gradeId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchGradeId(org.osid.id.Id gradeId, boolean match);


    /**
     *  Clears the grade <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGradeIdTerms();


    /**
     *  Tests if a <code> GradeQuery </code> is available. 
     *
     *  @return <code> true </code> if a grade query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradeQuery();


    /**
     *  Gets the query for a grade. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return a grade system query 
     *  @throws org.osid.UnimplementedException <code> supportsGradeQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradeQuery() </code> is <code> true. </code> 
     */

    public org.osid.grading.GradeQuery getGradeQuery();


    /**
     *  Matches entries that have any grade. 
     *
     *  @param  match <code> true </code> to match entries with any grade, 
     *          <code> false </code> to match entries with no grade 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyGrade(boolean match);


    /**
     *  Clears the grade terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGradeTerms();


    /**
     *  Matches a score scale <code> Id. </code> 
     *
     *  @param  gradeSystemId a grade system <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> gradeSystemId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchScoreScaleId(org.osid.id.Id gradeSystemId, boolean match);


    /**
     *  Clears the grade system <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearScoreScaleIdTerms();


    /**
     *  Tests if a <code> GradeSystemQuery </code> is available. 
     *
     *  @return <code> true </code> if a grade system query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsScoreScaleQuery();


    /**
     *  Gets the query for a grade system. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return a grade system query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsScoreScaleQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsScoreScaleQuery() </code> is <code> true. </code> 
     */

    public org.osid.grading.GradeSystemQuery getScoreScaleQuery();


    /**
     *  Matches entries that have any score scale. 
     *
     *  @param  match <code> true </code> to match entries with any score 
     *          scale, <code> false </code> to match entries with no score 
     *          scale 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyScoreScale(boolean match);


    /**
     *  Clears the score scale terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearScoreScaleTerms();


    /**
     *  Matches scores between the given range inclusive. 
     *
     *  @param  from starting value 
     *  @param  to ending value 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchScore(java.math.BigDecimal from, java.math.BigDecimal to, 
                           boolean match);


    /**
     *  Matches entries that have any score. 
     *
     *  @param  match <code> true </code> to match entries with any score, 
     *          <code> false </code> to match entries with no score 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyScore(boolean match);


    /**
     *  Clears the score terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearScoreTerms();


    /**
     *  Sets the enrollment <code> Id </code> for this query. 
     *
     *  @param  enrollmentId an enrollment <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> enrollmentId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRegistrationId(org.osid.id.Id enrollmentId, boolean match);


    /**
     *  Clears the registration <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRegistrationIdTerms();


    /**
     *  Tests if a <code> RegistrationQuery </code> is available. 
     *
     *  @return <code> true </code> if a registration query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRegistrationQuery();


    /**
     *  Gets the query for a registration entry. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return a registration query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRegistrationQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRegistrationQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.registration.RegistrationQuery getRegistrationQuery();


    /**
     *  Matches entries that have any registration. 
     *
     *  @param  match <code> true </code> to match enries with any 
     *          registration, <code> false </code> to match enries with no 
     *          registration 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRegistration(boolean match);


    /**
     *  Clears the registration terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRegistrationTerms();


    /**
     *  Sets the course catalog <code> Id </code> for this query to match 
     *  entries assigned to course catalogs. 
     *
     *  @param  courseCatalogId the course catalog <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCourseCatalogId(org.osid.id.Id courseCatalogId, 
                                     boolean match);


    /**
     *  Clears the course catalog <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCourseCatalogIdTerms();


    /**
     *  Tests if a <code> CourseCatalogQuery </code> is available. 
     *
     *  @return <code> true </code> if a course catalog query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseCatalogQuery();


    /**
     *  Gets the query for a course catalog. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the course catalog query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCourseCatalogQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCourseCatalogQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.CourseCatalogQuery getCourseCatalogQuery();


    /**
     *  Clears the course catalog terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCourseCatalogTerms();


    /**
     *  Gets the course entry query record corresponding to the given <code> 
     *  CourseEntry </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  courseEntryRecordType a course entry record type 
     *  @return the course entry query record 
     *  @throws org.osid.NullArgumentException <code> courseEntryRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(courseEntryRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.records.CourseEntryQueryRecord getCourseEntryQueryRecord(org.osid.type.Type courseEntryRecordType)
        throws org.osid.OperationFailedException;
}
