//
// org.osid.course.chronicle.CredentialEntry
//
//     The OSID Java specification for org.osid.course.chronicle.CredentialEntry.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.chronicle;


/**
 *  <p>A <code> CredentialEntry </code> represents an academic record entry 
 *  for a credential. </p>
 */

public interface CredentialEntry
    extends org.osid.OsidRelationship {


    /**
     *  Gets the <code> Id </code> of the <code> Student. </code> 
     *
     *  @return the student <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getStudentId();


    /**
     *  Gets the <code> Student. </code> 
     *
     *  @return the student 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getStudent()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of the <code> Credential. </code> 
     *
     *  @return the credential <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCredentialId();


    /**
     *  Gets the <code> Credential. </code> 
     *
     *  @return the credential 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.Credential getCredential()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the award date. 
     *
     *  @return the date awarded 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getDateAwarded();


    /**
     *  Tests if a program is associated with this credential. 
     *
     *  @return <code> true </code> if a program is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasProgram();


    /**
     *  Gets the <code> Id </code> of the <code> Program. </code> 
     *
     *  @return the program <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> hasProgram() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getProgramId();


    /**
     *  Gets the <code> Program. </code> 
     *
     *  @return the program 
     *  @throws org.osid.IllegalStateException <code> hasProgram() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.Program getProgram()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the credential entry record corresponding to the given <code> 
     *  CredentialEntry </code> record <code> Type. </code> This method is 
     *  used to retrieve an object implementing the requested record. The 
     *  <code> credentialEntryRecordType </code> may be the <code> Type 
     *  </code> returned in <code> getRecordTypes() </code> or any of its 
     *  parents in a <code> Type </code> hierarchy where <code> 
     *  hasRecordType(credentialEntryRecordType) </code> is <code> true 
     *  </code> . 
     *
     *  @param  credentialEntryRecordType the type of credential entry record 
     *          to retrieve 
     *  @return the credential entry record 
     *  @throws org.osid.NullArgumentException <code> 
     *          credentialEntryRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(credentialEntryRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.records.CredentialEntryRecord getCredentialEntryRecord(org.osid.type.Type credentialEntryRecordType)
        throws org.osid.OperationFailedException;
}
