//
// org.osid.course.chronicle.ProgramEntry
//
//     The OSID Java specification for org.osid.course.chronicle.ProgramEntry.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.chronicle;


/**
 *  <p>A <code> ProgramEntry </code> represents an academic record entry for a 
 *  <code> Program. </code> The fields in the <code> ProgramEntry </code> may 
 *  be for the entire enrollment through the academic career or specific to an 
 *  academic <code> Term. </code> </p> 
 *  
 *  <p> A <code> ProgramEntry </code> is also an <code> OsidRelationship 
 *  </code> between the student and <code> Program. </code> The effectiveness 
 *  of the <code> OsidRelationship </code> describes the effectiveness of the 
 *  academic record entry itself, not the student's enrollment in the <code> 
 *  Program. </code> A <code> ProgramEntry </code> may be superseded with a 
 *  manual update or forced entry and the temporal nature of the relationship 
 *  provides a history of changes to the academic record. </p>
 */

public interface ProgramEntry
    extends org.osid.OsidRelationship {


    /**
     *  Gets the <code> Id </code> of the <code> Student. </code> 
     *
     *  @return the student <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getStudentId();


    /**
     *  Gets the <code> Student. </code> 
     *
     *  @return the student 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getStudent()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of the <code> Program. </code> 
     *
     *  @return the program <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getProgramId();


    /**
     *  Gets the <code> Program. </code> 
     *
     *  @return the program 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.Program getProgram()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the date in which the student was admitted. 
     *
     *  @return the admission date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getAdmissionDate();


    /**
     *  Tests if the program has been completed. If this entry is for summary 
     *  information an a past term, <code> isComplete() </code> may be <code> 
     *  true. </code> 
     *
     *  @return <code> true </code> if the program has been completed, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isComplete();


    /**
     *  Tests if this entry is a progression entry applying to a single term. 
     *  A program entry may provide summary information for the entire 
     *  duration or for a single term. If <code> isForTerm() </code> is <code> 
     *  false, </code> this entry applies to the entire enrollement period. 
     *
     *  @return <code> true </code> if the program has a term, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isForTerm();


    /**
     *  Gets the <code> Id </code> of the <code> Term. </code> 
     *
     *  @return the term <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> isForTerm() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getTermId();


    /**
     *  Gets the <code> Term. </code> 
     *
     *  @return the term 
     *  @throws org.osid.IllegalStateException <code> isForTerm() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.Term getTerm()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of the <code> GradeSystem. </code> 
     *
     *  @return the grade system <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCreditScaleId();


    /**
     *  Gets the <code> GradeSystem. </code> 
     *
     *  @return the grade system 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeSystem getCreditScale()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the number of credits earned in this program or earned within the 
     *  included term. 
     *
     *  @return the credits earned 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getCreditsEarned();


    /**
     *  Tests if a cumulative GPA in this program of the GPA for the included 
     *  term. 
     *
     *  @return <code> true </code> if a GPA is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasGPA();


    /**
     *  Gets the <code> Id </code> of the <code> GradeSystem. </code> 
     *
     *  @return the grade system <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> hasGPA() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getGPAScaleId();


    /**
     *  Gets the <code> GradeSystem. </code> 
     *
     *  @return the grade system 
     *  @throws org.osid.IllegalStateException <code> hasGPA() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeSystem getGPAScale()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the cumulative GPA in this porgram or within the included term. 
     *
     *  @return the GPA 
     *  @throws org.osid.IllegalStateException <code> hasGPA() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getGPA();


    /**
     *  Tests if <code> Enrollments </code> are available. 
     *
     *  @return <code> true </code> if enrollments are available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasEnrollments();


    /**
     *  Gets the <code> Ids </code> of the <code> Enrollments. </code> 
     *
     *  @return the enrollment <code> Ids </code> 
     *  @throws org.osid.IllegalStateException <code> hasEnrollments() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getEnrollmentIds();


    /**
     *  Gets the <code> Enrollments. </code> 
     *
     *  @return the enrollments 
     *  @throws org.osid.IllegalStateException <code> hasEnrollments() </code> 
     *          is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.EnrollmentList getEnrollments()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the program entry record corresponding to the given <code> 
     *  ProgramEntry </code> record <code> Type. </code> This method is used 
     *  to retrieve an object implementing the requested record. The <code> 
     *  programEntryRecordType </code> may be the <code> Type </code> returned 
     *  in <code> getRecordTypes() </code> or any of its parents in a <code> 
     *  Type </code> hierarchy where <code> 
     *  hasRecordType(programEntryRecordType) </code> is <code> true </code> . 
     *
     *  @param  programEntryRecordType the type of program entry record to 
     *          retrieve 
     *  @return the program entry record 
     *  @throws org.osid.NullArgumentException <code> programEntryRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(programEntryRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.records.ProgramEntryRecord getProgramEntryRecord(org.osid.type.Type programEntryRecordType)
        throws org.osid.OperationFailedException;
}
