//
// org.osid.course.chronicle.ProgramEntryAdminSession
//
//     The OSID Java specification for org.osid.course.chronicle.ProgramEntryAdminSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.chronicle;


/**
 *  <p>This session creates, updates, and deletes <code> ProgramEntries. 
 *  </code> The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  ProgramEntry, </code> a <code> ProgramEntryForm </code> is requested using 
 *  <code> getProgramEntryFormForCreate() </code> specifying the desired 
 *  record <code> Types </code> or none if no record <code> Types </code> are 
 *  needed. The returned <code> ProgramEntryForm </code> will indicate that it 
 *  is to be used with a create operation and can be used to examine metdata 
 *  or validate data prior to creation. Once the <code> ProgramEntryForm 
 *  </code> is submiited to a create operation, it cannot be reused with 
 *  another create operation unless the first operation was unsuccessful. Each 
 *  <code> ProgramEntryForm </code> corresponds to an attempted transaction. 
 *  </p> 
 *  
 *  <p> For updates, <code> ProgramEntryForms </code> are requested to the 
 *  <code> ProgramEntry </code> <code> Id </code> that is to be updated using 
 *  <code> getProgramEntryFormForUpdate(). </code> Similarly, the <code> 
 *  ProgramEntryForm </code> has metadata about the data that can be updated 
 *  and it can perform validation before submitting the update. The <code> 
 *  ProgramEntryForm </code> can only be used once for a successful update and 
 *  cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> ProgramEntries. </code> To unmap a 
 *  <code> ProgramEntry </code> from the current <code> CourseCatalog, </code> 
 *  the <code> ProgramEntryCourseCatalogAssignmentSession </code> should be 
 *  used. These delete operations attempt to remove the <code> ProgramEntry 
 *  </code> itself thus removing it from all known <code> CourseCatalog 
 *  </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface ProgramEntryAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> CourseCatalog </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> CourseCatalog Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCourseCatalogId();


    /**
     *  Gets the <code> CourseCatalog </code> associated with this session. 
     *
     *  @return the course catalog 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseCatalog getCourseCatalog()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> ProgramEntries. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> ProgramEntry </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer create operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> ProgramEntry </code> creation 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateProgramEntries();


    /**
     *  Tests if this user can create a single <code> Porgram </code> using 
     *  the desired record types. While <code> 
     *  CourseChronicleManager.getProgramEntryRecordTypes() </code> can be 
     *  used to examine which records are supported, this method tests which 
     *  record(s) are required for creating a specific <code> ProgramEntry. 
     *  </code> Providing an empty array tests if a <code> ProgramEntry 
     *  </code> can be created with no records. 
     *
     *  @param  programEntryRecordTypes array of program entry record types 
     *  @return <code> true </code> if <code> ProgramEntry </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> programEntryRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateProgramEntryWithRecordTypes(org.osid.type.Type[] programEntryRecordTypes);


    /**
     *  Gets the program entry form for creating new program entries. A new 
     *  form should be requested for each create transaction. 
     *
     *  @param  programId the <code> Id </code> of a <code> Program </code> 
     *  @param  resourceId the <code> Id </code> of a student 
     *  @param  programEntryRecordTypes array of program entry record types 
     *  @return the program entry form 
     *  @throws org.osid.NotFoundException <code> programId </code> or <code> 
     *          resourceId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> programId, resourceId 
     *          </code> , or <code> programEntryRecordTypes </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.ProgramEntryForm getProgramEntryFormForCreate(org.osid.id.Id programId, 
                                                                                   org.osid.id.Id resourceId, 
                                                                                   org.osid.type.Type[] programEntryRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> ProgramEntry. </code> 
     *
     *  @param  programEntryForm the form for this <code> ProgramEntry </code> 
     *  @return the new <code> ProgramEntry </code> 
     *  @throws org.osid.IllegalStateException <code> programEntryForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> programEntryForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> programEntryForm </code> 
     *          did not originate from <code> getProgramEntryFormForCreate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.ProgramEntry createProgramEntry(org.osid.course.chronicle.ProgramEntryForm programEntryForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> ProgramEntries. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> ProgramEntry </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer update operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> ProgramEntry </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateProgramEntries();


    /**
     *  Gets the program entry form for updating an existing program entry. A 
     *  new program entry form should be requested for each update 
     *  transaction. 
     *
     *  @param  programEntryId the <code> Id </code> of the <code> 
     *          ProgramEntry </code> 
     *  @return the program entry form 
     *  @throws org.osid.NotFoundException <code> programEntryId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> programEntryId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.ProgramEntryForm getProgramEntryFormForUpdate(org.osid.id.Id programEntryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing program entry. 
     *
     *  @param  programEntryForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> programEntryForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> programEntryForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> programEntryForm </code> 
     *          did not originate from <code> getProgramEntryFormForUpdate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateProgramEntry(org.osid.course.chronicle.ProgramEntryForm programEntryForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> ProgramEntries. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> ProgramEntry </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer delete operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> ProgramEntry </code> deletion 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteProgramEntries();


    /**
     *  Tests if this user can delete a specified <code> ProgramEntry. </code> 
     *  A return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known deleting the <code> ProgramEntry 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer a 
     *  delete operation to an unauthorized user for this program entry. 
     *
     *  @param  programEntryId the <code> Id </code> of the <code> 
     *          ProgramEntry </code> 
     *  @return <code> false </code> if deletion of this <code> ProgramEntry 
     *          </code> is not authorized, <code> true </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> programEntryId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If the <code> programEntryId </code> is not found, then it is 
     *          acceptable to return false to indicate the lack of a delete 
     *          available. 
     */

    public boolean canDeleteProgramEntry(org.osid.id.Id programEntryId);


    /**
     *  Deletes a <code> ProgramEntry. </code> 
     *
     *  @param  programEntryId the <code> Id </code> of the <code> 
     *          ProgramEntry </code> to remove 
     *  @throws org.osid.NotFoundException <code> programEntryId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> programEntryId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteProgramEntry(org.osid.id.Id programEntryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  ProgramEntries. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> ProgramEntry </code> aliasing 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageProgramEntryAliases();


    /**
     *  Adds an <code> Id </code> to a <code> ProgramEntry </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> ProgramEntry </code> is determined by the provider. The new 
     *  <code> Id </code> performs as an alias to the primary <code> Id. 
     *  </code> If the alias is a pointer to another program entry, it is 
     *  reassigned to the given program entry <code> Id. </code> 
     *
     *  @param  programEntryId the <code> Id </code> of a <code> ProgramEntry 
     *          </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is in 
     *          use as a primary <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> programEntryId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> programEntryId </code> 
     *          or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasProgramEntry(org.osid.id.Id programEntryId, 
                                  org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
