//
// org.osid.course.chronicle.ProgramEntryForm
//
//     The OSID Java specification for org.osid.course.chronicle.ProgramEntryForm.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.chronicle;


/**
 *  <p>This is the form for creating and updating <code> ProgramEntries. 
 *  </code> Like all <code> OsidForm </code> objects, various data elements 
 *  may be set here for use in the create and update methods in the <code> 
 *  ProgramEntryAdminSession. </code> For each data element that may be set, 
 *  metadata may be examined to provide display hints or data constraints. 
 *  </p>
 */

public interface ProgramEntryForm
    extends org.osid.OsidRelationshipForm {


    /**
     *  Gets the metadata for the admission date. 
     *
     *  @return metadata for the admission date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getAdmissionDateMetadata();


    /**
     *  Sets the admission date. 
     *
     *  @param  date the new date 
     *  @throws org.osid.InvalidArgumentException <code> date </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setAdmissionDate(org.osid.calendaring.DateTime date);


    /**
     *  Clears the admission date. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAdmissionDate();


    /**
     *  Gets the metadta for the completionm flag. 
     *
     *  @return metadata for the complete flag 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getCompleteMetadata();


    /**
     *  Sets the program is complete flag. 
     *
     *  @param  complete the new complete flag 
     *  @throws org.osid.InvalidArgumentException <code> complete </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setComplete(boolean complete);


    /**
     *  Clears the complete flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearComplete();


    /**
     *  Gets the metadata for the term. 
     *
     *  @return metadata for the term 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getTermMetadata();


    /**
     *  Sets the term. 
     *
     *  @param  termId the new term 
     *  @throws org.osid.InvalidArgumentException <code> termId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> termId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setTerm(org.osid.id.Id termId);


    /**
     *  Clears the term. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTerm();


    /**
     *  Gets the metadata for the credit scale. 
     *
     *  @return metadata for the credit scale 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getCreditScaleMetadata();


    /**
     *  Sets the credit scale. 
     *
     *  @param  gradeSystemId the new grade system 
     *  @throws org.osid.InvalidArgumentException <code> gradeSystemId </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> gradeSystemId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setCreditScale(org.osid.id.Id gradeSystemId);


    /**
     *  Clears the credit scale. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCreditScale();


    /**
     *  Gets the metadata for the credits earned. 
     *
     *  @return metadata for the credits earned 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getCreditsEarnedMetadata();


    /**
     *  Sets the credits earned. 
     *
     *  @param  credits the new credits 
     *  @throws org.osid.InvalidArgumentException <code> credits </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setCreditsEarned(java.math.BigDecimal credits);


    /**
     *  Clears the credits earned. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCreditsEarned();


    /**
     *  Gets the metadata for the gpa scale. 
     *
     *  @return metadata for the gpa scale 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getGPAScaleMetadata();


    /**
     *  Sets the gpa scale. 
     *
     *  @param  gradeSystemId the new grade system 
     *  @throws org.osid.InvalidArgumentException <code> gradeSystemId </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> gradeSystemId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setGPAScale(org.osid.id.Id gradeSystemId);


    /**
     *  Clears the gpa scale. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGPAScale();


    /**
     *  Gets the metadata for the gpa. 
     *
     *  @return metadata for the gpa 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getGPAMetadata();


    /**
     *  Sets the gpa. 
     *
     *  @param  gpa the new gpa 
     *  @throws org.osid.InvalidArgumentException <code> gpa </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setGPA(java.math.BigDecimal gpa);


    /**
     *  Clears the gpa. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGPA();


    /**
     *  Gets the <code> ProgramEntryFormRecord </code> corresponding to the 
     *  given program entry record <code> Type. </code> 
     *
     *  @param  programEntryRecordType a program entry record type 
     *  @return the program entry form record 
     *  @throws org.osid.NullArgumentException <code> programEntryRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(programEntryRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.records.ProgramEntryFormRecord getProgramEntryFormRecord(org.osid.type.Type programEntryRecordType)
        throws org.osid.OperationFailedException;
}
