//
// org.osid.course.chronicle.batch.CredentialEntryBatchAdminSession
//
//     The OSID Java specification for org.osid.course.chronicle.batch.CredentialEntryBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.chronicle.batch;


/**
 *  <p>This session creates, updates, and deletes <code> CredentialEntries 
 *  </code> in bulk. The data for create and update is provided by the 
 *  consumer via the form object. <code> OsidForms </code> are requested for 
 *  each create or update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  CredentialEntry, </code> a <code> CredentialEntryForm </code> is requested 
 *  using <code> getCredentialEntryFormsForCreate() </code> specifying the 
 *  desired credential, student, and record <code> Types </code> or none if no 
 *  record <code> Types </code> are needed. Each of the returned <code> 
 *  CredentialEntryForms </code> will indicate that it is to be used with a 
 *  create operation and can be used to examine metdata or validate data prior 
 *  to creation. Once a <code> CredentialEntryForm </code> is submiited to a 
 *  create operation, it cannot be reused with another create operation unless 
 *  the first operation was unsuccessful. Each <code> CredentialEntryForm 
 *  </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> CredentialEntryForms </code> returned from <code> 
 *  getCredentialEntryFormsForCreate() </code> may be linked to the 
 *  originating request through the peer <code> Ids </code> of the <code> 
 *  CredentialEntryForm. </code> In the case where there may be duplicates, 
 *  any <code> CredentialEntryForm </code> of the same peer <code> Ids </code> 
 *  may be used for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> CredentialEntryForms </code> are submitted for 
 *  create, a <code> CreateResponse </code> is returned for each <code> 
 *  CredentialEntryForm, </code> although the ordering is not defined. Only 
 *  errors that pertain to the entire create operation are returned from 
 *  <code> createCredentialEntries(), </code> errors specific to an individual 
 *  <code> CredentialEntryForm </code> are indicated in the corresponding 
 *  <code> CreateResponse. </code> <code> CreateResponses </code> may be 
 *  linked to the originating <code> CredentialEntryForm </code> through the 
 *  <code> CredentialEntryForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> CredentialEntryForms </code> are requested to the 
 *  <code> CredentialEntry </code> <code> Id </code> that is to be updated 
 *  using <code> getCredentialEntryFormsForUpdate() </code> where the 
 *  reference <code> Id </code> in the <code> CredentialEntryForm </code> may 
 *  be used to link the request. Similarly, the <code> CredentialEntryForm 
 *  </code> has metadata about the data that can be updated and it can perform 
 *  validation before submitting the update. The <code> CredentialEntryForm 
 *  </code> can only be used once for a successful update and cannot be 
 *  reused. </p> 
 *  
 *  <p> Once a batch of <code> CredentialEntryForms </code> are submitted for 
 *  update, an <code> UpdateResponse </code> is returned for each <code> 
 *  CredentialEntryForm, </code> although the ordering is not defined. Only 
 *  errors that pertain to the entire update operation are returned from 
 *  <code> updateCredentialEntries(), </code> errors specific to an individual 
 *  <code> CredentialEntryForm </code> are indicated in the corresponding 
 *  <code> UpdateResponse. </code> <code> UpdateResponses </code> may be 
 *  linked to the originating <code> CredentialEntryForm </code> through the 
 *  <code> CredentialEntryForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> CredentialEntries </code> in bulk. 
 *  To unmap a <code> CredentialEntry </code> from the current <code> 
 *  CourseCatalog, </code> the <code> 
 *  CredentialEntryCourseCatalogAssignmentSession </code> should be used. 
 *  These delete operations attempt to remove the <code> CredentialEntry 
 *  </code> itself thus removing it from all known <code> CourseCatalog 
 *  </code> catalogs. Bulk delete operations return the results in <code> 
 *  DeleteResponses. </code> </p>
 */

public interface CredentialEntryBatchAdminSession
    extends org.osid.course.chronicle.CredentialEntryAdminSession {


    /**
     *  Gets the credential entry forms for creating a bunch of new credential 
     *  entries. A form is returned for each credential and student pair. 
     *
     *  @param  peers a list of credential entry peers 
     *  @param  credentialEntryRecordTypes array of credential entryrecord 
     *          types to be included in each create operation or an empty list 
     *          if none 
     *  @return the credential entry forms 
     *  @throws org.osid.NotFoundException <code> credentialId </code> or 
     *          <code> resourceId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> peers </code> or c 
     *          <code> redentialEntryRecordTypes </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.batch.CredentialEntryBatchFormList getCredentialEntryFormsForCreate(org.osid.course.chronicle.batch.CredentialEntryPeerList peers, 
                                                                                                         org.osid.type.Type[] credentialEntryRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> CredentialEntries. </code> This method 
     *  returns an error if the entire operation fails. Otherwise, the status 
     *  of an individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  credentialEntryForms the credential entry forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> credentialEntryForms 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createCredentialEntries(org.osid.course.chronicle.batch.CredentialEntryBatchFormList credentialEntryForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the credential entryforms for updating an existing set of 
     *  credential entries. A new credential entryform should be requested for 
     *  each update transaction. 
     *
     *  @param  credentialEntryIds the <code> Ids </code> of the <code> 
     *          CredentialEntry </code> 
     *  @return the credential entry form 
     *  @throws org.osid.NotFoundException a <code> credentialEntryId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> credentialEntryIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.batch.CredentialEntryBatchFormList getCredentialEntryFormsForUpdate(org.osid.id.IdList credentialEntryIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing credential entries. This method returns an error if 
     *  the entire operation fails. Otherwise, the status of an individual 
     *  update operation is indicated in the <code> BatchCreateResponse 
     *  </code> . 
     *
     *  @param  credentialEntryForms the form containing the elements to be 
     *          updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> credentialEntryForms 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateCredentialEntries(org.osid.course.chronicle.batch.CredentialEntryBatchFormList credentialEntryForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> CredentialEntries </code> in this <code> 
     *  CourseCatalog </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllCredentialEntries()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes credential entries for the given <code> Ids. </code> 
     *
     *  @param  credentialEntryIds the <code> Ids </code> of the credential 
     *          entries to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> credentialEntryIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteCredentialEntries(org.osid.id.IdList credentialEntryIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes credential entries for the given credential. 
     *
     *  @param  credentialId the <code> Id </code> of a credential 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> credentialId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteCredentialEntriesForCredential(org.osid.id.Id credentialId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes credential entries for the given student. 
     *
     *  @param  resourceId the <code> Id </code> of a student 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteCredentialEntriesForStudent(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes credential entries expired before the given date. 
     *
     *  @param  date a date 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteIneffectiveCredentialEntriesByDate(org.osid.calendaring.DateTime date)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> CredentialEntry </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> CredentialEntry </code> is determined by the provider. The 
     *  new <code> Id </code> is an alias to the primary <code> Id. </code> If 
     *  the alias is a pointer to another credential entry, it is reassigned 
     *  to the given credential entry <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasCredentialEntries(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
