//
// org.osid.course.plan.CoursePlanProfile
//
//     The OSID Java specification for org.osid.course.plan.CoursePlanProfile.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.plan;


/**
 *  <p>The course profile describes the interoperability among course 
 *  services. </p>
 */

public interface CoursePlanProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any lesson federation is exposed. Federation is exposed when 
     *  a specific lesson may be identified, selected and used to create a 
     *  lookup or admin session. Federation is not exposed when a set of 
     *  lessonsappears as a single lesson. 
     *
     *  @return <code> true </code> if visible federation is supproted, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests for the availability of a plan lookup service. 
     *
     *  @return <code> true </code> if plan lookup is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPlanLookup();


    /**
     *  Tests if querying plans is available. 
     *
     *  @return <code> true </code> if plan query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPlanQuery();


    /**
     *  Tests if searching for plans is available. 
     *
     *  @return <code> true </code> if plan search is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPlanSearch();


    /**
     *  Tests if searching for plans is available. 
     *
     *  @return <code> true </code> if plan search is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPlanAdmin();


    /**
     *  Tests if plan notification is available. 
     *
     *  @return <code> true </code> if plan notification is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPlanNotification();


    /**
     *  Tests if a plan to course catalog lookup session is available. 
     *
     *  @return <code> true </code> if plan course catalog lookup session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPlanCourseCatalog();


    /**
     *  Tests if a plan to course catalog assignment session is available. 
     *
     *  @return <code> true </code> if plan course catalog assignment is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPlanCourseCatalogAssignment();


    /**
     *  Tests if a plan smart course catalog session is available. 
     *
     *  @return <code> true </code> if plan smart course catalog is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPlanSmartCourseCatalog();


    /**
     *  Tests for the availability of a lesson lookup service. 
     *
     *  @return <code> true </code> if lesson lookup is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLessonLookup();


    /**
     *  Tests if querying lessonsis available. 
     *
     *  @return <code> true </code> if lesson query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLessonQuery();


    /**
     *  Tests if searching for lessons is available. 
     *
     *  @return <code> true </code> if lesson search is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLessonSearch();


    /**
     *  Tests for the availability of a lesson administrative service for 
     *  creating and deleting lessons. 
     *
     *  @return <code> true </code> if lesson administration is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLessonAdmin();


    /**
     *  Tests for the availability of a lesson notification service. 
     *
     *  @return <code> true </code> if lesson notification is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsLessonNotification();


    /**
     *  Tests if a lesson to course catalog lookup session is available. 
     *
     *  @return <code> true </code> if lesson course catalog lookup session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLessonCourseCatalog();


    /**
     *  Tests if a lesson to course catalog assignment session is available. 
     *
     *  @return <code> true </code> if lesson course catalog assignment is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLessonCourseCatalogAssignment();


    /**
     *  Tests if a lesson smart course catalog session is available. 
     *
     *  @return <code> true </code> if lesson smart course catalog is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLessonSmartCourseCatalog();


    /**
     *  Tests if looking at lesson conflicts available. 
     *
     *  @return <code> true </code> if lesson conflict is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLessonConflict();


    /**
     *  Tests if anchoring lessons is available. 
     *
     *  @return <code> true </code> if lesson anchoring is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLessonAnchoring();


    /**
     *  Gets the supported <code> Syllabus </code> record types. 
     *
     *  @return a list containing the supported syllabus record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSyllabusRecordTypes();


    /**
     *  Tests if the given <code> Syllabus </code> record type is supported. 
     *
     *  @param  syllabusRecordType a <code> Type </code> indicating a <code> 
     *          Syllabus </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> syllabusRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSyllabusRecordType(org.osid.type.Type syllabusRecordType);


    /**
     *  Gets the supported syllabus search record types. 
     *
     *  @return a list containing the supported syllabus search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSyllabusSearchRecordTypes();


    /**
     *  Tests if the given syllabus search record type is supported. 
     *
     *  @param  syllabusSearchRecordType a <code> Type </code> indicating a 
     *          syllabus record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> syllabusSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSyllabusSearchRecordType(org.osid.type.Type syllabusSearchRecordType);


    /**
     *  Gets the supported <code> Plan </code> record types. 
     *
     *  @return a list containing the supported plan record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getPlanRecordTypes();


    /**
     *  Tests if the given <code> Plan </code> record type is supported. 
     *
     *  @param  planRecordType a <code> Type </code> indicating a <code> Plan 
     *          </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> planRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPlanRecordType(org.osid.type.Type planRecordType);


    /**
     *  Gets the supported plan search record types. 
     *
     *  @return a list containing the supported plan search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getPlanSearchRecordTypes();


    /**
     *  Tests if the given plan search record type is supported. 
     *
     *  @param  planSearchRecordType a <code> Type </code> indicating a plan 
     *          record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> planSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPlanSearchRecordType(org.osid.type.Type planSearchRecordType);


    /**
     *  Gets the supported <code> Lesson </code> record types. 
     *
     *  @return a list containing the supported lesson record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getLessonRecordTypes();


    /**
     *  Tests if the given <code> Lesson </code> record type is supported. 
     *
     *  @param  lessonRecordType a <code> Type </code> indicating a <code> 
     *          Lesson </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> lessonRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLessonRecordType(org.osid.type.Type lessonRecordType);


    /**
     *  Gets the supported lesson search record types. 
     *
     *  @return a list containing the supported lesson search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getLessonSearchRecordTypes();


    /**
     *  Tests if the given lesson search record type is supported. 
     *
     *  @param  lessonSearchRecordType a <code> Type </code> indicating a 
     *          lesson record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> lessonSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLessonSearchRecordType(org.osid.type.Type lessonSearchRecordType);
}
