//
// org.osid.course.plan.LessonSearchOrder
//
//     The OSID Java specification for org.osid.course.plan.LessonSearchOrder.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.plan;


/**
 *  <p>An interface for specifying the ordering of search results. </p>
 */

public interface LessonSearchOrder
    extends org.osid.OsidRelationshipSearchOrder {


    /**
     *  Specified a preference for ordering results by the plan. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByPlan(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a <code> PlanSearchOrder </code> is available. 
     *
     *  @return <code> true </code> if a plan search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPlanSearchOrder();


    /**
     *  Gets the search order for a plan. 
     *
     *  @return the plan search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPlanSearchOrder() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPlanSearchOrder() </code> is <code> true. </code> 
     */

    public org.osid.course.plan.PlanSearchOrder getPlanSearchOrder();


    /**
     *  Specified a preference for ordering results by the docet. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByDocet(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a <code> DocetSearchOrder </code> is available. 
     *
     *  @return <code> true </code> if a docet search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDocetSearchOrder();


    /**
     *  Gets the search order for a docet. 
     *
     *  @return the docet search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDocetSearchOrder() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDocetSearchOrder() </code> is <code> true. </code> 
     */

    public org.osid.course.syllabus.DocetSearchOrder getDocetSearchOrder();


    /**
     *  Specified a preference for ordering results by the planned start time. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByPlannedStartTime(org.osid.SearchOrderStyle style);


    /**
     *  Specified a preference for ordering results by the begun flag. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByBegun(org.osid.SearchOrderStyle style);


    /**
     *  Specified a preference for ordering results by the actual start time. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByActualStartTime(org.osid.SearchOrderStyle style);


    /**
     *  Specified a preference for ordering results by the actual starting 
     *  activity. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByActualStartingActivity(org.osid.SearchOrderStyle style);


    /**
     *  Tests if an <code> ActivitySearchOrder </code> is available. 
     *
     *  @return <code> true </code> if an activity search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActualStartingActivitySearchOrder();


    /**
     *  Gets the search order for an actual starting actvity. 
     *
     *  @return the activity search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActualStartingActivitySearchOrder() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActualStartingActivitySearchOrder() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.course.ActivitySearchOrder getActualStartingActivitySearchOrder();


    /**
     *  Specified a preference for ordering results by the complete flag. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByComplete(org.osid.SearchOrderStyle style);


    /**
     *  Specified a preference for ordering results by the skipped flag. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderBySkipped(org.osid.SearchOrderStyle style);


    /**
     *  Specified a preference for ordering results by the actual end time. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByActualEndTime(org.osid.SearchOrderStyle style);


    /**
     *  Specified a preference for ordering results by the actual ending 
     *  activity. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByActualEndingActivity(org.osid.SearchOrderStyle style);


    /**
     *  Tests if an <code> ActivitySearchOrder </code> is available. 
     *
     *  @return <code> true </code> if an activity search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActualEndingActivitySearchOrder();


    /**
     *  Gets the search order for an actual ending actvity. 
     *
     *  @return the activity search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActualEndingActivitySearchOrder() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActualEndingActivitySearchOrder() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.course.ActivitySearchOrder getActualEndingActivitySearchOrder();


    /**
     *  Specified a preference for ordering results by the actual time spent. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByActualTimeSpent(org.osid.SearchOrderStyle style);


    /**
     *  Gets the lesson search order record corresponding to the given lesson 
     *  record Type. Multiple retrievals return the same underlying object. 
     *
     *  @param  lessonRecordType a lesson record type 
     *  @return the lesson search order record 
     *  @throws org.osid.NullArgumentException <code> lessonRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(lessonRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.plan.records.LessonSearchOrderRecord getLessonSearchOrderRecord(org.osid.type.Type lessonRecordType)
        throws org.osid.OperationFailedException;
}
