//
// org.osid.course.plan.LessonSearchSession
//
//     The OSID Java specification for org.osid.course.plan.LessonSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.plan;


/**
 *  <p>This session provides methods for searching <code> Lesson </code> 
 *  objects. The search query is constructed using the <code> LessonQuery. 
 *  </code> The lesson record <code> Type </code> also specifies the record 
 *  for the lesson query. </p> 
 *  
 *  <p> <code> getLessonsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Lesson </code> elements. A more advanced search 
 *  may be performed with <code> getLessonsBySearch(). </code> It accepts a 
 *  <code> LessonSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getLessonsBySearch() </code> returns a <code> 
 *  LessonSearchResults </code> that can be used to access the resulting 
 *  <code> LessonList </code> or be used to perform a search within the result 
 *  set through <code> LessonSearch. </code> </p> 
 *  
 *  <p> Lessons may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> LessonQuery. </code> 
 *  The returns in this session may not be cast directly to these interfaces. 
 *  </p>
 */

public interface LessonSearchSession
    extends org.osid.course.plan.LessonQuerySession {


    /**
     *  Gets a lesson search. 
     *
     *  @return the lesson search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.plan.LessonSearch getLessonSearch();


    /**
     *  Gets a lesson search order. The <code> LessonSearchOrder </code> is 
     *  supplied to a <code> LessonSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the lesson search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.plan.LessonSearchOrder getLessonSearchOrder();


    /**
     *  Gets the search results matching the given search. 
     *
     *  @param  lessonQuery the lesson query 
     *  @param  lessonSearch the lesson search 
     *  @return the lesson search results 
     *  @throws org.osid.NullArgumentException <code> lessonQuery </code> or 
     *          <code> lessonSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> lessonQuery </code> or 
     *          <code> lessonSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.plan.LessonSearchResults getLessonsBySearch(org.osid.course.plan.LessonQuery lessonQuery, 
                                                                       org.osid.course.plan.LessonSearch lessonSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a lesson query from an inspector. The inspector is available from 
     *  a <code> LessonSearchResults. </code> 
     *
     *  @param  lessonQueryInspector a lesson query inspector 
     *  @return the course catalog query 
     *  @throws org.osid.NullArgumentException <code> lessonQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> lessonQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.plan.LessonQuery getLessonQueryFromInspector(org.osid.course.plan.LessonQueryInspector lessonQueryInspector);
}
