//
// org.osid.course.plan.PlanQueryInspector
//
//     The OSID Java specification for org.osid.course.plan.PlanQueryInspector.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.plan;


/**
 *  <p>The inspector for examining plan queries. </p>
 */

public interface PlanQueryInspector
    extends org.osid.OsidRelationshipQueryInspector {


    /**
     *  Gets the syllabus <code> Id </code> terms. 
     *
     *  @return the syllabus <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getSyllabusIdTerms();


    /**
     *  Gets the syllabus terms. 
     *
     *  @return the syllabus terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.syllabus.SyllabusQueryInspector[] getSyllabusTerms();


    /**
     *  Gets the course offering <code> Id </code> terms. 
     *
     *  @return the course offering <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getCourseOfferingIdTerms();


    /**
     *  Gets the course offering terms. 
     *
     *  @return the course offering terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseOfferingQueryInspector[] getCourseOfferingTerms();


    /**
     *  Gets the module <code> Id </code> terms. 
     *
     *  @return the module <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getModuleIdTerms();


    /**
     *  Gets the module terms. 
     *
     *  @return the module terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.syllabus.ModuleQueryInspector[] getModuleTerms();


    /**
     *  Gets the lesson <code> Id </code> terms. 
     *
     *  @return the lesson <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getLessonIdTerms();


    /**
     *  Gets the lesson terms. 
     *
     *  @return the lesson terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.plan.LessonQueryInspector[] getLessonTerms();


    /**
     *  Gets the course catalog <code> Id </code> terms. 
     *
     *  @return the course catalog <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getCourseCatalogIdTerms();


    /**
     *  Gets the course catalog terms. 
     *
     *  @return the course catalog terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseCatalogQueryInspector[] getCourseCatalogTerms();


    /**
     *  Gets the plan query inspector record corresponding to the given <code> 
     *  Plan </code> record <code> Type. </code> 
     *
     *  @param  planRecordType a plan record type 
     *  @return the plan query inspector record 
     *  @throws org.osid.NullArgumentException <code> planRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(planRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.plan.records.PlanQueryInspectorRecord getPlanQueryInspectorRecord(org.osid.type.Type planRecordType)
        throws org.osid.OperationFailedException;
}
