//
// org.osid.course.plan.PlanSearchSession
//
//     The OSID Java specification for org.osid.course.plan.PlanSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.plan;


/**
 *  <p>This session provides methods for searching <code> Plan </code> 
 *  objects. The search query is constructed using the <code> PlanQuery. 
 *  </code> The plan record <code> Type </code> also specifies the record for 
 *  the plan query. </p> 
 *  
 *  <p> <code> getPlansByQuery() </code> is the basic search method and 
 *  returns a list of <code> CourseCatalog </code> elements. A more advanced 
 *  search may be performed with <code> getPlansBySearch(). </code> It accepts 
 *  a <code> PlanSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getPlansBySearch() </code> returns a <code> 
 *  PlanSearchResults </code> that can be used to access the resulting <code> 
 *  PlanList </code> or be used to perform a search within the result set 
 *  through <code> PlanSearch. </code> </p> 
 *  
 *  <p> Plans may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> PlanQuery. </code> The 
 *  returns in this session may not be cast directly to these interfaces. </p>
 */

public interface PlanSearchSession
    extends org.osid.course.plan.PlanQuerySession {


    /**
     *  Gets a plan search. 
     *
     *  @return the plan search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.plan.PlanSearch getPlanSearch();


    /**
     *  Gets a plan search order. The <code> PlanSearchOrder </code> is 
     *  supplied to a <code> PlanSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the plan search order interface 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.plan.PlanSearchOrder getPlanSearchOrder();


    /**
     *  Gets the search results matching the given search. 
     *
     *  @param  planQuery the plan query 
     *  @param  planSearch the plan search 
     *  @return the plan search results 
     *  @throws org.osid.NullArgumentException <code> planQuery </code> or 
     *          <code> planSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> planQuery </code> or 
     *          <code> planSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.plan.PlanSearchResults getPlansBySearch(org.osid.course.plan.PlanQuery planQuery, 
                                                                   org.osid.course.plan.PlanSearch planSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a plan query from an inspector. The inspector is available from 
     *  an <code> PlanSearchResults. </code> 
     *
     *  @param  planQueryInspector a plan query inspector 
     *  @return the plan query 
     *  @throws org.osid.NullArgumentException <code> planQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> planQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.plan.PlanQuery getPlanQueryFromInspector(org.osid.course.plan.PlanQueryInspector planQueryInspector);
}
