//
// org.osid.course.program.CourseProgramProfile
//
//     The OSID Java specification for org.osid.course.program.CourseProgramProfile.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.program;


/**
 *  <p>The course program profile describes the interoperability among course 
 *  program services. </p>
 */

public interface CourseProgramProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any course catalog federation is exposed. Federation is 
     *  exposed when a specific course catalog may be identified, selected and 
     *  used to create a lookup or admin session. Federation is not exposed 
     *  when a set of catalogs appears as a single catalog. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if looking up programs is supported. 
     *
     *  @return <code> true </code> if program lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProgramLookup();


    /**
     *  Tests if querying programs is supported. 
     *
     *  @return <code> true </code> if program query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProgramQuery();


    /**
     *  Tests if searching programs is supported. 
     *
     *  @return <code> true </code> if program search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProgramSearch();


    /**
     *  Tests if program administrative service is supported. 
     *
     *  @return <code> true </code> if program administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProgramAdmin();


    /**
     *  Tests if a program <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if program notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProgramNotification();


    /**
     *  Tests if a program cataloging service is supported. 
     *
     *  @return <code> true </code> if program cataloging is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProgramCourseCatalog();


    /**
     *  Tests if a course cataloging service is supported. A course cataloging 
     *  service maps programs to catalogs. 
     *
     *  @return <code> true </code> if course cataloging is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProgramCourseCatalogAssignment();


    /**
     *  Tests if a program smart course catalog session is available. 
     *
     *  @return <code> true </code> if a program smart course catalog session 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProgramSmartCourseCatalog();


    /**
     *  Tests if a course/program lookup service is supported. 
     *
     *  @return <code> true </code> if course/program lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseProgramLookup();


    /**
     *  Tests if a course/program mapping service is supported. 
     *
     *  @return <code> true </code> if course/program mapping service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseProgramAssignment();


    /**
     *  Tests if looking up program offerings is supported. 
     *
     *  @return <code> true </code> if program offering lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProgramOfferingLookup();


    /**
     *  Tests if querying program offerings is supported. 
     *
     *  @return <code> true </code> if program offering query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProgramOfferingQuery();


    /**
     *  Tests if searching program offerings is supported. 
     *
     *  @return <code> true </code> if program offering search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProgramOfferingSearch();


    /**
     *  Tests if course <code> </code> offering <code> </code> administrative 
     *  service is supported. 
     *
     *  @return <code> true </code> if program offering administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProgramOfferingAdmin();


    /**
     *  Tests if a program offering <code> </code> notification service is 
     *  supported. 
     *
     *  @return <code> true </code> if program offering notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProgramOfferingNotification();


    /**
     *  Tests if a program offering cataloging service is supported. 
     *
     *  @return <code> true </code> if program offering catalog is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProgramOfferingCourseCatalog();


    /**
     *  Tests if a program offering cataloging service is supported. A 
     *  cataloging service maps program offerings to catalogs. 
     *
     *  @return <code> true </code> if program offering cataloging is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProgramOfferingCourseCatalogAssignment();


    /**
     *  Tests if a program offering smart course catalog session is available. 
     *
     *  @return <code> true </code> if a program offering smart course catalog 
     *          session is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProgramOfferingSmartCourseCatalog();


    /**
     *  Tests if looking up courses is supported. 
     *
     *  @return <code> true </code> if course lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCredentialLookup();


    /**
     *  Tests if querying courses is supported. 
     *
     *  @return <code> true </code> if credential query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCredentialQuery();


    /**
     *  Tests if searching courses is supported. 
     *
     *  @return <code> true </code> if credential search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCredentialSearch();


    /**
     *  Tests if course <code> </code> administrative service is supported. 
     *
     *  @return <code> true </code> if course administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCredentialAdmin();


    /**
     *  Tests if a course <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if course notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCredentialNotification();


    /**
     *  Tests if a course cataloging service is supported. 
     *
     *  @return <code> true </code> if course cataloging is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCredentialCourseCatalog();


    /**
     *  Tests if a course cataloging service is supported. A course cataloging 
     *  service maps courses to catalogs. 
     *
     *  @return <code> true </code> if course cataloging is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCredentialCourseCatalogAssignment();


    /**
     *  Tests if a credential smart course catalog session is available. 
     *
     *  @return <code> true </code> if a credential smart course catalog 
     *          session is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCredentialSmartCourseCatalog();


    /**
     *  Tests if looking up enrollments is supported. 
     *
     *  @return <code> true </code> if enrollment lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEnrollmentLookup();


    /**
     *  Tests if querying enrollments is supported. 
     *
     *  @return <code> true </code> if enrollment query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEnrollmentQuery();


    /**
     *  Tests if searching enrollments is supported. 
     *
     *  @return <code> true </code> if enrollment search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEnrollmentSearch();


    /**
     *  Tests if an enrollment <code> </code> administrative service is 
     *  supported. 
     *
     *  @return <code> true </code> if enrollment administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEnrollmentAdmin();


    /**
     *  Tests if an enrollment <code> </code> notification service is 
     *  supported. 
     *
     *  @return <code> true </code> if enrollment notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEnrollmentNotification();


    /**
     *  Tests if an enrollment cataloging service is supported. 
     *
     *  @return <code> true </code> if enrollment catalog is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEnrollmentCourseCatalog();


    /**
     *  Tests if an enrollment cataloging service is supported. A cataloging 
     *  service maps enrollments to catalogs. 
     *
     *  @return <code> true </code> if enrollment cataloging is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEnrollmentCourseCatalogAssignment();


    /**
     *  Tests if an enrollment smart course catalog session is available. 
     *
     *  @return <code> true </code> if an enrollment smart course catalog 
     *          session is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEnrollmentSmartCourseCatalog();


    /**
     *  Tests if a course program batch service is available. 
     *
     *  @return <code> true </code> if a course program batch service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseProgramBatch();


    /**
     *  Gets the supported <code> program </code> record types. 
     *
     *  @return a list containing the supported <code> Program </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getProgramRecordTypes();


    /**
     *  Tests if the given <code> program </code> record type is supported. 
     *
     *  @param  programRecordType a <code> Type </code> indicating a <code> 
     *          program </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> programRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProgramRecordType(org.osid.type.Type programRecordType);


    /**
     *  Gets the supported <code> program </code> search record types. 
     *
     *  @return a list containing the supported <code> program </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getProgramSearchRecordTypes();


    /**
     *  Tests if the given <code> program </code> search record type is 
     *  supported. 
     *
     *  @param  programSearchRecordType a <code> Type </code> indicating a 
     *          <code> Program </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> programSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProgramSearchRecordType(org.osid.type.Type programSearchRecordType);


    /**
     *  Gets the supported <code> ProgramOffering </code> record types. 
     *
     *  @return a list containing the supported <code> ProgramOffering </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getProgramOfferingRecordTypes();


    /**
     *  Tests if the given <code> ProgramOffering </code> record type is 
     *  supported. 
     *
     *  @param  programOfferingRecordType a <code> Type </code> indicating an 
     *          <code> ProgramOffering </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          programOfferingRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProgramOfferingRecordType(org.osid.type.Type programOfferingRecordType);


    /**
     *  Gets the supported <code> ProgramOffering </code> search record types. 
     *
     *  @return a list containing the supported <code> ProgramOffering </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getProgramOfferingSearchRecordTypes();


    /**
     *  Tests if the given <code> ProgramOffering </code> search record type 
     *  is supported. 
     *
     *  @param  programOfferingSearchRecordType a <code> Type </code> 
     *          indicating an <code> ProgramOffering </code> search record 
     *          type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          programOfferingSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProgramOfferingSearchRecordType(org.osid.type.Type programOfferingSearchRecordType);


    /**
     *  Gets the supported <code> credential </code> record types. 
     *
     *  @return a list containing the supported <code> credential </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCredentialRecordTypes();


    /**
     *  Tests if the given <code> credential </code> record type is supported. 
     *
     *  @param  credentialRecordType a <code> Type </code> indicating a <code> 
     *          credential </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> credentialRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCredentialRecordType(org.osid.type.Type credentialRecordType);


    /**
     *  Gets the supported <code> credential </code> search record types. 
     *
     *  @return a list containing the supported <code> credential </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCredentialSearchRecordTypes();


    /**
     *  Tests if the given <code> credential </code> search record type is 
     *  supported. 
     *
     *  @param  credentialSearchRecordType a <code> Type </code> indicating a 
     *          <code> credential </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          credentialSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCredentialSearchRecordType(org.osid.type.Type credentialSearchRecordType);


    /**
     *  Gets the supported <code> Enrollment </code> record types. 
     *
     *  @return a list containing the supported <code> Enrollment </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getEnrollmentRecordTypes();


    /**
     *  Tests if the given <code> Enrollment </code> record type is supported. 
     *
     *  @param  enrollmentRecordType a <code> Type </code> indicating an 
     *          <code> Enrollment </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> enrollmentRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEnrollmentRecordType(org.osid.type.Type enrollmentRecordType);


    /**
     *  Gets the supported <code> Enrollment </code> search record types. 
     *
     *  @return a list containing the supported <code> Enrollment </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getEnrollmentSearchRecordTypes();


    /**
     *  Tests if the given <code> Enrollment </code> search record type is 
     *  supported. 
     *
     *  @param  enrollmentSearchRecordType a <code> Type </code> indicating an 
     *          <code> Enrollment </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          enrollmentSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEnrollmentSearchRecordType(org.osid.type.Type enrollmentSearchRecordType);
}
