//
// org.osid.course.program.Credential
//
//     The OSID Java specification for org.osid.course.program.Credential.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.program;


/**
 *  <p>A <code> Credential </code> represents something awarded at program 
 *  completion. </p>
 */

public interface Credential
    extends org.osid.OsidObject {


    /**
     *  Tests if this credential has a limited lifetime. 
     *
     *  @return <code> true </code> if this credential expires, <code> false 
     *          </code> if permanent 
     *  @compliance mandatory This method is must be implemented. 
     */

    public boolean hasLifeTime();


    /**
     *  Gets the lifetime of this credential once awarded. 
     *
     *  @return the lifetime 
     *  @throws org.osid.IllegalStateException <code> hasLifetime() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Duration getLifetime();


    /**
     *  Gets the credential record corresponding to the given <code> 
     *  Credential </code> record <code> Type. </code> This method is used to 
     *  retrieve an object implementing the requested record. The <code> 
     *  credentialRecordType </code> may be the <code> Type </code> returned 
     *  in <code> getRecordTypes() </code> or any of its parents in a <code> 
     *  Type </code> hierarchy where <code> 
     *  hasRecordType(credentialRecordType) </code> is <code> true </code> . 
     *
     *  @param  credentialRecordType the type of credential record to retrieve 
     *  @return the credential record 
     *  @throws org.osid.NullArgumentException <code> credentialRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(credentialRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.records.CredentialRecord getCredentialRecord(org.osid.type.Type credentialRecordType)
        throws org.osid.OperationFailedException;
}
