//
// org.osid.course.program.CredentialLookupSession
//
//     The OSID Java specification for org.osid.course.program.CredentialLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.program;


/**
 *  <p>This session defines methods for retrieving credentials. A <code> 
 *  Credential </code> is an award granted at he completion of a program. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated course catalog view: All credential methods in this 
 *      session operate, retrieve and pertain to credential defined explicitly 
 *      in the current course catalog. Using an isolated view is useful for 
 *      managing <code> Credentials </code> with the <code> 
 *      CredentialAdminSession. </code> </li> 
 *      <li> federated course catalog view: All credentials lookup methods in 
 *      this session operate, retrieve and pertain to all credentials defined 
 *      in this course catalog and any other credentials implicitly available 
 *      in this course catalog through course catalog inheritence. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedCourseCatalogView() </code> and <code> 
 *  useIsolatedCourseCatalogView() </code> behave as a radio group and one 
 *  should be selected before invoking any lookup methods. </p> 
 *  
 *  <p> Credentials may have an additional records indicated by their 
 *  respective record types. The record may not be accessed through a cast of 
 *  the <code> Credential. </code> </p>
 */

public interface CredentialLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> CourseCatalog </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> CourseCatalog Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCourseCatalogId();


    /**
     *  Gets the <code> CourseCatalog </code> associated with this session. 
     *
     *  @return the course catalog 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseCatalog getCourseCatalog()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Credential </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupCredentials();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeCredentialView();


    /**
     *  A complete view of the <code> credential </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryCredentialView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include credentials in catalogs which are children of this catalog in 
     *  the course catalog hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCourseCatalogView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this course catalog only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCourseCatalogView();


    /**
     *  Gets the <code> Credential </code> specified by its <code> Id. </code> 
     *  In plenary mode, the exact <code> Id </code> is found or a <code> 
     *  NOT_FOUND </code> results. Otherwise, the returned <code> Credential 
     *  </code> may have a different <code> Id </code> than requested, such as 
     *  the case where a duplicate <code> Id </code> was assigned to a <code> 
     *  Credential </code> and retained for compatibility. 
     *
     *  @param  credentialId the <code> Id </code> of the <code> Credential 
     *          </code> to retrieve 
     *  @return the returned <code> Credential </code> 
     *  @throws org.osid.NotFoundException no <code> Credential </code> found 
     *          with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> credentialId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.Credential getCredential(org.osid.id.Id credentialId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CredentialList </code> corresponding to the given <code> 
     *  IdList. </code> In plenary mode, the returned list contains all of the 
     *  credentials specified in the <code> Id </code> list, in the order of 
     *  the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Credentials </code> may be omitted from the list 
     *  and may present the elements in any order including returning a unique 
     *  set. 
     *
     *  @param  credentialIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> CredentialList </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> credentialIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.CredentialList getCredentialsByIds(org.osid.id.IdList credentialIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CredentialList </code> corresponding to the given 
     *  credential genus <code> Type </code> which does not include 
     *  credentials of types derived from the specified <code> Type. </code> 
     *  In plenary mode, the returned list contains all known credentials or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  credentials that are accessible through this session. 
     *
     *  @param  credentialGenusType a credential genus type 
     *  @return the returned <code> CredentialList </code> list 
     *  @throws org.osid.NullArgumentException <code> credentialGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.CredentialList getCredentialsByGenusType(org.osid.type.Type credentialGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CredentialList </code> corresponding to the given 
     *  credential genus <code> Type </code> and include any additional 
     *  credentials with genus types derived from the specified <code> Type. 
     *  </code> In plenary mode, the returned list contains all known 
     *  credentials or an error results. Otherwise, the returned list may 
     *  contain only those credentials that are accessible through this 
     *  session. 
     *
     *  @param  credentialGenusType a credential genus type 
     *  @return the returned <code> CredentialList </code> list 
     *  @throws org.osid.NullArgumentException <code> credentialGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.CredentialList getCredentialsByParentGenusType(org.osid.type.Type credentialGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CredentialList </code> containing the given credential 
     *  record <code> Type. </code> In plenary mode, the returned list 
     *  contains all known credentials or an error results. Otherwise, the 
     *  returned list may contain only those credentials that are accessible 
     *  through this session. 
     *
     *  @param  credentialRecordType a credential record type 
     *  @return the returned <code> CredentialList </code> list 
     *  @throws org.osid.NullArgumentException <code> credentialRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.CredentialList getCredentialsByRecordType(org.osid.type.Type credentialRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Credentials. </code> In plenary mode, the returned 
     *  list contains all known credentials or an error results. Otherwise, 
     *  the returned list may contain only those credentials that are 
     *  accessible through this session. 
     *
     *  @return a list of <code> Credentials </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.CredentialList getCredentials()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
