//
// org.osid.course.program.CredentialQuery
//
//     The OSID Java specification for org.osid.course.program.CredentialQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.program;


/**
 *  <p>This is the query for searching credentials. Each method match 
 *  specifies an <code> AND </code> term while multiple invocations of the 
 *  same method produce a nested <code> OR. </code> </p>
 */

public interface CredentialQuery
    extends org.osid.OsidObjectQuery {


    /**
     *  Matches lifetimes between the given range inclusive. 
     *
     *  @param  low start of range 
     *  @param  high end of range 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> low </code> is 
     *          greater than <code> high </code> 
     *  @throws org.osid.NullArgumentException <code> low </code> or <code> 
     *          high </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchLifetime(org.osid.calendaring.Duration low, 
                              org.osid.calendaring.Duration high, 
                              boolean match);


    /**
     *  Matches credentials that have any lifetime. 
     *
     *  @param  match <code> true </code> to match credentials with any 
     *          lifetime, <code> false </code> to match credentials with no 
     *          lifetime 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyLifetime(boolean match);


    /**
     *  Clears the lifetime <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLifetimeTerms();


    /**
     *  Sets the program <code> Id </code> for this query to match credentials 
     *  that have a related program. 
     *
     *  @param  programId a program <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> programId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchProgramId(org.osid.id.Id programId, boolean match);


    /**
     *  Clears the program <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProgramIdTerms();


    /**
     *  Tests if a <code> ProgramQuery </code> is available. 
     *
     *  @return <code> true </code> if a program query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProgramQuery();


    /**
     *  Gets the query for a program. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the program query 
     *  @throws org.osid.UnimplementedException <code> supportsProgramQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProgramQuery() </code> is <code> true. </code> 
     */

    public org.osid.course.program.ProgramQuery getProgramQuery();


    /**
     *  Matches credentials that have any program. 
     *
     *  @param  match <code> true </code> to match credentials with any 
     *          related program, <code> false </code> to match credentials 
     *          with no programs 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyProgram(boolean match);


    /**
     *  Clears the program terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProgramTerms();


    /**
     *  Sets the course catalog <code> Id </code> for this query to match 
     *  credentials assigned to course catalogs. 
     *
     *  @param  courseCatalogId the course catalog <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCourseCatalogId(org.osid.id.Id courseCatalogId, 
                                     boolean match);


    /**
     *  Clears the course catalog <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCourseCatalogIdTerms();


    /**
     *  Tests if a <code> CourseCatalogQuery </code> is available. 
     *
     *  @return <code> true </code> if a course catalog query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseCatalogQuery();


    /**
     *  Gets the query for a course catalog. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the course catalog query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCourseCatalogQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCourseCatalogQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.CourseCatalogQuery getCourseCatalogQuery();


    /**
     *  Clears the course catalog terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCourseCatalogTerms();


    /**
     *  Gets the credential query record corresponding to the given <code> 
     *  Credential </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  credentialRecordType a credential record type 
     *  @return the credential query record 
     *  @throws org.osid.NullArgumentException <code> credentialRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(credentialRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.records.CredentialQueryRecord getCredentialQueryRecord(org.osid.type.Type credentialRecordType)
        throws org.osid.OperationFailedException;
}
