//
// org.osid.course.program.CredentialSearchSession
//
//     The OSID Java specification for org.osid.course.program.CredentialSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.program;


/**
 *  <p>This session provides methods for searching among <code> credential 
 *  </code> objects. The search query is constructed using the <code> 
 *  CredentialQuery. </code> </p> 
 *  
 *  <p> <code> getCredentialsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Credentials. </code> A more advanced search may 
 *  be performed with <code> getCredentialsBySearch(). </code> It accepts a 
 *  <code> CredentialSearch </code> in addition to the query for the purpose 
 *  of specifying additional options affecting the entire search, such as 
 *  ordering. <code> getCredentialsBySearch() </code> returns a <code> 
 *  CredentialSearchResults </code> that can be used to access the resulting 
 *  <code> CredentialList </code> or be used to perform a search within the 
 *  result set through <code> CredentialSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated course catalog view: searches include credentials in 
 *      course catalogs of which this course catalog is an ancestor in the 
 *      course catalog hierarchy </li> 
 *      <li> isolated course catalog view: searches are restricted to 
 *      credentials in this course catalog </li> 
 *  </ul>
 *  
 *  
 *  <p> Credentials may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> CredentialQuery. 
 *  </code> </p>
 */

public interface CredentialSearchSession
    extends org.osid.course.program.CredentialQuerySession {


    /**
     *  Gets a credential search. 
     *
     *  @return the credential search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.CredentialSearch getCredentialSearch();


    /**
     *  Gets a credential search order. The <code> CredentialSearchOrder 
     *  </code> is supplied to a <code> CredentialSearch </code> to specify 
     *  the ordering of results. 
     *
     *  @return the credential search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.CredentialSearchOrder getCredentialSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  credentialQuery the credential query 
     *  @param  credentialSearch the credential search 
     *  @return the credential search results 
     *  @throws org.osid.NullArgumentException <code> credentialQuery </code> 
     *          or <code> credentialSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> credentialQuery </code> 
     *          or <code> credentialSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.CredentialSearchResults getCredentialsBySearch(org.osid.course.program.CredentialQuery credentialQuery, 
                                                                                  org.osid.course.program.CredentialSearch credentialSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a credential query from an inspector. The inspector is available 
     *  from a <code> CredentialSearchResults. </code> 
     *
     *  @param  credentialQueryInspector a credential query inspector 
     *  @return the credential query 
     *  @throws org.osid.NullArgumentException <code> credentialQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> credentialQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.CredentialQuery getCredentialQueryFromInspector(org.osid.course.program.CredentialQueryInspector credentialQueryInspector);
}
