//
// org.osid.course.program.ProgramLookupSession
//
//     The OSID Java specification for org.osid.course.program.ProgramLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.program;


/**
 *  <p>This session defines methods for retrieving programs. A P <code> rogram 
 *  </code> is canonical and a <code> ProgramOffering </code> is derived from 
 *  a <code> Program. </code> </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated course catalog view: All program methods in this session 
 *      operate, retrieve and pertain to programs defined explicitly in the 
 *      current course catalog. Using an isolated view is useful for managing 
 *      <code> Programs </code> with the Program <code> AdminSession. </code> 
 *      </li> 
 *      <li> federated course catalog view: All program lookup methods in this 
 *      session operate, retrieve and pertain to all programs defined in this 
 *      course catalog and any other programs implicitly available in this 
 *      course catalog through course catalog inheritence. </li> 
 *      <li> active program view: All program lookup methods return active 
 *      programs. </li> 
 *      <li> any status program view: Programs of any active or inactive 
 *      status are returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedCourseCatalogView() </code> and <code> 
 *  useIsolatedCourseCatalogView() </code> behave as a radio group and one 
 *  should be selected before invoking any lookup methods. </p> 
 *  
 *  <p> Programs may have an additional records indicated by their respective 
 *  record types. The record may not be accessed through a cast of the <code> 
 *  Program. </code> </p>
 */

public interface ProgramLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> CourseCatalog </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> CourseCatalog Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCourseCatalogId();


    /**
     *  Gets the <code> CourseCatalog </code> associated with this session. 
     *
     *  @return the course catalog 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseCatalog getCourseCatalog()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Program </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupPrograms();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeProgramView();


    /**
     *  A complete view of the <code> Program </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryProgramView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include programs in catalogs which are children of this catalog in the 
     *  course catalog hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCourseCatalogView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this course catalog only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCourseCatalogView();


    /**
     *  Only active programs are returned by methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveProgramView();


    /**
     *  All programs of any active or inactive status are returned by methods 
     *  in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusProgramView();


    /**
     *  Gets the <code> Program </code> specified by its <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  program </code> may have a different <code> Id </code> than requested, 
     *  such as the case where a duplicate <code> Id </code> was assigned to a 
     *  <code> program </code> and retained for compatibility. 
     *  
     *  In active mode, active programs are returned. In any status mode, 
     *  active and inactive programs are returned. 
     *
     *  @param  programId the <code> Id </code> of the <code> Program </code> 
     *          to retrieve 
     *  @return the returned <code> Program </code> 
     *  @throws org.osid.NotFoundException no <code> program </code> found 
     *          with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> programId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.Program getProgram(org.osid.id.Id programId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProgramList </code> corresponding to the given <code> 
     *  IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  programs specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Programs </code> may be omitted from the list and 
     *  may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In active mode, active programs are returned. In any status mode, 
     *  active and inactive programs are returned. 
     *
     *  @param  programIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> ProgramList </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> programIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.ProgramList getProgramsByIds(org.osid.id.IdList programIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProgramList </code> corresponding to the given program 
     *  genus <code> Type </code> which does not include programs of types 
     *  derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  programs or an error results. Otherwise, the returned list may contain 
     *  only those programs that are accessible through this session. 
     *  
     *  In active mode, active programs are returned. In any status mode, 
     *  active and inactive programs are returned. 
     *
     *  @param  programGenusType a program genus type 
     *  @return the returned <code> ProgramList </code> list 
     *  @throws org.osid.NullArgumentException <code> programGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.ProgramList getProgramsByGenusType(org.osid.type.Type programGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProgramList </code> corresponding to the given program 
     *  genus <code> Type </code> and include any additional programs with 
     *  genus types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  programs or an error results. Otherwise, the returned list may contain 
     *  only those programs that are accessible through this session. 
     *  
     *  In active mode, active programs are returned. In any status mode, 
     *  active and inactive programs are returned. 
     *
     *  @param  programGenusType a program genus type 
     *  @return the returned <code> ProgramList </code> list 
     *  @throws org.osid.NullArgumentException <code> programGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.ProgramList getProgramsByParentGenusType(org.osid.type.Type programGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProgramList </code> containing the given program record 
     *  <code> Type. </code> 
     *  
     *  In plenary mode, the returned list contains all known programs or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  programs that are accessible through this session. 
     *  
     *  In active mode, active programs are returned. In any status mode, 
     *  active and inactive programs are returned. 
     *
     *  @param  programRecordType a program record type 
     *  @return the returned <code> ProgramList </code> list 
     *  @throws org.osid.NullArgumentException <code> programRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.ProgramList getProgramsByRecordType(org.osid.type.Type programRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProgramList </code> containing the given creential. 
     *  
     *  In plenary mode, the returned list contains all known programs or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  programs that are accessible through this session. 
     *  
     *  In active mode, active programs are returned. In any status mode, 
     *  active and inactive programs are returned. 
     *
     *  @param  credentialId a credential <code> Id </code> 
     *  @return the returned <code> ProgramList </code> list 
     *  @throws org.osid.NullArgumentException <code> credentialId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.ProgramList getProgramsByCredential(org.osid.id.Id credentialId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Programs. </code> 
     *  
     *  In plenary mode, the returned list contains all known programs or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  programs that are accessible through this session. 
     *  
     *  In active mode, active programs are returned. In any status mode, 
     *  active and inactive programs are returned. 
     *
     *  @return a list of <code> Programs </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.ProgramList getPrograms()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
