//
// org.osid.course.program.ProgramOfferingForm
//
//     The OSID Java specification for org.osid.course.program.ProgramOfferingForm.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.program;


/**
 *  <p>This is the form for creating and updating <code> ProgramOfferings. 
 *  </code> Like all <code> OsidForm </code> objects, various data elements 
 *  may be set here for use in the create and update methods in the <code> 
 *  ProgramOfferingAdminSession. </code> For each data element that may be 
 *  set, metadata may be examined to provide display hints or data 
 *  constraints. </p>
 */

public interface ProgramOfferingForm
    extends org.osid.OsidRelationshipForm {


    /**
     *  Gets the metadata for a program title. 
     *
     *  @return metadata for the title 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getTitleMetadata();


    /**
     *  Sets the title. 
     *
     *  @param  title the new title 
     *  @throws org.osid.InvalidArgumentException <code> title </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> title </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setTitle(String title);


    /**
     *  Removes the title. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTitle();


    /**
     *  Gets the metadata for a program offering number. 
     *
     *  @return metadata for the program number 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getNumberMetadata();


    /**
     *  Sets the program number. 
     *
     *  @param  number the new program number 
     *  @throws org.osid.InvalidArgumentException <code> number </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> number </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setNumber(String number);


    /**
     *  Removes the program number. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearNumber();


    /**
     *  Gets the metadata for the sponsors. 
     *
     *  @return metadata for the sponsors 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getSponsorsMetadata();


    /**
     *  Sets the sponsors. 
     *
     *  @param  sponsorIds the new sponsors 
     *  @throws org.osid.InvalidArgumentException <code> sponsorIds </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> sponsorIds </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setSponsors(org.osid.id.Id[] sponsorIds);


    /**
     *  Removes the sponsors. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSponsors();


    /**
     *  Gets the metadata for a completion requirements informational string. 
     *
     *  @return metadata for the prerequisite information 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getCompletionRequirementsInfoMetadata();


    /**
     *  Sets the completion requirements information. 
     *
     *  @param  requirements the new requirements information 
     *  @throws org.osid.InvalidArgumentException <code> requirements </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> requirements </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setCompletionRequirementsInfo(String requirements);


    /**
     *  Removes the completion requirements information. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCompletionRequirementsInfo();


    /**
     *  Gets the metadata for a completion requirements requisites. 
     *
     *  @return metadata for the requisites 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getCompletionRequirementsMetadata();


    /**
     *  Sets the completion requirements requisites. 
     *
     *  @param  requisiteIds the new requisites 
     *  @throws org.osid.InvalidArgumentException <code> ruleId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> requisiteIds </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setCompletionRequirements(org.osid.id.Id[] requisiteIds);


    /**
     *  Removes the completion requirements requisites. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCompletionRequirements();


    /**
     *  Gets the metadata for a set of credentials. 
     *
     *  @return metadata for the credentials 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getCredentialsMetadata();


    /**
     *  Sets the credentials. 
     *
     *  @param  credentialIds the new credentials 
     *  @throws org.osid.InvalidArgumentException <code> gradeSystemIds 
     *          </code> is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> credentialIds </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setCredentials(org.osid.id.Id[] credentialIds);


    /**
     *  Removes the credentials. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCredentials();


    /**
     *  Gets the metadata for requires registration flag. 
     *
     *  @return metadata for registration flag 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getRequiresRegistrationMetadata();


    /**
     *  Sets the requires registration flag. 
     *
     *  @param  requiresRegistration the new registration flag 
     *  @throws org.osid.InvalidArgumentException <code> requiresRegistration 
     *          </code> is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setRequiresRegistration(boolean requiresRegistration);


    /**
     *  Removes the requires registration flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRequiresRegistration();


    /**
     *  Gets the metadata for the minimum seats. 
     *
     *  @return metadata for the minimum seats 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getMinimumSeatsMetadata();


    /**
     *  Sets the minimum seating count. 
     *
     *  @param  seats the new minimum seats 
     *  @throws org.osid.InvalidArgumentException <code> seats </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setMinimumSeats(long seats);


    /**
     *  Removes the minimum seats. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMinimumSeats();


    /**
     *  Gets the metadata for the maximum seats. 
     *
     *  @return metadata for the maximum seats 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getMaximumSeatsMetadata();


    /**
     *  Sets the maximum seating count. 
     *
     *  @param  seats the new maximum seats 
     *  @throws org.osid.InvalidArgumentException <code> seats </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setMaximumSeats(long seats);


    /**
     *  Removes the maximum seats. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMaximumSeats();


    /**
     *  Gets the metadata for a program url. 
     *
     *  @return metadata for the url 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getURLMetadata();


    /**
     *  Sets the url for a program web site. 
     *
     *  @param  url the new url 
     *  @throws org.osid.InvalidArgumentException <code> url </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> url </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setURL(String url);


    /**
     *  Removes the url. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearURL();


    /**
     *  Gets the <code> ProgramOfferingFormRecord </code> corresponding to the 
     *  given program offering record <code> Type. </code> 
     *
     *  @param  programOfferingRecordType a program offering record type 
     *  @return the program offering form record 
     *  @throws org.osid.NullArgumentException <code> 
     *          programOfferingRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(programOfferingRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.records.ProgramOfferingFormRecord getProgramOfferingFormRecord(org.osid.type.Type programOfferingRecordType)
        throws org.osid.OperationFailedException;
}
