//
// org.osid.course.program.ProgramOfferingQuery
//
//     The OSID Java specification for org.osid.course.program.ProgramOfferingQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.program;


/**
 *  <p>This is the query for searching program offerings. Each method match 
 *  specifies an <code> AND </code> term while multiple invocations of the 
 *  same method produce a nested <code> OR. </code> </p>
 */

public interface ProgramOfferingQuery
    extends org.osid.OsidRelationshipQuery {


    /**
     *  Sets the program <code> Id </code> for this query to match program 
     *  offerings that have a related program. 
     *
     *  @param  programId a program <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> programId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchProgramId(org.osid.id.Id programId, boolean match);


    /**
     *  Clears the program <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProgramIdTerms();


    /**
     *  Tests if a <code> ProgramQuery </code> is available. 
     *
     *  @return <code> true </code> if a program query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProgramQuery();


    /**
     *  Gets the query for a program. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the program query 
     *  @throws org.osid.UnimplementedException <code> supportsProgramQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProgramQuery() </code> is <code> true. </code> 
     */

    public org.osid.course.program.ProgramQuery getProgramQuery();


    /**
     *  Clears the program terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProgramTerms();


    /**
     *  Sets the term <code> Id </code> for this query to match program 
     *  offerings that have a related term. 
     *
     *  @param  termId a term <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> termId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchTermId(org.osid.id.Id termId, boolean match);


    /**
     *  Clears the term <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTermIdTerms();


    /**
     *  Tests if a <code> TermQuery </code> is available. 
     *
     *  @return <code> true </code> if a term query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTermQuery();


    /**
     *  Gets the query for a reporting term. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the term query 
     *  @throws org.osid.UnimplementedException <code> supportsTermQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTermQuery() </code> is <code> true. </code> 
     */

    public org.osid.course.TermQuery getTermQuery();


    /**
     *  Clears the reporting term terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTermTerms();


    /**
     *  Adds a title for this query. 
     *
     *  @param  title title string to match 
     *  @param  stringMatchType the string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> title </code> not of 
     *          <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> title </code> or <code> 
     *          stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchTitle(String title, org.osid.type.Type stringMatchType, 
                           boolean match);


    /**
     *  Matches a title that has any value. 
     *
     *  @param  match <code> true </code> to match program offerings with any 
     *          title, <code> false </code> to match program offerings with no 
     *          title 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyTitle(boolean match);


    /**
     *  Clears the title terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTitleTerms();


    /**
     *  Adds a program number for this query. 
     *
     *  @param  number program number string to match 
     *  @param  stringMatchType the string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> number </code> not of 
     *          <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> number </code> or <code> 
     *          stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchNumber(String number, org.osid.type.Type stringMatchType, 
                            boolean match);


    /**
     *  Matches a program number that has any value. 
     *
     *  @param  match <code> true </code> to match program offerings with any 
     *          number, <code> false </code> to match program offerings with 
     *          no number 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyNumber(boolean match);


    /**
     *  Clears the number terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearNumberTerms();


    /**
     *  Sets the resource <code> Id </code> for this query to match program 
     *  offerings that have an instructor. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchInstructorId(org.osid.id.Id resourceId, boolean match);


    /**
     *  Clears the instructor <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearInstructorIdTerms();


    /**
     *  Tests if a <code> ResourceQuery </code> is available. 
     *
     *  @return <code> true </code> if a resource query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInstructorQuery();


    /**
     *  Gets the query for an instructor. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return a resource query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInstructorQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInstructorQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceQuery getInstructorQuery();


    /**
     *  Matches program offerings that have any instructor. 
     *
     *  @param  match <code> true </code> to match program offerings with any 
     *          instructor, <code> false </code> to match program offerings 
     *          with no instructors 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyInstructor(boolean match);


    /**
     *  Clears the instructor terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearInstructorTerms();


    /**
     *  Sets the resource <code> Id </code> for this query to match programs 
     *  that have a sponsor. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSponsorId(org.osid.id.Id resourceId, boolean match);


    /**
     *  Clears the sponsor <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSponsorIdTerms();


    /**
     *  Tests if a <code> ResourceQuery </code> is available. 
     *
     *  @return <code> true </code> if a resource query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSponsorQuery();


    /**
     *  Gets the query for a sponsor. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return a resource query 
     *  @throws org.osid.UnimplementedException <code> supportsSponsorQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSponsorQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceQuery getSponsorQuery();


    /**
     *  Matches programs that have any sponsor. 
     *
     *  @param  match <code> true </code> to match programs with any sponsor, 
     *          <code> false </code> to match programs with no sponsors 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnySponsor(boolean match);


    /**
     *  Clears the sponsor terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSponsorTerms();


    /**
     *  Matches programs with the prerequisites informational string. 
     *
     *  @param  requirementsInfo completion requirements string to match 
     *  @param  stringMatchType the string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> requirementsInfo 
     *          </code> not of <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> requirementsInfo </code> 
     *          or <code> stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCompletionRequirementsInfo(String requirementsInfo, 
                                                org.osid.type.Type stringMatchType, 
                                                boolean match);


    /**
     *  Matches a program that has any completion requirements information 
     *  assigned. 
     *
     *  @param  match <code> true </code> to match programs with any 
     *          completion requirements information, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCompletionRequirementsInfo(boolean match);


    /**
     *  Clears the completion requirements info terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCompletionRequirementsInfoTerms();


    /**
     *  Sets the requisite <code> Id </code> for this query. 
     *
     *  @param  ruleId a rule <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> ruleId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCompletionRequirementsId(org.osid.id.Id ruleId, 
                                              boolean match);


    /**
     *  Clears the requisite <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCompletionRequirementsIdTerms();


    /**
     *  Tests if a <code> RequisiteQuery </code> is available. 
     *
     *  @return <code> true </code> if a requisite query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCompletionRequirementsQuery();


    /**
     *  Gets the query for a requisite. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return a requisite query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCompletionRequirementsQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCompletionRequirementsQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.course.requisite.RequisiteQuery getCompletionRequirementsQuery();


    /**
     *  Matches programs that have any completion requirement requisite. 
     *
     *  @param  match <code> true </code> to match programs with any 
     *          requisite, <code> false </code> to match programs with no 
     *          requisites 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCompletionRequirements(boolean match);


    /**
     *  Clears the requisite terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCompletionRequirementsTerms();


    /**
     *  Sets the credential <code> Id </code> for this query. 
     *
     *  @param  credentialId a credential <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> credentialId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCredentialId(org.osid.id.Id credentialId, boolean match);


    /**
     *  Clears the credential <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCredentialIdTerms();


    /**
     *  Tests if a <code> CredentialQuery </code> is available. 
     *
     *  @return <code> true </code> if a credential query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCredentialQuery();


    /**
     *  Gets the query for a credential. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return a credential query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCredentialQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCredentialQuery() </code> is <code> true. </code> 
     */

    public org.osid.course.program.CredentialQuery getCredentialQuery();


    /**
     *  Matches programs that have any credentials. 
     *
     *  @param  match <code> true </code> to match programs with any 
     *          credentials, <code> false </code> to match programs with no 
     *          credentials 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCredential(boolean match);


    /**
     *  Clears the credential terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCredentialTerms();


    /**
     *  Matches program offerings that require registration. 
     *
     *  @param  match <code> true </code> to match program offerings requiring 
     *          registration,, <code> false </code> to match program offerings 
     *          not requiring registration 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRequiresRegistration(boolean match);


    /**
     *  Clears the requires registration terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRequiresRegistrationTerms();


    /**
     *  Matches program offerings with minimum seating between the given 
     *  numbers inclusive. 
     *
     *  @param  min low number 
     *  @param  max high number 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> max </code> is less 
     *          than <code> min </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMinimumSeats(long min, long max, boolean match);


    /**
     *  Matches a program offering that has any minimum seating assigned. 
     *
     *  @param  match <code> true </code> to match program offerings with any 
     *          minimum seats, <code> false </code> to match program offerings 
     *          with no minimum seats 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyMinimumSeats(boolean match);


    /**
     *  Clears the minimum seats terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMinimumSeatsTerms();


    /**
     *  Matches program offerings with maximum seating between the given 
     *  numbers inclusive. 
     *
     *  @param  min low number 
     *  @param  max high number 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> max </code> is less 
     *          than <code> min </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMaximumSeats(long min, long max, boolean match);


    /**
     *  Matches a program offering that has any maximum seating assigned. 
     *
     *  @param  match <code> true </code> to match program offerings with any 
     *          maximum seats, <code> false </code> to match program offerings 
     *          with no maximum seats 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyMaximumSeats(boolean match);


    /**
     *  Clears the maximum seats terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMaximumSeatsTerms();


    /**
     *  Adds a class url for this query. 
     *
     *  @param  url url string to match 
     *  @param  stringMatchType the string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> url </code> not of 
     *          <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> url </code> or <code> 
     *          stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchURL(String url, org.osid.type.Type stringMatchType, 
                         boolean match);


    /**
     *  Matches a url that has any value. 
     *
     *  @param  match <code> true </code> to match program offerings with any 
     *          url, <code> false </code> to match program offerings with no 
     *          url 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyURL(boolean match);


    /**
     *  Clears the url terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearURLTerms();


    /**
     *  Sets the course catalog <code> Id </code> for this query to match 
     *  program offerings assigned to course catalogs. 
     *
     *  @param  courseCatalogId the course catalog <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCourseCatalogId(org.osid.id.Id courseCatalogId, 
                                     boolean match);


    /**
     *  Clears the course catalog <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCourseCatalogIdTerms();


    /**
     *  Tests if a <code> CourseCatalogQuery </code> is available. 
     *
     *  @return <code> true </code> if a course catalog query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseCatalogQuery();


    /**
     *  Gets the query for a course catalog. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the course catalog query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCourseCatalogQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCourseCatalogQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.CourseCatalogQuery getCourseCatalogQuery();


    /**
     *  Clears the course catalog terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCourseCatalogTerms();


    /**
     *  Gets the program offering query record corresponding to the given 
     *  <code> ProgramOffering </code> record <code> Type. </code> Multiple 
     *  record retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  programOfferingRecordType a program offering record type 
     *  @return the program offering query record 
     *  @throws org.osid.NullArgumentException <code> 
     *          programOfferingRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(programOfferingRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.records.ProgramOfferingQueryRecord getProgramOfferingQueryRecord(org.osid.type.Type programOfferingRecordType)
        throws org.osid.OperationFailedException;
}
