//
// org.osid.course.program.ProgramOfferingSearchSession
//
//     The OSID Java specification for org.osid.course.program.ProgramOfferingSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.program;


/**
 *  <p>This session provides methods for searching among <code> 
 *  ProgramOffering </code> objects. The search query is constructed using the 
 *  <code> ProgramOfferingQuery. </code> </p> 
 *  
 *  <p> <code> getProgramOfferingsByQuery() </code> is the basic search method 
 *  and returns a list of <code> ProgramOfferings. </code> A more advanced 
 *  search may be performed with <code> getProgramOfferingsBySearch(). </code> 
 *  It accepts a <code> ProgramOfferingSearch </code> in addition to the query 
 *  for the purpose of specifying additional options affecting the entire 
 *  search, such as ordering. <code> getProgramOfferingsBySearch() </code> 
 *  returns a <code> ProgramOfferingSearchResults </code> that can be used to 
 *  access the resulting <code> ProgramOfferingList </code> or be used to 
 *  perform a search within the result set through <code> 
 *  ProgramOfferingSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated course catalog view: searches include program offerings 
 *      in course catalogs of which this course catalog is an ancestor in the 
 *      course catalog hierarchy </li> 
 *      <li> isolated course catalog view: searches are restricted to program 
 *      offerings in this course catalog </li> 
 *  </ul>
 *  
 *  
 *  <p> Program offerings may have a query record indicated by their 
 *  respective record types. The queryrecord is accessed via the <code> 
 *  ProgramOfferingQuery. </code> </p>
 */

public interface ProgramOfferingSearchSession
    extends org.osid.course.program.ProgramOfferingQuerySession {


    /**
     *  Gets a program offering search. 
     *
     *  @return the program offering search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.ProgramOfferingSearch getProgramOfferingSearch();


    /**
     *  Gets a program offering search order. The <code> 
     *  ProgramOfferingSearchOrder </code> is supplied to a <code> 
     *  ProgramOfferingSearch </code> to specify the ordering of results. 
     *
     *  @return the program offering search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.ProgramOfferingSearchOrder getProgramOfferingSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  programOfferingQuery the program offering query 
     *  @param  programOfferingSearch the program offering search 
     *  @return the program offering search results 
     *  @throws org.osid.NullArgumentException <code> programOfferingQuery 
     *          </code> or <code> programOfferingSearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> programOfferingQuery 
     *          </code> or <code> programOfferingSearch </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.ProgramOfferingSearchResults getProgramOfferingsBySearch(org.osid.course.program.ProgramOfferingQuery programOfferingQuery, 
                                                                                            org.osid.course.program.ProgramOfferingSearch programOfferingSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a program offering query from an inspector. The inspector is 
     *  available from a <code> ProgramOfferingSearchResults. </code> 
     *
     *  @param  programOfferingQueryInspector a program offering query 
     *          inspector 
     *  @return the program offering query 
     *  @throws org.osid.NullArgumentException <code> 
     *          programOfferingQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          programOfferingQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.ProgramOfferingQuery getProgramOfferingQueryFromInspector(org.osid.assessment.ItemQueryInspector programOfferingQueryInspector);
}
