//
// org.osid.course.program.batch.EnrollmentBatchAdminSession
//
//     The OSID Java specification for org.osid.course.program.batch.EnrollmentBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.program.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Enrollments </code> 
 *  in bulk. The data for create and update is provided by the consumer via 
 *  the form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create an 
 *  <code> Enrollment, </code> an <code> EnrollmentForm </code> is requested 
 *  using <code> getEnrollmentFormsForCreate() </code> specifying the desired 
 *  activity, student, and record <code> Types </code> or none if no record 
 *  <code> Types </code> are needed. Each of the returned <code> 
 *  EnrollmentForms </code> will indicate that it is to be used with a create 
 *  operation and can be used to examine metdata or validate data prior to 
 *  creation. Once an <code> EnrollmentForm </code> is submiited to a create 
 *  operation, it cannot be reused with another create operation unless the 
 *  first operation was unsuccessful. Each <code> EnrollmentForm </code> 
 *  corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> EnrollmentForms </code> returned from <code> 
 *  getEnrollmentFormsForCreate() </code> may be linked to the originating 
 *  request through the peer <code> Ids </code> of the <code> EnrollmentForm. 
 *  </code> In the case where there may be duplicates, any <code> 
 *  EnrollmentForm </code> of the same peer <code> Ids </code> may be used for 
 *  a create operation. </p> 
 *  
 *  <p> Once a batch of <code> EnrollmentForms </code> are submitted for 
 *  create, a <code> CreateResponse </code> is returned for each <code> 
 *  EnrollmentForm, </code> although the ordering is not defined. Only errors 
 *  that pertain to the entire create operation are returned from <code> 
 *  createEnrollments(), </code> errors specific to an individual <code> 
 *  EnrollmentForm </code> are indicated in the corresponding <code> 
 *  CreateResponse. </code> <code> CreateResponses </code> may be linked to 
 *  the originating <code> EnrollmentForm </code> through the <code> 
 *  EnrollmentForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> EnrollmentForms </code> are requested to the 
 *  <code> Enrollment </code> <code> Id </code> that is to be updated using 
 *  <code> getEnrollmentFormsForUpdate() </code> where the reference <code> Id 
 *  </code> in the <code> EnrollmentForm </code> may be used to link the 
 *  request. Similarly, the <code> EnrollmentForm </code> has metadata about 
 *  the data that can be updated and it can perform validation before 
 *  submitting the update. The <code> EnrollmentForm </code> can only be used 
 *  once for a successful update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> EnrollmentForms </code> are submitted for 
 *  update, an <code> UpdateResponse </code> is returned for each <code> 
 *  EnrollmentForm, </code> although the ordering is not defined. Only errors 
 *  that pertain to the entire update operation are returned from <code> 
 *  updateEnrollments(), </code> errors specific to an individual <code> 
 *  EnrollmentForm </code> are indicated in the corresponding <code> 
 *  UpdateResponse. </code> <code> UpdateResponses </code> may be linked to 
 *  the originating <code> EnrollmentForm </code> through the <code> 
 *  EnrollmentForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> Enrollments </code> in bulk. To 
 *  unmap an <code> Enrollment </code> from the current <code> CourseCatalog, 
 *  </code> the <code> EnrollmentCourseCatalogAssignmentSession </code> should 
 *  be used. These delete operations attempt to remove the <code> Enrollment 
 *  </code> itself thus removing it from all known <code> CourseCatalog 
 *  </code> catalogs. Bulk delete operations return the results in <code> 
 *  DeleteResponses. </code> </p>
 */

public interface EnrollmentBatchAdminSession
    extends org.osid.course.program.EnrollmentAdminSession {


    /**
     *  Gets the enrollment forms for creating a bunch of new enrollments. A 
     *  form is returned for each activity and resource pair. 
     *
     *  @param  peers the relationship peers 
     *  @param  enrollmentRecordTypes array of enrollment record types to be 
     *          included in each create operation or an empty list if none 
     *  @return the enrollment forms 
     *  @throws org.osid.NotFoundException a <code> programId </code> or 
     *          <code> resourceId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> peers </code> or <code> 
     *          enrollmentRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.batch.EnrollmentBatchFormList getEnrollmentFormsForCreate(org.osid.course.program.batch.EnrollmentPeerList peers, 
                                                                                             org.osid.type.Type[] enrollmentRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Enrollments. </code> This method returns 
     *  an error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  enrollmentForms the enrollment forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> enrollmentForms </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createEnrollments(org.osid.course.program.batch.EnrollmentBatchFormList enrollmentForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the enrollment forms for updating an existing set of enrollments. 
     *  A new enrollment form should be requested for each update transaction. 
     *
     *  @param  enrollmentIds the <code> Ids </code> of the <code> Enrollment 
     *          </code> 
     *  @return the enrollment form 
     *  @throws org.osid.NotFoundException an <code> enrollmentId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> enrollmentIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.batch.EnrollmentBatchFormList getEnrollmentFormsForUpdate(org.osid.id.IdList enrollmentIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing enrollments. This method returns an error if the 
     *  entire operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  enrollmentForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> enrollmentForms </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateEnrollments(org.osid.course.program.batch.EnrollmentBatchFormList enrollmentForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Enrollments </code> in this <code> CourseCatalog 
     *  </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllEnrollments()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes enrollments for the given <code> Ids. </code> 
     *
     *  @param  enrollmentIds the <code> Ids </code> of the enrollments to 
     *          delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> enrollmentIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteEnrollments(org.osid.id.IdList enrollmentIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes enrollments for the given program offering. 
     *
     *  @param  programOfferingId an <code> Id </code> of a program 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> programOfferingId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteEnrollmentsForProgramOffering(org.osid.id.Id programOfferingId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes enrollments for the given student resource. 
     *
     *  @param  resourceId an <code> Id </code> of a resource 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteEnrollmentsForStudent(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes enrollments expired before the given date. 
     *
     *  @param  date a date 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteIneffectiveEnrollmentsByDate(org.osid.calendaring.DateTime date)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to an <code> Enrollment </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Enrollment </code> is determined by the provider. The new 
     *  <code> Id </code> is an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another enrollment, it is reassigned to the 
     *  given enrollment <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasEnrollments(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
