//
// org.osid.course.program.batch.ProgramOfferingBatchAdminSession
//
//     The OSID Java specification for org.osid.course.program.batch.ProgramOfferingBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.program.batch;


/**
 *  <p>This session creates, updates, and deletes <code> ProgramOfferings 
 *  </code> in bulk. The data for create and update is provided by the 
 *  consumer via the form object. <code> OsidForms </code> are requested for 
 *  each create or update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  ProgramOffering, </code> a <code> ProgramOfferingForm </code> is requested 
 *  using <code> getProgramOfferingFormsForCreate() </code> specifying the 
 *  desired program, term, and record <code> Types </code> or none if no 
 *  record <code> Types </code> are needed. Each of the returned <code> 
 *  ProgramForms </code> will indicate that it is to be used with a create 
 *  operation and can be used to examine metdata or validate data prior to 
 *  creation. Once a <code> ProgramOfferingForm </code> is submiited to a 
 *  create operation, it cannot be reused with another create operation unless 
 *  the first operation was unsuccessful. Each <code> ProgramOfferingForm 
 *  </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> ProgramForms </code> returned from <code> 
 *  getProgramOfferingFormsForCreate() </code> may be linked to the 
 *  originating request through the peer <code> Ids </code> of the <code> 
 *  ProgramOfferingForm. </code> In the case where there may be duplicates, 
 *  any <code> ProgramOfferingForm </code> of the same peer <code> Ids </code> 
 *  may be used for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> ProgramOfferingForms </code> are submitted for 
 *  create, a <code> CreateResponse </code> is returned for each <code> 
 *  ProgramOfferingForm, </code> although the ordering is not defined. Only 
 *  errors that pertain to the entire create operation are returned from 
 *  <code> createProgramOfferings(), </code> errors specific to an individual 
 *  <code> ProgramForm </code> are indicated in the corresponding <code> 
 *  CreateResponse. </code> <code> CreateResponses </code> may be linked to 
 *  the originating <code> ProgramOfferingForm </code> through the <code> 
 *  ProgramOfferingForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> ProgramOfferingForms </code> are requested to the 
 *  <code> ProgramOffering </code> <code> Id </code> that is to be updated 
 *  using <code> getProgramOfferingFormsForUpdate() </code> where the 
 *  reference <code> Id </code> in the <code> ProgramOfferingForm </code> may 
 *  be used to link the request. Similarly, the <code> ProgramOfferingForm 
 *  </code> has metadata about the data that can be updated and it can perform 
 *  validation before submitting the update. The <code> ProgramOfferingForm 
 *  </code> can only be used once for a successful update and cannot be 
 *  reused. </p> 
 *  
 *  <p> Once a batch of <code> ProgramOfferingForm </code> are submitted for 
 *  update, an <code> UpdateResponse </code> is returned for each <code> 
 *  ProgramOfferingForm, </code> although the ordering is not defined. Only 
 *  errors that pertain to the entire update operation are returned from 
 *  <code> updateProgramOfferings(), </code> errors specific to an individual 
 *  <code> ProgramOfferingForm </code> are indicated in the corresponding 
 *  <code> UpdateResponse. </code> <code> UpdateResponses </code> may be 
 *  linked to the originating <code> ProgramOfferingForm </code> through the 
 *  <code> ProgramOfferingForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> ProgramOfferings </code> in bulk. 
 *  To unmap a <code> ProgramOffering </code> from the current <code> 
 *  CourseCatalog, </code> the <code> 
 *  ProgramOfferingCourseCatalogAssignmentSession </code> should be used. 
 *  These delete operations attempt to remove the <code> ProgramOffering 
 *  </code> itself thus removing it from all known <code> CourseCatalog 
 *  </code> catalogs. Bulk delete operations return the results in <code> 
 *  DeleteResponses. </code> </p>
 */

public interface ProgramOfferingBatchAdminSession
    extends org.osid.course.program.ProgramAdminSession {


    /**
     *  Gets the program offering forms for creating a bunch of new program 
     *  offerings. A form is returned for supplied canonical program and term 
     *  pair. 
     *
     *  @param  peers a list of course offering peers 
     *  @param  programOfferingRecordTypes array of program record types to be 
     *          included in each create operation or an empty list if none 
     *  @return the program offering forms 
     *  @throws org.osid.NotFoundException a <code> programId </code> or 
     *          <code> termId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> peers </code> or <code> 
     *          programRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.batch.ProgramOfferingBatchFormList getProgramOfferingFormsForCreate(org.osid.course.program.batch.ProgramOfferingPeerList peers, 
                                                                                                       org.osid.type.Type[] programOfferingRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> ProgramOfferings. </code> This method 
     *  returns an error if the entire operation fails. Otherwise, the status 
     *  of an individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  programOfferingForms the program offering forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> programOfferingForms 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createProgramOfferings(org.osid.course.program.batch.ProgramOfferingBatchFormList programOfferingForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the program offering forms for updating an existing set of 
     *  program offerings. A new program offering form should be requested for 
     *  each update transaction. 
     *
     *  @param  programOfferingIds the <code> Ids </code> of the <code> 
     *          ProgramOffering </code> 
     *  @return the program offering forms 
     *  @throws org.osid.NotFoundException a <code> programOfferingId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> programOfferingIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.batch.ProgramOfferingBatchFormList getProgramOfferingFormsForUpdate(org.osid.id.IdList programOfferingIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing program offerings. This method returns an error if 
     *  the entire operation fails. Otherwise, the status of an individual 
     *  update operation is indicated in the <code> BatchCreateResponse 
     *  </code> . 
     *
     *  @param  programOfferingForms the form containing the elements to be 
     *          updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> programOfferingForms 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateProgramOfferings(org.osid.course.program.batch.ProgramOfferingBatchFormList programOfferingForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> ProgramOfferings </code> in this <code> 
     *  CourseCatalog </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllProgramOfferings()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes program offerings for the given <code> Ids. </code> 
     *
     *  @param  programOfferingIds the <code> Ids </code> of the program 
     *          offerings to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> programOfferingIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteProgramOfferings(org.osid.id.IdList programOfferingIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes program offerings for the given program. 
     *
     *  @param  programId the <code> Id </code> of a program 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> programId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteProgramOffeingsForProgram(org.osid.id.Id programId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes programs for the given term. 
     *
     *  @param  termId the <code> Id </code> of a term 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> termId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteProgramOfferingsForTerm(org.osid.id.Id termId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> ProgramOffering </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> ProgramOffering </code> is determined by the provider. The 
     *  new <code> Id </code> is an alias to the primary <code> Id. </code> If 
     *  the alias is a pointer to another program offering, it is reassigned 
     *  to the given program <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasProgramOfferings(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
