//
// org.osid.course.registration.ActivityBundle
//
//     The OSID Java specification for org.osid.course.registration.ActivityBundle.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.registration;


/**
 *  <p>An <code> ActivityBundle </code> represents a set of <code> Activities 
 *  </code> in which a <code> Registration </code> is permissable. </p>
 */

public interface ActivityBundle
    extends org.osid.OsidObject {


    /**
     *  Gets the course offering <code> Id </code> associated with this 
     *  activity bundle. 
     *
     *  @return the course offering <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCourseOfferingId();


    /**
     *  Gets the course offering associated with this activity bundle. 
     *
     *  @return the course offering 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseOffering getCourseOffering()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the activity <code> Ids </code> in this bundle. 
     *
     *  @return <code> Ids </code> of the <code> l </code> earning objectives 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.id.IdList getActivityIds();


    /**
     *  Gets the activities in this bundle. 
     *
     *  @return the activites 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.ActivityList getActivities()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if registration to this bundle results in credits to be earned. 
     *
     *  @return <code> true </code> if this course has credits, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean definesCredits();


    /**
     *  Gets the number of credits available to register for in this course. 
     *  Each array element is a distinct option. 
     *
     *  @return the number of credits 
     *  @throws org.osid.IllegalStateException <code> definesCredits() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal[] getCredits();


    /**
     *  Tests if a registration to this bundle will be for for grades. 
     *
     *  @return <code> true </code> if this registration is for grades, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isGraded();


    /**
     *  Gets the various grading option <code> Ids </code> available to 
     *  register in this course. 
     *
     *  @return the returned list of grading option <code> Ids </code> 
     *  @throws org.osid.IllegalStateException <code> isGraded() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getGradingOptionIds();


    /**
     *  Gets the various grading options available to register in this course. 
     *
     *  @return the returned list of grading options 
     *  @throws org.osid.IllegalStateException <code> isGraded() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeSystemList getGradingOptions()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the activity bundle record corresponding to the given <code> 
     *  ActivityBundle </code> record <code> Type. </code> This method is used 
     *  to retrieve an object implementing the requested record. The <code> 
     *  activityBundleRecordType </code> may be the <code> Type </code> 
     *  returned in <code> getRecordTypes() </code> or any of its parents in a 
     *  <code> Type </code> hierarchy where <code> 
     *  hasRecordType(activityBundleRecordType) </code> is <code> true </code> 
     *  . 
     *
     *  @param  activityBundleRecordType the type of activity bundle record to 
     *          retrieve 
     *  @return the activity bundle record 
     *  @throws org.osid.NullArgumentException <code> activityBundleRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(activityBundleRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.records.ActivityBundleRecord getActivityBundleRecord(org.osid.type.Type activityBundleRecordType)
        throws org.osid.OperationFailedException;
}
