//
// org.osid.course.registration.ActivityBundleAdminSession
//
//     The OSID Java specification for org.osid.course.registration.ActivityBundleAdminSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.registration;


/**
 *  <p>This session creates, updates, and deletes <code> ActivityBundles. 
 *  </code> The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create an 
 *  <code> ActivityBundle, </code> an <code> ActivityBundleForm </code> is 
 *  requested using <code> getActivityBundleFormForCreate() </code> specifying 
 *  the desired record <code> Types </code> or none if no record <code> Types 
 *  </code> are needed. The returned <code> ActivityBundleForm </code> will 
 *  indicate that it is to be used with a create operation and can be used to 
 *  examine metdata or validate data prior to creation. Once the <code> 
 *  ActivityBundleForm </code> is submiited to a create operation, it cannot 
 *  be reused with another create operation unless the first operation was 
 *  unsuccessful. Each <code> ActivityBundleForm </code> corresponds to an 
 *  attempted transaction. </p> 
 *  
 *  <p> For updates, <code> ActivityBundleForms </code> are requested to the 
 *  <code> ActivityBundle </code> <code> Id </code> that is to be updated 
 *  using <code> getActivityBundleFormForUpdate(). </code> Similarly, the 
 *  <code> ActivityBundleForm </code> has metadata about the data that can be 
 *  updated and it can perform validation before submitting the update. The 
 *  <code> ActivityBundleForm </code> can only be used once for a successful 
 *  update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> ActivityBundles. </code> To unmap 
 *  an <code> ActivityBundle </code> from the current <code> CourseCatalog, 
 *  </code> the <code> ActivityBundleCourseCatalogAssignmentSession </code> 
 *  should be used. These delete operations attempt to remove the <code> 
 *  ActivityBundle </code> itself thus removing it from all known <code> 
 *  CourseCatalog </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface ActivityBundleAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> CourseCatalog </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> CourseCatalog Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCourseCatalogId();


    /**
     *  Gets the <code> CourseCatalog </code> associated with this session. 
     *
     *  @return the course catalog 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseCatalog getCourseCatalog()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> ActivityBundles. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating an <code> ActivityBundle </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer create operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> ActivityBundle </code> creation 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateActivityBundles();


    /**
     *  Tests if this user can create a single <code> ActivityBundle </code> 
     *  using the desired record types. While <code> 
     *  CourseRegistrationManager.getActivityBundleRecordTypes() </code> can 
     *  be used to examine which records are supported, this method tests 
     *  which record(s) are required for creating a specific <code> 
     *  ActivityBundle. </code> Providing an empty array tests if an <code> 
     *  ActivityBundle </code> can be created with no records. 
     *
     *  @param  activityBundleRecordTypes array of types 
     *  @return <code> true </code> if <code> ActivityBundle </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          activityBundleRecordTypes </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateActivityBundleWithRecordTypes(org.osid.type.Type[] activityBundleRecordTypes);


    /**
     *  Tests if this user can create a single <code> ActivityBundle </code> 
     *  for a course offering. 
     *
     *  @param  courseOfferingId a course offering <code> Id </code> 
     *  @return <code> true </code> if <code> ActivityBundle </code> creation 
     *          for the specified <code> CourseOffering </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> courseOfferingId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateActivityBundlesForCourseOffering(org.osid.id.Id courseOfferingId);


    /**
     *  Gets the course form for creating new activity bundles. A new form 
     *  should be requested for each create transaction. 
     *
     *  @param  courseOfferingId a course offering <code> Id </code> 
     *  @param  activityBundleRecordTypes array of types 
     *  @return the activity bundle form 
     *  @throws org.osid.NotFoundException <code> courseOfferingId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> courseOfferingId </code> 
     *          or <code> activityBundleRecordTypes </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.ActivityBundleForm getActivityBundleFormForCreate(org.osid.id.Id courseOfferingId, 
                                                                                          org.osid.type.Type[] activityBundleRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> ActivityBundle. </code> 
     *
     *  @param  activityBundleForm the form for this <code> ActivityBundle 
     *          </code> 
     *  @return the new <code> ActivityBundle </code> 
     *  @throws org.osid.IllegalStateException <code> activityBundleForm 
     *          </code> already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> activityBundleForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> activityBundleForm 
     *          </code> did not originate from <code> 
     *          getActivityBundleFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.ActivityBundle createActivityBundle(org.osid.course.registration.ActivityBundleForm activityBundleForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> ActivityBundles. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating an <code> ActivityBundle </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer update operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> ActivityBundle </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateActivityBundles();


    /**
     *  Gets the activity bundle form for updating an existing activity 
     *  bundle. A new activity bundle form should be requested for each update 
     *  transaction. 
     *
     *  @param  activityBundleId the <code> Id </code> of the <code> 
     *          ActivityBundle </code> 
     *  @return the activity bundle form 
     *  @throws org.osid.NotFoundException <code> activityBundleId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> activityBundleId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.ActivityBundleForm getActivityBundleFormForUpdate(org.osid.id.Id activityBundleId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing activity bundle. 
     *
     *  @param  activityBundleForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> activityBundleForm 
     *          </code> already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> activityBundleForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> activityBundleForm did 
     *          not originate from getActivityBundleFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateActivityBundle(org.osid.course.registration.ActivityBundleForm activityBundleForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> ActivityBundles. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting an <code> ActivityBundle </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer delete operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> ActivityBundle </code> deletion 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteActivityBundles();


    /**
     *  Deletes an <code> ActivityBundle. </code> 
     *
     *  @param  activityBundleId the <code> Id </code> of the <code> 
     *          ActivityBundle </code> to remove 
     *  @throws org.osid.NotFoundException <code> activityBundleId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> activityBundleId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteActivityBundle(org.osid.id.Id activityBundleId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  ActivityBundles. </code> A return of true does not guarantee 
     *  successful authorization. A return of false indicates that it is known 
     *  changing an alias will result in a <code> PERMISSION_DENIED. </code> 
     *  This is intended as a hint to an application that may opt not to offer 
     *  alias operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> ActivityBundle </code> aliasing 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageActivityBundleAliases();


    /**
     *  Adds an <code> Id </code> to an <code> ActivityBundle </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Course </code> is deactivityined by the provider. The new 
     *  <code> Id </code> performs as an alias to the primary <code> Id. 
     *  </code> If the alias is a pointer to another activity bundle, it is 
     *  reassigned to the given activity bundle <code> Id. </code> 
     *
     *  @param  activityBundleId the <code> Id </code> of an <code> 
     *          ActivityBundle </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is in 
     *          use as a primary <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> activityBundleId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> activityBundleId </code> 
     *          or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasActivityBundle(org.osid.id.Id activityBundleId, 
                                    org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
