//
// org.osid.course.registration.ActivityBundleLookupSession
//
//     The OSID Java specification for org.osid.course.registration.ActivityBundleLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.registration;


/**
 *  <p>This session defines methods for retrieving activity bundles. An <code> 
 *  ActivityBundle </code> is a set of <code> Activities </code> in which a 
 *  student can be registered. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated course catalog view: All activity bundle methods in this 
 *      session operate, retrieve and pertain to activity bundles defined 
 *      explicitly in the current course catalog. Using an isolated view is 
 *      useful for managing <code> ActivityBundles </code> with the <code> 
 *      ActivityBundleAdminSession. </code> </li> 
 *      <li> federated course catalog view: All activity bundle lookup methods 
 *      in this session operate, retrieve and pertain to all activity bundles 
 *      defined in this course catalog and any other courses implicitly 
 *      available in this course catalog through course catalog inheritence. 
 *      </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedCourseCatalogView() </code> and <code> 
 *  useIsolatedCourseCatalogView() </code> behave as a radio group and one 
 *  should be selected before invoking any lookup methods. </p>
 */

public interface ActivityBundleLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> CourseCatalog </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> CourseCatalog Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCourseCatalogId();


    /**
     *  Gets the <code> CourseCatalog </code> associated with this session. 
     *
     *  @return the course catalog 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseCatalog getCourseCatalog()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> ActivityBundle </code> lookups. 
     *  A return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupActivityBundles();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeActivityBundleView();


    /**
     *  A complete view of the <code> ActivityBundle </code> returns is 
     *  desired. Methods will return what is requested or result in an error. 
     *  This view is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryActivityBundleView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include activity bundles in catalogs which are children of this 
     *  catalog in the course catalog hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCourseCatalogView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this course catalog only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCourseCatalogView();


    /**
     *  Gets the <code> ActivityBundle </code> specified by its <code> Id. 
     *  </code> In plenary mode, the exact <code> Id </code> is found or a 
     *  <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  ActivityBundle </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> Course </code> and retained for compatibility. 
     *
     *  @param  activityBundleId the <code> Id </code> of the <code> 
     *          ActivityBundle </code> to retrieve 
     *  @return the returned <code> ActivityBundle </code> 
     *  @throws org.osid.NotFoundException no <code> ActivityBundle </code> 
     *          found with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> activityBundleId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.ActivityBundle getActivityBundle(org.osid.id.Id activityBundleId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ActivityBundleList </code> corresponding to the given 
     *  <code> IdList. </code> In plenary mode, the returned list contains all 
     *  of the activity bundles specified in the <code> Id </code> list, in 
     *  the order of the list, including duplicates, or an error results if an 
     *  <code> Id </code> in the supplied list is not found or inaccessible. 
     *  Otherwise, inaccessible <code> ActivityBundles </code> may be omitted 
     *  from the list and may present the elements in any order including 
     *  returning a unique set. 
     *
     *  @param  activityBundleIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> ActivityBundle </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> activityBundleIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.ActivityBundleList getActivityBundlesByIds(org.osid.id.IdList activityBundleIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ActivityBundleList </code> corresponding to the given 
     *  activity bundle genus <code> Type </code> which does not include 
     *  activity bundles of types derived from the specified <code> Type. 
     *  </code> In plenary mode, the returned list contains all known activity 
     *  bundles or an error results. Otherwise, the returned list may contain 
     *  only those activity bundles that are accessible through this session. 
     *
     *  @param  activityBundleGenusType an activity bundle genus type 
     *  @return the returned <code> ActivityBundle </code> list 
     *  @throws org.osid.NullArgumentException <code> activityBundleGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.ActivityBundleList getActivityBundlesByGenusType(org.osid.type.Type activityBundleGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ActivityBundleList </code> corresponding to the given 
     *  course genus <code> Type </code> and include any additional activity 
     *  bundles with genus types derived from the specified <code> Type. 
     *  </code> In plenary mode, the returned list contains all known activity 
     *  bundles or an error results. Otherwise, the returned list may contain 
     *  only those activity bundles that are accessible through this session. 
     *
     *  @param  activityBundleGenusType an activity bundle genus type 
     *  @return the returned <code> ActivityBundle </code> list 
     *  @throws org.osid.NullArgumentException <code> activityBundleGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.ActivityBundleList getActivityBundlesByParentGenusType(org.osid.type.Type activityBundleGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ActivityBundleList </code> containing the given 
     *  activity bundle record <code> Type. </code> In plenary mode, the 
     *  returned list contains all known courses or an error results. 
     *  Otherwise, the returned list may contain only those activity bundles 
     *  that are accessible through this session. 
     *
     *  @param  activityBundleRecordType an activity bundle record type 
     *  @return the returned <code> ActivityBundle </code> list 
     *  @throws org.osid.NullArgumentException <code> activityBundleRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.ActivityBundleList getActivityBundlesByRecordType(org.osid.type.Type activityBundleRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ActivityBundleList </code> for a given course offering 
     *  <code> . </code> In plenary mode, the returned list contains all known 
     *  courses or an error results. Otherwise, the returned list may contain 
     *  only those activity bundles that are accessible through this session. 
     *
     *  @param  courseOfferingId a course offering <code> Id </code> 
     *  @return the returned <code> ActivityBundle </code> list 
     *  @throws org.osid.NullArgumentException <code> courseOfferingId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.ActivityBundleList getActivityBundlesForCourseOffering(org.osid.id.Id courseOfferingId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ActivityBundleList </code> for a given activity. In 
     *  plenary mode, the returned list contains all known courses or an error 
     *  results. Otherwise, the returned list may contain only those activity 
     *  bundles that are accessible through this session. 
     *
     *  @param  activityId an activity <code> Id </code> 
     *  @return the returned <code> ActivityBundle </code> list 
     *  @throws org.osid.NullArgumentException <code> activityId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.ActivityBundleList getActivityBundlesByActivity(org.osid.id.Id activityId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> ActivityBundles. </code> In plenary mode, the returned 
     *  list contains all known activity bundles or an error results. 
     *  Otherwise, the returned list may contain only those courses that are 
     *  accessible through this session. 
     *
     *  @return a list of <code> ActivityBundles </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.ActivityBundleList getActivityBundles()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
