//
// org.osid.course.registration.ActivityRegistrationNotificationSession
//
//     The OSID Java specification for org.osid.course.registration.ActivityRegistrationNotificationSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.registration;


/**
 *  <p>This session defines methods to receive notifications on adds/changes 
 *  to <code> ActivityRegistration </code> objects in this <code> 
 *  CourseCatalog. </code> This also includes existing activity registrations 
 *  that may appear or disappear due to changes in the <code> CourseCatalog 
 *  </code> hierarchy, This session is intended for consumers needing to 
 *  synchronize their state with this service without the use of polling. 
 *  Notifications are cancelled when this session is closed. </p> 
 *  
 *  <p> The views defined in this session correspond to the views in the 
 *  <code> ActivityRegistrationLookupSession. </code> </p>
 */

public interface ActivityRegistrationNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> CourseCatalog </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> CourseCatalog Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCourseCatalogId();


    /**
     *  Gets the <code> CourseCatalog </code> associated with this session. 
     *
     *  @return the course catalog 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseCatalog getCourseCatalog()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can register for <code> ActivityRegistration 
     *  </code> notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForActivityRegistrationNotifications();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include activity registrations in catalogs which are children of this 
     *  catalog in the course catalog hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCourseCatalogView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts notifications to this course catalog only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCourseCatalogView();


    /**
     *  Reliable notifications are desired. In reliable mode, notifications 
     *  are to be acknowledged using <code> 
     *  acknowledgeActivityRegistrationNotification() </code> . 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void reliableActivityRegistrationNotifications();


    /**
     *  Unreliable notifications are desired. In unreliable mode, 
     *  notifications do not need to be acknowledged. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void unreliableActivityRegistrationNotifications();


    /**
     *  Acknowledge an activity registration notification. 
     *
     *  @param  notificationId the <code> Id </code> of the notification 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void acknowledgeActivityRegistrationNotification(org.osid.id.Id notificationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new activity registrations. <code> 
     *  ActivityRegistrationReceiver.newActivityRegistrations() </code> is 
     *  invoked when a new <code> ActivityRegistration </code> appears in this 
     *  course catalog. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewActivityRegistrations()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new registrations for the given 
     *  registration. <code> 
     *  ActivityRegistrationReceiver.newActivityRegistrations() </code> is 
     *  invoked when a new <code> ActivityRegistration </code> appears in this 
     *  course catalog. 
     *
     *  @param  registrationId the <code> Id </code> of the <code> 
     *          Registration </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> registrationId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewActivityRegistrationsForRegistration(org.osid.id.Id registrationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new registrations for the given 
     *  activity. <code> 
     *  ActivityRegistrationReceiver.newActivityRegistrations() </code> is 
     *  invoked when a new <code> ActivityRegistration </code> appears in this 
     *  course catalog. 
     *
     *  @param  activityId the <code> Id </code> of the <code> Activity 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> activityId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewActivityRegistrationsForActivity(org.osid.id.Id activityId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new registrations for the given student. 
     *  <code> ActivityRegistrationnReceiver.newActivityRegistrations() 
     *  </code> is invoked when a new <code> ActivityRegistration </code> 
     *  appears in this course catalog. 
     *
     *  @param  resourceId the <code> Id </code> of the <code> Resource 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewActivityRegistrationsForStudent(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated activity registrations. <code> 
     *  ActivityRegistrationReceiver.changedActivityRegistrations() </code> is 
     *  invoked when a course in this course catalog is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedActivityRegistrations()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated activity registrations for the 
     *  given registration. <code> 
     *  ActivityRegistrationReceiver.changedActivityRegistrations() </code> is 
     *  invoked when a course in this course catalog is changed. 
     *
     *  @param  registrationId the <code> Id </code> of the <code> 
     *          Regitsration </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> registrationId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedActivityRegistrationsForRegistration(org.osid.id.Id registrationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated activity registrations for the 
     *  given activity. <code> 
     *  ActivityRegistrationReceiver.changedActivityRegistrations() </code> is 
     *  invoked when a course in this course catalog is changed. 
     *
     *  @param  activityId the <code> Id </code> of the <code> Activity 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> activityId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedActivityRegistrationsForActivity(org.osid.id.Id activityId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated activity registrations for the 
     *  given student. <code> 
     *  ActivityRegistrationReceiver.changedActivityRegistrations() </code> is 
     *  invoked when a course in this course catalog is changed. 
     *
     *  @param  resourceId the <code> Id </code> of the <code> Resource 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedActivityRegistrationsForStudent(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated activity registration. <code> 
     *  ActivityRegistrationReceiver.changedActivityRegistrations() </code> is 
     *  invoked when the specified activity registration in this course 
     *  catalog is changed. 
     *
     *  @param  activityRegistrationId the <code> Id </code> of the <code> 
     *          ActivityRegistration </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> activityRegistrationId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedActivityRegistration(org.osid.id.Id activityRegistrationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted activity registrations. <code> 
     *  ActivityRegistrationReceiver.deletedActivityRegistrations() </code> is 
     *  invoked when an activity registration is deleted or removed from this 
     *  course catalog. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedActivityRegistrations()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted activity registrations for the 
     *  given registration. <code> 
     *  ActivityRegistrationReceiver.deletedActivityRegistrations() </code> is 
     *  invoked when an activity registration is deleted or removed from this 
     *  course catalog. 
     *
     *  @param  registrationId the <code> Id </code> of the <code> 
     *          Registration </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> registrationId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedActivityRegistrationsForRegistration(org.osid.id.Id registrationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted activity registrations for the 
     *  given activity. <code> 
     *  ActivityRegistrationReceiver.deletedActivityRegistrations() </code> is 
     *  invoked when an activity registration is deleted or removed from this 
     *  course catalog. 
     *
     *  @param  activityId the <code> Id </code> of the <code> Activity 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> activityId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedActivityRegistrationsForActivity(org.osid.id.Id activityId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted activity registrations for the 
     *  given student. <code> 
     *  ActivityRegistrationReceiver.deletedActivityRegistrations() </code> is 
     *  invoked when an activity registration is deleted or removed from this 
     *  course catalog. 
     *
     *  @param  resourceId the <code> Id </code> of the <code> Resource 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedActivityRegistrationsForStudent(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted activity registration. <code> 
     *  ActivityRegistrationReceiver.deletedActivityRegistrations() </code> is 
     *  invoked when the specified activity registration is deleted or removed 
     *  from this course catalog. 
     *
     *  @param  activityRegistrationId the <code> Id </code> of the <code> 
     *          ActivityRegistration </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> activityRegistrationId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedActivityRegistration(org.osid.id.Id activityRegistrationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
