//
// org.osid.course.registration.CourseRegistrationManager
//
//     The OSID Java specification for org.osid.course.registration.CourseRegistrationManager.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.registration;


/**
 *  <p>The course registration manager provides access to registration 
 *  sessions and provides interoperability tests for various aspects of this 
 *  service. The sessions included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> ActivityBundleLookupSession: </code> a session to retrieve 
 *      activity bundles </li> 
 *      <li> <code> ActivityBundleQuerySession: </code> a session to query 
 *      activity bundles </li> 
 *      <li> <code> ActivityBundleSearchSession: </code> a session to search 
 *      for activity bundles </li> 
 *      <li> <code> ActivityBundleAdminSession: </code> a session to create 
 *      and delete activity bundles </li> 
 *      <li> <code> ActivityBundleNotificationSession: </code> a session to 
 *      receive notifications pertaining to activity bundle changes </li> 
 *      <li> <code> ActivityBundleCourseCatalogSession: </code> a session to 
 *      look up activity bundle to course catalog mappings </li> 
 *      <li> <code> ActivityBundleCourseCatalogAssignmentSession: </code> a 
 *      session to manage activity bundle to course catalog mappings </li> 
 *      <li> <code> ActivityBundleSmartCourseCatalogSession: </code> a session 
 *      to manage dynamic course catalogs of activity bundles </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> RegistrationLookupSession: </code> a session to retrieve 
 *      registrations </li> 
 *      <li> <code> RegistrationQuerySession: </code> a session to query 
 *      registrations </li> 
 *      <li> <code> RegistrationSearchSession: </code> a session to search for 
 *      registrations </li> 
 *      <li> <code> RegistrationAdminSession: </code> a session to create and 
 *      delete registrations </li> 
 *      <li> <code> RegistrationNotificationSession: </code> a session to 
 *      receive notifications pertaining to registration changes </li> 
 *      <li> <code> RegistrationCourseCatalogSession: </code> a session to 
 *      look up registration to course catalog mappings </li> 
 *      <li> <code> RegistrationCourseCatalogAssignmentSession: </code> a 
 *      session to manage registration to course catalog mappings </li> 
 *      <li> <code> RegistrationSmartCourseCatalogSession: </code> a session 
 *      to manage dynamic course catalogs of registrations </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> ActivityRegistrationLookupSession: </code> a session to 
 *      retrieve activity registrations </li> 
 *      <li> <code> ActivityRegistrationQuerySession: </code> a session to 
 *      query activity registrations </li> 
 *      <li> <code> ActivityRegistrationSearchSession: </code> a session to 
 *      search for activity registrations </li> 
 *      <li> <code> ActivityRegistrationAdminSession: </code> a session to 
 *      create and delete activity registrations </li> 
 *      <li> <code> ActivityRegistrationNotificationSession: </code> a session 
 *      to receive notifications pertaining to activity registration changes 
 *      </li> 
 *      <li> <code> ActivityRegistrationCourseCatalogSession: </code> a 
 *      session to look up activity registration to course catalog mappings 
 *      </li> 
 *      <li> <code> ActivityRegistrationCourseCatalogAssignmentSession: 
 *      </code> a session to manage activity registration to course catalog 
 *      mappings </li> 
 *      <li> <code> ActivityRegistrationSmartCourseCatalogSession: </code> a 
 *      session to manage dynamic course catalogs of activity registrations 
 *      </li> 
 *  </ul>
 *  
 */

public interface CourseRegistrationManager
    extends org.osid.OsidManager,
            org.osid.course.registration.CourseRegistrationProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the activity 
     *  bundle lookup service. 
     *
     *  @return an <code> ActivityBundleSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActivityBundleLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityBundleLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.registration.ActivityBundleLookupSession getActivityBundleLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the activity 
     *  bundle lookup service for the given course catalog. 
     *
     *  @param  courseCatalogId the <code> Id </code> of the course catalog 
     *  @return an <code> ActivityBundleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> CourseCatalog </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActivityBundleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityBundleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.course.registration.ActivityBundleLookupSession getActivityBundleLookupSessionForCourseCatalog(org.osid.id.Id courseCatalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the activity 
     *  bundle query service. 
     *
     *  @return an <code> ActivityBundleQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActivityBundleQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityBundleQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.registration.ActivityBundleQuerySession getActivityBundleQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the activity 
     *  bundle query service for the given course catalog. 
     *
     *  @param  courseCatalogId the <code> Id </code> of the <code> 
     *          CourseCatalog </code> 
     *  @return an <code> ActivityBundleQuerySession </code> 
     *  @throws org.osid.NotFoundException no course catalog found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActivityBundleQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityBundleQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.course.registration.ActivityBundleQuerySession getActivityBundleQuerySessionForCourseCatalog(org.osid.id.Id courseCatalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the activity 
     *  bundle search service. 
     *
     *  @return an <code> ActivityBundleSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActivityBundleSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityBundleSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.registration.ActivityBundleSearchSession getActivityBundleSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the activity 
     *  bundle search service for the given course catalog. 
     *
     *  @param  courseCatalogId the <code> Id </code> of the <code> 
     *          CourseCatalog </code> 
     *  @return an <code> ActivityBundleSearchSession </code> 
     *  @throws org.osid.NotFoundException no course catalog found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActivityBundleSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityBundleSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.course.registration.ActivityBundleSearchSession getActivityBundleSearchSessionForCourseCatalog(org.osid.id.Id courseCatalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the activity 
     *  bundle administration service. 
     *
     *  @return an <code> ActivityBundleAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActivityBundleAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityBundleAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.registration.ActivityBundleAdminSession getActivityBundleAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the activity 
     *  bundle administration service for the given course catalog. 
     *
     *  @param  courseCatalogId the <code> Id </code> of the <code> 
     *          CourseCatalog </code> 
     *  @return an <code> ActivityBundleAdminSession </code> 
     *  @throws org.osid.NotFoundException no course catalog found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActivityBundleAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityBundleAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.course.registration.ActivityBundleAdminSession getActivityBundleAdminSessionForCourseCatalog(org.osid.id.Id courseCatalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the activity 
     *  bundle notification service. 
     *
     *  @param  activityBundleReceiver the notification callback 
     *  @return an <code> ActivityBundleNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> activityBundleReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActivityBundleNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityBundleNotification() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.course.registration.ActivityBundleNotificationSession getActivityBundleNotificationSession(org.osid.course.registration.ActivityBundleReceiver activityBundleReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the activity 
     *  bundle notification service for the given course catalog. 
     *
     *  @param  activityBundleReceiver the notification callback 
     *  @param  courseCatalogId the <code> Id </code> of the <code> 
     *          CourseCatalog </code> 
     *  @return an <code> ActivityBundleNotificationSession </code> 
     *  @throws org.osid.NotFoundException no course catalog found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> activityBundleReceiver 
     *          </code> or <code> courseCatalogId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActivityBundleNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityBundleNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.course.registration.ActivityBundleNotificationSession getActivityBundleNotificationSessionForCourseCatalog(org.osid.course.registration.ActivityBundleReceiver activityBundleReceiver, 
                                                                                                                               org.osid.id.Id courseCatalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup activity bundle/catalog 
     *  mappings. 
     *
     *  @return an <code> ActivityBundleCourseCatalogSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActivityBundleCourseCatalog() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityBundleCourseCatalog() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.course.registration.ActivityBundleCourseCatalogSession getActivityBundleCourseCatalogSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning activity 
     *  bundles to course catalogs. 
     *
     *  @return an <code> ActivityBundleCourseCatalogAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActivityBundleCourseCatalogAssignment() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityBundleCourseCatalogAssignment() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.course.registration.ActivityBundleCourseCatalogAssignmentSession getActivityBundleCourseCatalogAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the activity 
     *  bundle smart course catalog service. 
     *
     *  @param  courseCatalogId the <code> Id </code> of the <code> 
     *          CourseCatalog </code> 
     *  @return an <code> ActivityBundleSmartCourseCatalogSession </code> 
     *  @throws org.osid.NotFoundException no course catalog found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActivityBundleSmartCourseCatalog() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityBundleSmartCourseCatalog() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.course.registration.ActivityBundleSmartCourseCatalogSession getActivityBundleSmartCourseCatalogSession(org.osid.id.Id courseCatalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the registration 
     *  lookup service. 
     *
     *  @return a <code> RegistrationSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRegistrationLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRegistrationLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.registration.RegistrationLookupSession getRegistrationLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the registration 
     *  lookup service for the given course catalog. 
     *
     *  @param  courseCatalogId the <code> Id </code> of the course catalog 
     *  @return a <code> RegistrationLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> CourseCatalog </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRegistrationLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRegistrationLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.course.registration.RegistrationLookupSession getRegistrationLookupSessionForCourseCatalog(org.osid.id.Id courseCatalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the registration 
     *  query service. 
     *
     *  @return a <code> RegistrationQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRegistrationQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRegistrationQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.registration.RegistrationQuerySession getRegistrationQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the registration 
     *  query service for the given course catalog. 
     *
     *  @param  courseCatalogId the <code> Id </code> of the <code> 
     *          CourseCatalog </code> 
     *  @return a <code> RegistrationQuerySession </code> 
     *  @throws org.osid.NotFoundException no course catalog found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRegistrationQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRegistrationQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.course.registration.RegistrationQuerySession getRegistrationQuerySessionForCourseCatalog(org.osid.id.Id courseCatalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the registration 
     *  search service. 
     *
     *  @return a <code> RegistrationSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRegistrationSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRegistrationSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.registration.RegistrationSearchSession getRegistrationSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the registration 
     *  search service for the given course catalog. 
     *
     *  @param  courseCatalogId the <code> Id </code> of the <code> 
     *          CourseCatalog </code> 
     *  @return a <code> RegistrationSearchSession </code> 
     *  @throws org.osid.NotFoundException no course catalog found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRegistrationSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRegistrationSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.course.registration.RegistrationSearchSession getRegistrationSearchSessionForCourseCatalog(org.osid.id.Id courseCatalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the registration 
     *  administration service. 
     *
     *  @return a <code> RegistrationAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRegistrationAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRegistrationAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.registration.RegistrationAdminSession getRegistrationAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the registration 
     *  administration service for the given course catalog. 
     *
     *  @param  courseCatalogId the <code> Id </code> of the <code> 
     *          CourseCatalog </code> 
     *  @return a <code> RegistrationAdminSession </code> 
     *  @throws org.osid.NotFoundException no course catalog found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRegistrationAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRegistrationAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.course.registration.RegistrationAdminSession getRegistrationAdminSessionForCourseCatalog(org.osid.id.Id courseCatalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the registration 
     *  notification service. 
     *
     *  @param  registrationReceiver the notification callback 
     *  @return a <code> RegistrationNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> registrationReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRegistrationNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRegistrationNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.registration.RegistrationNotificationSession getRegistrationNotificationSession(org.osid.course.registration.RegistrationReceiver registrationReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the registration 
     *  notification service for the given course catalog. 
     *
     *  @param  registrationReceiver the notification callback 
     *  @param  courseCatalogId the <code> Id </code> of the <code> 
     *          CourseCatalog </code> 
     *  @return a <code> RegistrationNotificationSession </code> 
     *  @throws org.osid.NotFoundException no course catalog found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> registrationReceiver 
     *          </code> or <code> courseCatalogId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRegistrationNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRegistrationNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.course.registration.RegistrationNotificationSession getRegistrationNotificationSessionForCourseCatalog(org.osid.course.registration.RegistrationReceiver registrationReceiver, 
                                                                                                                           org.osid.id.Id courseCatalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup registration/catalog 
     *  mappings. 
     *
     *  @return a <code> RegistrationCourseCatalogSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRegistrationCourseCatalog() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRegistrationCourseCatalog() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.course.registration.RegistrationCourseCatalogSession getRegistrationCourseCatalogSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning 
     *  registrations to course catalogs. 
     *
     *  @return a <code> RegistrationCourseCatalogAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRegistrationCourseCatalogAssignment() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRegistrationCourseCatalogAssignment() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.course.registration.RegistrationCourseCatalogAssignmentSession getRegistrationCourseCatalogAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the registration 
     *  smart course catalog service. 
     *
     *  @param  courseCatalogId the <code> Id </code> of the <code> 
     *          CourseCatalog </code> 
     *  @return a <code> RegistrationSmartCourseCatalogSession </code> 
     *  @throws org.osid.NotFoundException no course catalog found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRegistrationSmartCourseCatalog() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRegistrationSmartCourseCatalog() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.course.registration.RegistrationSmartCourseCatalogSession getRegistrationSmartCourseCatalogSession(org.osid.id.Id courseCatalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the activity 
     *  registration lookup service. 
     *
     *  @return an <code> ActivityRegistrationSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActivityRegistrationLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityRegistrationLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.course.registration.ActivityRegistrationLookupSession getActivityRegistrationLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the activity 
     *  registration lookup service for the given course catalog. 
     *
     *  @param  courseCatalogId the <code> Id </code> of the course catalog 
     *  @return an <code> ActivityRegistrationLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> CourseCatalog </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActivityRegistrationLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityRegistrationLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.course.registration.ActivityRegistrationLookupSession getActivityRegistrationLookupSessionForCourseCatalog(org.osid.id.Id courseCatalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the activity 
     *  registration query service. 
     *
     *  @return an <code> ActivityRegistrationQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActivityRegistrationQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityRegistrationQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.course.registration.ActivityRegistrationQuerySession getActivityRegistrationQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the activity 
     *  registration query service for the given course catalog. 
     *
     *  @param  courseCatalogId the <code> Id </code> of the <code> 
     *          CourseCatalog </code> 
     *  @return an <code> ActivityRegistrationQuerySession </code> 
     *  @throws org.osid.NotFoundException no course catalog found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActivityRegistrationQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityRegistrationQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.course.registration.ActivityRegistrationQuerySession getActivityRegistrationQuerySessionForCourseCatalog(org.osid.id.Id courseCatalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the activity 
     *  registration search service. 
     *
     *  @return an <code> ActivityRegistrationSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActivityRegistrationSearch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityRegistrationSearch() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.course.registration.ActivityRegistrationSearchSession getActivityRegistrationSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the activity 
     *  registration search service for the given course catalog. 
     *
     *  @param  courseCatalogId the <code> Id </code> of the <code> 
     *          CourseCatalog </code> 
     *  @return an <code> ActivityRegistrationSearchSession </code> 
     *  @throws org.osid.NotFoundException no course catalog found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActivityRegistrationSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityRegistrationSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.course.registration.ActivityRegistrationSearchSession getActivityRegistrationSearchSessionForCourseCatalog(org.osid.id.Id courseCatalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the activity 
     *  registration administration service. 
     *
     *  @return an <code> ActivityRegistrationAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActivityRegistrationAdmin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityRegistrationAdmin() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.course.registration.ActivityRegistrationAdminSession getActivityRegistrationAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the activity 
     *  registration administration service for the given course catalog. 
     *
     *  @param  courseCatalogId the <code> Id </code> of the <code> 
     *          CourseCatalog </code> 
     *  @return an <code> ActivityRegistrationAdminSession </code> 
     *  @throws org.osid.NotFoundException no course catalog found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActivityRegistrationAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityRegistrationAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.course.registration.ActivityRegistrationAdminSession getActivityRegistrationAdminSessionForCourseCatalog(org.osid.id.Id courseCatalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the activity 
     *  registration notification service. 
     *
     *  @param  activityRegistrationReceiver the notification callback 
     *  @return an <code> ActivityRegistrationNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          activityRegistrationReceiver </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActivityRegistrationNotification() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityRegistrationNotification() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.course.registration.ActivityRegistrationNotificationSession getActivityRegistrationNotificationSession(org.osid.course.registration.ActivityRegistrationReceiver activityRegistrationReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the activity 
     *  registration notification service for the given course catalog. 
     *
     *  @param  activityRegistrationReceiver the notification callback 
     *  @param  courseCatalogId the <code> Id </code> of the <code> 
     *          CourseCatalog </code> 
     *  @return an <code> ActivityRegistrationNotificationSession </code> 
     *  @throws org.osid.NotFoundException no course catalog found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          activityRegistrationReceiver </code> or <code> courseCatalogId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActivityRegistrationNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityRegistrationNotification() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.course.registration.ActivityRegistrationNotificationSession getActivityRegistrationNotificationSessionForCourseCatalog(org.osid.course.registration.ActivityRegistrationReceiver activityRegistrationReceiver, 
                                                                                                                                           org.osid.id.Id courseCatalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup activity 
     *  registration/catalog mappings. 
     *
     *  @return an <code> ActivityRegistrationCourseCatalogSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActivityRegistrationCourseCatalog() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityRegistrationCourseCatalog() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.course.registration.ActivityRegistrationCourseCatalogSession getActivityRegistrationCourseCatalogSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning activity 
     *  registrations to course catalogs. 
     *
     *  @return an <code> ActivityRegistrationCourseCatalogAssignmentSession 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActivityRegistrationCourseCatalogAssignment() </code> 
     *          is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityRegistrationCourseCatalogAssignment() 
     *              </code> is <code> true. </code> 
     */

    public org.osid.course.registration.ActivityRegistrationCourseCatalogAssignmentSession getActivityRegistrationCourseCatalogAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the activity 
     *  registration smart course catalog service. 
     *
     *  @param  courseCatalogId the <code> Id </code> of the <code> 
     *          CourseCatalog </code> 
     *  @return an <code> ActivityRegistrationSmartCourseCatalogSession 
     *          </code> 
     *  @throws org.osid.NotFoundException no course catalog found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActivityRegistrationSmartCourseCatalog() </code> or 
     *          <code> supportsVisibleFederation() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityRegistrationSmartCourseCatalog() </code> 
     *              and <code> supportsVisibleFederation() </code> are <code> 
     *              true </code> 
     */

    public org.osid.course.registration.ActivityRegistrationSmartCourseCatalogSession getActivityRegistrationSmartCourseCatalogSession(org.osid.id.Id courseCatalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets a <code> CourseRegistrationBatchManager. </code> 
     *
     *  @return a <code> CourseRegistrationBatchManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCourseRegistrationBatch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsACourseRegistrationBatch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.registration.batch.CourseRegistrationBatchManager getCourseRegistrationBatchManager()
        throws org.osid.OperationFailedException;
}
