//
// org.osid.course.registration.Registration
//
//     The OSID Java specification for org.osid.course.registration.Registration.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.registration;


/**
 *  <p>A <code> Registration </code> is an <code> OsidRelationship </code> 
 *  between a student and an <code> ActivityBundle. </code> </p>
 */

public interface Registration
    extends org.osid.OsidRelationship {


    /**
     *  Gets the activity bundle <code> Id </code> associated with this 
     *  registration. 
     *
     *  @return the activity bundle <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getActivityBundleId();


    /**
     *  Gets the activity bundle associated with this registration. 
     *
     *  @return the activity bundle 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.ActivityBundle getActivityBundle()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of the student <code> Resource. </code> 
     *
     *  @return the <code> Student </code> <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getStudentId();


    /**
     *  Gets the student <code> Resource. </code> 
     *
     *  @return the student 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getStudent()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this registration defines credits to be earned. 
     *
     *  @return <code> true </code> if this registration has credits, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean definesCredits();


    /**
     *  Gets the number of credits the student is registered to earn. Multiple 
     *  credit options indicates a set of credits to be determined at the 
     *  completion of the course. 
     *
     *  @return the number of credits 
     *  @throws org.osid.IllegalStateException <code> definesCredits() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal[] getCredits();


    /**
     *  Tests if this registration includes a specific grading option. 
     *
     *  @return <code> true </code> if this course is graded, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isGraded();


    /**
     *  Gets the grading option <code> Id </code> for this registration. 
     *
     *  @return the grading option <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> isGraded() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getGradingOptionId();


    /**
     *  Gets the grading option for this registration. 
     *
     *  @return a grading system 
     *  @throws org.osid.IllegalStateException <code> isGraded() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeSystem getGradingOption()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the registration record corresponding to the given <code> 
     *  Registration </code> record <code> Type. </code> This method is used 
     *  to retrieve an object implementing the requested record. The <code> 
     *  registrationRecordType </code> may be the <code> Type </code> returned 
     *  in <code> getRecordTypes() </code> or any of its parents in a <code> 
     *  Type </code> hierarchy where <code> 
     *  hasRecordType(registrationRecordType) </code> is <code> true </code> . 
     *
     *  @param  registrationRecordType the type of registration record to 
     *          retrieve 
     *  @return the registration record 
     *  @throws org.osid.NullArgumentException <code> registrationRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(registrationRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.records.RegistrationRecord getRegistrationRecord(org.osid.type.Type registrationRecordType)
        throws org.osid.OperationFailedException;
}
