//
// org.osid.course.registration.RegistrationLookupSession
//
//     The OSID Java specification for org.osid.course.registration.RegistrationLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.registration;


/**
 *  <p>This session defines methods for retrieving registrations. A <code> 
 *  Registration </code> is a relationship between a student and an <code> 
 *  ActivityBundle. </code> </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated course catalog view: All registration methods in this 
 *      session operate, retrieve and pertain to registrations defined 
 *      explicitly in the current course catalog. Using an isolated view is 
 *      useful for managing <code> Registrations </code> with the <code> 
 *      RegistrationAdminSession. </code> </li> 
 *      <li> federated course catalog view: All registration lookup methods in 
 *      this session operate, retrieve and pertain to all registrations 
 *      defined in this course catalog and any other courses implicitly 
 *      available in this course catalog through course catalog inheritence. 
 *      </li> 
 *      <li> effective registration view: All registration lookup methods 
 *      return registrations where the current date falls in between the 
 *      effective dates inclusive. </li> 
 *      <li> any effective registration view: Registrations of any effective 
 *      date are returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedCourseCatalogView() </code> and <code> 
 *  useIsolatedCourseCatalogView() </code> behave as a radio group and one 
 *  should be selected before invoking any lookup methods. </p> 
 *  
 *  <p> Registrations may have an additional records indicated by their 
 *  respective record types. The record may not be accessed through a cast of 
 *  the <code> Registration. </code> </p>
 */

public interface RegistrationLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> CourseCatalog </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> CourseCatalog Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCourseCatalogId();


    /**
     *  Gets the <code> CourseCatalog </code> associated with this session. 
     *
     *  @return the course catalog 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseCatalog getCourseCatalog()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Registration </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupRegistrations();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeRegistrationView();


    /**
     *  A complete view of the <code> Registration </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryRegistrationView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include registrations in catalogs which are children of this catalog 
     *  in the course catalog hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCourseCatalogView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this course catalog only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCourseCatalogView();


    /**
     *  Only registrations whose effective dates are current are returned by 
     *  methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useEffectiveRegistrationView();


    /**
     *  All registrations of any effective dates are returned by methods in 
     *  this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyEffectiveRegistrationView();


    /**
     *  Gets the <code> Registration </code> specified by its <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Registration </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> Course </code> and retained for compatibility. 
     *  
     *  In effective mode, registrations are returned that are currently 
     *  effective. In any effective mode, effective registrations and those 
     *  currently expired are returned. 
     *
     *  @param  registrationId the <code> Id </code> of the <code> 
     *          Registration </code> to retrieve 
     *  @return the returned <code> Registration </code> 
     *  @throws org.osid.NotFoundException no <code> Registration </code> 
     *          found with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> registrationId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.Registration getRegistration(org.osid.id.Id registrationId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RegistrationList </code> corresponding to the given 
     *  <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  registrations specified in the <code> Id </code> list, in the order of 
     *  the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Registrations </code> may be omitted from the list 
     *  and may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In effective mode, registrations are returned that are currently 
     *  effective. In any effective mode, effective registrations and those 
     *  currently expired are returned. 
     *
     *  @param  registrationIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Registration </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> registrationIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.RegistrationList getRegistrationsByIds(org.osid.id.IdList registrationIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RegistrationList </code> corresponding to the given 
     *  registration genus <code> Type </code> which does not include 
     *  registrations of types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  registrations or an error results. Otherwise, the returned list may 
     *  contain only those registrations that are accessible through this 
     *  session. 
     *  
     *  In effective mode, registrations are returned that are currently 
     *  effective. In any effective mode, effective registrations and those 
     *  currently expired are returned. 
     *
     *  @param  registrationGenusType a registration genus type 
     *  @return the returned <code> Registration </code> list 
     *  @throws org.osid.NullArgumentException <code> registrationGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.RegistrationList getRegistrationsByGenusType(org.osid.type.Type registrationGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RegistrationList </code> corresponding to the given 
     *  course genus <code> Type </code> and include any additional 
     *  registrations with genus types derived from the specified <code> Type. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  registrations or an error results. Otherwise, the returned list may 
     *  contain only those registrations that are accessible through this 
     *  session. 
     *  
     *  In effective mode, registrations are returned that are currently 
     *  effective. In any effective mode, effective registrations and those 
     *  currently expired are returned. 
     *
     *  @param  registrationGenusType a registration genus type 
     *  @return the returned <code> Registration </code> list 
     *  @throws org.osid.NullArgumentException <code> registrationGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.RegistrationList getRegistrationsByParentGenusType(org.osid.type.Type registrationGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RegistrationList </code> containing the given 
     *  registration record <code> Type. </code> 
     *  
     *  In plenary mode, the returned list contains all known courses or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  registrations that are accessible through this session. 
     *  
     *  In effective mode, registrations are returned that are currently 
     *  effective. In any effective mode, effective registrations and those 
     *  currently expired are returned. 
     *
     *  @param  registrationRecordType a registration record type 
     *  @return the returned <code> Registration </code> list 
     *  @throws org.osid.NullArgumentException <code> registrationRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.RegistrationList getRegistrationsByRecordType(org.osid.type.Type registrationRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Registrations </code> effective during the entire 
     *  given date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known registrations or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  registrations that are accessible through this session. 
     *  
     *  In effective mode, registrations are returned that are currently 
     *  effective. In any effective mode, effective registrations and those 
     *  currently expired are returned. 
     *
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return a list of <code> Registrations </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.RegistrationList getRegistrationsOnDate(org.osid.calendaring.DateTime from, 
                                                                                org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Registrations </code> associated with a given <code> 
     *  ActivityBundle. </code> 
     *  
     *  In effective mode, registrations are returned that are currently 
     *  effective. In any effective mode, effective registrations and those 
     *  currently expired are returned. 
     *  
     *  In plenary mode, the returned list contains all known registrations or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  registrations that are accessible through this session. 
     *
     *  @param  activityBundleId an activity bundle <code> Id </code> 
     *  @return a list of <code> Registrations </code> 
     *  @throws org.osid.NullArgumentException <code> activityBundleId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.RegistrationList getRegistrationsForActivityBundle(org.osid.id.Id activityBundleId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Registrations </code> effective during the entire 
     *  given date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known registrations or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  registrations that are accessible through this session. 
     *  
     *  In effective mode, registrations are returned that are currently 
     *  effective. In any effective mode, effective registrations and those 
     *  currently expired are returned. 
     *
     *  @param  activityBundleId an activity bundle <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return a list of <code> Registrations </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> activityBundleId, from 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.RegistrationList getRegistrationsForActivityBundleOnDate(org.osid.id.Id activityBundleId, 
                                                                                                 org.osid.calendaring.DateTime from, 
                                                                                                 org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Registrations </code> for a given student. 
     *  
     *  In plenary mode, the returned list contains all known registrations or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  registrations that are accessible through this session. 
     *  
     *  In effective mode, registrations are returned that are currently 
     *  effective. In any effective mode, effective registrations and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @return a list of <code> Registrations </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.RegistrationList getRegistrationsForStudent(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Registrations </code> for a student effective during 
     *  the entire given date range inclusive but not confined to the date 
     *  range. 
     *  
     *  In plenary mode, the returned list contains all known registrations or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  registrations that are accessible through this session. 
     *  
     *  In effective mode, registrations are returned that are currently 
     *  effective. In any effective mode, effective registrations and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return a list of <code> Registrations </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, from </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.RegistrationList getRegistrationsForStudentOnDate(org.osid.id.Id resourceId, 
                                                                                          org.osid.calendaring.DateTime from, 
                                                                                          org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Registrations </code> for a given activity bundle and 
     *  student. 
     *  
     *  In plenary mode, the returned list contains all known registrations or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  registrations that are accessible through this session. 
     *  
     *  In effective mode, registrations are returned that are currently 
     *  effective. In any effective mode, effective registrations and those 
     *  currently expired are returned. 
     *
     *  @param  activityBundleId an activity bundle <code> Id </code> 
     *  @param  resourceId a resource <code> Id </code> 
     *  @return a list of <code> Registrations </code> 
     *  @throws org.osid.NullArgumentException <code> activityBundleId </code> 
     *          or <code> resourceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.RegistrationList getRegistrationsForActivityBundleAndStudent(org.osid.id.Id activityBundleId, 
                                                                                                     org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Registrations </code> for an activity bundle and 
     *  student effective during the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known registrations or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  registrations that are accessible through this session. 
     *  
     *  In effective mode, registrations are returned that are currently 
     *  effective. In any effective mode, effective registrations and those 
     *  currently expired are returned. 
     *
     *  @param  activityBundleId an activity bundle <code> Id </code> 
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return a list of <code> Registrations </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> activityBundleId, 
     *          resourceId, from </code> or <code> to </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.RegistrationList getRegistrationsForActivityBundleAndStudentOnDate(org.osid.id.Id activityBundleId, 
                                                                                                           org.osid.id.Id resourceId, 
                                                                                                           org.osid.calendaring.DateTime from, 
                                                                                                           org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Registrations </code> related to a course offering. 
     *  
     *  In plenary mode, the returned list contains all known registrations or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  registrations that are accessible through this session. 
     *  
     *  In effective mode, registrations are returned that are currently 
     *  effective. In any effective mode, effective registrations and those 
     *  currently expired are returned. 
     *
     *  @param  courseOfferingId a course offering <code> Id </code> 
     *  @return a list of <code> Registrations </code> 
     *  @throws org.osid.NullArgumentException <code> courseOfferingId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.RegistrationList getRegistrationsForCourseOffering(org.osid.id.Id courseOfferingId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Registrations </code> for a course offering effective 
     *  during the entire given date range inclusive but not confined to the 
     *  date range. 
     *  
     *  In plenary mode, the returned list contains all known registrations or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  registrations that are accessible through this session. 
     *  
     *  In effective mode, registrations are returned that are currently 
     *  effective. In any effective mode, effective registrations and those 
     *  currently expired are returned. 
     *
     *  @param  courseOfferingId a course offering <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return a list of <code> Registrations </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> courseOfferingId, from 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.RegistrationList getRegistrationsForCourseOfferingOnDate(org.osid.id.Id courseOfferingId, 
                                                                                                 org.osid.calendaring.DateTime from, 
                                                                                                 org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Registrations </code> for a given course offering and 
     *  student. 
     *  
     *  In plenary mode, the returned list contains all known registrations or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  registrations that are accessible through this session. 
     *  
     *  In effective mode, registrations are returned that are currently 
     *  effective. In any effective mode, effective registrations and those 
     *  currently expired are returned. 
     *
     *  @param  courseOfferingId a course offering <code> Id </code> 
     *  @param  resourceId a resource <code> Id </code> 
     *  @return a list of <code> Registrations </code> 
     *  @throws org.osid.NullArgumentException <code> courseOfferingId </code> 
     *          or <code> resourceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.RegistrationList getRegistrationsForCourseOfferingAndStudent(org.osid.id.Id courseOfferingId, 
                                                                                                     org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Registrations </code> for a course offering and 
     *  student effective during the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known registrations or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  registrations that are accessible through this session. 
     *  
     *  In effective mode, registrations are returned that are currently 
     *  effective. In any effective mode, effective registrations and those 
     *  currently expired are returned. 
     *
     *  @param  courseOfferingId a course offering <code> Id </code> 
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return a list of <code> Registrations </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> courseOfferingId, 
     *          resourceId, from </code> or <code> to </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.RegistrationList getRegistrationsForCourseOfferingAndStudentOnDate(org.osid.id.Id courseOfferingId, 
                                                                                                           org.osid.id.Id resourceId, 
                                                                                                           org.osid.calendaring.DateTime from, 
                                                                                                           org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Registrations. </code> 
     *  
     *  In plenary mode, the returned list contains all known registrations or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  courses that are accessible through this session. 
     *  
     *  In effective mode, registrations are returned that are currently 
     *  effective. In any effective mode, effective registrations and those 
     *  currently expired are returned. 
     *
     *  @return a list of <code> Registrations </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.RegistrationList getRegistrations()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
