//
// org.osid.course.registration.batch.ActivityBundleBatchAdminSession
//
//     The OSID Java specification for org.osid.course.registration.batch.ActivityBundleBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.registration.batch;


/**
 *  <p>This session creates, updates, and deletes <code> ActivityBundles 
 *  </code> in bulk. The data for create and update is provided by the 
 *  consumer via the form object. <code> OsidForms </code> are requested for 
 *  each create or update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  ActivityBundle, </code> a <code> ActivityBundleForm </code> is requested 
 *  using <code> getActivityBundleFormsForCreate() </code> specifying the 
 *  desired course offering and record <code> Types </code> or none if no 
 *  record <code> Types </code> are needed. Each of the returned <code> 
 *  ActivityBundleForms </code> will indicate that it is to be used with a 
 *  create operation and can be used to examine metdata or validate data prior 
 *  to creation. Once a <code> ActivityBundleForm </code> is submiited to a 
 *  create operation, it cannot be reused with another create operation unless 
 *  the first operation was unsuccessful. Each <code> ActivityBundleForm 
 *  </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> ActivityBundleForms </code> returned from <code> 
 *  getActivityBundleFormsForCreate() </code> may be linked to the originating 
 *  request through the peer <code> Ids </code> of the <code> 
 *  ActivityBundleForm. </code> In the case where there may be duplicates, any 
 *  <code> ActivityBundleForm </code> of the same peer <code> Ids </code> may 
 *  be used for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> ActivityBundleForms </code> are submitted for 
 *  create, a <code> CreateResponse </code> is returned for each <code> 
 *  ActivityBundleForm, </code> although the ordering is not defined. Only 
 *  errors that pertain to the entire create operation are returned from 
 *  <code> createActivityBundles(), </code> errors specific to an individual 
 *  <code> ActivityBundleForm </code> are indicated in the corresponding 
 *  <code> CreateResponse. </code> <code> CreateResponses </code> may be 
 *  linked to the originating <code> ActivityBundleForm </code> through the 
 *  <code> ActivityBundleForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> ActivityBundleForms </code> are requested to the 
 *  <code> ActivityBundle </code> <code> Id </code> that is to be updated 
 *  using <code> getActivityBundleFormsForUpdate() </code> where the reference 
 *  <code> Id </code> in the <code> ActivityBundleForm </code> may be used to 
 *  link the request. Similarly, the <code> ActivityBundleForm </code> has 
 *  metadata about the data that can be updated and it can perform validation 
 *  before submitting the update. The <code> ActivityBundleForm </code> can 
 *  only be used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> ActivityBundleForms </code> are submitted for 
 *  update, an <code> UpdateResponse </code> is returned for each <code> 
 *  ActivityBundleForm, </code> although the ordering is not defined. Only 
 *  errors that pertain to the entire update operation are returned from 
 *  <code> updateActivityBundles(), </code> errors specific to an individual 
 *  <code> ActivityBundleForm </code> are indicated in the corresponding 
 *  <code> UpdateResponse. </code> <code> UpdateResponses </code> may be 
 *  linked to the originating <code> ActivityBundleForm </code> through the 
 *  <code> ActivityBundleForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> ActivityBundles </code> in bulk. 
 *  To unmap a <code> ActivityBundle </code> from the current <code> 
 *  CourseCatalog, </code> the <code> 
 *  ActivityBundleCourseCatalogAssignmentSession </code> should be used. These 
 *  delete operations attempt to remove the <code> ActivityBundle </code> 
 *  itself thus removing it from all known <code> CourseCatalog </code> 
 *  catalogs. Bulk delete operations return the results in <code> 
 *  DeleteResponses. </code> </p>
 */

public interface ActivityBundleBatchAdminSession
    extends org.osid.course.registration.ActivityBundleAdminSession {


    /**
     *  Gets the activity bundle forms for creating a bunch of new actvity 
     *  bundles. An ActivityBundleForm is returned for each supplied course 
     *  offering. 
     *
     *  @param  courseOfferingIds a list of course offering <code> Ids </code> 
     *  @param  activityBundleRecordTypes array of activity bundle record 
     *          types to be included in each create operation or an empty list 
     *          if none 
     *  @return the activity bundle forms 
     *  @throws org.osid.NotFoundException a <code> courseOfferingId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> courseOfferingIds 
     *          </code> or <code> activityBundleRecordTypes </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.batch.ActivityBundleBatchFormList getActivityBundleFormsForCreate(org.osid.id.IdList courseOfferingIds, 
                                                                                                          org.osid.type.Type[] activityBundleRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> ActivityBundles. </code> This method 
     *  returns an error if the entire operation fails. Otherwise, the status 
     *  of an individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  activityBundleForms the activity bundle forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> activityBundleForms 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createActivityBundles(org.osid.course.registration.batch.ActivityBundleBatchFormList activityBundleForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the activity bundle forms for updating an existing set of actvity 
     *  bundles. A new activity bundle form should be requested for each 
     *  update transaction. 
     *
     *  @param  activityBundleIds the <code> Ids </code> of the <code> 
     *          ActivityBundle </code> 
     *  @return the activity bundle form 
     *  @throws org.osid.NotFoundException a <code> activityBundleId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> activityBundleIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.batch.ActivityBundleBatchFormList getActivityBundleFormsForUpdate(org.osid.id.IdList activityBundleIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing actvity bundles. This method returns an error if the 
     *  entire operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  activityBundleForms the form containing the elements to be 
     *          updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> activityBundleForms 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateActivityBundles(org.osid.course.registration.batch.ActivityBundleBatchFormList activityBundleForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> ActivityBundles </code> in this <code> 
     *  CourseCatalog </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllActivityBundles()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes actvity bundles for the given <code> Ids. </code> 
     *
     *  @param  activityBundleIds the <code> Ids </code> of the actvity 
     *          bundles to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> activityBundleIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteActivityBundles(org.osid.id.IdList activityBundleIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes actvity bundles for the given course offering. 
     *
     *  @param  courseOfferingId the <code> Id </code> of a course offering 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> courseOfferingId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteActivityBundlesForCourseOffering(org.osid.id.Id courseOfferingId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes actvity bundles containing the given activity offering. 
     *
     *  @param  activityOfferingId the <code> Id </code> of an activity 
     *          offering 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> activityOfferingId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteActivityBundlesByActivityOffering(org.osid.id.Id activityOfferingId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> ActivityBundle </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> ActivityBundle </code> is determined by the provider. The 
     *  new <code> Id </code> is an alias to the primary <code> Id. </code> If 
     *  the alias is a pointer to another activity bundle, it is reassigned to 
     *  the given activity bundle <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasActivityBundles(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
