//
// org.osid.course.registration.batch.RegistrationBatchAdminSession
//
//     The OSID Java specification for org.osid.course.registration.batch.RegistrationBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.registration.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Registrations </code> 
 *  in bulk. The data for create and update is provided by the consumer via 
 *  the form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Registration, </code> a <code> RegistrationForm </code> is requested using 
 *  <code> getRegistrationFormsForCreate() </code> specifying the desired 
 *  activity bundle, student, and record <code> Types </code> or none if no 
 *  record <code> Types </code> are needed. Each of the returned <code> 
 *  RegistrationForms </code> will indicate that it is to be used with a 
 *  create operation and can be used to examine metdata or validate data prior 
 *  to creation. Once a <code> RegistrationForm </code> is submiited to a 
 *  create operation, it cannot be reused with another create operation unless 
 *  the first operation was unsuccessful. Each <code> RegistrationForm </code> 
 *  corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> RegistrationForms </code> returned from <code> 
 *  getRegistrationFormsForCreate() </code> may be linked to the originating 
 *  request through the peer <code> Ids </code> of the <code> 
 *  RegistrationForm. </code> In the case where there may be duplicates, any 
 *  <code> RegistrationForm </code> of the same peer <code> Ids </code> may be 
 *  used for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> RegistrationForms </code> are submitted for 
 *  create, a <code> CreateResponse </code> is returned for each <code> 
 *  RegistrationForm, </code> although the ordering is not defined. Only 
 *  errors that pertain to the entire create operation are returned from 
 *  <code> createRegistrations(), </code> errors specific to an individual 
 *  <code> RegistrationForm </code> are indicated in the corresponding <code> 
 *  CreateResponse. </code> <code> CreateResponses </code> may be linked to 
 *  the originating <code> RegistrationForm </code> through the <code> 
 *  RegistrationForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> RegistrationForms </code> are requested to the 
 *  <code> Registration </code> <code> Id </code> that is to be updated using 
 *  <code> getRegistrationFormsForUpdate() </code> where the reference <code> 
 *  Id </code> in the <code> RegistrationForm </code> may be used to link the 
 *  request. Similarly, the <code> RegistrationForm </code> has metadata about 
 *  the data that can be updated and it can perform validation before 
 *  submitting the update. The <code> RegistrationForm </code> can only be 
 *  used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> RegistrationForms </code> are submitted for 
 *  update, an <code> UpdateResponse </code> is returned for each <code> 
 *  RegistrationForm, </code> although the ordering is not defined. Only 
 *  errors that pertain to the entire update operation are returned from 
 *  <code> updateRegistrations(), </code> errors specific to an individual 
 *  <code> RegistrationForm </code> are indicated in the corresponding <code> 
 *  UpdateResponse. </code> <code> UpdateResponses </code> may be linked to 
 *  the originating <code> RegistrationForm </code> through the <code> 
 *  RegistrationForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> Registrations </code> in bulk. To 
 *  unmap a <code> Registration </code> from the current <code> CourseCatalog, 
 *  </code> the <code> RegistrationCourseCatalogAssignmentSession </code> 
 *  should be used. These delete operations attempt to remove the <code> 
 *  Registration </code> itself thus removing it from all known <code> 
 *  CourseCatalog </code> catalogs. Bulk delete operations return the results 
 *  in <code> DeleteResponses. </code> </p>
 */

public interface RegistrationBatchAdminSession
    extends org.osid.course.registration.RegistrationAdminSession {


    /**
     *  Gets the registration forms for creating a bunch of new registrations. 
     *  A form is returned for supplied activity bundle and student pair. 
     *
     *  @param  peers a list of course offering peers 
     *  @param  registrationRecordTypes array of registration record types to 
     *          be included in each create operation or an empty list if none 
     *  @return the registration forms 
     *  @throws org.osid.NotFoundException an <code> activityBundleId </code> 
     *          or <code> resourceId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> peers </code> or <code> 
     *          registrationRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.batch.RegistrationBatchFormList getRegistrationFormsForCreate(org.osid.course.registration.batch.RegistrationPeerList peers, 
                                                                                                      org.osid.type.Type[] registrationRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Registrations. </code> This method returns 
     *  an error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  registrationForms the registration forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> registrationForms 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createRegistrations(org.osid.course.registration.batch.RegistrationBatchFormList registrationForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the registration forms for updating an existing set of 
     *  registrations. A new registration form should be requested for each 
     *  update transaction. 
     *
     *  @param  registrationIds the <code> Ids </code> of the <code> 
     *          Registration </code> 
     *  @return the registration form 
     *  @throws org.osid.NotFoundException a <code> registrationId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> registrationIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.batch.RegistrationBatchFormList getRegistrationFormsForUpdate(org.osid.id.IdList registrationIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing registrations. This method returns an error if the 
     *  entire operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  registrationForms the form containing the elements to be 
     *          updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> registrationForms 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateRegistrations(org.osid.course.registration.batch.RegistrationBatchFormList registrationForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Registrations </code> in this <code> CourseCatalog 
     *  </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllRegistrations()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes registrations for the given <code> Ids. </code> 
     *
     *  @param  registrationIds the <code> Ids </code> of the registrations to 
     *          delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> registrationIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteRegistrations(org.osid.id.IdList registrationIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes registrations for the given activity bundle. 
     *
     *  @param  activityBundleId the <code> Id </code> of an activity bundle 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> actviityBundleId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteRegistrationsForActivityBundle(org.osid.id.Id activityBundleId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes registrations for the given student. 
     *
     *  @param  resourceId the <code> Id </code> of a student resource 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteRegistrationsForStudent(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes registrations indirectly related to the given activity. 
     *
     *  @param  activityId the <code> Id </code> of an activity 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> activityId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteRegistrationsForActivity(org.osid.id.Id activityId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes registrations indirectly related to the given course offering. 
     *
     *  @param  courseOfferingId the <code> Id </code> of a course offering 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> courseOfferingId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteRegistrationsForCourseOffering(org.osid.id.Id courseOfferingId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes registrations expired before the given date. 
     *
     *  @param  date a date 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteIneffectiveRegistrationsByDate(org.osid.calendaring.DateTime date)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Registration </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Registration </code> is determined by the provider. The new 
     *  <code> Id </code> is an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another registration, it is reassigned to the 
     *  given registration <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasRegistrations(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
