/**
 * <p>The Open Service Interface Definitions for the org.osid.course.registration
 * service.</p>
 * 
 * <p>The Course Registration OSID provides course registration services. </p> 
 * <h4> ActivityBundle </h4> 
 * 
 * <p> An <code> ActivityBundle </code> is a set of activities within a <code> 
 * CourseOffering </code> in which a student can register. A <code> 
 * CourseOffering </code> may have a variety of activity offerings and the 
 * activity bundle groups sets of these offerings together. For example, each 
 * section of a class may have a lecture and a lab but multiple labs may be 
 * offered. For each valid registration option grouping together a lecture and 
 * one of the offered labs is presented as an <code> ActivityBundle </code> . 
 * </p> 
 * 
 * <p> Some registration mechanisms only require a registration at the <code> 
 * CourseOffering </code> level and do not permit students to select below 
 * that level. In this case, a single <code> ActivityBundle </code> is created 
 * for the top level <code> CourseOffering </code> . </p> 
 * 
 * <p> <code> ActivityBundles </code> may further constrain the grading and 
 * credit options defined at the <code> CourseOffering </code> level. </p> 
 * <h4> Registrations </h4> 
 * 
 * <p> A <code> Registration </code> is an <code> OsidRelationship </code> 
 * between a <code> Resource </code> (student) and an <code> ActivityBundle 
 * </code> . </p> 
 * 
 * <p> Currently, transactional submission of <code> Registrations </code> 
 * across multiple <code> CourseOfferings </code> is not defined but 
 * transactional submission may be abstractly performed in the Ordering OSID. 
 * Similarly, management of waitlists may be performed in the Provisioning 
 * OSID although there is no management of waitlist behavior through <code> 
 * CourseOfferings </code> and <code> ActivityBundles </code> . </p> 
 * <h4> ActivityRegistrations </h4> 
 * 
 * <p> An <code> ActivityRegistration </code> is an <code> OsidRelationship 
 * </code> between a Resource and an Activity. <code> ActivityRegistrations 
 * </code> permit hanging data off of each <code> Activity. </code> <code> 
 * ActivityRegistrations </code> may be implicitly created upon the creation 
 * of a <code> Regsitration. </code> </p> 
 * <h4> Course Catalog Cataloging </h4> 
 * 
 * <p> <code> ActivityBundles, </code> <code> Registrations </code> , and 
 * <code> ActivityRegistrations </code> can be organized into federateble 
 * <code> OsidCatalogs. </code> <code> CourseCatalogs </code> can be used to 
 * represent a set of <code> Registrations </code> offered in a specific 
 * <code> Term, </code> year, or by subject area or sponsor. </p>
 * 
 * <br/><hr/><br/>
 * 
 * <p>Copyright &copy; 2010 Ingenescus. All Rights Reserved. </p>
 * 
 * <p>This Work is being provided by the copyright holder(s) subject to the 
 * following license. By obtaining, using and/or copying this Work, you agree 
 * that you have read, understand, and will comply with the following terms 
 * and conditions. </p> 
 * 
 * <p> Permission to use, copy and distribute unmodified versions of this 
 * Work, for any purpose, without fee or royalty is hereby granted, provided 
 * that you include the above copyright notices and the terms of this license 
 * on ALL copies of the Work or portions thereof. </p> 
 * 
 * <p> You may modify or create Derivatives of this Work only for your 
 * internal purposes. You shall not distribute or transfer any such Derivative 
 * of this Work to any location or to any third party. For the purposes of 
 * this license, "Derivative" shall mean any derivative of the Work as defined 
 * in the United States Copyright Act of 1976, such as a translation or 
 * modification. </p> 
 * 
 * <p> This Work and the information contained herein is provided on an "AS 
 * IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT 
 * NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR 
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT 
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN 
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN 
 * CONNECTION WITH THE WORK OR THE USE OR OTHER DEALINGS IN THE WORK. </p> 
 * 
 * <p> The export of software employing encryption technology may require a 
 * specific license from the United States Government. It is the 
 * responsibility of any person or organization contemplating export to obtain 
 * such a license before exporting this Work. </p>
 */

package org.osid.course.registration;
