//
// org.osid.course.requisite.CourseRequirement
//
//     The OSID Java specification for org.osid.course.requisite.CourseRequirement.
//
// Copyright (C) 2011 Massachusetts Institute of Technology. All Rights 
// Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     This Work and the information contained herein is provided on an ""AS 
//     IS"" basis. The Massachusetts Institute of Technology, the Open 
//     Knowledge Initiative, and THE AUTHORS DISCLAIM ALL WARRANTIES, EXPRESS 
//     OR IMPLIED, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, 
//     FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
//     THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
//     OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
//     ARISING FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notice and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, Derivative shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization comtemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.requisite;


/**
 *  <p>A <code> CourseRequirement </code> is an <code> OsidRule </code> and 
 *  represents a requirement based on the completion or a co-requsite of a 
 *  course. </p>
 */

public interface CourseRequirement
    extends org.osid.OsidRule,
            org.osid.Aggregateable {


    /**
     *  Gets any <code> Requisites </code> that may be substituted in place of 
     *  this <code> CourseRequirement. </code> All <code> Requisites </code> 
     *  must be satisifed to be a substitute for this course requirement. 
     *  Inactive <code> Requisites </code> are not evaluated but if no 
     *  applicable requisite exists, then the alternate requisite is not 
     *  satisifed. 
     *
     *  @return the alternate requisites 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.Requisite[] getAltRequisites();


    /**
     *  Gets the <code> Id </code> of the <code> Course. </code> 
     *
     *  @return the course <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCourseId();


    /**
     *  Gets the <code> Course. </code> 
     *
     *  @return the course 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.Course getCourse()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this requirement requires completion of the course with a 
     *  passing grade. 
     *
     *  @return <code> true </code> if a completion of the course is required, 
     *          <code> false </code> is the course is a co-requisite 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean requiresCompletion();


    /**
     *  Tests if the course must be completed within the required duration. 
     *
     *  @return <code> true </code> if the course must be completed within a 
     *          required time, <code> false </code> if it could have been 
     *          completed at any time in the past 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasTimeframe();


    /**
     *  Gets the timeframe in which the course has to be completed. A negative 
     *  duration indicates the course had to be completed within the specified 
     *  amount of time in the past. A posiitive duration indicates the course 
     *  must be completed within the specified amount of time in the future. A 
     *  zero duration indicates the course must be completed in the current 
     *  term. 
     *
     *  @return the time frame 
     *  @throws org.osid.IllegalStateException <code> hasTimeframe() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Duration getTimeframe();


    /**
     *  Tests if a minimum grade above passing is required in the completion 
     *  of the course or maintained at this level during a co-requisite. 
     *
     *  @return <code> true </code> if a minimum grade is required, <code> 
     *          false </code> if the course just has to be passed 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasMinimumGrade();


    /**
     *  Gets the minimum grade <code> Id. </code> 
     *
     *  @return the minimum grade <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> hasMinimumGrade() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getMinimumGradeId();


    /**
     *  Gets the minimum grade. 
     *
     *  @return the minimum grade 
     *  @throws org.osid.IllegalStateException <code> hasMinimumGrade() 
     *          </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.Grade getMinimumGrade()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if a minimum score above passing is required in the completion 
     *  of the course or maintained at this level during a co-requisite. 
     *
     *  @return <code> true </code> if a minimum score is required, <code> 
     *          false </code> if the course just has to be passed 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasMinimumScore();


    /**
     *  Gets the scoring system <code> Id </code> for the minimum score. 
     *
     *  @return the scoring system <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> hasMinimumScore() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getMinimumScoreSystemId();


    /**
     *  Gets the scoring system for the minimum score. 
     *
     *  @return the scoring system 
     *  @throws org.osid.IllegalStateException <code> hasMinimumScore() 
     *          </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeSystem getMinimumScoreSystem()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the minimum score. 
     *
     *  @return the minimum score 
     *  @throws org.osid.IllegalStateException <code> hasMinimumScore() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getMinimumScore();


    /**
     *  Tests if a minimum credits earned from the completion of the course, 
     *  or registered for in a co-requisite is required. 
     *
     *  @return <code> true </code> if a minimum credits is required, <code> 
     *          false </code> otehrwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasMinimumEarnedCredits();


    /**
     *  Gets the minimum earned credits. 
     *
     *  @return the minimum credits 
     *  @throws org.osid.IllegalStateException <code> 
     *          hasMinimumEarnedCredits() </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getMinimumEarnedCredits();


    /**
     *  Gets the course requirement record corresponding to the given <code> 
     *  CourseRequirement </code> record <code> Type. </code> This method is 
     *  used to retrieve an object implementing the requested record. The 
     *  <code> courseRequirementRecordType </code> may be the <code> Type 
     *  </code> returned in <code> getRecordTypes() </code> or any of its 
     *  parents in a <code> Type </code> hierarchy where <code> 
     *  hasRecordType(courseRequirementRecordType) </code> is <code> true 
     *  </code> . 
     *
     *  @param  courseRequirementRecordType the type of course requirement 
     *          record to retrieve 
     *  @return the course requirement record 
     *  @throws org.osid.NullArgumentException <code> 
     *          courseRequirementRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(courseRequirementRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.records.CourseRequirementRecord getCourseRequirementRecord(org.osid.type.Type courseRequirementRecordType)
        throws org.osid.OperationFailedException;
}
