//
// org.osid.course.requisite.CourseRequisiteProfile
//
//     The OSID Java specification for org.osid.course.requisite.CourseRequisiteProfile.
//
// Copyright (C) 2011 Massachusetts Institute of Technology. All Rights 
// Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     This Work and the information contained herein is provided on an ""AS 
//     IS"" basis. The Massachusetts Institute of Technology, the Open 
//     Knowledge Initiative, and THE AUTHORS DISCLAIM ALL WARRANTIES, EXPRESS 
//     OR IMPLIED, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, 
//     FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
//     THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
//     OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
//     ARISING FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notice and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, Derivative shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization comtemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.requisite;


/**
 *  <p>The course requisite profile describes the interoperability among 
 *  course requisite services. </p>
 */

public interface CourseRequisiteProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any course catalog federation is exposed. Federation is 
     *  exposed when a specific course catalog may be identified, selected and 
     *  used to create a lookup or admin session. Federation is not exposed 
     *  when a set of catalogs appears as a single catalog. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if looking up requisites is supported. 
     *
     *  @return <code> true </code> if requisite lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRequisiteLookup();


    /**
     *  Tests if querying requisites is supported. 
     *
     *  @return <code> true </code> if requisite query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRequisiteQuery();


    /**
     *  Tests if searching requisites is supported. 
     *
     *  @return <code> true </code> if requisite search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRequisiteSearch();


    /**
     *  Tests if requisite administrative service is supported. 
     *
     *  @return <code> true </code> if requisite administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRequisiteAdmin();


    /**
     *  Tests if a requisite <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if requisite notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRequisiteNotification();


    /**
     *  Tests if a requisite cataloging service is supported. 
     *
     *  @return <code> true </code> if requisite cataloging is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRequisiteCourseCatalog();


    /**
     *  Tests if a course cataloging service is supported. A course cataloging 
     *  service maps requisites to catalogs. 
     *
     *  @return <code> true </code> if course cataloging is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRequisiteCourseCatalogAssignment();


    /**
     *  Tests if a requisite smart course catalog session is available. 
     *
     *  @return <code> true </code> if a requisite smart course catalog 
     *          session is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRequisiteSmartCourseCatalog();


    /**
     *  Gets the supported <code> Requisite </code> record types. 
     *
     *  @return a list containing the supported <code> Requisite </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getRequisiteRecordTypes();


    /**
     *  Tests if the given <code> Requisite </code> record type is supported. 
     *
     *  @param  requisiteRecordType a <code> Type </code> indicating a <code> 
     *          Requisite </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> requisiteRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRequisiteRecordType(org.osid.type.Type requisiteRecordType);


    /**
     *  Gets the supported <code> Requisite </code> search record types. 
     *
     *  @return a list containing the supported <code> Requisite </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getRequisiteSearchRecordTypes();


    /**
     *  Tests if the given <code> Requisite </code> search record type is 
     *  supported. 
     *
     *  @param  requisiteSearchRecordType a <code> Type </code> indicating a 
     *          <code> Requisite </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          requisiteSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRequisiteSearchRecordType(org.osid.type.Type requisiteSearchRecordType);


    /**
     *  Gets the supported <code> CourseRequirement </code> record types. 
     *
     *  @return a list containing the supported <code> CourseRequirement 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCourseRequirementRecordTypes();


    /**
     *  Tests if the given <code> CourseRequirement </code> record type is 
     *  supported. 
     *
     *  @param  courseRequirementRecordType a <code> Type </code> indicating a 
     *          <code> CourseRequirement </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          courseRequirementRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseRequirementRecordType(org.osid.type.Type courseRequirementRecordType);


    /**
     *  Gets the supported <code> ProgramRequirement </code> record types. 
     *
     *  @return a list containing the supported <code> ProgramRequirement 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getProgramRequirementRecordTypes();


    /**
     *  Tests if the given <code> ProgramRequirement </code> record type is 
     *  supported. 
     *
     *  @param  programRequirementRecordType a <code> Type </code> indicating 
     *          a <code> ProgramRequirement </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          programRequirementRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProgramRequirementRecordType(org.osid.type.Type programRequirementRecordType);


    /**
     *  Gets the supported <code> CredentialRequirement </code> record types. 
     *
     *  @return a list containing the supported <code> CredentialRequirement 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCredentialRequirementRecordTypes();


    /**
     *  Tests if the given <code> CredentialRequirement </code> record type is 
     *  supported. 
     *
     *  @param  credentialRequirementRecordType a <code> Type </code> 
     *          indicating a <code> CredentialRequirement </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          credentialRequirementRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCredentialRequirementRecordType(org.osid.type.Type credentialRequirementRecordType);


    /**
     *  Gets the supported <code> LearningObjectiveRequirement </code> record 
     *  types. 
     *
     *  @return a list containing the supported <code> 
     *          LearningObjectiveRequirement </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getLearningObjectiveRequirementRecordTypes();


    /**
     *  Tests if the given <code> LearningObjectiveRequirement </code> record 
     *  type is supported. 
     *
     *  @param  learningObjectiveRequirementRecordType a <code> Type </code> 
     *          indicating a <code> LearningObjectivelRequirement </code> 
     *          record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          learningObjectiveRequirementRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLearningObjectiveRequirementRecordType(org.osid.type.Type learningObjectiveRequirementRecordType);


    /**
     *  Gets the supported <code> AsessmentRequirement </code> record types. 
     *
     *  @return a list containing the supported <code> AssessmentRequirement 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAssessmentRequirementRecordTypes();


    /**
     *  Tests if the given <code> AsessmentRequirement </code> record type is 
     *  supported. 
     *
     *  @param  assessmentRequirementRecordType a <code> Type </code> 
     *          indicating an <code> AssessmentRequirement </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          assessmentRequirementRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentRequirementRecordType(org.osid.type.Type assessmentRequirementRecordType);


    /**
     *  Gets the supported <code> AsessmentRequirement </code> record types. 
     *
     *  @return a list containing the supported <code> AwardRequirement 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAwardRequirementRecordTypes();


    /**
     *  Tests if the given <code> AsessmentRequirement </code> record type is 
     *  supported. 
     *
     *  @param  awardRequirementRecordType a <code> Type </code> indicating an 
     *          <code> AwardRequirement </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          awardRequirementRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAwardRequirementRecordType(org.osid.type.Type awardRequirementRecordType);
}
