//
// org.osid.course.requisite.Requisite
//
//     The OSID Java specification for org.osid.course.requisite.Requisite.
//
// Copyright (C) 2011 Massachusetts Institute of Technology. All Rights 
// Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     This Work and the information contained herein is provided on an ""AS 
//     IS"" basis. The Massachusetts Institute of Technology, the Open 
//     Knowledge Initiative, and THE AUTHORS DISCLAIM ALL WARRANTIES, EXPRESS 
//     OR IMPLIED, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, 
//     FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
//     THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
//     OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
//     ARISING FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notice and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, Derivative shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization comtemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.requisite;


/**
 *  <p>A <code> Requisite </code> represents a requirement. A <code> Requisite 
 *  </code> has 8 terms for evaluation that must all be true for this <code> 
 *  Requisite </code> to be satisfied. Additional terms may be defined in the 
 *  <code> RequisiteRecord. </code> </p> 
 *  
 *  <ul>
 *      <li> CourseRequirements </li> 
 *      <li> ProgramRequirements </li> 
 *      <li> CredentialRequirements </li> 
 *      <li> AssessmentRequirements </li> 
 *      <li> AwardRequirements </li> 
 *      <li> LearningObjectiveRequirements </li> 
 *      <li> an external <code> Rule </code> </li> 
 *      <li> Requisite options for nested <code> OR </code> terms </li> 
 *  </ul>
 *  
 *  
 *  <p> A <code> Requsite </code> is true if the active <code> Requisite 
 *  </code> options term <code> AND </code> the <code> CourseRequirements 
 *  </code> term <code> AND </code> the <code> ProgramRequirements </code> 
 *  term AND <code> CredentialRequirements </code> term <code> AND </code> the 
 *  <code> AssessemnetRequirements </code> term <code> AND </code> the <code> 
 *  LearningObjectiveRequirements </code> AND <code> Rule </code> are all 
 *  <code> true. </code> </p> 
 *  
 *  <p> <code> Requisites </code> are also <code> OsidEnablers </code> that 
 *  have effectiveness and may apply to specific populations of students. </p>
 */

public interface Requisite
    extends org.osid.OsidRule,
            org.osid.OsidEnabler,
            org.osid.Containable {


    /**
     *  Tests if any requisite options are defined. If no requisite options 
     *  are defined, this requisite term evaluates to <code> true. </code> If 
     *  requisite options are defined, then at least one <code> Requisite 
     *  </code> must evaluate to <code> true </code> for the requisite option 
     *  term to be <code> true. </code> 
     *
     *  @return <code> true </code> if any requisite options are defined, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasRequisiteOptions();


    /**
     *  Gets the requisite options for the <code> Requisite </code> options 
     *  term. If any active requisite options are available, meeting the 
     *  requirements of any one of these requisite options evaluates this 
     *  requisite options term as <code> true. </code> If no active requisite 
     *  options apply then this term evaluates to <code> false. </code> 
     *
     *  @return the requsites 
     *  @throws org.osid.IllegalStateException <code> hasRequisiteOptions() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.Requisite[] getRequisiteOptions();


    /**
     *  Tests if any course requirements are defined. If no course 
     *  requirements are defined, this course requirements term evaluates to 
     *  <code> true. </code> If course requirements are defined, then at least 
     *  one <code> CourseRequirement </code> must evaluate to <code> true 
     *  </code> for the course requirement term to be <code> true. </code> 
     *
     *  @return <code> true </code> if any course requirements are defined, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasCourseRequirements();


    /**
     *  Gets the course requirements term. If any <code> CourseRequirements 
     *  </code> are available, meeting the requirements of any one of the 
     *  <code> CourseRequirements </code> evaluates this course requirements 
     *  term as <code> true. </code> If no active course requirements apply 
     *  then this course requirements term is <code> false. </code> 
     *
     *  @return the course requirements 
     *  @throws org.osid.IllegalStateException <code> hasCourseRequirements() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.CourseRequirement[] getCourseRequirements();


    /**
     *  Tests if any program requirements are defined. If no program 
     *  requirements are defined, this program requirements term evaluates to 
     *  <code> true. </code> If program requirements are defined, then at 
     *  least one <code> ProgramRequirement </code> must evaluate to <code> 
     *  true </code> for the program requirement term to be <code> true. 
     *  </code> 
     *
     *  @return <code> true </code> if any program requirements are defined, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasProgramRequirements();


    /**
     *  Gets the program requirements term. If any <code> ProgramRequirements 
     *  </code> are available, meeting the requirements of any one of the 
     *  <code> ProgramRequirements </code> evaluates this program requirements 
     *  term as <code> true. </code> If no program requirements apply then 
     *  this program requirements term evaluates to <code> false. </code> 
     *
     *  @return the program requirements 
     *  @throws org.osid.IllegalStateException <code> hasProgramRequirements() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.ProgramRequirement[] getProgramRequirements();


    /**
     *  Tests if any credential requirements are defined. If no credential 
     *  requirements are defined, this credential requirements term evaluates 
     *  to <code> true. </code> If credential requirements are defined, then 
     *  at least one <code> CredentialRequirement </code> must evaluate to 
     *  <code> true </code> for the credential requirement term to be <code> 
     *  true. </code> 
     *
     *  @return <code> true </code> if any credential requirements are 
     *          defined, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasCredentialRequirements();


    /**
     *  Gets the credential requirements term. If any <code> 
     *  CredentialRequirements </code> are available, meeting the requirements 
     *  of any one of the <code> CredentialRequirements </code> evaluates this 
     *  credential requirements term as <code> true. </code> If no credential 
     *  requirements are available, this credential requirements term 
     *  evaluates to <code> false. </code> 
     *
     *  @return the credential requirements 
     *  @throws org.osid.IllegalStateException <code> 
     *          hasCredentialRequirements() </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.CredentialRequirement[] getCredentialRequirements();


    /**
     *  Tests if any learning objective requirements are defined. If no 
     *  learning objective requirements are defined, this learning objective 
     *  requirements term evaluates to <code> true. </code> If learning 
     *  objective requirements are defined, then at least one <code> 
     *  LearningObjectiveRequirement </code> must evaluate to <code> true 
     *  </code> for the learning objective requirement term to be <code> true. 
     *  </code> 
     *
     *  @return <code> true </code> if any learning objective requirements are 
     *          defined, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasLearningObjectiveRequirements();


    /**
     *  Gets the learning objective requirements term. If any <code> 
     *  LearningObjectiveRequirements </code> are available, meeting the 
     *  requirements of any one of the <code> LearningObjectiveRequirements 
     *  </code> evaluates this learning objective requirements term as <code> 
     *  true. </code> If no learning objective requirements applythen this 
     *  learning objective requirements term evaluates to <code> false. 
     *  </code> 
     *
     *  @return the learning objective requirements 
     *  @throws org.osid.IllegalStateException <code> 
     *          hasLearningObjectiveRequirements() </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.LearningObjectiveRequirement[] getLearningObjectiveRequirements();


    /**
     *  Tests if any assessment requirements are defined. If no assessment 
     *  requirements are defined, this assessment requirements term evaluates 
     *  to <code> true. </code> If assessment requirements are defined, then 
     *  at least one <code> AssessmentRequirement </code> must evaluate to 
     *  <code> true </code> for the assessment requirement term to be <code> 
     *  true. </code> 
     *
     *  @return <code> true </code> if any assessment requirements are 
     *          defined, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasAssessmentRequirements();


    /**
     *  Gets the assessment requirements term. If any <code> 
     *  AssessmentRequirements </code> are available, meeting the requirements 
     *  of any one of the <code> AssessmentRequirements </code> evaluates this 
     *  assessment requirements term as <code> true. </code> If no assessment 
     *  requirements are available, this assessment requirements term 
     *  evaluates to <code> false. </code> 
     *
     *  @return the assessment requirements 
     *  @throws org.osid.IllegalStateException <code> 
     *          hasAssessmentRequirements() </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.AssessmentRequirement[] getAssessmentRequirements();


    /**
     *  Tests if any award requirements are defined. If no award requirements 
     *  are defined, this award requirements term evaluates to <code> true. 
     *  </code> If award requirements are defined, then at least one <code> 
     *  AwardRequirement </code> must evaluate to <code> true </code> for the 
     *  award requirement term to be <code> true. </code> 
     *
     *  @return <code> true </code> if any award requirements are defined, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasAwardRequirements();


    /**
     *  Gets the award requirements term. If any <code> AwardRequirements 
     *  </code> are available, meeting the requirements of any one of the 
     *  <code> AwardRequirements </code> evaluates this award requirements 
     *  term as <code> true. </code> If no award requirements are available, 
     *  this award requirements term evaluates to <code> false. </code> 
     *
     *  @return the award requirements 
     *  @throws org.osid.IllegalStateException <code> hasAwardRequirements() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.AwardRequirement[] getAwardRequirements();


    /**
     *  Gets the requisite record corresponding to the given <code> Requisite 
     *  </code> record <code> Type. </code> This method is used to retrieve an 
     *  object implementing the requested record. The <code> 
     *  requisiteRecordType </code> may be the <code> Type </code> returned in 
     *  <code> getRecordTypes() </code> or any of its parents in a <code> Type 
     *  </code> hierarchy where <code> hasRecordType(requisiteRecordType) 
     *  </code> is <code> true </code> . 
     *
     *  @param  requisiteRecordType the type of requisite record to retrieve 
     *  @return the requisite record 
     *  @throws org.osid.NullArgumentException <code> requisiteRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(requisiteRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.records.RequisiteRecord getRequisiteRecord(org.osid.type.Type requisiteRecordType)
        throws org.osid.OperationFailedException;
}
