//
// org.osid.course.requisite.RequisiteCourseCatalogAssignmentSession
//
//     The OSID Java specification for org.osid.course.requisite.RequisiteCourseCatalogAssignmentSession.
//
// Copyright (C) 2011 Massachusetts Institute of Technology. All Rights 
// Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     This Work and the information contained herein is provided on an ""AS 
//     IS"" basis. The Massachusetts Institute of Technology, the Open 
//     Knowledge Initiative, and THE AUTHORS DISCLAIM ALL WARRANTIES, EXPRESS 
//     OR IMPLIED, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, 
//     FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
//     THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
//     OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
//     ARISING FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notice and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, Derivative shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization comtemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.requisite;


/**
 *  <p>This session provides methods to re-assign <code> Requisites </code> to 
 *  <code> CourseCatalogs. </code> A <code> Requisite </code> may appear in 
 *  multiple <code> CourseCatalogs </code> and removing the last reference to 
 *  a <code> Requisite </code> is the equivalent of deleting it. Each <code> 
 *  CourseCatalog </code> may have its own authorizations governing who is 
 *  allowed to operate on it. </p> 
 *  
 *  <p> Adding a reference of a <code> Requisite </code> to another <code> 
 *  CourseCatalog </code> is not a copy operation (eg: does not change its 
 *  <code> Id </code> ). </p>
 */

public interface RequisiteCourseCatalogAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter requisite/course catalog mappings. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer assignment 
     *  operations to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignRequisites();


    /**
     *  Tests if this user can alter requisite/course catalog mappings. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @param  courseCatalogId the <code> Id </code> of the <code> 
     *          CourseCatalog </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignRequisiteToCourseCatalog(org.osid.id.Id courseCatalogId);


    /**
     *  Gets a list of course catalogs including and under the given course 
     *  catalog node in which any requisite can be assigned. 
     *
     *  @param  courseCatalogId the <code> Id </code> of the <code> 
     *          CourseCatalog </code> 
     *  @return list of assignable course catalog <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableCourseCatalogIds(org.osid.id.Id courseCatalogId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of course catalogs including and under the given course 
     *  catalog node in which a specific requisite can be assigned. 
     *
     *  @param  courseCatalogId the <code> Id </code> of the <code> 
     *          CourseCatalog </code> 
     *  @param  requisiteId the <code> Id </code> of the <code> Requisite 
     *          </code> 
     *  @return list of assignable course catalog <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          or <code> requisiteId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableCourseCatalogIdsForRequisite(org.osid.id.Id courseCatalogId, 
                                                                        org.osid.id.Id requisiteId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> Requisite </code> to a <code> CourseCatalog. 
     *  </code> 
     *
     *  @param  requisiteId the <code> Id </code> of the <code> Requisite 
     *          </code> 
     *  @param  courseCatalogId the <code> Id </code> of the <code> 
     *          CourseCatalog </code> 
     *  @throws org.osid.AlreadyExistsException <code> requisiteId </code> is 
     *          already assigned to <code> courseCatalogId </code> 
     *  @throws org.osid.NotFoundException <code> requisiteId </code> or 
     *          <code> courseCatalogId </code> not found 
     *  @throws org.osid.NullArgumentException <code> requisiteId </code> or 
     *          <code> courseCatalogId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignRequisiteToCourseCatalog(org.osid.id.Id requisiteId, 
                                               org.osid.id.Id courseCatalogId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> Requisite </code> from a <code> CourseCatalog. 
     *  </code> 
     *
     *  @param  requisiteId the <code> Id </code> of the <code> Requisite 
     *          </code> 
     *  @param  courseCatalogId the <code> Id </code> of the <code> 
     *          CourseCatalog </code> 
     *  @throws org.osid.NotFoundException <code> requisiteId </code> or 
     *          <code> courseCatalogId </code> not found or <code> requisiteId 
     *          </code> not assigned to <code> courseCatalogId </code> 
     *  @throws org.osid.NullArgumentException <code> requisiteId </code> or 
     *          <code> courseCatalogId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignRequisiteFromCourseCatalog(org.osid.id.Id requisiteId, 
                                                   org.osid.id.Id courseCatalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Moves a <code> Requiisite </code> from one <code> CourseCatalog 
     *  </code> to another. Mappings to other <code> CourseCatalogs </code> 
     *  are unaffected. 
     *
     *  @param  requisiteId the <code> Id </code> of the <code> Requisite 
     *          </code> 
     *  @param  fromCourseCatalogId the <code> Id </code> of the current 
     *          <code> CourseCatalog </code> 
     *  @param  toCourseCatalogId the <code> Id </code> of the destination 
     *          <code> CourseCatalog </code> 
     *  @throws org.osid.NotFoundException <code> requisiteId, 
     *          fromCourseCatalogId, </code> or <code> toCourseCatalogId 
     *          </code> not found or <code> requisiteId </code> not mapped to 
     *          <code> fromCourseCatalogId </code> 
     *  @throws org.osid.NullArgumentException <code> requisiteId, 
     *          fromCourseCatalogId, </code> or <code> toCourseCatalogId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void reassignCreditToCourseCatalog(org.osid.id.Id requisiteId, 
                                              org.osid.id.Id fromCourseCatalogId, 
                                              org.osid.id.Id toCourseCatalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
