//
// org.osid.course.requisite.RequisiteNotificationSession
//
//     The OSID Java specification for org.osid.course.requisite.RequisiteNotificationSession.
//
// Copyright (C) 2011 Massachusetts Institute of Technology. All Rights 
// Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     This Work and the information contained herein is provided on an ""AS 
//     IS"" basis. The Massachusetts Institute of Technology, the Open 
//     Knowledge Initiative, and THE AUTHORS DISCLAIM ALL WARRANTIES, EXPRESS 
//     OR IMPLIED, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, 
//     FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
//     THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
//     OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
//     ARISING FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notice and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, Derivative shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization comtemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.requisite;


/**
 *  <p>This session defines methods to receive notifications on adds/changes 
 *  to <code> Requisite </code> objects in this <code> CourseCatalog. </code> 
 *  This also includes existing courses that may appear or disappear due to 
 *  changes in the <code> CourseCatalog </code> hierarchy, This session is 
 *  intended for consumers needing to synchronize their state with this 
 *  service without the use of polling. Notifications are cancelled when this 
 *  session is closed. </p> 
 *  
 *  <p> The two views defined in this session correspond to the views in the 
 *  <code> RequisiteLookupSession. </code> </p>
 */

public interface RequisiteNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> CourseCatalog </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> CourseCatalog Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCourseCatalogId();


    /**
     *  Gets the <code> CourseCatalog </code> associated with this session. 
     *
     *  @return the course catalog 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseCatalog getCourseCatalog()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can register for <code> Requisite </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForRequisiteNotifications();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include requisites in catalogs which are children of this catalog in 
     *  the course catalog hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCourseCatalogView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts notifications to this course catalog only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCourseCatalogView();


    /**
     *  Reliable notifications are desired. In reliable mode, notifications 
     *  are to be acknowledged using <code> acknowledgeRequisiteNotification() 
     *  </code> . 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void reliableRequisiteNotifications();


    /**
     *  Unreliable notifications are desired. In unreliable mode, 
     *  notifications do not need to be acknowledged. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void unreliableRequisiteNotifications();


    /**
     *  Acknowledge a requisite notification. 
     *
     *  @param  notificationId the <code> Id </code> of the notification 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void acknowledgeRequisiteNotification(org.osid.id.Id notificationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new requisites. <code> 
     *  RequisiteReceiver.newRequisites() </code> is invoked when a new <code> 
     *  Requisite </code> appears in this course catalog. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewRequisites()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated requisites. <code> 
     *  RequisiteReceiver.changedRequisites() </code> is invoked when a 
     *  requisite in this course catalog is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedRequisites()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated requisite. <code> 
     *  RequisiteReceiver.changedRequisites() </code> is invoked when the 
     *  specified requisite in this course catalog is changed. 
     *
     *  @param  requisiteId the <code> Id </code> of the <code> Requisite 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> requisiteId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedRequisite(org.osid.id.Id requisiteId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted requisites. <code> 
     *  RequisiteReceiver.deletedRequisites() </code> is invoked when a 
     *  requisite is deleted or removed from this course catalog. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedRequisites()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted requisite. <code> 
     *  RequisiteReceiver.deletedRequisites() </code> is invoked when the 
     *  specified requisite is deleted or removed from this course catalog. 
     *
     *  @param  requisiteId the <code> Id </code> of the <code> Requisite 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> requisiteId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedRequisite(org.osid.id.Id requisiteId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new course requirements. <code> 
     *  RequisiteReceiver.newCourseRequirements() </code> is invoked when a 
     *  new <code> CourseRequirement </code> appears in this course catalog. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewCourseRequirements()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated course requirements. <code> 
     *  RequisiteReceiver.changedCourseRequirements() </code> is invoked when 
     *  a course requirement in this course catalog is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedCourseRequirements()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated course requirement. <code> 
     *  RequisiteReceiver.changedCourseRequirements() </code> is invoked when 
     *  the specified course requirement in this course catalog is changed. 
     *
     *  @param  courseRequirementId the <code> Id </code> of the <code> 
     *          CourseRequirement </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> courseRequirementId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedCourseRequirement(org.osid.id.Id courseRequirementId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted course requirements. <code> 
     *  RequisiteReceiver.deletedCourseRequirements() </code> is invoked when 
     *  a course requirement is deleted or removed from this course catalog. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedCourseRequirements()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted course requirement. <code> 
     *  RequisiteReceiver.deletedCourseRequirements() </code> is invoked when 
     *  the specified course requirement is deleted or removed from this 
     *  course catalog. 
     *
     *  @param  courseRequirementId the <code> Id </code> of the <code> 
     *          CourseRequirement </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> courseRequirementId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedCourseRequirement(org.osid.id.Id courseRequirementId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new program requirements. <code> 
     *  RequisiteReceiver.newProgramRequirements() </code> is invoked when a 
     *  new <code> ProgramRequirement </code> appears in this course catalog. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewProgramRequirements()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated program requirements. <code> 
     *  RequisiteReceiver.changedProgramRequirements() </code> is invoked when 
     *  a program requirement in this course catalog is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedProgramRequirements()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated program requirement. <code> 
     *  RequisiteReceiver.changedProgramRequirements() </code> is invoked when 
     *  the specified program requirement in this course catalog is changed. 
     *
     *  @param  programRequirementId the <code> Id </code> of the <code> 
     *          ProgramRequirement </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> programRequirementId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedProgramRequirement(org.osid.id.Id programRequirementId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted program requirements. <code> 
     *  RequisiteReceiver.deletedProgramRequirements() </code> is invoked when 
     *  a program requirement is deleted or removed from this course catalog. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedProgramRequirements()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted program requirement. <code> 
     *  RequisiteReceiver.deletedProgramRequirements() </code> is invoked when 
     *  the specified program requirement is deleted or removed from this 
     *  course catalog. 
     *
     *  @param  programRequirementId the <code> Id </code> of the <code> 
     *          ProgramRequirement </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> programRequirementId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedProgramRequirement(org.osid.id.Id programRequirementId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new credential requirements. <code> 
     *  RequisiteReceiver.newCredentialRequirements() </code> is invoked when 
     *  a new <code> CredentialRequirement </code> appears in this course 
     *  catalog. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewCredentialRequirements()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated credential requirements. <code> 
     *  RequisiteReceiver.changedCredentialRequirements() </code> is invoked 
     *  when a credential requirement in this course catalog is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedCredentialRequirements()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated credential requirement. 
     *  <code> RequisiteReceiver.changedCredentialRequirements() </code> is 
     *  invoked when the specified credential requirement in this course 
     *  catalog is changed. 
     *
     *  @param  credentialRequirementId the <code> Id </code> of the <code> 
     *          CredentialRequirement </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> credentialRequirementId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedCredentialRequirement(org.osid.id.Id credentialRequirementId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted credential requirements. <code> 
     *  RequisiteReceiver.deletedCredentialRequirements() </code> is invoked 
     *  when a credential requirement is deleted or removed from this course 
     *  catalog. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedCredentialRequirements()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted credential requirement. <code> 
     *  RequisiteReceiver.deletedCredentialRequirements() </code> is invoked 
     *  when the specified credential requirement is deleted or removed from 
     *  this course catalog. 
     *
     *  @param  credentialRequirementId the <code> Id </code> of the <code> 
     *          CredentialRequirement </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> credentialRequirementId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedCredentialRequirement(org.osid.id.Id credentialRequirementId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new learning objective requirements. 
     *  <code> RequisiteReceiver.newLearningObjectiveRequirements() </code> is 
     *  invoked when a new <code> LearningObjectiveRequirement </code> appears 
     *  in this course catalog. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewLearningObjectiveRequirements()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated learning objective requirements. 
     *  <code> RequisiteReceiver.changedLearningObjectiveRequirements() 
     *  </code> is invoked when a learning objective requirement in this 
     *  course catalog is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedLearningObjectiveRequirements()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated learning objective 
     *  requirement. <code> 
     *  RequisiteReceiver.changedLearningObjectiveRequirements() </code> is 
     *  invoked when the specified learning objective requirement in this 
     *  course catalog is changed. 
     *
     *  @param  learningObjectiveRequirementId the <code> Id </code> of the 
     *          <code> LearningObjectiveRequirement </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> 
     *          learningObjectiveRequirementId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedLearningObjectiveRequirement(org.osid.id.Id learningObjectiveRequirementId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted learning objective requirements. 
     *  <code> RequisiteReceiver.deletedLearningObjectiveRequirements() 
     *  </code> is invoked when a learning objective requirement is deleted or 
     *  removed from this course catalog. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedLearningObjectiveRequirements()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted learning objective 
     *  requirement. <code> 
     *  RequisiteReceiver.deletedLearningObjectiveRequirements() </code> is 
     *  invoked when the specified learning objective requirement is deleted 
     *  or removed from this course catalog. 
     *
     *  @param  learningObjectiveRequirementId the <code> Id </code> of the 
     *          <code> LearningObjectiveRequirement </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> 
     *          learningObjectiveRequirementId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedLearningObjectiveRequirement(org.osid.id.Id learningObjectiveRequirementId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new assessment requirements. <code> 
     *  RequisiteReceiver.newAssessmentRequirements() </code> is invoked when 
     *  a new <code> AssessmentRequirement </code> appears in this course 
     *  catalog. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewAssessmentRequirements()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated assessment requirements. <code> 
     *  RequisiteReceiver.changedAssessmentRequirements() </code> is invoked 
     *  when an assessment requirement in this course catalog is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedAssessmentRequirements()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated assessment requirement. 
     *  <code> RequisiteReceiver.changedAssessmentRequirements() </code> is 
     *  invoked when the specified assessment requirement in this course 
     *  catalog is changed. 
     *
     *  @param  assessmentRequirementId the <code> Id </code> of the <code> 
     *          AssessmentRequirement </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> assessmentRequirementId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedAssessmentRequirement(org.osid.id.Id assessmentRequirementId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted assessment requirements. <code> 
     *  RequisiteReceiver.deletedAssessmentRequirements() </code> is invoked 
     *  when an assessment requirement is deleted or removed from this course 
     *  catalog. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedAssessmentRequirements()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted assessment requirement. <code> 
     *  RequisiteReceiver.deletedAssessmentRequirements() </code> is invoked 
     *  when the specified assessment requirement is deleted or removed from 
     *  this course catalog. 
     *
     *  @param  assessmentRequirementId the <code> Id </code> of the <code> 
     *          AssessmentRequirement </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> assessmentRequirementId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedAssessmentRequirement(org.osid.id.Id assessmentRequirementId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new award requirements. <code> 
     *  RequisiteReceiver.newAwardRequirements() </code> is invoked when a new 
     *  <code> AwardRequirement </code> appears in this course catalog. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewAwardRequirements()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated award requirements. <code> 
     *  RequisiteReceiver.changedAwardRequirements() </code> is invoked when 
     *  an award requirement in this course catalog is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedAwardRequirements()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated award requirement. <code> 
     *  RequisiteReceiver.changedAwardRequirements() </code> is invoked when 
     *  the specified award requirement in this course catalog is changed. 
     *
     *  @param  awardRequirementId the <code> Id </code> of the <code> 
     *          AwardRequirement </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> awardRequirementId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedAwardRequirement(org.osid.id.Id awardRequirementId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted award requirements. <code> 
     *  RequisiteReceiver.deletedAwardRequirements() </code> is invoked when 
     *  an award requirement is deleted or removed from this course catalog. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedAwardRequirements()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted award requirement. <code> 
     *  RequisiteReceiver.deletedAwardRequirements() </code> is invoked when 
     *  the specified award requirement is deleted or removed from this course 
     *  catalog. 
     *
     *  @param  awardRequirementId the <code> Id </code> of the <code> 
     *          AwardRequirement </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> awardRequirementId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedAwardRequirement(org.osid.id.Id awardRequirementId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
