//
// org.osid.course.requisite.RequisiteSearchSession
//
//     The OSID Java specification for org.osid.course.requisite.RequisiteSearchSession.
//
// Copyright (C) 2011 Massachusetts Institute of Technology. All Rights 
// Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     This Work and the information contained herein is provided on an ""AS 
//     IS"" basis. The Massachusetts Institute of Technology, the Open 
//     Knowledge Initiative, and THE AUTHORS DISCLAIM ALL WARRANTIES, EXPRESS 
//     OR IMPLIED, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, 
//     FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
//     THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
//     OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
//     ARISING FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notice and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, Derivative shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization comtemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.requisite;


/**
 *  <p>This session provides methods for searching among <code> Requisites. 
 *  </code> The search query is constructed using the <code> RequisiteQuery. 
 *  </code> </p> 
 *  
 *  <p> <code> getRequisitesByQuery() </code> is the basic search method and 
 *  returns a list of <code> Requisites. </code> A more advanced search may be 
 *  performed with <code> getRequisitesBySearch(). </code> It accepts a <code> 
 *  RequisiteSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getRequisitesBySearch() </code> returns a <code> 
 *  RequisiteSearchResults </code> that can be used to access the resulting 
 *  <code> RequisiteList </code> or be used to perform a search within the 
 *  result set through <code> RequisiteSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated course catalog view: searches include requisites in 
 *      course catalogs of which this course catalog is an ancestor in the 
 *      course catalog hierarchy </li> 
 *      <li> isolated course catalog view: searches are restricted to courses 
 *      in this course catalog </li> 
 *  </ul>
 *  
 *  
 *  <p> Requisites may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> RequisiteQuery. 
 *  </code> </p>
 */

public interface RequisiteSearchSession
    extends org.osid.course.requisite.RequisiteQuerySession {


    /**
     *  Gets a requisite search. 
     *
     *  @return the requisite search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.RequisiteSearch getRequisiteSearch();


    /**
     *  Gets a requisite search order. The <code> RequisiteSearchOrder </code> 
     *  is supplied to a <code> RequisiteSearch </code> to specify the 
     *  ordering of results. 
     *
     *  @return the requisite search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.RequisiteSearchOrder getRequisiteSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  requisiteQuery the requisite query 
     *  @param  requisiteSearch the requisite search 
     *  @return the requisite search results 
     *  @throws org.osid.NullArgumentException <code> requisiteQuery </code> 
     *          or <code> requisiteSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> requisiteQuery </code> or 
     *          <code> requisiteSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.RequisiteSearchResults getRequisitesBySearch(org.osid.course.requisite.RequisiteQuery requisiteQuery, 
                                                                                  org.osid.course.requisite.RequisiteSearch requisiteSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a requisite query from an inspector. The inspector is available 
     *  from a <code> RequisiteSearchResults. </code> 
     *
     *  @param  requisiteQueryInspector a requisite query inspector 
     *  @return the requisite query 
     *  @throws org.osid.NullArgumentException <code> requisiteQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> requisiteQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.RequisiteQuery getRequisiteQueryFromInspector(org.osid.course.requisite.RequisiteQueryInspector requisiteQueryInspector);
}
