//
// org.osid.course.syllabus.CourseSyllabusManager
//
//     The OSID Java specification for org.osid.course.syllabus.CourseSyllabusManager.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.syllabus;


/**
 *  <p>The course syllabus manager provides access to syllabus sessions and 
 *  provides interoperability tests for various aspects of this service. The 
 *  sessions included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> SyllabusLookupSession: </code> a session to lookup syllabi 
 *      </li> 
 *      <li> <code> SyllabusQuerySession: </code> a session to query syllabi 
 *      </li> 
 *      <li> <code> SyllabusSearchSession: </code> a session to search syllabi 
 *      </li> 
 *      <li> <code> SyllabusAdminSession: </code> a session to manage syllabi 
 *      </li> 
 *      <li> <code> SyllabusNotificationSession: </code> a session to 
 *      subscribe to notifications of syllabus changes </li> 
 *      <li> <code> SyllabusCourseCatalogSession: </code> a session to lookup 
 *      syllabus course catalog mappings </li> 
 *      <li> <code> SyllabusCourseCatalogAssignmentSession: </code> a session 
 *      to manage syllabus course catalog mappings </li> 
 *      <li> <code> SyllabusSmartCourseCatalogSession: </code> a session to 
 *      manage smart course catalogs of syllabi </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> ModuleSession </code> : a session to get available modules 
 *      for a resource </li> 
 *      <li> <code> ModuleLookupSession: </code> a session to lookup modules 
 *      </li> 
 *      <li> <code> ModuleQuerySession: </code> a session to query modules 
 *      </li> 
 *      <li> <code> ModuleSearchSession: </code> a session to search modules 
 *      </li> 
 *      <li> <code> ModuleAdminSession: </code> a session to manage modules 
 *      </li> 
 *      <li> <code> ModuleNotificationSession: </code> a session to subscribe 
 *      to notifications of module changes </li> 
 *      <li> <code> ModuleCourseCatalogSession: </code> a session to lookup 
 *      module course catalog mappings </li> 
 *      <li> <code> ModuleCourseCatalogAssignmentSession: </code> a session to 
 *      manage module course catalog mappings </li> 
 *      <li> <code> ModuleSmartCourseCatalogSession: </code> a session to 
 *      manage smart course catalogs of modules </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> DocetLookupSession: </code> a session to retrieve docets 
 *      </li> 
 *      <li> <code> DocetQuerySession: </code> a session to query docets </li> 
 *      <li> <code> DocetSearchSession: </code> a session to search for docets 
 *      </li> 
 *      <li> <code> DocetAdminSession: </code> a session to create, update and 
 *      delete docets </li> 
 *      <li> <code> DocetNotificationSession: </code> a session to receive 
 *      notifications for changes in docets </li> 
 *      <li> <code> DocetCourseCatalogSession: </code> a session to lookup 
 *      docet course catalog mappings </li> 
 *      <li> <code> DocetCourseCatalogAssignmentSession: </code> a session to 
 *      manage docet course catalog mappings </li> 
 *      <li> <code> DocetSmartCourseCatalogSession: </code> a session to 
 *      manage smart course catalogs of docets </li> 
 *  </ul>
 *  
 *  
 *  <p> The course manager also provides a profile for determing the supported 
 *  search types supported by this service. </p>
 */

public interface CourseSyllabusManager
    extends org.osid.OsidManager,
            org.osid.course.syllabus.CourseSyllabusProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the syllabus 
     *  lookup service. 
     *
     *  @return a <code> SyllabusLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSyllabusLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSyllabusLookup() </code> is <code> true. </code> 
     */

    public org.osid.course.syllabus.SyllabusLookupSession getSyllabusLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the syllabus 
     *  lookup service for the given course catalog. 
     *
     *  @param  courseCatalogId the <code> Id </code> of the <code> 
     *          CourseCatalog </code> 
     *  @return a <code> SyllabusLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> CourseCatalog </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSyllabusLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSyllabusLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.course.syllabus.SyllabusLookupSession getSyllabusLookupSessionForCourseCatalog(org.osid.id.Id courseCatalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the syllabus query 
     *  service. 
     *
     *  @return a <code> SyllabusQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsSyllabusQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSyllabusQuery() </code> is <code> true. </code> 
     */

    public org.osid.course.syllabus.SyllabusQuerySession getSyllabusQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the syllabus query 
     *  service for the given course catalog. 
     *
     *  @param  courseCatalogId the <code> Id </code> of the <code> 
     *          CourseCatalog </code> 
     *  @return a <code> SyllabusQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> CourseCatalog </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsSyllabusQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSyllabusQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.course.syllabus.SyllabusQuerySession getSyllabusQuerySessionForCourseCatalog(org.osid.id.Id courseCatalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the syllabus 
     *  search service. 
     *
     *  @return a <code> SyllabusSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSyllabusSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSyllabusSearch() </code> is <code> true. </code> 
     */

    public org.osid.course.syllabus.SyllabusSearchSession getSyllabusSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the syllabus 
     *  search service for the given course catalog. 
     *
     *  @param  courseCatalogId the <code> Id </code> of the <code> 
     *          CourseCatalog </code> 
     *  @return a <code> SyllabusSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> CourseCatalog </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSyllabusSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSyllabusSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.course.syllabus.SyllabusSearchSession getSyllabusSearchSessionForCourseCatalog(org.osid.id.Id courseCatalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the syllabus 
     *  administration service. 
     *
     *  @return a <code> SyllabusAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsSyllabusAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSyllabusAdmin() </code> is <code> true. </code> 
     */

    public org.osid.course.syllabus.SyllabusAdminSession getSyllabusAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the syllabus 
     *  administration service for the given course catalog. 
     *
     *  @param  courseCatalogId the <code> Id </code> of the <code> 
     *          CourseCatalog </code> 
     *  @return a <code> SyllabusAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> CourseCatalog </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsSyllabusAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSyllabusAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.course.syllabus.SyllabusAdminSession getSyllabusAdminSessionForCourseCatalog(org.osid.id.Id courseCatalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the syllabus 
     *  notification service. 
     *
     *  @param  syllabusReceiver the receiver 
     *  @return a <code> SyllabusNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> syllabusReceiver </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSyllabusNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSyllabusNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.syllabus.SyllabusNotificationSession getSyllabusNotificationSession(org.osid.course.syllabus.SyllabusReceiver syllabusReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the syllabus 
     *  notification service for the given course catalog. 
     *
     *  @param  syllabusReceiver the receiver 
     *  @param  courseCatalogId the <code> Id </code> of the <code> 
     *          CourseCatalog </code> 
     *  @return a <code> SyllabusNotificationSession </code> 
     *  @throws org.osid.NotFoundException no <code> CourseCatalog </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> syllabusReceiver </code> 
     *          or <code> courseCatalogId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSyllabusNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSyllabusNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.course.syllabus.SyllabusNotificationSession getSyllabusNotificationSessionForCourseCatalog(org.osid.course.syllabus.SyllabusReceiver syllabusReceiver, 
                                                                                                               org.osid.id.Id courseCatalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving syllabus to course catalog mappings. 
     *
     *  @return a <code> SyllabusCourseCatalogSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSyllabusCourseCatalog() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSyllabusCourseCatalog() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.syllabus.SyllabusCourseCatalogSession getSyllabusCourseCatalogSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning syllabus to course catalog mappings. 
     *
     *  @return a <code> SyllabusCourseCatalogAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSyllabusCourseCatalogAssignment() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSyllabusCourseCatalogAssignment() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.course.syllabus.SyllabusCourseCatalogAssignmentSession getSyllabusCourseCatalogAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session associated with the syllabus smart course catalog for 
     *  the given course catalog. 
     *
     *  @param  courseCatalogId the <code> Id </code> of the course catalog 
     *  @return a <code> SyllabusSmartCourseCatalogSession </code> 
     *  @throws org.osid.NotFoundException <code> courseCatalogId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSyllabusSmartCourseCatalog() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSyllabusSmartCourseCatalog() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.course.syllabus.SyllabusSmartCourseCatalogSession getSyllabusSmartCourseCatalogSession(org.osid.id.Id courseCatalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the module lookup 
     *  service. 
     *
     *  @return a <code> ModuleLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsModuleLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsModuleLookup() </code> is <code> true. </code> 
     */

    public org.osid.course.syllabus.ModuleLookupSession getModuleLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the module lookup 
     *  service for the given course catalog. 
     *
     *  @param  courseCatalogId the <code> Id </code> of the <code> 
     *          CourseCatalog </code> 
     *  @return a <code> ModuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> CourseCatalog </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsModuleLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsModuleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.course.syllabus.ModuleLookupSession getModuleLookupSessionForCourseCatalog(org.osid.id.Id courseCatalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the module query 
     *  service. 
     *
     *  @return a <code> ModuleQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsModuleQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsModuleQuery() </code> is <code> true. </code> 
     */

    public org.osid.course.syllabus.ModuleQuerySession getModuleQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the module query 
     *  service for the given course catalog. 
     *
     *  @param  courseCatalogId the <code> Id </code> of the <code> 
     *          CourseCatalog </code> 
     *  @return a <code> ModuleQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> CourseCatalog </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsModuleQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsModuleQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.course.syllabus.ModuleQuerySession getModuleQuerySessionForCourseCatalog(org.osid.id.Id courseCatalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the module search 
     *  service. 
     *
     *  @return a <code> ModuleSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsModuleSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsModuleSearch() </code> is <code> true. </code> 
     */

    public org.osid.course.syllabus.ModuleSearchSession getModuleSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the module search 
     *  service for the given course catalog. 
     *
     *  @param  courseCatalogId the <code> Id </code> of the <code> 
     *          CourseCatalog </code> 
     *  @return a <code> ModuleSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> CourseCatalog </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsModuleSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsModuleSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.course.syllabus.ModuleSearchSession getModuleSearchSessionForCourseCatalog(org.osid.id.Id courseCatalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the module 
     *  administration service. 
     *
     *  @return a <code> ModuleAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsModuleAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsModuleAdmin() </code> is <code> true. </code> 
     */

    public org.osid.course.syllabus.ModuleAdminSession getModuleAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the module 
     *  administration service for the given course catalog. 
     *
     *  @param  courseCatalogId the <code> Id </code> of the <code> 
     *          CourseCatalog </code> 
     *  @return a <code> ModuleAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> CourseCatalog </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsModuleAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsModuleAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.course.syllabus.ModuleAdminSession getModuleAdminSessionForCourseCatalog(org.osid.id.Id courseCatalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the module 
     *  notification service. 
     *
     *  @param  moduleReceiver the receiver 
     *  @return a <code> ModuleNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> moduleReceiver </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsModuleNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsModuleNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.syllabus.ModuleNotificationSession getModuleNotificationSession(org.osid.course.syllabus.ModuleReceiver moduleReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the module 
     *  notification service for the given course catalog. 
     *
     *  @param  moduleReceiver the receiver 
     *  @param  courseCatalogId the <code> Id </code> of the <code> 
     *          CourseCatalog </code> 
     *  @return a <code> ModuleNotificationSession </code> 
     *  @throws org.osid.NotFoundException no <code> CourseCatalog </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> moduleReceiver </code> 
     *          or <code> courseCatalogId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsModuleNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsModuleNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.course.syllabus.ModuleNotificationSession getModuleNotificationSessionForCourseCatalog(org.osid.course.syllabus.ModuleReceiver moduleReceiver, 
                                                                                                           org.osid.id.Id courseCatalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving module to course catalog mappings. 
     *
     *  @return a <code> ModuleCourseCatalogSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsModuleCourseCatalog() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsModuleCourseCatalog() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.syllabus.ModuleCourseCatalogSession getModuleCourseCatalogSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning module to course catalog mappings. 
     *
     *  @return a <code> ModuleCourseCatalogAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsModuleCourseCatalogAssignment() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsModuleCourseCatalogAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.course.syllabus.ModuleCourseCatalogAssignmentSession getModuleCourseCatalogAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session associated with the module smart course catalog for 
     *  the given course catalog. 
     *
     *  @param  courseCatalogId the <code> Id </code> of the course catalog 
     *  @return a <code> ModuleSmartCourseCatalogSession </code> 
     *  @throws org.osid.NotFoundException <code> courseCatalogId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsModuleSmartCourseCatalog() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsModuleSmartCourseCatalog() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.syllabus.ModuleSmartCourseCatalogSession getModuleSmartCourseCatalogSession(org.osid.id.Id courseCatalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the docet lookup 
     *  service. 
     *
     *  @return a <code> DocetLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsDocetLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDocetLookup() </code> is <code> true. </code> 
     */

    public org.osid.course.syllabus.DocetLookupSession getDocetLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the docet lookup 
     *  service for the given course catalog. 
     *
     *  @param  courseCatalogId the <code> Id </code> of the <code> Docet 
     *          </code> 
     *  @return a <code> DocetLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> CourseCatalog </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsDocetLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDocetLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.course.syllabus.DocetLookupSession getDocetLookupSessionForCourseCatalog(org.osid.id.Id courseCatalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the docet query 
     *  service. 
     *
     *  @return a <code> DocetQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsDocetQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDocetQuery() </code> is <code> true. </code> 
     */

    public org.osid.course.syllabus.DocetQuerySession getDocetQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the docet query 
     *  service for the given course catalog. 
     *
     *  @param  courseCatalogId the <code> Id </code> of the <code> Docet 
     *          </code> 
     *  @return a <code> DocetQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> CourseCatalog </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsDocetQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDocetQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.course.syllabus.DocetQuerySession getDocetQuerySessionForCourseCatalog(org.osid.id.Id courseCatalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the docet search 
     *  service. 
     *
     *  @return a <code> DocetSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsDocetSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDocetSearch() </code> is <code> true. </code> 
     */

    public org.osid.course.syllabus.DocetSearchSession getDocetSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the docet search 
     *  service for the given course catalog. 
     *
     *  @param  courseCatalogId the <code> Id </code> of the <code> Docet 
     *          </code> 
     *  @return a <code> DocetSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> CourseCatalog </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsDocetSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDocetSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.course.syllabus.DocetSearchSession getDocetSearchSessionForCourseCatalog(org.osid.id.Id courseCatalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the docet 
     *  administrative service. 
     *
     *  @return a <code> DocetAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsDocetAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDocetAdmin() </code> is <code> true. </code> 
     */

    public org.osid.course.syllabus.DocetAdminSession getDocetAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the docet 
     *  administrative service for the given course catalog. 
     *
     *  @param  courseCatalogId the <code> Id </code> of the <code> Docet 
     *          </code> 
     *  @return a <code> DocetAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> CourseCatalog </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsDocetAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDocetAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.course.syllabus.DocetAdminSession getDocetAdminSessionForCourseCatalog(org.osid.id.Id courseCatalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the docet 
     *  notification service. 
     *
     *  @param  docetReceiver the receiver 
     *  @return a <code> DocetNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> docetReceiver </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDocetNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDocetNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.syllabus.DocetNotificationSession getDocetNotificationSession(org.osid.course.syllabus.DocetReceiver docetReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the docet 
     *  notification service for the given course catalog. 
     *
     *  @param  docetReceiver the receiver 
     *  @param  courseCatalogId the <code> Id </code> of the <code> 
     *          CourseCatalog </code> 
     *  @return a <code> DocetNotificationSession </code> 
     *  @throws org.osid.NotFoundException no <code> CourseCatalog </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> docetReceiver </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDocetNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDocetNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.course.syllabus.DocetNotificationSession getDocetNotificationSessionForCourseCatalog(org.osid.course.syllabus.DocetReceiver docetReceiver, 
                                                                                                         org.osid.id.Id courseCatalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving docet to course catalog mappings. 
     *
     *  @return a <code> DocetCourseCatalogSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDocetCourseCatalog() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDocetCourseCatalog() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.syllabus.DocetCourseCatalogSession getDocetCourseCatalogSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning docet to course catalog mappings. 
     *
     *  @return a <code> DocetCourseCatalogAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDocetCourseCatalogAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDocetCourseCatalogAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.course.syllabus.DocetCourseCatalogAssignmentSession getDocetCourseCatalogAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session associated with the docet smart course catalog for 
     *  the given course catalog. 
     *
     *  @param  courseCatalogId the <code> Id </code> of the course catalog 
     *  @return a <code> DocetSmartCourseCatalogSession </code> 
     *  @throws org.osid.NotFoundException <code> courseCatalogId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDocetSmartCourseCatalog() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDocetSmartCourseCatalog() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.syllabus.DocetSmartCourseCatalogSession getDocetSmartCourseCatalogSession(org.osid.id.Id courseCatalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets a <code> CourseSyllabusBatchManager. </code> 
     *
     *  @return a <code> CourseSyllabusBatchManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCourseSyllabusBatch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCourseSyllabusBatchj() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.syllabus.batch.CourseSyllabusBatchManager getCourseSyllabusBatchManager()
        throws org.osid.OperationFailedException;
}
