//
// org.osid.course.syllabus.DocetAdminSession
//
//     The OSID Java specification for org.osid.course.syllabus.DocetAdminSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.syllabus;


/**
 *  <p>This session creates, updates, and deletes <code> Docets. </code> The 
 *  data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Docet, </code> a <code> DocetForm </code> is requested using <code> 
 *  getDocetFormForCreate() </code> specifying the desired record <code> Types 
 *  </code> or none if no record <code> Types </code> are needed. The returned 
 *  <code> DocetForm </code> will indicate that it is to be used with a create 
 *  operation and can be used to examine metdata or validate data prior to 
 *  creation. Once the <code> DocetForm </code> is submiited to a create 
 *  operation, it cannot be reused with another create operation unless the 
 *  first operation was unsuccessful. Each <code> DocetForm </code> 
 *  corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> DocetForms </code> are requested to the <code> 
 *  DocetForm </code> <code> Id </code> that is to be updated using <code> 
 *  geDocetFormForUpdate(). </code> Similarly, the <code> DocetForm </code> 
 *  has metadata about the data that can be updated and it can perform 
 *  validation before submitting the update. The <code> DocetForm </code> can 
 *  only be used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Docet. </code> To unmap a <code> 
 *  Docet </code> from the current <code> CourseCatalog, </code> the <code> 
 *  DocetCourseCatalogAssignmentSession </code> should be used. These delete 
 *  operations attempt to remove the <code> Docet </code> itself thus removing 
 *  it from all known <code> CourseCatalog </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface DocetAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> CourseCatalog </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> CourseCatalog Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCourseCatalogId();


    /**
     *  Gets the <code> CourseCatalog </code> associated with this session. 
     *
     *  @return the course catalog 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseCatalog getCourseCatalog()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> Docets. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating an <code> Docet </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not wish to offer create operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Docet </code> creation is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateDocets();


    /**
     *  Tests if this user can create a single <code> Docet </code> using the 
     *  desired record types. While <code> 
     *  CourseSyllabusManager.getDocetRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> Docet. </code> Providing 
     *  an empty array tests if an <code> Docet </code> can be created with no 
     *  records. 
     *
     *  @param  docetRecordTypes array of docet record types 
     *  @return <code> true </code> if <code> Docet </code> creation using the 
     *          specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> docetRecordTypes </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateDocetWithRecordTypes(org.osid.type.Type[] docetRecordTypes);


    /**
     *  Gets the docet form for creating new docets. A new form should be 
     *  requested for each create transaction. 
     *
     *  @param  moduleId a module <code> Id </code> 
     *  @param  activityUnitId an activity unit <code> Id </code> 
     *  @param  docetRecordTypes array of docet record types 
     *  @return the docet form 
     *  @throws org.osid.NotFoundException <code> moduleId </code> or <code> 
     *          activityUnitId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> moduleId, 
     *          acticvtyUnitId, </code> or <code> docetRecordTypes </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.syllabus.DocetForm getDocetFormForCreate(org.osid.id.Id moduleId, 
                                                                    org.osid.id.Id activityUnitId, 
                                                                    org.osid.type.Type[] docetRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Docet. </code> 
     *
     *  @param  docetForm the form for this <code> Docet </code> 
     *  @return the new <code> Docet </code> 
     *  @throws org.osid.IllegalStateException <code> docetForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> docetForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> docetForm </code> did not 
     *          originate from <code> getDocetFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.syllabus.Docet createDocet(org.osid.course.syllabus.DocetForm docetForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Docets. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating an <code> Docet </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not wish to offer update operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Docet </code> modification is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateDocets();


    /**
     *  Gets the docet form for updating an existing docet. A new docet form 
     *  should be requested for each update transaction. 
     *
     *  @param  docetId the <code> Id </code> of the <code> Docet </code> 
     *  @return the docet form 
     *  @throws org.osid.NotFoundException <code> docetId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> docetId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.syllabus.DocetForm getDocetFormForUpdate(org.osid.id.Id docetId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing docet. 
     *
     *  @param  docetForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> docetForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> docetForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> docetForm </code> did not 
     *          originate from <code> getDocetFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateDocet(org.osid.course.syllabus.DocetForm docetForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> Docets </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting an <code> Docet </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not wish to offer delete operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Docet </code> deletion is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteDocets();


    /**
     *  Deletes an <code> Docet. </code> 
     *
     *  @param  docetId the <code> Id </code> of the <code> Docet </code> to 
     *          remove 
     *  @throws org.osid.NotFoundException <code> docetId </code> not found 
     *  @throws org.osid.NullArgumentException <code> docetId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteDocet(org.osid.id.Id docetId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Docets. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Docet </code> aliasing is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageDocetAliases();


    /**
     *  Adds an <code> Id </code> to an <code> Docet </code> for the purpose 
     *  of creating compatibility. The primary <code> Id </code> of the <code> 
     *  Docet </code> is determined by the provider. The new <code> Id </code> 
     *  performs as an alias to the primary <code> Id. </code> If the alias is 
     *  a pointer to another docet, it is reassigned to the given docet <code> 
     *  Id. </code> 
     *
     *  @param  docetId the <code> Id </code> of an <code> Docet </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> docetId </code> not found 
     *  @throws org.osid.NullArgumentException <code> docetId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasDocet(org.osid.id.Id docetId, org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> Docets. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known changing an alias will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Docet </code> ordering is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceDocets();


    /**
     *  Reorders docets in a module by moving the specified docet in front of 
     *  a reference docet. 
     *
     *  @param  docetId the <code> Id </code> of a <code> Docet </code> 
     *  @param  moduleId the <code> Id </code> of a <code> Module </code> 
     *  @param  referenceId the reference docet <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> docetId, moduleId, </code> 
     *          or <code> referenceId </code> not found or, <code> docetId 
     *          </code> or <code> referenceId </code> not related to <code> 
     *          moduleId </code> 
     *  @throws org.osid.NullArgumentException <code> docetId, moduleId, 
     *          </code> or <code> referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveDocetAhead(org.osid.id.Id docetId, org.osid.id.Id moduleId, 
                               org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders docets in a module by moving the specified docet behind a 
     *  reference docet. 
     *
     *  @param  docetId the <code> Id </code> of a <code> Docet </code> 
     *  @param  moduleId the <code> Id </code> of a <code> Module </code> 
     *  @param  referenceId the reference docet <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> docetId, moduleId, </code> 
     *          or <code> referenceId </code> not found or, <code> docetId 
     *          </code> or <code> referenceId </code> not related to <code> 
     *          moduleId </code> 
     *  @throws org.osid.NullArgumentException <code> docetId, moduleId 
     *          </code> or <code> referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveDocetBehind(org.osid.id.Id docetId, 
                                org.osid.id.Id moduleId, 
                                org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of docets in a module. 
     *
     *  @param  docetIds the <code> Ids </code> for a set of <code> Docets 
     *          </code> 
     *  @param  moduleId the <code> Id </code> of a <code> Module </code> 
     *  @throws org.osid.NotFoundException <code> docetId </code> not found 
     *          or, a <code> docetId </code> not related to <code> moduleId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> docetIds </code> or 
     *          <code> moduleId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderDocets(org.osid.id.Id[] docetIds, org.osid.id.Id moduleId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
