//
// org.osid.course.syllabus.DocetLookupSession
//
//     The OSID Java specification for org.osid.course.syllabus.DocetLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.syllabus;


/**
 *  <p>This session provides methods for retrieving <code> Docet </code> 
 *  objects. The <code> Docet </code> represents a collection of syllabi. </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete view or is an error condition 
 *      </li> 
 *      <li> isolated course catalog view: All docet methods in this session 
 *      operate, retrieve and pertain to docetsdefined explicitly in the 
 *      current course catalog. Using an isolated view is useful for managing 
 *      docetswith the <code> DocetAdminSession. </code> </li> 
 *      <li> federated course catalog view: All docet lookup methods in this 
 *      session operate, retrieve and pertain to all docetsdefined in this 
 *      course catalog and any other course catalogs implicitly available in 
 *      this course catalog through course catalog inheritence. </li> 
 *      <li> effective docet view: All docet lookup methods return docets 
 *      where the current date falls in between the effective dates inclusive. 
 *      </li> 
 *      <li> any effective docet view: Docets of any effective date are 
 *      returned from methods. </li> 
 *  </ul>
 *  
 */

public interface DocetLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> CourseCatalog </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> CourseCatalog Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCourseCatalogId();


    /**
     *  Gets the <code> CourseCatalog </code> associated with this session. 
     *
     *  @return the course catalog 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseCatalog getCourseCatalog()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Docet </code> lookups. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not offer lookup operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupDocets();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeDocetView();


    /**
     *  A complete view of the <code> Docet </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryDocetView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include docetsin course catalogs which are children of this course 
     *  catalog in the course catalog hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCourseCatalogView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this course catalog only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCourseCatalogView();


    /**
     *  Only docets whose effective dates are current are returned by methods 
     *  in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useEffectiveDocetView();


    /**
     *  All docets of any effective dates are returned by all methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyEffectiveDocetView();


    /**
     *  Gets the <code> Docet </code> specified by its <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Docet </code> may have a different <code> Id </code> than requested, 
     *  such as the case where a duplicate <code> Id </code> was assigned to 
     *  an <code> Docet </code> and retained for compatibility. 
     *  
     *  In effective mode, docets are returned that are currently effective. 
     *  In any effective mode, effective docets and those currently expired 
     *  are returned. 
     *
     *  @param  docetId <code> Id </code> of the <code> Docet </code> 
     *  @return the docet 
     *  @throws org.osid.NotFoundException <code> docetId </code> not found 
     *  @throws org.osid.NullArgumentException <code> docetId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.course.syllabus.Docet getDocet(org.osid.id.Id docetId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> DocetList </code> corresponding to the given <code> 
     *  IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  docetsspecified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Docets </code> may be omitted from the list and 
     *  may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In effective mode, docets are returned that are currently effective. 
     *  In any effective mode, effective docets and those currently expired 
     *  are returned. 
     *
     *  @param  docetIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Docet </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> docetIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.syllabus.DocetList getDocetsByIds(org.osid.id.IdList docetIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> DocetList </code> corresponding to the given docet 
     *  genus <code> Type </code> which does not include docetsof genus types 
     *  derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  docetsor an error results. Otherwise, the returned list may contain 
     *  only those docets that are accessible through this session. 
     *  
     *  In effective mode, docets are returned that are currently effective. 
     *  In any effective mode, effective docets and those currently expired 
     *  are returned. 
     *
     *  @param  docetGenusType a docet genus type 
     *  @return the returned <code> Docet </code> list 
     *  @throws org.osid.NullArgumentException <code> docetGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.syllabus.DocetList getDocetsByGenusType(org.osid.type.Type docetGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> DocetList </code> corresponding to the given docet 
     *  genus <code> Type </code> and include any additional docetswith genus 
     *  types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  docetsor an error results. Otherwise, the returned list may contain 
     *  only those docets that are accessible through this session. 
     *  
     *  In effective mode, docets are returned that are currently effective. 
     *  In any effective mode, effective docets and those currently expired 
     *  are returned. 
     *
     *  @param  docetGenusType a docet genus type 
     *  @return the returned <code> Docet </code> list 
     *  @throws org.osid.NullArgumentException <code> docetGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.syllabus.DocetList getDocetsByParentGenusType(org.osid.type.Type docetGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> DocetList </code> containing the given docet record 
     *  <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  docetsor an error results. Otherwise, the returned list may contain 
     *  only those docets that are accessible through this session. 
     *  
     *  In effective mode, docets are returned that are currently effective. 
     *  In any effective mode, effective docets and those currently expired 
     *  are returned. 
     *
     *  @param  docetRecordType a docet record type 
     *  @return the returned <code> Docet </code> list 
     *  @throws org.osid.NullArgumentException <code> docetRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.syllabus.DocetList getDocetsByRecordType(org.osid.type.Type docetRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> DocetList </code> effective sduring the entire given 
     *  date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known docetsor an 
     *  error results. Otherwise, the returned list may contain only those 
     *  docets that are accessible through this session. 
     *  
     *  In effective mode, docets are returned that are currently effective. 
     *  In any effective mode, effective docets and those currently expired 
     *  are returned. 
     *
     *  @param  from s atsrting date 
     *  @param  to an ending date 
     *  @return the returned <code> Docet </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.syllabus.DocetList getDocetsOnDate(org.osid.calendaring.DateTime from, 
                                                              org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> DocetList </code> for the given module <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  docetsor an error results. Otherwise, the returned list may contain 
     *  only those docets that are accessible through this session. 
     *  
     *  In effective mode, docets are returned that are currently effective. 
     *  In any effective mode, effective docets and those currently expired 
     *  are returned. 
     *
     *  @param  moduleId a module <code> Id </code> 
     *  @return the returned <code> Docet </code> list 
     *  @throws org.osid.NullArgumentException <code> moduleId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.syllabus.DocetList getDocetsForModule(org.osid.id.Id moduleId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> DocetList </code> for a module effective during the 
     *  entire given date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known docetsor an 
     *  error results. Otherwise, the returned list may contain only those 
     *  docets that are accessible through this session. 
     *  
     *  In effective mode, docets are returned that are currently effective. 
     *  In any effective mode, effective docets and those currently expired 
     *  are returned. 
     *
     *  @param  moduleId a module <code> Id </code> 
     *  @param  from s atsrting date 
     *  @param  to an ending date 
     *  @return the returned <code> Docet </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> moduleId, from </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.syllabus.DocetList getDocetsForModuleOnDate(org.osid.id.Id moduleId, 
                                                                       org.osid.calendaring.DateTime from, 
                                                                       org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> DocetList </code> for the given activity unit <code> 
     *  Id. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  docetsor an error results. Otherwise, the returned list may contain 
     *  only those docets that are accessible through this session. 
     *  
     *  In effective mode, docets are returned that are currently effective. 
     *  In any effective mode, effective docets and those currently expired 
     *  are returned. 
     *
     *  @param  activityUnitId an activity unit <code> Id </code> 
     *  @return the returned <code> Docet </code> list 
     *  @throws org.osid.NullArgumentException <code> activityUnitId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.syllabus.DocetList getDocetsForActivityUnit(org.osid.id.Id activityUnitId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> DocetList </code> for an activity unit effective 
     *  sduring the entire given date range inclusive but not confined to the 
     *  date range. 
     *  
     *  In plenary mode, the returned list contains all known docetsor an 
     *  error results. Otherwise, the returned list may contain only those 
     *  docets that are accessible through this session. 
     *  
     *  In effective mode, docets are returned that are currently effective. 
     *  In any effective mode, effective docets and those currently expired 
     *  are returned. 
     *
     *  @param  activityUnitId an activity unit <code> Id </code> 
     *  @param  from s atsrting date 
     *  @param  to an ending date 
     *  @return the returned <code> Docet </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> activityUnitId, from, 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.syllabus.DocetList getDocetsForActivityUnitOnDate(org.osid.id.Id activityUnitId, 
                                                                             org.osid.calendaring.DateTime from, 
                                                                             org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> DocetList </code> for the given module and activity 
     *  unit <code> . </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  docetsor an error results. Otherwise, the returned list may contain 
     *  only those docets that are accessible through this session. 
     *  
     *  In effective mode, docets are returned that are currently effective. 
     *  In any effective mode, effective docets and those currently expired 
     *  are returned. 
     *
     *  @param  moduleId a module <code> Id </code> 
     *  @param  activityUnitId an activity unit <code> Id </code> 
     *  @return the returned <code> Docet </code> list 
     *  @throws org.osid.NullArgumentException <code> moduleId </code> or 
     *          <code> activityUnitId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.syllabus.DocetList getDocetsForModuleAndActivityUnit(org.osid.id.Id moduleId, 
                                                                                org.osid.id.Id activityUnitId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> DocetList </code> for a module and activity unit 
     *  effective during the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known docetsor an 
     *  error results. Otherwise, the returned list may contain only those 
     *  docets that are accessible through this session. 
     *  
     *  In effective mode, docets are returned that are currently effective. 
     *  In any effective mode, effective docets and those currently expired 
     *  are returned. 
     *
     *  @param  moduleId a module <code> Id </code> 
     *  @param  activityUnitId an activity unit <code> Id </code> 
     *  @param  from s atsrting date 
     *  @param  to an ending date 
     *  @return the returned <code> Docet </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> moduleId, 
     *          activityUnitId, from, </code> or <code> to </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.syllabus.DocetList getDocetsForModuleAndActivityUnitOnDate(org.osid.id.Id moduleId, 
                                                                                      org.osid.id.Id activityUnitId, 
                                                                                      org.osid.calendaring.DateTime from, 
                                                                                      org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Docets. </code> 
     *  
     *  In plenary mode, the returned list contains all known docetsor an 
     *  error results. Otherwise, the returned list may contain only those 
     *  docets that are accessible through this session. 
     *  
     *  In effective mode, docets are returned that are currently effective. 
     *  In any effective mode, effective docets and those currently expired 
     *  are returned. 
     *
     *  @return a list of <code> Docets </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.syllabus.DocetList getDocets()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
