//
// org.osid.course.syllabus.DocetQueryInspector
//
//     The OSID Java specification for org.osid.course.syllabus.DocetQueryInspector.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.syllabus;


/**
 *  <p>This is the query inspector for searching for docets. Each method 
 *  specifies an <code> AND </code> term while multiple invocations of the 
 *  same method produce a nested <code> OR. </code> </p>
 */

public interface DocetQueryInspector
    extends org.osid.OsidRelationshipQueryInspector {


    /**
     *  Gets the module <code> Id </code> terms. 
     *
     *  @return the module <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getModuleIdTerms();


    /**
     *  Gets the module terms. 
     *
     *  @return the module terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.syllabus.ModuleQueryInspector[] getModuleTerms();


    /**
     *  Gets the activity unit <code> Id </code> terms. 
     *
     *  @return the activity unit <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getActivityUnitIdTerms();


    /**
     *  Gets the activity unit terms. 
     *
     *  @return the activity unit terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.ActivityUnitQueryInspector[] getActivityUnitTerms();


    /**
     *  Gets the objective <code> Id </code> query terms. 
     *
     *  @return the objective <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getLearningObjectiveIdTerms();


    /**
     *  Gets the objective query terms. 
     *
     *  @return the objective terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveQueryInspector[] getLearningObjectiveTerms();


    /**
     *  Gets the in class query terms. 
     *
     *  @return the in class query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.BooleanTerm[] getInClassTerms();


    /**
     *  Gets the duration query terms. 
     *
     *  @return the duration query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DurationRangeTerm[] getDurationTerms();


    /**
     *  Gets the asset <code> Id </code> query terms. 
     *
     *  @return the asset <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getAssetIdTerms();


    /**
     *  Gets the asset query terms. 
     *
     *  @return the asset terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.AssetQueryInspector[] getAssetTerms();


    /**
     *  Gets the asset <code> Id </code> query terms. 
     *
     *  @return the asset <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getAssessmentIdTerms();


    /**
     *  Gets the asset query terms. 
     *
     *  @return the asset terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.AssetQueryInspector[] getAssessmentTerms();


    /**
     *  Gets the course catalog <code> Id </code> terms. 
     *
     *  @return the course catalog <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getCourseCatalogIdTerms();


    /**
     *  Gets the course catalog terms. 
     *
     *  @return the course catalog terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseCatalogQueryInspector[] getCourseCatalogTerms();


    /**
     *  Gets the query inspector record corresponding to the given <code> 
     *  Docet </code> record <code> Type. </code> 
     *
     *  @param  docetRecordType a docet record type 
     *  @return the docet query inspector record 
     *  @throws org.osid.NullArgumentException <code> docetRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(docetRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.syllabus.records.DocetQueryInspectorRecord getDocetQueryInspectorRecord(org.osid.type.Type docetRecordType)
        throws org.osid.OperationFailedException;
}
