//
// org.osid.course.syllabus.ModuleSmartCourseCatalogSession
//
//     The OSID Java specification for org.osid.course.syllabus.ModuleSmartCourseCatalogSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.syllabus;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. A <code> ModuleQuery </code> can be retrieved from this session 
 *  and mapped to this <code> CourseCatalog </code> to create a virtual 
 *  collection of <code> Modules. </code> The docetsmay be sequenced using the 
 *  <code> ModuleSearchOrder </code> from this session. </p> 
 *  
 *  <p> This <code> CourseCatalog </code> has a default query that matches any 
 *  module and a default search order that specifies no sequencing. The 
 *  queries may be examined using a <code> ModuleQueryInspector. </code> The 
 *  query may be modified by converting the inspector back to a <code> 
 *  ModuleQuery. </code> </p>
 */

public interface ModuleSmartCourseCatalogSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> CourseCatalog </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> CourseCatalog Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCourseCatalogId();


    /**
     *  Gets the <code> CourseCatalog </code> associated with this session. 
     *
     *  @return the <code> CourseCatalog </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseCatalog getCourseCatalog()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart course catalogs. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known methods in this session will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart course catalog management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartCourseCatalogs();


    /**
     *  Gets a module query. 
     *
     *  @return the module query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.syllabus.ModuleQuery getModuleQuery();


    /**
     *  Gets a module search order. 
     *
     *  @return the module search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.syllabus.ModuleSearchOrder getModuleSearchOrder();


    /**
     *  Applies a module query to this course catalog. 
     *
     *  @param  moduleQuery the module query 
     *  @throws org.osid.NullArgumentException <code> moduleQuery </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> moduleQuery </code> not 
     *          of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyModuleQuery(org.osid.course.syllabus.ModuleQuery moduleQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a module query inspector for this course catalog. 
     *
     *  @return the module query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.syllabus.ModuleQueryInspector inspectModuleQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a module search order to this course catalog. 
     *
     *  @param  moduleSearchOrder the module search order 
     *  @throws org.osid.NullArgumentException <code> moduleSearchOrder 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> moduleSearchOrder </code> 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyModuleSequencing(org.osid.course.syllabus.ModuleSearchOrder moduleSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a module query from an inspector. 
     *
     *  @param  moduleQueryInspector a query inspector 
     *  @return the module query 
     *  @throws org.osid.NullArgumentException <code> moduleQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> moduleQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.syllabus.ModuleQuery getModuleQueryFromInspector(org.osid.course.syllabus.ModuleQueryInspector moduleQueryInspector);
}
