//
// org.osid.course.syllabus.batch.ModuleBatchAdminSession
//
//     The OSID Java specification for org.osid.course.syllabus.batch.ModuleBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.syllabus.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Modules </code> in 
 *  bulk. The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Module, </code> a <code> ModuleForm </code> is requested using <code> 
 *  getModuleFormsForCreate() </code> specifying the desired syllabus and 
 *  record <code> Types </code> or none if no record <code> Types </code> are 
 *  needed. Each of the returned <code> ModuleForms </code> will indicate that 
 *  it is to be used with a create operation and can be used to examine 
 *  metdata or validate data prior to creation. Once a <code> ModuleForm 
 *  </code> is submiited to a create operation, it cannot be reused with 
 *  another create operation unless the first operation was unsuccessful. Each 
 *  <code> ModuleForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> ModuleForm </code> returned from <code> 
 *  getModuleFormsForCreate() </code> may be linked to the originating request 
 *  through the peer <code> Ids </code> of the <code> ModuleForm. </code> In 
 *  the case where there may be duplicates, any <code> ModuletForm </code> of 
 *  the same peer <code> Ids </code> may be used for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> ModuleForms </code> are submitted for create, a 
 *  <code> CreateResponse </code> is returned for each <code> ModuleForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire create operation are returned from <code> createModules(), 
 *  </code> errors specific to an individual <code> ModuleForm </code> are 
 *  indicated in the corresponding <code> CreateResponse. </code> <code> 
 *  CreateResponses </code> may be linked to the originating <code> ModuleForm 
 *  </code> through the <code> ModuleForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> ModuleForms </code> are requested to the <code> 
 *  Module </code> <code> Id </code> that is to be updated using <code> 
 *  getModuleFormsForUpdate() </code> where the reference <code> Id </code> in 
 *  the <code> ModuleForm </code> may be used to link the request. Similarly, 
 *  the <code> ModuleForm </code> has metadata about the data that can be 
 *  updated and it can perform validation before submitting the update. The 
 *  <code> ModuleForm </code> can only be used once for a successful update 
 *  and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> ModuleForms </code> are submitted for update, 
 *  an <code> UpdateResponse </code> is returned for each <code> ModuleForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire update operation are returned from <code> updateModuleForms(), 
 *  </code> errors specific to an individual <code> ModuleForm </code> are 
 *  indicated in the corresponding <code> UpdateResponse. </code> <code> 
 *  UpdateResponses </code> may be linked to the originating <code> ModuleForm 
 *  </code> through the <code> ModuleForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> Modules </code> in bulk. To unmap 
 *  s <code> Module </code> from the current <code> CourseCatalog, </code> the 
 *  <code> ModuleCourseCatalogAssignmentSession </code> should be used. These 
 *  delete operations attempt to remove the <code> Module </code> itself thus 
 *  removing it from all known <code> CourseCatalog </code> catalogs. Bulk 
 *  delete operations return the results in <code> DeleteResponses. </code> 
 *  </p>
 */

public interface ModuleBatchAdminSession
    extends org.osid.course.syllabus.ModuleAdminSession {


    /**
     *  Gets the module forms for creating a bunch of new modules. A new form 
     *  isreturned for each supplied syllabus. 
     *
     *  @param  syllabusIds a list of syllabus <code> Ids </code> 
     *  @param  moduleRecordTypes array of module record types to be included 
     *          in each create operation or an empty list if none 
     *  @return the module forms 
     *  @throws org.osid.NotFoundException a <code> syllabusId </code> is no 
     *          found 
     *  @throws org.osid.NullArgumentException <code> syllabusIds </code> or 
     *          <code> moduleRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.syllabus.batch.ModuleBatchFormList getModuleFormsForCreate(org.osid.id.IdList syllabusIds, 
                                                                                      org.osid.type.Type[] moduleRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Modules. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  moduleForms the module forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> moduleForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createModules(org.osid.course.syllabus.batch.ModuleBatchFormList moduleForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the module forms for updating an existing set of modules. A new 
     *  module form should be requested for each update transaction. 
     *
     *  @param  moduleIds the <code> Ids </code> of the <code> Module </code> 
     *  @return the module form 
     *  @throws org.osid.NotFoundException a <code> moduleId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> moduleIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.syllabus.batch.ModuleBatchFormList getModuleFormsForUpdate(org.osid.id.IdList moduleIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing modules. This method returns an error if the entire 
     *  operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  moduleForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> moduleForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateModules(org.osid.course.syllabus.batch.ModuleBatchFormList moduleForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Modules </code> in this <code> CourseCatalog 
     *  </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllModules()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes modules for the given <code> Ids. </code> 
     *
     *  @param  moduleIds the <code> Ids </code> of the modules to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> moduleIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteModules(org.osid.id.IdList moduleIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes modules for the given syllabus. 
     *
     *  @param  syllabusId the <code> Id </code> of a syllabus 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> syllabusId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteModulesForSyllabus(org.osid.id.Id syllabusId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Module </code> for the purpose 
     *  of creating compatibility. The primary <code> Id </code> of the <code> 
     *  Module </code> is determined by the provider. The new <code> Id 
     *  </code> is an alias to the primary <code> Id. </code> If the alias is 
     *  a pointer to another module, it is reassigned to the given module 
     *  <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasModules(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
