//
// org.osid.course.syllabus.batch.SyllabusBatchAdminSession
//
//     The OSID Java specification for org.osid.course.syllabus.batch.SyllabusBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.syllabus.batch;


/**
 *  <p>This session creates, updates, and deletes Syllabi in bulk. The data 
 *  for create and update is provided by the consumer via the form object. 
 *  OsidForms are requested for each create or update and may not be reused. 
 *  </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a 
 *  Syllabus, a SyllabusForm is requested using getSyllabusFormsForCreate() 
 *  specifying the desired course and record Types or none if no record Types 
 *  are needed. Each of the returned SyllabusForms will indicate that it is to 
 *  be used with a create operation and can be used to examine metdata or 
 *  validate data prior to creation. Once a SyllabusForm is submiited to a 
 *  create operation, it cannot be reused with another create operation unless 
 *  the first operation was unsuccessful. Each SyllabusForm corresponds to an 
 *  attempted transaction. </p> 
 *  
 *  <p> The SyllabusForms returned from getSyllabusFormsForCreate() may be 
 *  linked to the originating request through the peer Ids of the 
 *  SyllabusForm. In the case where there may be duplicates, any SyllabusForm 
 *  of the same peer Ids may be used for a create operation. </p> 
 *  
 *  <p> Once a batch of SyllabusForms are submitted for create, a 
 *  CreateResponse is returned for each SyllabusForm, although the ordering is 
 *  not defined. Only errors that pertain to the entire create operation are 
 *  returned from createSyllabi(), errors specific to an individual 
 *  SyllabusForm are indicated in the corresponding CreateResponse. 
 *  CreateResponses may be linked to the originating SyllabusForm through the 
 *  SyllabusForm Id. </p> 
 *  
 *  <p> For updates, <code> SyllabusForms </code> are requested to the <code> 
 *  Syllabus </code> <code> Id </code> that is to be updated using <code> 
 *  getSyllabusFormsForUpdate() </code> where the reference <code> Id </code> 
 *  in the <code> SyllabusForm </code> may be used to link the request. 
 *  Similarly, the <code> SyllabusForm </code> has metadata about the data 
 *  that can be updated and it can perform validation before submitting the 
 *  update. The <code> SyllabusForm </code> can only be used once for a 
 *  successful update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> SyllabusForms </code> are submitted for update, 
 *  an <code> UpdateResponse </code> is returned for each <code> SyllabusForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire update operation are returned from <code> updateSyllabi(), 
 *  </code> errors specific to an individual <code> SyllabusForm </code> are 
 *  indicated in the corresponding <code> UpdateResponse. </code> <code> 
 *  UpdateResponses </code> may be linked to the originating <code> 
 *  SyllabusForm </code> through the <code> SyllabusForm </code> <code> Id. 
 *  </code> </p> 
 *  
 *  <p> The delete operations delete <code> Syllabi </code> in bulk. To unmap 
 *  a <code> Syllabus </code> from the current <code> CourseCatalog, </code> 
 *  the <code> SyllabusCourseCatalogAssignmentSession </code> should be used. 
 *  These delete operations attempt to remove the <code> Syllabus </code> 
 *  itself thus removing it from all known <code> CourseCatalog </code> 
 *  catalogs. Bulk delete operations return the results in <code> 
 *  DeleteResponses. </code> </p>
 */

public interface SyllabusBatchAdminSession
    extends org.osid.course.syllabus.SyllabusAdminSession {


    /**
     *  Gets the syllabus forms for creating a bunch of new syllabi. A new 
     *  form is returned for each supplied course. 
     *
     *  @param  courseIds a list of course <code> Ids </code> 
     *  @param  syllabusRecordTypes array of syllabus record types to be 
     *          included in each create operation or an empty list if none 
     *  @return the syllabus forms 
     *  @throws org.osid.NotFoundException a <code> courseId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> courseIds </code> or 
     *          <code> syllabusRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.syllabus.batch.SyllabusBatchFormList getSyllabusFormsForCreate(org.osid.id.IdList courseIds, 
                                                                                          org.osid.type.Type[] syllabusRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Syllabi. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  syllabusForms the syllabus forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> syllabusForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createSyllabi(org.osid.course.syllabus.batch.SyllabusBatchFormList syllabusForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the syllabus forms for updating an existing set of syllabi. A new 
     *  syllabus form should be requested for each update transaction. 
     *
     *  @param  syllabusIds the <code> Ids </code> of the <code> Syllabus 
     *          </code> 
     *  @return the syllabus form 
     *  @throws org.osid.NotFoundException a <code> syllabusId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> syllabusIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.syllabus.batch.SyllabusBatchFormList getSyllabusFormsForUpdate(org.osid.id.IdList syllabusIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing syllabi. This method returns an error if the entire 
     *  operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  syllabusForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> syllabusForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateSyllabi(org.osid.course.syllabus.batch.SyllabusBatchFormList syllabusForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Syllabi </code> in this <code> CourseCatalog 
     *  </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllSyllabi()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes syllabi for the given <code> Ids. </code> 
     *
     *  @param  syllabusIds the <code> Ids </code> of the syllabi to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> syllabusIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteSyllabi(org.osid.id.IdList syllabusIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes syllabi for the given course. 
     *
     *  @param  courseId a course <code> Id </code> 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> courseId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteSyllabiForCourse(org.osid.id.Id courseId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Syllabus </code> for the purpose 
     *  of creating compatibility. The primary <code> Id </code> of the <code> 
     *  Syllabus </code> is determined by the provider. The new <code> Id 
     *  </code> is an alias to the primary <code> Id. </code> If the alias is 
     *  a pointer to another syllabus, it is reassigned to the given syllabus 
     *  <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasSyllabi(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
