/**
 * <p>The Open Service Interface Definitions for the org.osid.course.syllabus
 * service.</p>
 * 
 * <p>The Course Syllabus OSID is a service that manages curriculum within a 
 * <code> Course </code> and relating the material to learning <code> 
 * Objectives </code> to create lesson plans. It may be defined very broadly 
 * or at a fine-grained level to facilitate the production of lesson <code> 
 * Plans </code> in the Course Plan OSID. </p> 
 * <h4> Syllabus </h4> 
 * 
 * <p> A <code> Syllabus </code> is an <code> OsidObject </code> representing 
 * the content of a <code> Course. </code> A <code> Course </code> may have 
 * multiple syllabi. </p> 
 * <h4> Module </h4> 
 * 
 * <p> A <code> Module </code> is a major division of a <code> Syllabus. 
 * </code> <code> Modules </code> are <code> OsidGovernators </code> that may 
 * be toggled for inclusion in an overall <code> Syllabus. </code> <code> 
 * Modules </code> are subdivided into <code> Docets. </code> </p> 
 * <h4> Docet </h4> 
 * 
 * <p> A <code> Docet </code> is an <code> OsidRelationship </code> serving as 
 * a piece of content within a Module. A <code> Docet </code> relates to one 
 * or more learning <code> Objectives. </code> The learning <code> Objectives 
 * </code> visible through a <code> Course </code> may be built up using the 
 * Course Syllabus OSID. </p> 
 * 
 * <p> Each <code> Docet </code> may include <code> Assets </code> for 
 * materials serving to instruct this portion of the <code> Course </code> or 
 * <code> Assessments </code> for quizzes and assignments. </p> 
 * 
 * <p> A <code> Docet </code> may be a portion of an activity that is 
 * designated is in or out of class time and an estimated time duration. The 
 * Course Plan OSID can examine the in class <code> Docets </code> and their 
 * durations to understand the schedule of lesson plans through a <code> 
 * CourseOffering </code> in a <code> Term. </code> </p> 
 * 
 * <p> <code> Docets </code> may apply to a subset of <code> ActivityUnits 
 * </code> with a <code> Course </code> . </p> 
 * 
 * <p> Although <code> Docets </code> may be defined at very broad levels 
 * covering multiple learning <code> Objectives </code> and multiple <code> 
 * ActivityUniits </code> with long durations, when managed down to the level 
 * of a single <code> Objective </code> can serve to structure the lesson 
 * plan, homework assignments, and other exercises within a single instance of 
 * an <code> Activity </code> offering. </p> 
 * <h4> CourseCatalog Cataloging </h4> 
 * 
 * <p> <code> Syllabi, </code> <code> Modules, </code> and <code> Docets 
 * </code> can be organized into federateable <code> CourseCatalog </code> 
 * catalogs. </p>
 * 
 * <br/><hr/><br/>
 * 
 * <p>Copyright &copy; 2010 Ingenescus. All Rights Reserved. </p>
 * 
 * <p>This Work is being provided by the copyright holder(s) subject to the 
 * following license. By obtaining, using and/or copying this Work, you agree 
 * that you have read, understand, and will comply with the following terms 
 * and conditions. </p> 
 * 
 * <p> Permission to use, copy and distribute unmodified versions of this 
 * Work, for any purpose, without fee or royalty is hereby granted, provided 
 * that you include the above copyright notices and the terms of this license 
 * on ALL copies of the Work or portions thereof. </p> 
 * 
 * <p> You may modify or create Derivatives of this Work only for your 
 * internal purposes. You shall not distribute or transfer any such Derivative 
 * of this Work to any location or to any third party. For the purposes of 
 * this license, "Derivative" shall mean any derivative of the Work as defined 
 * in the United States Copyright Act of 1976, such as a translation or 
 * modification. </p> 
 * 
 * <p> This Work and the information contained herein is provided on an "AS 
 * IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT 
 * NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR 
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT 
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN 
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN 
 * CONNECTION WITH THE WORK OR THE USE OR OTHER DEALINGS IN THE WORK. </p> 
 * 
 * <p> The export of software employing encryption technology may require a 
 * specific license from the United States Government. It is the 
 * responsibility of any person or organization contemplating export to obtain 
 * such a license before exporting this Work. </p>
 */

package org.osid.course.syllabus;
