//
// org.osid.dictionary.DictionaryAdminSession
//
//     The OSID Java specification for org.osid.dictionary.DictionaryAdminSession.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.dictionary;


/**
 *  <p>This session creates, updates, and deletes <code> Dictionaries. </code> 
 *  The data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Dictionary, </code> a <code> DictionaryForm </code> is requested using 
 *  <code> getDictionaryFormForCreate() </code> specifying the desired record 
 *  <code> Types </code> or none if no record <code> Types </code> are needed. 
 *  The returned <code> DictionaryForm </code> will indicate that it is to be 
 *  used with a create operation and can be used to examine metdata or 
 *  validate data prior to creation. Once the <code> DictionaryForm </code> is 
 *  submiited to a create operation, it cannot be reused with another create 
 *  operation unless the first operation was unsuccessful. Each <code> 
 *  DictionaryForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> DictionaryForms </code> are requested to the 
 *  <code> Dictionary </code> <code> Id </code> that is to be updated using 
 *  <code> getDictionaryFormForUpdate(). </code> Similarly, the <code> 
 *  DictionaryForm </code> has metadata about the data that can be updated and 
 *  it can perform validation before submitting the update. The <code> 
 *  DictionaryForm </code> can only be used once for a successful update and 
 *  cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Dictionaries. </code> </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface DictionaryAdminSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can create <code> Dictionaries. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> Dictionary </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer create operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Dictionary </code> creation is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateDictionaries();


    /**
     *  Tests if this user can create a single <code> Dictionary </code> using 
     *  the desired record types. While <code> 
     *  DictionaryManager.getDictionaryRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> Dictionary. </code> 
     *  Providing an empty array tests if a <code> Dictionary </code> can be 
     *  created with no records. 
     *
     *  @param  dictionaryRecordTypes array of dictionary record types 
     *  @return <code> true </code> if <code> Dictionary </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> dictionaryRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateDictionaryWithRecordTypes(org.osid.type.Type[] dictionaryRecordTypes);


    /**
     *  Gets the dictionary form for creating new dictionaries. A new form 
     *  should be requested for each create transaction. 
     *
     *  @param  dictionaryRecordTypes array of dictionary record types 
     *  @return the dictionary form 
     *  @throws org.osid.NullArgumentException <code> dictionaryRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.dictionary.DictionaryForm getDictionaryFormForCreate(org.osid.type.Type[] dictionaryRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Dictionary. </code> 
     *
     *  @param  dictionaryForm the form for the new <code> Dictionary </code> 
     *  @return the new <code> Dictionary </code> 
     *  @throws org.osid.IllegalStateException <code> dictionaryForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> dictionaryForms </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> dictionaryForm </code> 
     *          did not originate from <code> getDictionaryFormForCreate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.dictionary.Dictionary createDictionary(org.osid.dictionary.DictionaryForm dictionaryForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Dictionaries. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a Dictionary will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer update operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Dictionary </code> modification 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateDictionaries();


    /**
     *  Gets the dictionary form for updating an existing dictionary. A new 
     *  dictionary form should be requested for each update transaction. 
     *
     *  @param  dictionaryId the <code> Id </code> of the <code> Dictionary 
     *          </code> 
     *  @return the dictionary form 
     *  @throws org.osid.NotFoundException <code> dictionaryId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> dictionaryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.dictionary.DictionaryForm getDictionaryFormForUpdate(org.osid.id.Id dictionaryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing dictionary. 
     *
     *  @param  dictionaryForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> dictionaryForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> dictionaryForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException a <code> dictionaryForm </code> 
     *          did not originate from <code> getDictionaryFormForUpdate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateDictionary(org.osid.dictionary.DictionaryForm dictionaryForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> Dictionaries. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> Dictionary </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer delete operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Dictionary </code> deletion is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteDictionaries();


    /**
     *  Deletes a <code> Dictionary. </code> 
     *
     *  @param  dictionaryId the <code> Id </code> of the <code> Dictionary 
     *          </code> to delete 
     *  @throws org.osid.NotFoundException <code> dictionaryId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> dictionaryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteDictionary(org.osid.id.Id dictionaryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for 
     *  dictionaries. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Dictionary </code> aliasing is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageDictionaryAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Dictionary </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Dictionary </code> is determined by the provider. The new 
     *  <code> Id </code> performs as an alias to the primary <code> Id. 
     *  </code> If the alias is a pointer to another dictionary it is 
     *  reassigned to the given dictionary <code> Id. </code> 
     *
     *  @param  dictionaryId the <code> Id </code> of an <code> Dictionary 
     *          </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> dictionaryId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> dictionaryId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasDictionary(org.osid.id.Id dictionaryId, 
                                org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
