//
// org.osid.dictionary.DictionaryProfile
//
//     The OSID Java specification for org.osid.dictionary.DictionaryProfile.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.dictionary;


/**
 *  <p>The <code> DictionaryProfile </code> describes the interoperability 
 *  among dictionary services. </p>
 */

public interface DictionaryProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any dictionary federation is exposed. Federation is exposed 
     *  when a specific dictionary may be identified, selected and used to 
     *  create a lookup or admin session. Federation is not exposed when a set 
     *  of dictionaries appears as a single dictionary. 
     *
     *  @return <code> true </code> if federation is visible <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if retrieving dictionary entries are supported. 
     *
     *  @return <code> true </code> if entry retrieval is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEntryRetrieval();


    /**
     *  Tests if looking up dictionary entries are supported. 
     *
     *  @return <code> true </code> if entry lookup is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEntryLookup();


    /**
     *  Tests if querying dictionary entries are supported. 
     *
     *  @return <code> true </code> if entry query is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEntryQuery();


    /**
     *  Tests if searching dictionary entries are supported. 
     *
     *  @return <code> true </code> if entry search is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEntrySearch();


    /**
     *  Tests if a dictionary entry administrative service is supported. 
     *
     *  @return <code> true </code> if dictionary entry administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEntryAdmin();


    /**
     *  Tests if a dictionary entry notification service is supported. 
     *
     *  @return <code> true </code> if dictionary entry notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEntryNotification();


    /**
     *  Tests if retrieving mappings of entry and dictionarys is supported. 
     *
     *  @return <code> true </code> if entry dictionary mapping retrieval is 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEntryDictionary();


    /**
     *  Tests if managing mappings of entry and dictionarys is supported. 
     *
     *  @return <code> true </code> if entry dictionary assignment is 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEntryDictionaryAssignment();


    /**
     *  Tests if entry smart dictionarys are available. 
     *
     *  @return <code> true </code> if entry smart dictionarys are supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEntrySmartDictionary();


    /**
     *  Tests if a dictionary lookup service is supported. 
     *
     *  @return <code> true </code> if dictionary lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDictionaryLookup();


    /**
     *  Tests if a dictionary query service is supported. 
     *
     *  @return <code> true </code> if dictionary query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDictionaryQuery();


    /**
     *  Tests if a dictionary search service is supported. 
     *
     *  @return <code> true </code> if dictionary search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDictionarySearch();


    /**
     *  Tests if a dictionary administrative service is supported. 
     *
     *  @return <code> true </code> if dictionary administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDictionaryAdmin();


    /**
     *  Tests if a dictionary notification service is supported. 
     *
     *  @return <code> true </code> if dictionary notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDictionaryNotification();


    /**
     *  Tests if a dictionary hierarchy traversal service is supported. 
     *
     *  @return <code> true </code> if dictionary hierarchy traversal is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDictionaryHierachyTraversal();


    /**
     *  Tests if a dictionary hierarchy design service is supported. 
     *
     *  @return <code> true </code> if dictionary hierarchy design is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDictionaryHierachyDesign();


    /**
     *  Tests if a dictionary batch service is supported. 
     *
     *  @return <code> true </code> if dictionary batch service is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDictionaryBatch();


    /**
     *  Gets the supported <code> Entry </code> key types. 
     *
     *  @return a list containing the supported <code> Entry </code> key types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getEntryKeyTypes();


    /**
     *  Tests if the given <code> Entry </code> key type is supported. 
     *
     *  @param  entryKeyType a <code> Type </code> indicating an <code> Entry 
     *          </code> key type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> entryKeyType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEntryKeyType(org.osid.type.Type entryKeyType);


    /**
     *  Gets the supported <code> Entry </code> value types. 
     *
     *  @return a list containing the supported <code> Entry </code> value 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getEntryValueTypes();


    /**
     *  Tests if the given <code> Entry </code> value type is supported. 
     *
     *  @param  entryValueType a <code> Type </code> indicating an <code> 
     *          Entry </code> value type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> entryRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEntryValueType(org.osid.type.Type entryValueType);


    /**
     *  Gets the list of value types supported for the given key type. 
     *
     *  @param  entryKeyType a <code> Type </code> indicating an <code> Entry 
     *          </code> key type 
     *  @return a list of value types 
     *  @throws org.osid.NullArgumentException <code> entryKeyType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getEntryValueTypesForKeyType(org.osid.type.Type entryKeyType);


    /**
     *  Tests if the given <code> Entry </code> key and value types are 
     *  supported. 
     *
     *  @param  entryKeyType a <code> Type </code> indicating an <code> Entry 
     *          </code> key type 
     *  @param  entryValueType a <code> Type </code> indicating an <code> 
     *          Entry </code> value type 
     *  @return <code> true </code> if the given Types are supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> entryKeyType </code> or 
     *          <code> entryValueType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEntryTypes(org.osid.type.Type entryKeyType, 
                                      org.osid.type.Type entryValueType);


    /**
     *  Gets the supported <code> Entry </code> record types. 
     *
     *  @return a list containing the supported <code> Entry </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getEntryRecordTypes();


    /**
     *  Tests if the given <code> Entry </code> record type is supported. 
     *
     *  @param  entryRecordType a <code> Type </code> indicating an <code> 
     *          Entry </code> record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> entryRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEntryRecordType(org.osid.type.Type entryRecordType);


    /**
     *  Gets the supported <code> Entry </code> search record types. 
     *
     *  @return a list containing the supported <code> Entry </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getEntrySearchRecordTypes();


    /**
     *  Tests if the given <code> Entry </code> search record type is 
     *  supported. 
     *
     *  @param  entrySearchRecordType a <code> Type </code> indicating an 
     *          <code> Entry </code> search record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> entrySearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEntrySearchRecordType(org.osid.type.Type entrySearchRecordType);


    /**
     *  Gets the supported <code> Dictionary </code> record types. 
     *
     *  @return a list containing the supported <code> Dictionary </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getDictionaryRecordTypes();


    /**
     *  Tests if the given <code> Dictionary </code> record type is supported. 
     *
     *  @param  dictionaryRecordType a <code> Type </code> indicating a <code> 
     *          Dictionary </code> record type 
     *  @return <code> true </code> if the given record Type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> dictionaryRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDictionaryRecordType(org.osid.type.Type dictionaryRecordType);


    /**
     *  Gets the supported <code> Dictionary </code> search record types. 
     *
     *  @return a list containing the supported <code> Dictionary </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getDictionarySearchRecordTypes();


    /**
     *  Tests if the given <code> Dictionary </code> search record type is 
     *  supported. 
     *
     *  @param  dictionarySearchRecordType a <code> Type </code> indicating a 
     *          <code> Dictionary </code> search record type 
     *  @return <code> true </code> if the given record <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          dictionarySearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDictionarySearchRecordType(org.osid.type.Type dictionarySearchRecordType);
}
