//
// org.osid.dictionary.EntryDictionaryAssignmentSession
//
//     The OSID Java specification for org.osid.dictionary.EntryDictionaryAssignmentSession.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.dictionary;


/**
 *  <p>This session provides methods to re-assign enrties to dictionaries. A 
 *  <code> Entry </code> may map to multiple <code> Dictionary </code> objects 
 *  and removing the last reference to a <code> Entry </code> is the 
 *  equivalent of deleting it. Each <code> Dictionary </code> may have its own 
 *  authorizations governing who is allowed to operate on it. </p> 
 *  
 *  <p> Moving or adding a reference of a <code> Entry </code> to another 
 *  <code> Dictionary </code> is not a copy operation (eg: does not change its 
 *  <code> Id </code> ). </p>
 */

public interface EntryDictionaryAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter entry/dictionary mappings. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignEntries();


    /**
     *  Tests if this user can alter entry/dictionary mappings. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED </code> . This is intended as a hint to 
     *  an application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @param  dictionaryId the <code> Id </code> of the <code> Dictionary 
     *          </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> dictionaryId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignEntriesToDictionary(org.osid.id.Id dictionaryId);


    /**
     *  Gets a list of dictionaries including and under the given dictionary 
     *  node in which any entry can be assigned. 
     *
     *  @param  dictionaryId the <code> Id </code> of the <code> Dictionary 
     *          </code> 
     *  @return list of assignable dictionary <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> dictionaryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableDictionaryIds(org.osid.id.Id dictionaryId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of dictionaries including and under the given dictionary 
     *  node in which a specific entry can be assigned. 
     *
     *  @param  dictionaryId the <code> Id </code> of the <code> Dictionary 
     *          </code> 
     *  @param  entryId the <code> Id </code> of the <code> Entry </code> 
     *  @return list of assignable dictionary <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> dictionaryId </code> or 
     *          <code> entryId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableDictionaryIdsForEntry(org.osid.id.Id dictionaryId, 
                                                                 org.osid.id.Id entryId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> Entry </code> to a <code> Dictionary. </code> 
     *
     *  @param  entryId the <code> Id </code> of the <code> Entry </code> 
     *  @param  dictionaryId the <code> Id </code> of the <code> Dictionary 
     *          </code> 
     *  @throws org.osid.AlreadyExistsException <code> entryId </code> is 
     *          already assigned to <code> dictionaryId </code> 
     *  @throws org.osid.NotFoundException <code> entryId </code> or <code> 
     *          dictionaryId </code> not found 
     *  @throws org.osid.NullArgumentException <code> entryId </code> or 
     *          <code> dictionaryId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignEntryToDictionary(org.osid.id.Id entryId, 
                                        org.osid.id.Id dictionaryId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> Entry </code> from a <code> Dictionary. </code> 
     *
     *  @param  entryId the <code> Id </code> of the <code> Entry </code> 
     *  @param  dictionaryId the <code> Id </code> of the <code> Dictionary 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> entryId </code> or <code> 
     *          dictionaryId </code> not found or <code> entryId </code> not 
     *          assigned to <code> dictionaryId </code> 
     *  @throws org.osid.NullArgumentException <code> entryId </code> or 
     *          <code> dictionaryId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignEntryFromDictionary(org.osid.id.Id entryId, 
                                            org.osid.id.Id dictionaryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Moves an <code> Entry </code> from one <code> Dictionary </code> to 
     *  another. Mappings to other <code> Dictionaries </code> are unaffected. 
     *
     *  @param  entryId the <code> Id </code> of the <code> Entry </code> 
     *  @param  fromDictionaryId the <code> Id </code> of the current <code> 
     *          Dictionary </code> 
     *  @param  toDictionaryId the <code> Id </code> of the destination <code> 
     *          Dictionary </code> 
     *  @throws org.osid.NotFoundException <code> entryId, fromDictionaryId, 
     *          </code> or <code> toDictionaryId </code> not found or <code> 
     *          entryId </code> not mapped to <code> fromDictionaryId </code> 
     *  @throws org.osid.NullArgumentException <code> entryId 
     *          fromDictionaryId, </code> or <code> toDictionaryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void reassignEntryToDictionary(org.osid.id.Id entryId, 
                                          org.osid.id.Id fromDictionaryId, 
                                          org.osid.id.Id toDictionaryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
