//
// org.osid.dictionary.EntryLookupSession
//
//     The OSID Java specification for org.osid.dictionary.EntryLookupSession.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.dictionary;


/**
 *  <p><code> EntryLookupSession </code> is used to look up dictionary 
 *  entries. This session includes the methods defined in the <code> 
 *  EntryRetrievalSession. </code> </p> 
 *  
 *  <p> This session defines two views which offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete and ordered result set or is an 
 *      error condition </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data out of sync or there is an 
 *  authorization block in a particular element. </p>
 */

public interface EntryLookupSession
    extends org.osid.dictionary.EntryRetrievalSession {


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeEntryView();


    /**
     *  A complete view of the <code> Entry </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryEntryView();


    /**
     *  Gets the <code> Entry </code> specified by its <code> Id. </code> The 
     *  identifier represents the union of the key, keyType and valueType.In 
     *  plenary mode, the exact <code> Id </code> is found or a <code> 
     *  NOT_FOUND </code> results. Otherwise, the returned <code> Entry 
     *  </code> may have a different <code> Id </code> than requested, such as 
     *  the case where a duplicate <code> Id </code> was assigned to an <code> 
     *  Agency </code> and retained for compatibility. 
     *
     *  @param  entryId <code> Id </code> of the <code> Entry </code> 
     *  @return the entry 
     *  @throws org.osid.NotFoundException <code> entryId </code> not found 
     *  @throws org.osid.NullArgumentException <code> entryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.dictionary.Entry getEntry(org.osid.id.Id entryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> EntryList </code> corresponding to the given <code> 
     *  IdList. </code> In plenary mode, the returned list contains all of the 
     *  entries specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Entry </code> elements may be omitted from the 
     *  list and may present the elements in any order including returning a 
     *  unique set. 
     *
     *  @param  entryIds a list of <code> Entry Ids </code> 
     *  @return the entry list 
     *  @throws org.osid.NotFoundException <code> entryId </code> not found 
     *  @throws org.osid.NullArgumentException <code> entryIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.dictionary.EntryList getEntriesByIds(org.osid.id.IdList entryIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> EntryList </code> corresponding to the given entry 
     *  genus <code> Type </code> which does not include entries of genus 
     *  types derived from the specified <code> Type. </code> In plenary mode, 
     *  the returned list contains all known entries or an error results. 
     *  Otherwise, the returned list may contain only those entries that are 
     *  accessible through this session. 
     *
     *  @param  entryGenusType an entry genus type 
     *  @return the returned <code> Entry list </code> 
     *  @throws org.osid.NullArgumentException <code> entryGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.dictionary.EntryList getEntriesByGenusType(org.osid.type.Type entryGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> EntryList </code> corresponding to the given entry 
     *  genus <code> Type </code> and include any additional entries with 
     *  genus types derived from the specified <code> Type. </code> In plenary 
     *  mode, the returned list contains all known entries or an error 
     *  results. Otherwise, the returned list may contain only those entries 
     *  that are accessible through this session. 
     *
     *  @param  entryGenusType an entry genus type 
     *  @return the returned <code> Entry list </code> 
     *  @throws org.osid.NullArgumentException <code> entryGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.dictionary.EntryList getEntriesByParentGenusType(org.osid.type.Type entryGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> EntryList </code> containing the given entry record 
     *  <code> Type. </code> In plenary mode, the returned list contains all 
     *  known entries or an error results. Otherwise, the returned list may 
     *  contain only those entries that are accessible through this session. 
     *
     *  @param  entryyRecordType an entry record type 
     *  @return the returned <code> Entry </code> list 
     *  @throws org.osid.NullArgumentException <code> entryRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.dictionary.EntryList getEntriesByRecordType(org.osid.type.Type entryyRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all the <code> Dictionary </code> entries matching the given key 
     *  <code> Type. </code> In plenary mode, the returned list contains all 
     *  of the entries specified in the Id list, in the order of the list, 
     *  including duplicates, or an error results if an Id in the supplied 
     *  list is not found or inaccessible. Otherwise, inaccessible Entry 
     *  elements may be omitted from the list and may present the elements in 
     *  any order including returning a unique set. 
     *
     *  @param  keyType the type of the key to match 
     *  @return the list of entries matching <code> keyType </code> 
     *  @throws org.osid.NullArgumentException <code> keyType </code> is null 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.dictionary.EntryList getEntriesByKeyType(org.osid.type.Type keyType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all the <code> Dictionary </code> entries matching the given key 
     *  and value <code> Type. </code> In plenary mode, the returned list 
     *  contains all of the entries specified in the Id list, in the order of 
     *  the list, including duplicates, or an error results if an Id in the 
     *  supplied list is not found or inaccessible. Otherwise, inaccessible 
     *  Entry elements may be omitted from the list and may present the 
     *  elements in any order including returning a unique set. 
     *
     *  @param  keyType the type of the key to match 
     *  @param  valueType the type of the value to match 
     *  @return the list of entries matching <code> keyType </code> 
     *  @throws org.osid.NullArgumentException <code> keyType </code> or 
     *          <code> valueType </code> is null 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.dictionary.EntryList getEntriesByKeyTypeAndValueType(org.osid.type.Type keyType, 
                                                                         org.osid.type.Type valueType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all the <code> Dictionary </code> entries matching the given key 
     *  and key <code> Type </code> . In plenary mode, the returned list 
     *  contains all of the entries specified in the Id list, in the order of 
     *  the list, including duplicates, or an error results if an Id in the 
     *  supplied list is not found or inaccessible. Otherwise, inaccessible 
     *  Entry elements may be omitted from the list and may present the 
     *  elements in any order including returning a unique set. 
     *
     *  @param  key the key to match 
     *  @param  keyType the type of the value to match 
     *  @return the list of entries matching <code> keyType </code> 
     *  @throws org.osid.NullArgumentException <code> key </code> or <code> 
     *          keyType </code> is null 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.dictionary.EntryList getEntriesByKeyAndKeyType(java.lang.Object key, 
                                                                   org.osid.type.Type keyType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all the <code> Dictionary </code> entries. In plenary mode, the 
     *  returned list contains all of the entries specified in the Id list, in 
     *  the order of the list, including duplicates, or an error results if an 
     *  Id in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible Entry elements may be omitted from the list and may 
     *  present the elements in any order including returning a unique set. 
     *
     *  @return the list of entries 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.dictionary.EntryList getEntries()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
