//
// org.osid.dictionary.EntryRetrievalSession
//
//     The OSID Java specification for org.osid.dictionary.EntryRetrievalSession.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.dictionary;


/**
 *  <p><code> EntryRetrievalSession </code> is used to query dictionary 
 *  entries. A dictionary entry contains a key and a value. The uniqeness of 
 *  the entry depends on the key, the key type and the value type. </p> 
 *  
 *  <p> This session defines two views which offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> federated view: entries are accessible from the <code> Dictionary 
 *      </code> associated with this session and any descedant dictionaries in 
 *      the <code> Dictionary </code> hierarchy </li> 
 *      <li> isolated view: entries are accessible from this <code> Dictionary 
 *      </code> only </li> 
 *  </ul>
 *  
 */

public interface EntryRetrievalSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Dictionary </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Dictionary </code> <code> Id </code> associated 
     *          with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDictionaryId();


    /**
     *  Gets the <code> Dictionary </code> associated with this session. 
     *
     *  @return the <code> Dictionary </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.dictionary.Dictionary getDictionary()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Entry </code> lookups. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupEntries();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include entries from descendant dictionaries in the dictionary 
     *  hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedDictionaryView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this dictionary only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedDictionaryView();


    /**
     *  Gets the <code> Dictionary </code> entry associated with the given key 
     *  and types. The <code> keyType </code> indicates the key object type 
     *  and the <code> valueType </code> indicates the value object return. 
     *
     *  @param  key the key of the entry to retrieve 
     *  @param  keyType the key type of the entry to retrieve 
     *  @param  valueType the value type of the entry to retrieve 
     *  @return the returned <code> object </code> 
     *  @throws org.osid.InvalidArgumentException <code> key </code> is not of 
     *          <code> keyType </code> 
     *  @throws org.osid.NotFoundException no entry found 
     *  @throws org.osid.NullArgumentException <code> key, keyType, </code> or 
     *          <code> valueType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.lang.Object retrieveEntry(java.lang.Object key, 
                                          org.osid.type.Type keyType, 
                                          org.osid.type.Type valueType)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
