/**
 * <p>The Open Service Interface Definitions for the org.osid.dictionary
 * service.</p>
 * 
 * <p>The Dictionary OSID manages key/value pairs. A key and a value may be of 
 * an arbitrary type. Dictionaries may be used to support a Locale or 
 * Configuration OSID, or may be used to provide any dynamic translation or 
 * conversion. The Dictionary OSID is a powerful tool for abstracting and 
 * simplifying applications and other OSID implementations. </p> 
 * <h4> Entries </h4> 
 * 
 * <p> An <code> Entry </code> is indexed by a key and may contain multiple 
 * values of different types. The key, key type, and value type must be 
 * unique. The interpretation of the value and key are specified through the 
 * value type and key type. </p> 
 * <h4> Dictionary </h4> 
 * 
 * <p> <code> Entries </code> may be organized into federatable <code> 
 * OsidCatalogs </code> called <code> Dictionaries. </code> </p> 
 * <h4> Basic Example: </h4> 
 * 
 * <pre>
 *      
 *      
 *      EntryLookupSession lookupSession = mgr.getEntryLookupSession();
 *      string definition = (string) lookupSession.getEntry("gambrel", strType, strType);
 *      
 *              
 *      
 * </pre>
 * 
 * <h4> Federated Example: </h4> 
 * 
 * <pre>
 *      
 *      
 *      DictionaryLookupSession dictLookupSession = mgr.getDictionaryLookupSession();
 *      Dictionary dict = dictLookupSession.getDictionary(dict_id);
 *      EntryLookupSession lookupSession = mgr.getEntryLookupSessionForDictionary(dict);
 *      JpegImage jpg = lookupSession.getEntry(tiffImage, tiffType, jpegType);
 *      
 *              
 *      
 * </pre>
 * 
 * 
 * <br/><hr/><br/>
 * 
 * <p>Copyright &copy; 2002-2004, 2006-2008 Massachusetts Institute of 
 * Technology. </p> 
 * 
 * <p> Copyright &copy; 2010 Ingenescus. All Rights Reserved. </p>
 * 
 * <p>This Work is being provided by the copyright holder(s) subject to the 
 * following license. By obtaining, using and/or copying this Work, you agree 
 * that you have read, understand, and will comply with the following terms 
 * and conditions. </p> 
 * 
 * <p> Permission to use, copy and distribute unmodified versions of this 
 * Work, for any purpose, without fee or royalty is hereby granted, provided 
 * that you include the above copyright notices and the terms of this license 
 * on ALL copies of the Work or portions thereof. </p> 
 * 
 * <p> You may modify or create Derivatives of this Work only for your 
 * internal purposes. You shall not distribute or transfer any such Derivative 
 * of this Work to any location or to any third party. For the purposes of 
 * this license, "Derivative" shall mean any derivative of the Work as defined 
 * in the United States Copyright Act of 1976, such as a translation or 
 * modification. </p> 
 * 
 * <p> This Work and the information contained herein is provided on an "AS 
 * IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT 
 * NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR 
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT 
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN 
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN 
 * CONNECTION WITH THE WORK OR THE USE OR OTHER DEALINGS IN THE WORK. </p> 
 * 
 * <p> The export of software employing encryption technology may require a 
 * specific license from the United States Government. It is the 
 * responsibility of any person or organization contemplating export to obtain 
 * such a license before exporting this Work. </p>
 */

package org.osid.dictionary;
