//
// org.osid.filing.DirectoryAdminSession
//
//     The OSID Java specification for org.osid.filing.DirectoryAdminSession.
//
// Copyright (C) 2003-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010, 2014 Ingnescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.filing;


/**
 *  <p>This session creates and removes files and directories under the 
 *  directory associated with this session. </p> 
 *  
 *  <p> The view of the administrative methods defined in this session is 
 *  determined by the provider. For an instance of this session where no path 
 *  has been specified, it may not be parallel to the <code> 
 *  DirectoryLookupSession. </code> For example, a default <code> 
 *  DirectoryLookupSession </code> may view the entire directory hierarchy 
 *  while the default <code> DirectoryAdminSession </code> uses an isolated 
 *  <code> Directory </code> to create new entries. Another scenario is a 
 *  federated provider who does not wish to permit administrative operations 
 *  for the federation unaware. </p>
 */

public interface DirectoryAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Id </code> of this directory. 
     *
     *  @return the <code> Id </code> of this directory 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDirectoryId();


    /**
     *  Gets the directory associated with this session. 
     *
     *  @return the directory associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.Directory getDirectory()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create or remove entries in this directory. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known modifying this directory will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer create operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if modifying this directory is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canModifyDirectory();


    /**
     *  Overwrite files if a destination pathname exists and is a file. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void overwrite();


    /**
     *  Tests if this user can create a single <code> File </code> using the 
     *  desired record types. While <code> FilingManager.getFileRecordTypes() 
     *  </code> can be used to examine which records are supported, this 
     *  method tests which record(s) are required for creating a specific 
     *  <code> File. </code> Providing an empty array tests if a <code> File 
     *  </code> can be created with no records. 
     *
     *  @param  fileRecordTypes array of file record types 
     *  @return <code> true </code> if <code> File </code> creation using the 
     *          specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> fileRecordTypes </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateFileWithRecordTypes(org.osid.type.Type[] fileRecordTypes);


    /**
     *  Gets the file form for creating new files. A new form should be 
     *  requested for each create transaction. 
     *
     *  @param  name name of a file 
     *  @param  fileRecordTypes array of file record types 
     *  @return the file form 
     *  @throws org.osid.AlreadyExistsException <code> name </code> already 
     *          exists as a file in this direrctory and <code> overwrite() 
     *          </code> is <code> false </code> 
     *  @throws org.osid.InvalidArgumentException <code> name </code> is 
     *          invalid 
     *  @throws org.osid.NullArgumentException <code> name </code> or <code> 
     *          fileRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.FileForm getFileFormForCreate(String name, 
                                                         org.osid.type.Type[] fileRecordTypes)
        throws org.osid.AlreadyExistsException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new file in this directory. 
     *
     *  @param  fileForm the file form 
     *  @return the new file 
     *  @throws org.osid.IllegalStateException <code> fileForm </code> already 
     *          used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> fileForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> fileForm </code> did not 
     *          originate from <code> getFileFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.File createFile(org.osid.filing.FileForm fileForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the file form for updating an existing files. A new file form 
     *  should be requested for each update transaction. 
     *
     *  @param  fileId <code> Id </code> of the file to update 
     *  @return the file form 
     *  @throws org.osid.NotFoundException <code> fileId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> fileId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.FileForm getFileFormForUpdate(org.osid.id.Id fileId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing file. 
     *
     *  @param  fileForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> fileForm </code> already 
     *          used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> fileForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> fileForm </code> did not 
     *          originate from <code> getFileFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateFile(org.osid.filing.FileForm fileForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes a file. 
     *
     *  @param  fileId the <code> Id </code> of the file to delete 
     *  @throws org.osid.NotFoundException <code> fileId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> fileId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteFile(org.osid.id.Id fileId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create a single <code> Directory </code> using 
     *  the desired record types. While <code> 
     *  FilingManager.getDiectoryRecordTypes() </code> can be used to examine 
     *  which records are supported, this method tests which record(s) are 
     *  required for creating a specific <code> Directory. </code> Providing 
     *  an empty array tests if a <code> Directory </code> can be created with 
     *  no records. 
     *
     *  @param  directoryRecordTypes array of directory record types 
     *  @return <code> true </code> if <code> Directory </code> creation using 
     *          the specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> directoryRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateDirectoryWithRecordTypes(org.osid.type.Type[] directoryRecordTypes);


    /**
     *  Gets the file form for creating new directories. A new form should be 
     *  requested for each create transaction. This method is used for 
     *  creating new <code> Directories </code> where only the <code> 
     *  Directory </code> <code> Type </code> is known. 
     *
     *  @param  name the name of a subdirectory in this directory 
     *  @param  directoryRecordTypes array of directory record types 
     *  @return the directory form 
     *  @throws org.osid.AlreadyExistsException directory already exists and 
     *          <code> overwrite() </code> is false 
     *  @throws org.osid.InvalidArgumentException <code> name </code> is 
     *          invalid 
     *  @throws org.osid.NullArgumentException <code> name </code> or <code> 
     *          directoryRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.DirectoryForm getDirectoryFormForCreate(String name, 
                                                                   org.osid.type.Type[] directoryRecordTypes)
        throws org.osid.AlreadyExistsException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new directory. 
     *
     *  @param  directoryForm the directory form 
     *  @return the new directory 
     *  @throws org.osid.IllegalStateException <code> directoryForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> directoryForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> directoryForm </code> did 
     *          not originate from <code> getDirectoryFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.Directory createDirectory(org.osid.filing.DirectoryForm directoryForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the directory form for updating an existing files. A new 
     *  directory form should be requested for each update transaction. This 
     *  method is used when the <code> Directory </code> to be updated is 
     *  known and is desired to access any metadata specific to the <code> 
     *  Directory </code> being updated. 
     *
     *  @param  directoryId <code> Id </code> of the directory to update 
     *  @return the directory form 
     *  @throws org.osid.NotFoundException <code> directoryId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> directoryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.DirectoryForm getDirectoryFormForUpdate(org.osid.id.Id directoryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing directory. 
     *
     *  @param  directoryForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> directoryForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> directoryForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> directoryForm </code> did 
     *          not originate from <code> getDirectoryFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateDirectory(org.osid.filing.DirectoryForm directoryForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes a directory in this directory. The directory to remove must be 
     *  empty. 
     *
     *  @param  directoryId the <code> Id </code> of the directory to delete 
     *  @throws org.osid.NotFoundException <code> directoryId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> directoryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteDirectory(org.osid.id.Id directoryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all files and subdirectories within the given directory. 
     *
     *  @param  directoryId the <code> Id </code> of the directory to delete 
     *  @throws org.osid.NotFoundException <code> directoryId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> directoryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDirectory(org.osid.id.Id directoryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
