//
// org.osid.filing.DirectoryQuery
//
//     The OSID Java specification for org.osid.filing.DirectoryQuery.
//
// Copyright (C) 2003-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010, 2014 Ingnescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.filing;


/**
 *  <p>This is the query for searching directories. Each method match request 
 *  produces an <code> AND </code> term while multiple invocations of a method 
 *  produces a nested <code> OR. </code> </p> 
 *  
 *  <p> An example to find directories whose name is "Library". </p> 
 *  
 *  <pre>
 *       
 *       
 *       DirectoryQuery query = session.getDirectoryQuery();
 *       query.matchName("Library", wordStringMatchType, true);
 *       
 *       DirectoryList list = session.getDirectoriesByQuery(query);
 *       
 *                   
 *       
 *  </pre>
 *  
 */

public interface DirectoryQuery
    extends org.osid.OsidCatalogQuery,
            org.osid.filing.DirectoryEntryQuery {


    /**
     *  Matches directories that contain the specified file name. 
     *
     *  @param  name a file name 
     *  @param  stringMatchType the string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> name </code> not of 
     *          <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> name </code> or <code> 
     *          stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchFileName(String name, org.osid.type.Type stringMatchType, 
                              boolean match);


    /**
     *  Clears all file name terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFileNameTerms();


    /**
     *  Tests if a <code> FileQuery </code> is available. 
     *
     *  @return <code> true </code> if a file query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFileQuery();


    /**
     *  Gets the query for a file contained within the directory. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @return the directory query 
     *  @throws org.osid.UnimplementedException <code> supportsFileQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFileQuery() </code> is <code> true. </code> 
     */

    public org.osid.filing.FileQuery getFileQuery(boolean match);


    /**
     *  Matches directories with any file. 
     *
     *  @param  match <code> true </code> to match directories with any file,, 
     *          <code> false </code> to match directories with no file. 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyFile(boolean match);


    /**
     *  Clears all file terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFileTerms();


    /**
     *  Gets the directory query record corresponding to the given <code> 
     *  Directory </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested boolean <code> OR </code> term. 
     *
     *  @param  directoryRecordType a directory record type 
     *  @return the directory query record 
     *  @throws org.osid.NullArgumentException <code> directoryRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(directoryRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.records.DirectoryQueryRecord getDirectoryQueryRecord(org.osid.type.Type directoryRecordType)
        throws org.osid.OperationFailedException;
}
