//
// org.osid.filing.DirectorySearch
//
//     The OSID Java specification for org.osid.filing.DirectorySearch.
//
// Copyright (C) 2003-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010, 2014 Ingnescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.filing;


/**
 *  <p>The search interface for gioverning directory searches. </p> 
 *  
 *  <p> An example to find directories whose name is "Library" sorted by the 
 *  path name. </p> 
 *  
 *  <pre>
 *       
 *       
 *       DirectoryQuery query = session.getDirectoryQuery();
 *       query.addNameMatch("Library", wordStringMatchType, true);
 *       
 *       DirectorySearch search = session.getDirectorySearch();
 *       search.orderByPath();
 *       
 *       DirectorySearchResults results = session.getDirectoriesBySearch(query, search);
 *       DirectoryList directories = results.getDirectories();
 *       
 *                   
 *       
 *  </pre>
 *  
 */

public interface DirectorySearch
    extends org.osid.OsidSearch {


    /**
     *  Execute this search among the given list of diectories. 
     *
     *  @param  directoryIds list of directory <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> directoryIds </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void searchAmongDirectories(org.osid.id.IdList directoryIds);


    /**
     *  Specify an ordering to the search results. 
     *
     *  @param  directorySearchOrder directory search order 
     *  @throws org.osid.NullArgumentException <code> directorySearchOrder 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> directorySearchOrder 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderDirectoryResults(org.osid.filing.DirectorySearchOrder directorySearchOrder);


    /**
     *  Gets the directory search record corresponding to the given directory 
     *  search record <code> Type. </code> This method is used to retrieve an 
     *  object implementing the requested record. 
     *
     *  @param  directorySearchRecordType a directory search record type 
     *  @return the directory search record 
     *  @throws org.osid.NullArgumentException <code> 
     *          directorySearchRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(directorySearchRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.records.DirectorySearchRecord getDirectorySearchRecord(org.osid.type.Type directorySearchRecordType)
        throws org.osid.OperationFailedException;
}
