//
// org.osid.filing.DirectorySearchSession
//
//     The OSID Java specification for org.osid.filing.DirectorySearchSession.
//
// Copyright (C) 2003-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010, 2014 Ingnescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.filing;


/**
 *  <p>This session provides methods for searching among <code> Directory 
 *  </code> objects. The search query is constructed using the <code> 
 *  DirectoryQuery. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated directory view: searches include directories in 
 *      directories of which this directory is an ancestor </li> 
 *      <li> isolated directory view: searches are restricted to diectories in 
 *      this directory only </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> getDirectoriesByQuery() </code> is the basic search method and 
 *  returns a list of <code> Directories. </code> A more advanced search may 
 *  be performed with <code> getDirectoriesBySearch(). </code> It accepts a 
 *  <code> DirectorySearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getDirectoriesBySearch() </code> returns an <code> 
 *  DirectorySearchResults </code> that can be used to access the resulting 
 *  <code> DirectoryList </code> or be used to perform a search within the 
 *  result set through <code> DirectorySearch. </code> </p>
 */

public interface DirectorySearchSession
    extends org.osid.filing.DirectoryQuerySession {


    /**
     *  Gets a diectory search. 
     *
     *  @return the directory search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.DirectorySearch getDirectorySearch();


    /**
     *  Gets a directory search order. The <code> DirectorySearchOrder </code> 
     *  is supplied to a <code> DirectorySearch </code> to specify the 
     *  ordering of results. 
     *
     *  @return the directory search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.DirectorySearchOrder getDirectorySearchOrder();


    /**
     *  Gets the search results matching the given search. 
     *
     *  @param  directoryQuery the directory query 
     *  @param  directorySearch the directory search 
     *  @return the directory search results 
     *  @throws org.osid.NullArgumentException <code> directoryQuery </code> 
     *          or <code> directorySearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> directoryQuery </code> or 
     *          <code> directorySearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.DirectorySearchResults getDirectoriesBySearch(org.osid.filing.DirectoryQuery directoryQuery, 
                                                                         org.osid.filing.DirectorySearch directorySearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a directory query from an inspector. The inspector is available 
     *  from an <code> DirectorySearchResults. </code> 
     *
     *  @param  directoryQueryInspector a query inspector 
     *  @return the directory query 
     *  @throws org.osid.NullArgumentException <code> directoryQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> directoryQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.DirectoryQuery getDirectoryQueryFromInspector(org.osid.filing.DirectoryQueryInspector directoryQueryInspector);
}
