//
// org.osid.filing.FileQuery
//
//     The OSID Java specification for org.osid.filing.FileQuery.
//
// Copyright (C) 2003-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010, 2014 Ingnescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.filing;


/**
 *  <p>This is the query for searching files. Each method specifies an <code> 
 *  AND </code> term while multiple invocations of the same method produces a 
 *  nested <code> OR. </code> </p>
 */

public interface FileQuery
    extends org.osid.filing.DirectoryEntryQuery {


    /**
     *  Matches files whose size is within and including the given range. 
     *
     *  @param  from low file size 
     *  @param  to high file size 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is les 
     *          than <code> from </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSize(long from, long to, boolean match);


    /**
     *  Matches a file that has any known size. 
     *
     *  @param  match <code> true </code> to match any size, <code> false 
     *          </code> to match files with no known size 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnySize(boolean match);


    /**
     *  Clears all file size terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSizeTerms();


    /**
     *  Adds data strings to this query to match files whose content contains 
     *  these strings. Supplying multiple strings behaves like a boolean AND 
     *  among the elements each which must correspond to the <code> 
     *  stringMatchType. </code> An OR can be performed with multiple queries. 
     *
     *  @param  data string to match 
     *  @param  stringMatchType the string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> data </code> not of 
     *          <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> data </code> or <code> 
     *          stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDataString(String data, 
                                org.osid.type.Type stringMatchType, 
                                boolean match);


    /**
     *  Clears all file data string terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDataStringTerms();


    /**
     *  Matches files who data contains the given bytes. 
     *
     *  @param  data data to match 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @param  partial <code> true </code> for a partial match, <code> false 
     *          </code> for a complete match 
     *  @throws org.osid.NullArgumentException <code> data </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchData(byte[] data, boolean match, boolean partial);


    /**
     *  Matches a file that has any data. 
     *
     *  @param  match <code> true </code> to match any data, <code> false 
     *          </code> to match files with no data 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyData(boolean match);


    /**
     *  Clears all file data terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDataTerms();


    /**
     *  Gets the file query record corresponding to the given <code> File 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested boolean <code> OR </code> term. 
     *
     *  @param  fileRecordType a file record type 
     *  @return the file query record 
     *  @throws org.osid.NullArgumentException <code> fileRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(fileRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.records.FileQueryRecord getFileQueryRecord(org.osid.type.Type fileRecordType)
        throws org.osid.OperationFailedException;
}
