//
// org.osid.filing.FileSmartDirectorySession
//
//     The OSID Java specification for org.osid.filing.FileSmartDirectorySession.
//
// Copyright (C) 2003-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010, 2014 Ingnescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.filing;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. A <code> FileQuery </code> can be retrieved from this session 
 *  and mapped to this <code> Directory </code> to create a virtual collection 
 *  of files. The files may be sequenced using the <code> FileSearchOrder 
 *  </code> from this session. </p> 
 *  
 *  <p> This <code> Directory </code> has a default query that matches any 
 *  file and a default search order that specifies no sequencing. The queries 
 *  may be examined using a <code> FileQueryInspector. </code> The query may 
 *  be modified by converting the inspector back to a <code> FileQuery. 
 *  </code> </p>
 */

public interface FileSmartDirectorySession
    extends org.osid.OsidSession {


    /**
     *  Gets the absolute path of this directory. 
     *
     *  @return the <code> Id </code> of this directory 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDirectoryId();


    /**
     *  Gets the <code> Directory </code> associated with this session. 
     *
     *  @return the <code> Directory </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.Directory getDirectory()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart directories. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart directory management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartDirectories();


    /**
     *  Gets a file query. 
     *
     *  @return the file query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.FileQuery getFileQuery();


    /**
     *  Gets a file search order. The <code> FileSearchOrder </code> is 
     *  supplied to a <code> FileSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the file search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.FileSearchOrder getFileSearchOrder();


    /**
     *  Applies a file query to this directory. 
     *
     *  @param  fileQuery the file query 
     *  @throws org.osid.NullArgumentException <code> fileQuery </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> fileQuery </code> not of 
     *          this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyFileQuery(org.osid.filing.FileQuery fileQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a file query inspector for this directory. 
     *
     *  @return the file query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.FileQueryInspector inspectFileQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a file search order to this directory. 
     *
     *  @param  fileSearchOrder the file search order 
     *  @throws org.osid.NullArgumentException <code> fileSearchOrder </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> fileSearchOrder </code> 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyFileSequencing(org.osid.filing.FileSearchOrder fileSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a file query from an inspector. 
     *
     *  @param  fileQueryInspector a file query inspector 
     *  @return the file query 
     *  @throws org.osid.NullArgumentException <code> fileQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> fileQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.FileQuery getFileQueryFromInspector(org.osid.filing.FileQueryInspector fileQueryInspector);
}
