//
// org.osid.filing.FileSystemSession
//
//     The OSID Java specification for org.osid.filing.FileSystemSession.
//
// Copyright (C) 2003-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010, 2014 Ingnescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.filing;


/**
 *  <p>This session defines methods for examining file systems. A <code> 
 *  FileSystemSession </code> is associated with a directory that, unlike 
 *  other catalogs, behaves as the current directory path for supplying 
 *  relative path names. Absolute path names can be supplied to access any 
 *  file or directory in the file system. </p> 
 *  
 *  <p> This session defines the following views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> federated directory view: searches include entries in directories 
 *      of which this directory is an ancestor </li> 
 *      <li> isolated directory view: lookups are restricted to entries in 
 *      this directory only </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data out of sync. Some 
 *  administrative applications may need to know whether it had retrieved an 
 *  entire set of objects and may sacrifice some interoperability for the sake 
 *  of precision using the plenary view. </p>
 */

public interface FileSystemSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Id </code> of this directory. 
     *
     *  @return the <code> Id </code> of this directory 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDirectoryId();


    /**
     *  Gets the directory associated with this session. 
     *
     *  @return the directory associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.Directory getDirectory()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform entry lookups. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupDirectoryEntries();


    /**
     *  Tests if the directory associated with this session has a parent 
     *  directory. 
     *
     *  @return <code> true </code> if a parent exists, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method is must be implemented. 
     */

    public boolean hasParentDirectory();


    /**
     *  Gets the parent of the directory associated with this session. 
     *
     *  @return the parent of the directory associated with this session 
     *  @throws org.osid.IllegalStateException <code> hasParentDirectory() 
     *          </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.Directory getParentDirectory()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeDirectoryView();


    /**
     *  A complete view of the file or directory returns is desired. Methods 
     *  will return what is requested or result in an error. This view is used 
     *  when greater precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryDirectoryView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include entries in directories which are children of this directory. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedDirectoryView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this directory only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedDirectoryView();


    /**
     *  Tests if a file, directory or alias name exists. In a federated view, 
     *  the existence test is performed on this directory and any children of 
     *  this directory. In an isolated view, the existence test is restrcited 
     *  to this directory only. 
     *
     *  @param  name a file or directory name 
     *  @return <code> true </code> if the name exists, <code> false </code> 
     *          otherwise 
     *  @throws org.osid.NullArgumentException <code> name </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public boolean exists(String name)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if a name exists and is a file or an alias to a file. In a 
     *  federated view, the exietence test is performed on this directory and 
     *  any children of this directory. In an isolated view, the existence 
     *  test is restrcited to this directory only. 
     *
     *  @param  name a file name 
     *  @return <code> true </code> if the name is a file, <code> false 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> name </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public boolean isFile(String name)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if a name exists and is a directory or an alias to a directory. 
     *  In a federated view, the exietence test is performed on this directory 
     *  and any children of this directory. In an isolated view, the existence 
     *  test is restrcited to this directory only. 
     *
     *  @param  name a file or directory name 
     *  @return <code> true </code> if the path is a directory, <code> false 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> name </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public boolean isDirectory(String name)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if a name exists and is an alias. In a federated view, the 
     *  exietence test is performed on this directory and any children of this 
     *  directory. In an isolated view, the existence test is restrcited to 
     *  this directory only. 
     *
     *  @param  name a file or directory name 
     *  @return <code> true </code> if the path is an alias, <code> false 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> name </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public boolean isAlias(String name)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a specified file or alias to the file by its name in the current 
     *  directory only. For federated views, use <code> getFilesByName(). 
     *  </code> 
     *
     *  @param  name the name to the file 
     *  @return the file 
     *  @throws org.osid.NotFoundException <code> name </code> is not found or 
     *          is a directory 
     *  @throws org.osid.NullArgumentException <code> name </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.File getFile(String name)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a specified files and aliases to files for the given file name. 
     *  In an isolated view, this method behaves like <code> getFile(). 
     *  </code> Is a federated view, this method returns a list of files by 
     *  the same name in descendant directories. In plenary mode, the returned 
     *  list contains all known files or an error results. Otherwise, the 
     *  returned list may contain only those files that are accessible through 
     *  this session. 
     *
     *  @param  name the name of the file 
     *  @return the list of files of the given name 
     *  @throws org.osid.NullArgumentException <code> name </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.FileList getFilesByName(String name)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of files and aliases to files in this directory. In a 
     *  federated view, this method returns all files in descendant 
     *  directories. In plenary mode, the returned list contains all known 
     *  files or an error results. Otherwise, the returned list may contain 
     *  only those files that are accessible through this session. 
     *
     *  @return the list of files in this directory 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.FileList getFiles()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a specified directory or alias to the directory by its name in 
     *  the current directory only. For federated views, use <code> 
     *  getDirectoriesByName(). </code> 
     *
     *  @param  name the name of the directory 
     *  @return the directory 
     *  @throws org.osid.NotFoundException <code> name </code> is not found or 
     *          is a file 
     *  @throws org.osid.NullArgumentException <code> name </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.Directory getSubdirectory(String name)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a specified directories and aliases to directories for the given 
     *  directory name. In an isolated view, this method behaves like <code> 
     *  getDirectory(). </code> Is a federated view, this method returns a 
     *  list of directories by the same name in descedent directories. In 
     *  plenary mode, the returned list contains all known files or an error 
     *  results. Otherwise, the returned list may contain only those files 
     *  that are accessible through this session. 
     *
     *  @param  name the name of the file 
     *  @return the list of files of the given name 
     *  @throws org.osid.NullArgumentException <code> name </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.DirectoryList getSubdirectoriesByName(String name)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of directories and aliases to directories in this 
     *  directory. In a federated view, this method returns all directories in 
     *  descedent directories. In plenary mode, the returned list contains all 
     *  known files or an error results. Otherwise, the returned list may 
     *  contain only those files that are accessible through this session. 
     *
     *  @return the list of directories in this directory 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.DirectoryList getSubdirectories()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
