//
// org.osid.filing.FilingProfile
//
//     The OSID Java specification for org.osid.filing.FilingProfile.
//
// Copyright (C) 2003-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010, 2014 Ingnescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.filing;


/**
 *  <p>The filing profile describes the interoperability among filing 
 *  services. </p>
 */

public interface FilingProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if directory federation is exposed. Federation is exposed when a 
     *  specific directory may be identified, selected and used to access a 
     *  session. Federation is not exposed when a set of directories appears 
     *  as a single directory. 
     *
     *  @return <code> true </code> if federation is visible <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if a <code> FileSystemSession </code> is supported. 
     *
     *  @return <code> true </code> if a <code> FileSystemSession </code> is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFileSystem();


    /**
     *  Tests if a <code> FileSystemManagementSession </code> is supported. 
     *
     *  @return <code> true </code> if a <code> FileSystemManagementSession 
     *          </code> is available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFileSystemManagement();


    /**
     *  Tests if a <code> FileContentSession </code> is supported. 
     *
     *  @return <code> true </code> if a <code> FileContentSession </code> is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFileContent();


    /**
     *  Tests if file lookup is supported. 
     *
     *  @return <code> true </code> if a <code> FileLookupSession </code> is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFileLookup();


    /**
     *  Tests if file querying is supported. 
     *
     *  @return <code> true </code> if a <code> FileQuerySession </code> is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFileQuery();


    /**
     *  Tests if file searching is supported. 
     *
     *  @return <code> true </code> if a <code> FileSearchSession </code> is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFileSearch();


    /**
     *  Tests if file notification is supported. 
     *
     *  @return <code> true </code> if a <code> FileNotificationSession 
     *          </code> is available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFileNotification();


    /**
     *  Tests if managing smart directories is supported. 
     *
     *  @return <code> true </code> if a <code> FileSmartDirectorySession 
     *          </code> is available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFileSmartDirectory();


    /**
     *  Tests if a <code> DirectoryLookupSession </code> is supported. 
     *
     *  @return <code> true </code> if a <code> DirectoryLookupSession </code> 
     *          is available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDirectoryLookup();


    /**
     *  Tests if directory querying is supported. 
     *
     *  @return <code> true </code> if a <code> DirectoryQuerySession </code> 
     *          is available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDirectoryQuery();


    /**
     *  Tests if directory searching is supported. 
     *
     *  @return <code> true </code> if a <code> DirectorySearchSession </code> 
     *          is available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDirectorySearch();


    /**
     *  Tests if directory administration is supported. 
     *
     *  @return <code> true </code> if a <code> DirectoryAdminSession </code> 
     *          is available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDirectoryAdmin();


    /**
     *  Tests if a directory <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if a <code> DirectoryNotificationSession 
     *          </code> is available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDirectoryNotification();


    /**
     *  Tests if a file management service is supported. 
     *
     *  @return <code> true </code> if a <code> FileManagementSession </code> 
     *          is available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFilingManagement();


    /**
     *  Tests if a filing allocation service is supported. 
     *
     *  @return <code> true </code> if a <code> FilingAllocationManager 
     *          </code> is available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFilingAllocation();


    /**
     *  Gets the supported file record types. 
     *
     *  @return a list containing the supported <code> File </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getFileRecordTypes();


    /**
     *  Tests if the given file record type is supported. 
     *
     *  @param  fileRecordType a <code> Type </code> indicating a file record 
     *          type 
     *  @return <code> true </code> if the given record <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> fileRecordType </code> 
     *          is null 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFileRecordType(org.osid.type.Type fileRecordType);


    /**
     *  Gets the supported file search record types. 
     *
     *  @return a list containing the supported <code> File </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getFileSearchRecordTypes();


    /**
     *  Tests if the given file search record type is supported. 
     *
     *  @param  fileSearchRecordType a <code> Type </code> indicating a file 
     *          search record type 
     *  @return <code> true </code> if the given search record <code> Type 
     *          </code> is supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> fileSearchRecordType 
     *          </code> is null 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFileSearchRecordType(org.osid.type.Type fileSearchRecordType);


    /**
     *  Gets the supported directory record types. 
     *
     *  @return a list containing the supported <code> Directory </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getDirectoryRecordTypes();


    /**
     *  Tests if the given directory record type is supported. 
     *
     *  @param  directoryRecordType a <code> Type </code> indicating a 
     *          directory record type 
     *  @return <code> true </code> if the given record <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> directoryRecordType 
     *          </code> is null 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDirectoryRecordType(org.osid.type.Type directoryRecordType);


    /**
     *  Gets the supported directory search record types. 
     *
     *  @return a list containing the supported <code> Directory </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getDirectorySearchRecordTypes();


    /**
     *  Tests if the given directory search record type is supported. 
     *
     *  @param  directorySearchRecordType a <code> Type </code> indicating a 
     *          directory search record type 
     *  @return <code> true </code> if the given search record <code> Type 
     *          </code> is supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          directorySearchRecordType </code> is null 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDirectorySearchRecordType(org.osid.type.Type directorySearchRecordType);
}
