//
// org.osid.filing.allocation.AllocationAdminSession
//
//     The OSID Java specification for org.osid.filing.allocation.AllocationAdminSession.
//
// Copyright (C) 2010 Ingnescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.filing.allocation;


/**
 *  <p>This session defines methods for managing quotas. Allocations can be 
 *  assigned across all users in a directory structure or on a user by user 
 *  basis. </p>
 */

public interface AllocationAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the absolute path of this directory. 
     *
     *  @return the absolute path of this directory 
     *  @compliance mandatory This method must be implemented. 
     */

    public String getDirectoryPath();


    /**
     *  Gets the directory associated with this session. 
     *
     *  @return the directory associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.Directory getDirectory()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create allocations in this session for or under 
     *  the session directory. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer create operations to unauthorized users. 
     *
     *  @return <code> false </code> if filing allocation create methods are 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAllocations();


    /**
     *  Tests if this user can create a single <code> Allocation </code> using 
     *  the desired record types. While <code> 
     *  FilingAllocationManager.getAllocationRecordTypes() </code> can be used 
     *  to examine which records are supported, this method tests which 
     *  record(s) are required for creating a specific <code> Allocation. 
     *  </code> Providing an empty array tests if an <code> Allocation </code> 
     *  can be created with no records. 
     *
     *  @param  allocationRecordTypes array of allocation record types 
     *  @return <code> true </code> if <code> Allocation </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> allocationRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAllocationWithRecordTypes(org.osid.type.Type[] allocationRecordTypes);


    /**
     *  Gets the file form for creating new allocations across all users for a 
     *  directory. A new form should be requested for each create transaction. 
     *
     *  @param  name name of a directory 
     *  @param  allocationRecordTypes array of allocation record types 
     *  @return the allocation form 
     *  @throws org.osid.AlreadyExistsException allocation already exists 
     *  @throws org.osid.NotFoundException <code> name </code> not found 
     *  @throws org.osid.NullArgumentException <code> name </code> or <code> 
     *          allocationRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.allocation.AllocationForm getAllocationFormForCreate(String name, 
                                                                                org.osid.type.Type[] allocationRecordTypes)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new allocation across all users for a directory. 
     *
     *  @param  allocationForm the allocation form 
     *  @return the new allocation 
     *  @throws org.osid.IllegalStateException <code> allocationForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> allocationForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> fileForm </code> did not 
     *          originate from <code> getAllocationFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.allocation.Allocation createAllocation(org.osid.filing.allocation.AllocationForm allocationForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update allocations for directories in this 
     *  session. A return of true does not guarantee successful authorization. 
     *  A return of false indicates that it is known all methods in this 
     *  session will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer update 
     *  operations to unauthorized users. 
     *
     *  @return <code> false </code> if filing allocation update methods are 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateAllocations();


    /**
     *  Gets the allocation form for updating an existing allocation. A new 
     *  file form should be requested for each update transaction. 
     *
     *  @param  name name of the directory 
     *  @return the allocation form 
     *  @throws org.osid.NotFoundException <code> name </code> is not found or 
     *          no allocation exists 
     *  @throws org.osid.NullArgumentException <code> name </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.allocation.AllocationForm getAllocationFormForUpdate(String name)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing allocation. 
     *
     *  @param  allocationForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> allocationForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> allocationForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> allocationForm </code> 
     *          did not originate from <code> getAllocationFormForUpdate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateAllocation(org.osid.filing.allocation.AllocationForm allocationForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete allocations for directories in this 
     *  session. A return of true does not guarantee successful authorization. 
     *  A return of false indicates that it is known all methods in this 
     *  session will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer delete 
     *  operations to unauthorized users. 
     *
     *  @return <code> false </code> if filing allocation delete methods are 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteAllocations();


    /**
     *  Deletes the allocation for a directory. 
     *
     *  @param  name the name of the directory 
     *  @throws org.osid.NotFoundException <code> name </code> is not found or 
     *          no allocation exists 
     *  @throws org.osid.NullArgumentException <code> name </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteAllocation(String name)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create allocations in this session for or under 
     *  the session directory for specific users. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer create operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if user allocation create methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAllocationsForUsers();


    /**
     *  Tests if this user can create a single <code> Allocation </code> using 
     *  the desired record types targeted for specific users. While <code> 
     *  FilingAllocationManager.getAllocationRecordTypes() </code> can be used 
     *  to examine which records are supported, this method tests which 
     *  record(s) are required for creating a specific <code> Allocation. 
     *  </code> Providing an empty array tests if an <code> Allocation </code> 
     *  can be created with no records. 
     *
     *  @param  allocationRecordTypes array of allocation record types 
     *  @return <code> true </code> if <code> Allocation </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> allocationRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAllocationWithRecordTypesForUsers(org.osid.type.Type[] allocationRecordTypes);


    /**
     *  Gets the file form for creating new allocations across all users for a 
     *  directory. A new form should be requested for each create transaction. 
     *
     *  @param  name name of a directory 
     *  @param  agentId the <code> Id </code> of a user 
     *  @param  allocationRecordTypes array of allocation record types 
     *  @return the allocation form 
     *  @throws org.osid.AlreadyExistsException allocation already exists 
     *  @throws org.osid.NotFoundException <code> name </code> or <code> 
     *          agentId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> name, agentId, </code> 
     *          or <code> allocationRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.allocation.AllocationForm getAllocationFormForCreateForUser(String name, 
                                                                                       org.osid.id.Id agentId, 
                                                                                       org.osid.type.Type[] allocationRecordTypes)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new allocation for a specific user for a directory. 
     *
     *  @param  allocationForm the allocation form 
     *  @return the new allocation 
     *  @throws org.osid.IllegalStateException <code> allocationForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> allocationForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> fileForm </code> did not 
     *          originate from <code> getAllocationFormForCreateForUser() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.allocation.Allocation createAllocationForUser(org.osid.filing.allocation.AllocationForm allocationForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update allocations for users in directories in 
     *  this session. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer update operations to unauthorized users. 
     *
     *  @return <code> false </code> if filing allocation user update methods 
     *          are not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateAllocationsForUsers();


    /**
     *  Gets the allocation form for updating an existing allocation for a 
     *  user. A new file form should be requested for each update transaction. 
     *
     *  @param  name name of the directory 
     *  @param  agentId the <code> Id </code> of the user 
     *  @return the allocation form 
     *  @throws org.osid.NotFoundException <code> name </code> or <code> 
     *          agentId </code> is not found or no allocation exists 
     *  @throws org.osid.NullArgumentException <code> name </code> or <code> 
     *          agentId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.allocation.AllocationForm getAllocationFormForUpdateForUser(String name, 
                                                                                       org.osid.id.Id agentId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing allocation. 
     *
     *  @param  allocationForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> allocationForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> allocationForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> allocationForm </code> 
     *          did not originate from <code> 
     *          getAllocationFormForUpdateForUser() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateAllocationForUser(org.osid.filing.allocation.AllocationForm allocationForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete allocations for users in directories in 
     *  this session. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer delete operations to unauthorized users. 
     *
     *  @return <code> false </code> if filing allocation delete methods are 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteAllocationsForUser();


    /**
     *  Deletes the allocation for a directory. 
     *
     *  @param  name name of the directory 
     *  @param  agentId the <code> Id </code> of the user 
     *  @throws org.osid.NotFoundException <code> name </code> or <code> 
     *          agentId </code> is not found or no allocation exists 
     *  @throws org.osid.NullArgumentException <code> name </code> or <code> 
     *          agentId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteAllocationForUser(String name, org.osid.id.Id agentId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
