//
// org.osid.filing.allocation.AllocationForm
//
//     The OSID Java specification for org.osid.filing.allocation.AllocationForm.
//
// Copyright (C) 2010 Ingnescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.filing.allocation;


/**
 *  <p><code> DirectoryEntryForm </code> defines methods in common to both 
 *  <code> FileForm </code> and <code> DirectoryForm. </code> </p>
 */

public interface AllocationForm
    extends org.osid.OsidExtensibleForm,
            org.osid.OsidBrowsableForm {


    /**
     *  Gets the metadata for the total space. 
     *
     *  @return metadata for the total space 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getTotalSpaceMetadata();


    /**
     *  Sets the total space. 
     *
     *  @param  bytes the new total space 
     *  @throws org.osid.InvalidArgumentException <code> bytes </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setTotalSpace(long bytes);


    /**
     *  Clears the total space. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTotalSpace();


    /**
     *  Gets the metadata for the total files. 
     *
     *  @return metadata for the total files 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getTotalFilesMetadata();


    /**
     *  Sets the total files. 
     *
     *  @param  number the new total files 
     *  @throws org.osid.InvalidArgumentException <code> number </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setTotalFiles(long number);


    /**
     *  Clears the total files. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTotalFiles();


    /**
     *  Gets the <code> AllocationFormRecord </code> corresponding to the 
     *  given allocation record <code> Type. </code> 
     *
     *  @param  allocationRecordType the allocation record type 
     *  @return the allocation form record 
     *  @throws org.osid.NullArgumentException <code> allocationRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(allocationRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.allocation.records.AllocationFormRecord getAllocationFormRecord(org.osid.type.Type allocationRecordType)
        throws org.osid.OperationFailedException;
}
