//
// org.osid.filing.allocation.AllocationLookupSession
//
//     The OSID Java specification for org.osid.filing.allocation.AllocationLookupSession.
//
// Copyright (C) 2010 Ingnescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.filing.allocation;


/**
 *  <p>This session defines methods for accessing space allocation and quotas. 
 *  </p>
 */

public interface AllocationLookupSession
    extends org.osid.filing.allocation.AllocationSession {


    /**
     *  Gets the user quota allocations of the data store for the given user 
     *  including any subdirectories. The directory available by the 
     *  allocation may indicate a higher level directory than the one 
     *  requested if the one requested is a sub-directory inside the qoutad 
     *  data store. 
     *
     *  @param  agentId the agent <code> Id </code> of the user 
     *  @return the allocation 
     *  @throws org.osid.NullArgumentException <code> agentId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.allocation.AllocationList getUserAllocationsForUser(org.osid.id.Id agentId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the user quota allocation of the data store for each user. The 
     *  directory available by the allocation may indicate a higher level 
     *  directory than the one requested if the one requested is a 
     *  sub-directory inside the qoutad data store. 
     *
     *  @return the allocation 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.allocation.AllocationList getUserAllocations()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the quota allocations of the data store for all users matching or 
     *  exceeding the given utilization. The directory available by the 
     *  allocation may indicate a higher level directory than the one 
     *  requested if the one requested is a sub-directory inside the qoutad 
     *  data store. 
     *
     *  @param  percentage the utilization percentage (0-100) 
     *  @return the allocation 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.allocation.AllocationList getUserAllocationsByUtilization(long percentage)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
