//
// org.osid.filing.allocation.AllocationReceiver
//
//     The OSID Java specification for org.osid.filing.allocation.AllocationReceiver.
//
// Copyright (C) 2010 Ingnescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.filing.allocation;


/**
 *  <p>The allocation receiver is the consumer supplied interface for 
 *  receiving notifications pertaining to usage warnings and changed quota 
 *  assignments. </p>
 */

public interface AllocationReceiver
    extends org.osid.OsidReceiver {


    /**
     *  The callback for notifications of usage warnings. 
     *
     *  @param  directoryPath absolute pathname to the directory 
     *  @compliance mandatory This method must be implemented. 
     */

    public void warning(String directoryPath);


    /**
     *  The callback for notification of cleared usage warnings. 
     *
     *  @param  directoryPath absolute pathname to the directory 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearWarning(String directoryPath);


    /**
     *  The callback for notification of a new, removed or changed allocation 
     *  on a directory. 
     *
     *  @param  directoryPath absolute pathname to the directory 
     *  @compliance mandatory This method must be implemented. 
     */

    public void changedAllocation(String directoryPath);


    /**
     *  The callback for notification of a new, removed or changed quota 
     *  assignment. 
     *
     *  @param  directoryPath absolute pathname to the directory 
     *  @param  agentId the user <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void changedUserAllocation(String directoryPath, String agentId);
}
