/**
 * <p>The Open Service Interface Definitions for the org.osid.filing
 * service.</p>
 * 
 * <p>The Filing OSID provides a means for managing and accessing files and 
 * directories. The Filing OSID is used to abstract assumptions made about 
 * using a specific file system, or can be used to provide a file-based 
 * application a file system oriented view of other OSIDs. </p> 
 * <h4> Files </h4> 
 * 
 * <p> The Filing OSID defines a file access session that maps to a single 
 * <code> File. </code> This is the simplest application of the Filing OSID 
 * can be used in circumstances when it is desirable to confine knowledge of 
 * directories within a provider. </p> 
 * <h4> Directories </h4> 
 * 
 * <p> <code> Directories </code> are hierarchical <code> OsidCatalogs </code> 
 * of Files. </p> 
 * <h4> Differences from OSID Patterns </h4> 
 * 
 * <p> The Filing OSID assumes the pathname and filename of a <code> File 
 * </code> or <code> Directory </code> is globally unique. Typically, only the 
 * <code> Id </code> field is unique in an <code> OsidObject. </code> In the 
 * Filing OSID, there are two unique identifiers for identifying <code> Files 
 * </code> and Directories. </p> 
 * 
 * <p> The <code> Id </code> is used to conform to existing OSID patterns and 
 * more easily create relationships to other auxiliary services such as the 
 * Journaling OSID, Relationship OSID, or the Ontology OSID. However, in a 
 * file system one is accustomed to traversing a file system using path names. 
 * </p> 
 * 
 * <p> The standard <code> OsidSessions </code> refer to <code> Files </code> 
 * and <code> Directories </code> using their <code> Ids. </code> The file 
 * system-oriented and content sessions access and manipulate the file system 
 * using path names. Access to these sessions via the <code> OsidManagers 
 * </code> provide for both a path name and <code> Directory </code> <code> 
 * Id. </code> </p> 
 * 
 * <p> The cataloging in the file system and content sessions behave 
 * differently than that in other OsidSessions. Typically, one is constrained 
 * to <code> OsidObjects </code> within the <code> OsidCatalog, </code> and 
 * its children in a federated view. In these sessions which use the path name 
 * as a key, <code> Files </code> and <code> Directories </code> outside the 
 * local Directory may be accessed with the use of absolute path names. </p> 
 * 
 * <p> Finally, there are no hierarchical service patterns in the <code> 
 * Directory </code> <code> OsidCatalog </code> and a <code> File </code> or 
 * sub-directory may belong to one and only one <code> Directory </code> . 
 * </p> 
 * <h4> Example </h4> 
 * 
 * <pre>
 *      
 *      
 *      FilieSession session = filingManager.getFileContentSession();
 *      DataInputStream dis = session.getInputStream("/etc/passwd");
 *      
 *              
 *      
 * </pre>
 * 
 * <h4> Sub Packages </h4> 
 * 
 * <p> The Filing OSID contains a Filing Allocation OSID for examining and 
 * managing file system utilization and user quotas. </p>
 * 
 * <br/><hr/><br/>
 * 
 * <p>Copyright &copy; 2003-2004, 2007 Massachusetts Institute of Technology. 
 * </p> 
 * 
 * <p> Copyright &copy; 2010, 2014 Ingnescus. All Rights Reserved. </p>
 * 
 * <p>This Work is being provided by the copyright holder(s) subject to the 
 * following license. By obtaining, using and/or copying this Work, you agree 
 * that you have read, understand, and will comply with the following terms 
 * and conditions. </p> 
 * 
 * <p> Permission to use, copy and distribute unmodified versions of this 
 * Work, for any purpose, without fee or royalty is hereby granted, provided 
 * that you include the above copyright notices and the terms of this license 
 * on ALL copies of the Work or portions thereof. </p> 
 * 
 * <p> You may nodify or create Derivatives of this Work only for your 
 * internal purposes. You shall not distribute or transfer any such Derivative 
 * of this Work to any location or to any third party. For the purposes of 
 * this license, "Derivative" shall mean any derivative of the Work as defined 
 * in the United States Copyright Act of 1976, such as a translation or 
 * modification. </p> 
 * 
 * <p> This Work and the information contained herein is provided on an "AS 
 * IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT 
 * NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR 
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT 
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN 
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN 
 * CONNECTION WITH THE WORK OR THE USE OR OTHER DEALINGS IN THE WORK. </p> 
 * 
 * <p> The export of software employing encryption technology may require a 
 * specific license from the United States Government. It is the 
 * responsibility of any person or organization contemplating export to obtain 
 * such a license before exporting this Work. </p>
 */

package org.osid.filing;
