//
// org.osid.financials.AccountBusinessAssignmentSession
//
//     The OSID Java specification for org.osid.financials.AccountBusinessAssignmentSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.financials;


/**
 *  <p>This session provides methods to re-assign <code> Accounts </code> to 
 *  <code> Business </code> objects An <code> Account </code> may appear in 
 *  multiple <code> Business </code> objects and removing the last reference 
 *  to an <code> Account </code> is the equivalent of deleting it. Each <code> 
 *  Business </code> may have its own authorizations governing who is allowed 
 *  to operate on it. </p> 
 *  
 *  <p> Adding a reference of an <code> Account </code> to another <code> 
 *  Business </code> is not a copy operation (eg: does not change its <code> 
 *  Id </code> ). </p>
 */

public interface AccountBusinessAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter account/business mappings. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignAccounts();


    /**
     *  Tests if this user can alter account/business mappings. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @param  businessId the <code> Id </code> of the <code> Business 
     *          </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> businessId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignAccountToBusiness(org.osid.id.Id businessId);


    /**
     *  Gets a list of businesses including and under the given business node 
     *  in which any account can be assigned. 
     *
     *  @param  businessId the <code> Id </code> of the <code> Business 
     *          </code> 
     *  @return list of assignable business <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> businessId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableBusinessIds(org.osid.id.Id businessId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of businesses including and under the given business node 
     *  in which a specific account can be assigned. 
     *
     *  @param  businessId the <code> Id </code> of the <code> Business 
     *          </code> 
     *  @param  accountId the <code> Id </code> of the <code> Account </code> 
     *  @return list of assignable business <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> businessId </code> or 
     *          <code> accountId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableBusinessIdsForAccount(org.osid.id.Id businessId, 
                                                                 org.osid.id.Id accountId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> Account </code> to a <code> Business. </code> 
     *
     *  @param  accountId the <code> Id </code> of the <code> Account </code> 
     *  @param  businessId the <code> Id </code> of the <code> Business 
     *          </code> 
     *  @throws org.osid.AlreadyExistsException <code> accountId </code> is 
     *          already assigned to <code> businessId </code> 
     *  @throws org.osid.NotFoundException <code> accountId </code> or <code> 
     *          businessId </code> not found 
     *  @throws org.osid.NullArgumentException <code> accountId </code> or 
     *          <code> businessId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignAccountToBusiness(org.osid.id.Id accountId, 
                                        org.osid.id.Id businessId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes an <code> Account </code> from a <code> Business. </code> 
     *
     *  @param  accountId the <code> Id </code> of the <code> Account </code> 
     *  @param  businessId the <code> Id </code> of the <code> Business 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> accountId </code> or <code> 
     *          businessId </code> not found or <code> accountId </code> not 
     *          assigned to <code> businessId </code> 
     *  @throws org.osid.NullArgumentException <code> accountId </code> or 
     *          <code> businessId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignAccountFromBusiness(org.osid.id.Id accountId, 
                                            org.osid.id.Id businessId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
