//
// org.osid.financials.ActivityAdminSession
//
//     The OSID Java specification for org.osid.financials.ActivityAdminSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.financials;


/**
 *  <p>This session creates, updates, and deletes <code> Activities. </code> 
 *  The data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create an 
 *  <code> Activity, </code> an <code> ActivityForm </code> is requested using 
 *  <code> getActivityFormForCreate() </code> specifying the desired record 
 *  <code> Types </code> or none if no record <code> Types </code> are needed. 
 *  The returned <code> ActivityForm </code> will indicate that it is to be 
 *  used with a create operation and can be used to examine metdata or 
 *  validate data prior to creation. Once the <code> ActivityForm </code> is 
 *  submiited to a create operation, it cannot be reused with another create 
 *  operation unless the first operation was unsuccessful. Each <code> 
 *  ActivityForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> ActivityForms </code> are requested to the <code> 
 *  Activity </code> <code> Id </code> that is to be updated using <code> 
 *  getActivityFormForUpdate(). </code> Similarly, the <code> ActivityForm 
 *  </code> has metadata about the data that can be updated and it can perform 
 *  validation before submitting the update. The <code> ActivityForm </code> 
 *  can only be used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Activities. </code> To unmap an 
 *  <code> Activity </code> from the current <code> Business, </code> the 
 *  <code> ActivityBusinessAssignmentSession </code> should be used. These 
 *  delete operations attempt to remove the <code> Activity </code> itself 
 *  thus removing it from all known <code> Business </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface ActivityAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Business </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Business Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBusinessId();


    /**
     *  Gets the <code> Business </code> associated with this session. 
     *
     *  @return the business 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.Business getBusiness()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> Activities. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating an <code> Activity </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer create operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Activity </code> creation is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateActivities();


    /**
     *  Tests if this user can create a single <code> Activity </code> using 
     *  the desired record types. While <code> 
     *  FinancialsManager.getActivityRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> Activity. </code> 
     *  Providing an empty array tests if an <code> Activity </code> can be 
     *  created with no records. 
     *
     *  @param  activityRecordTypes array of activity record types 
     *  @return <code> true </code> if <code> Activity </code> creation using 
     *          the specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> activityRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateActivityWithRecordTypes(org.osid.type.Type[] activityRecordTypes);


    /**
     *  Gets the activity form for creating new activities. A new form should 
     *  be requested for each create transaction. 
     *
     *  @param  activityRecordTypes array of activity record types 
     *  @return the activity form 
     *  @throws org.osid.NullArgumentException <code> activityRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.ActivityForm getActivityFormForCreate(org.osid.type.Type[] activityRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Activity. </code> 
     *
     *  @param  activityForm the form for this <code> Activity </code> 
     *  @return the new <code> Activity </code> 
     *  @throws org.osid.IllegalStateException <code> activityForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> activityForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> activityForm </code> did 
     *          not originate from <code> getActvityFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.Activity createActivity(org.osid.financials.ActivityForm activityForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Activities. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating an <code> Activity </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer update operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Activity </code> modification 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateActivities();


    /**
     *  Gets the activity form for updating an existing activity. A new 
     *  activity form should be requested for each update transaction. 
     *
     *  @param  activityId the <code> Id </code> of the <code> Activity 
     *          </code> 
     *  @return the activity form 
     *  @throws org.osid.NotFoundException <code> activityId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> activityId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.ActivityForm getActivityFormForUpdate(org.osid.id.Id activityId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing activity. 
     *
     *  @param  activityForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> activityForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> activityForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> activityForm </code> did 
     *          not originate from <code> getActvityFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateActivity(org.osid.financials.ActivityForm activityForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> Activities. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting an <code> Activity </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer delete operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Activity </code> deletion is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteActivities();


    /**
     *  Deletes an <code> Activity. </code> 
     *
     *  @param  activityId the <code> Id </code> of the <code> Activity 
     *          </code> to remove 
     *  @throws org.osid.NotFoundException <code> activityId </code> not found 
     *  @throws org.osid.NullArgumentException <code> activityId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteActivity(org.osid.id.Id activityId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Activities. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Activity </code> aliasing is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageActivityAliases();


    /**
     *  Adds an <code> Id </code> to an <code> Activity </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Activity </code> is deactivityined by the provider. The new 
     *  <code> Id </code> performs as an alias to the primary <code> Id 
     *  </code> . If the alias is a pointer to another activity, it is 
     *  reassigned to the given activity <code> Id. </code> 
     *
     *  @param  activityId the <code> Id </code> of an <code> Activity </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is in 
     *          use as a primary <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> activityId </code> not found 
     *  @throws org.osid.NullArgumentException <code> activityId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasActivity(org.osid.id.Id activityId, 
                              org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
