//
// org.osid.financials.ActivityForm
//
//     The OSID Java specification for org.osid.financials.ActivityForm.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.financials;


/**
 *  <p>This is the form for creating and updating <code> Activities. </code> 
 *  Like all <code> OsidForm </code> objects, various data elements may be set 
 *  here for use in the create and update methods in the <code> 
 *  ActivityAdminSession. </code> For each data element that may be set, 
 *  metadata may be examined to provide display hints or data constraints. 
 *  </p>
 */

public interface ActivityForm
    extends org.osid.OsidObjectForm,
            org.osid.OsidFederateableForm,
            org.osid.OsidTemporalForm {


    /**
     *  Gets the metadata for the organization. 
     *
     *  @return metadata for the organization 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getOrganizationMetadata();


    /**
     *  Sets the organization. 
     *
     *  @param  organizationId the new organization 
     *  @throws org.osid.InvalidArgumentException <code> organizationId 
     *          </code> is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> organizationId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setOrganization(org.osid.id.Id organizationId);


    /**
     *  Removes the organization. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOrganization();


    /**
     *  Gets the metadata for the supervisor. 
     *
     *  @return metadata for the supervisor 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getSupervisorMetadata();


    /**
     *  Sets the supervisor. 
     *
     *  @param  supervisorId the new supervisor 
     *  @throws org.osid.InvalidArgumentException <code> supervisorId </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> supervisorId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setSupervisor(org.osid.id.Id supervisorId);


    /**
     *  Removes the supervisor. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSupervisor();


    /**
     *  Gets the metadata for the code flag. 
     *
     *  @return metadata for the code 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getCodeMetadata();


    /**
     *  Sets the code. 
     *
     *  @param  code the new code 
     *  @throws org.osid.InvalidArgumentException <code> code </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setCode(String code);


    /**
     *  Removes the code. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCode();


    /**
     *  Gets the <code> ActivityFormRecord </code> corresponding to the given 
     *  activity record <code> Type. </code> 
     *
     *  @param  activityRecordType an activity record type 
     *  @return the activity form record 
     *  @throws org.osid.NullArgumentException <code> activityRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(activityRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.records.ActivityFormRecord getActivityFormRecord(org.osid.type.Type activityRecordType)
        throws org.osid.OperationFailedException;
}
