//
// org.osid.financials.ActivityQuery
//
//     The OSID Java specification for org.osid.financials.ActivityQuery.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.financials;


/**
 *  <p>This is the query for searching activities. Each method match specifies 
 *  an <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface ActivityQuery
    extends org.osid.OsidObjectQuery,
            org.osid.OsidFederateableQuery,
            org.osid.OsidTemporalQuery {


    /**
     *  Sets the organization <code> Id </code> for this query. 
     *
     *  @param  organizationId a resource <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> organizationId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchOrganizationId(org.osid.id.Id organizationId, 
                                    boolean match);


    /**
     *  Clears the organization <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOrganizationIdTerms();


    /**
     *  Tests if a <code> ResourceQuery </code> is available. 
     *
     *  @return <code> true </code> if an organization query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOrganizationQuery();


    /**
     *  Gets the query for an organization. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the resource query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOrganizationQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOrganizationQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resource.ResourceQuery getOrganizationQuery();


    /**
     *  Matches an activity that has any organization. 
     *
     *  @param  match <code> true </code> to match activities with any 
     *          organization, <code> false </code> to match activities with no 
     *          organization 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyOrganization(boolean match);


    /**
     *  Clears the organization terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOrganizationTerms();


    /**
     *  Sets the supervisor <code> Id </code> for this query. 
     *
     *  @param  supervisorId a resource <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> supervisorId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSupervisorId(org.osid.id.Id supervisorId, boolean match);


    /**
     *  Clears the supervisor <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSupervisorIdTerms();


    /**
     *  Tests if a <code> ResourceQuery </code> is available. 
     *
     *  @return <code> true </code> if a supervisor query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSupervisorQuery();


    /**
     *  Gets the query for a supervisor. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the resource query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSupervisorQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSupervisorQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceQuery getSupervisorQuery();


    /**
     *  Matches an activity that has any supervisor. 
     *
     *  @param  match <code> true </code> to match activities with any 
     *          supervisor, <code> false </code> to match activities with no 
     *          supervisor 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnySupervisor(boolean match);


    /**
     *  Clears the supervisor terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSupervisorTerms();


    /**
     *  Matches an activity code. 
     *
     *  @param  code a code 
     *  @param  stringMatchType the string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> code </code> is not 
     *          of <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> code </code> is <code> 
     *          null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCode(String code, org.osid.type.Type stringMatchType, 
                          boolean match);


    /**
     *  Matches an activity that has any code assigned. 
     *
     *  @param  match <code> true </code> to match activities with any code, 
     *          <code> false </code> to match activities with no code 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCode(boolean match);


    /**
     *  Clears the code terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCodeTerms();


    /**
     *  Tests if a <code> SummaryQuery </code> is available. 
     *
     *  @return <code> true </code> if a summery query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSummaryQuery();


    /**
     *  Gets the query for a summary. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the summery query 
     *  @throws org.osid.UnimplementedException <code> supportsSummeryQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSupervisorQuery() </code> is <code> true. </code> 
     */

    public org.osid.financials.SummaryQuery getSummaryQuery();


    /**
     *  Clears the summary terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSummaryTerms();


    /**
     *  Sets the activity <code> Id </code> for this query to match activities 
     *  that have the specified activity as an ancestor. 
     *
     *  @param  activityId an activity <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> activityId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorActivityId(org.osid.id.Id activityId, 
                                        boolean match);


    /**
     *  Clears the ancestor activity <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorActivityIdTerms();


    /**
     *  Tests if an <code> ActivityQuery </code> is available. 
     *
     *  @return <code> true </code> if an activity query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorActivityQuery();


    /**
     *  Gets the query for an activity. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the activity query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorActivityQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorActivityQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.financials.ActivityQuery getAncestorActivityQuery();


    /**
     *  Matches activities with any activity ancestor. 
     *
     *  @param  match <code> true </code> to match activities with any 
     *          ancestor, <code> false </code> to match root activities 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorActivity(boolean match);


    /**
     *  Clears the ancestor activity query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorActivityTerms();


    /**
     *  Sets the activity <code> Id </code> for this query to match activities 
     *  that have the specified activity as a descendant. 
     *
     *  @param  activityId an activity <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> activityId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantActivityId(org.osid.id.Id activityId, 
                                          boolean match);


    /**
     *  Clears the descendant activity <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantActivityIdTerms();


    /**
     *  Tests if an <code> ActivityQuery </code> is available. 
     *
     *  @return <code> true </code> if an activity query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantActivityQuery();


    /**
     *  Gets the query for an activity. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the activity query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantActivityQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantActivityQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.financials.ActivityQuery getDescendantActivityQuery();


    /**
     *  Matches activities with any activity descendant. 
     *
     *  @param  match <code> true </code> to match activities with any 
     *          descendant, <code> false </code> to match leaf activities 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantActivity(boolean match);


    /**
     *  Clears the descendant activity query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantActivityTerms();


    /**
     *  Sets the business <code> Id </code> for this query to match activities 
     *  assigned to businesses. 
     *
     *  @param  businessId the business <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> businessId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBusinessId(org.osid.id.Id businessId, boolean match);


    /**
     *  Clears the business <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBusinessIdTerms();


    /**
     *  Tests if a <code> BusinessQuery </code> is available. 
     *
     *  @return <code> true </code> if a business query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBusinessQuery();


    /**
     *  Gets the query for a business. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the business query 
     *  @throws org.osid.UnimplementedException <code> supportsBusinessQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBusinessQuery() </code> is <code> true. </code> 
     */

    public org.osid.financials.BusinessQuery getBusinessQuery();


    /**
     *  Clears the business terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBusinessTerms();


    /**
     *  Gets the activity query record corresponding to the given <code> 
     *  Activity </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  activityRecordType an activity record type 
     *  @return the activity query record 
     *  @throws org.osid.NullArgumentException <code> activityRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(activityRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.records.ActivityQueryRecord getActivityQueryRecord(org.osid.type.Type activityRecordType)
        throws org.osid.OperationFailedException;
}
