//
// org.osid.financials.ActivityReceiver
//
//     The OSID Java specification for org.osid.financials.ActivityReceiver.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.financials;


/**
 *  <p>The activity receiver is the consumer supplied interface for receiving 
 *  notifications pertaining to new, updated or deleted <code> Activity 
 *  </code> objects. </p>
 */

public interface ActivityReceiver
    extends org.osid.OsidReceiver {


    /**
     *  The callback for notifications of new activities. 
     *
     *  @param  activityIds the <code> Ids </code> of the new <code> 
     *          Activities </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newActivities(org.osid.id.IdList activityIds);


    /**
     *  The callback for notifications of new activity ancestors. 
     *
     *  @param  activityId the <code> Id </code> of the <code> Activity 
     *          </code> 
     *  @param  ancestorId the <code> Id </code> of the new <code> Activity 
     *          </code> ancestor 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newAncestorActivity(org.osid.id.Id activityId, 
                                    org.osid.id.Id ancestorId);


    /**
     *  The callback for notifications of new activity descendants. 
     *
     *  @param  activityId the <code> Id </code> of the <code> Activity 
     *          </code> 
     *  @param  descendantId the <code> Id </code> of the new <code> Activity 
     *          </code> descendant 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newDescendantActivity(org.osid.id.Id activityId, 
                                      org.osid.id.Id descendantId);


    /**
     *  The callback for notification of updated activities. 
     *
     *  @param  activityIds the <code> Ids </code> of the updated <code> 
     *          Activities </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void changedActivities(org.osid.id.IdList activityIds);


    /**
     *  the callback for notification of deleted activities. 
     *
     *  @param  activityIds the <code> Ids </code> of the deleted <code> 
     *          Activities </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedActivities(org.osid.id.IdList activityIds);


    /**
     *  The callback for notifications of deleted activity ancestors. 
     *
     *  @param  activityId the <code> Id </code> of the <code> Activity 
     *          </code> 
     *  @param  ancestorId the <code> Id </code> of the new <code> Activity 
     *          </code> ancestor 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedAncestortActivity(org.osid.id.Id activityId, 
                                         org.osid.id.Id ancestorId);


    /**
     *  The callback for notifications of deleted activity descendants. 
     *
     *  @param  activityId the <code> Id </code> of the <code> Activity 
     *          </code> 
     *  @param  descendantId the <code> Id </code> of the new <code> Activity 
     *          </code> descendant 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedDescendantActivity(org.osid.id.Id activityId, 
                                          org.osid.id.Id descendantId);


    /**
     *  The callback for notifications of changes to an activity hierarchy 
     *  where the hierarchy needs to refreshed. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void restructuredActivityHierarchy();
}
