//
// org.osid.financials.FiscalPeriodForm
//
//     The OSID Java specification for org.osid.financials.FiscalPeriodForm.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.financials;


/**
 *  <p>This is the form for creating and updating <code> FiscalPeriods. 
 *  </code> Like all <code> OsidForm </code> objects, various data elements 
 *  may be set here for use in the create and update methods in the <code> 
 *  FiscalPeriodAdminSession. </code> For each data element that may be set, 
 *  metadata may be examined to provide display hints or data constraints. 
 *  </p>
 */

public interface FiscalPeriodForm
    extends org.osid.OsidObjectForm {


    /**
     *  Gets the metadata for a display label. 
     *
     *  @return metadata for the display label 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getDisplayLabelMetadata();


    /**
     *  Sets the display label. 
     *
     *  @param  label the new display label 
     *  @throws org.osid.InvalidArgumentException <code> label </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> label </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setDisplayLabel(String label);


    /**
     *  Removes the display label. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDisplayLabel();


    /**
     *  Gets the metadata for a fiscal year. 
     *
     *  @return metadata for the fiscal year 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getFiscalYearMetadata();


    /**
     *  Sets the fiscal year. 
     *
     *  @param  year the new fiscal year 
     *  @throws org.osid.InvalidArgumentException <code> year </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setFiscalYear(long year);


    /**
     *  Removes the fiscal year. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFiscalYear();


    /**
     *  Gets the metadata for the start date. 
     *
     *  @return metadata for the start date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getStartDateMetadata();


    /**
     *  Sets the start date. 
     *
     *  @param  date the new start date 
     *  @throws org.osid.InvalidArgumentException <code> date </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setStartDate(org.osid.calendaring.DateTime date);


    /**
     *  Removes the start date. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStartDate();


    /**
     *  Gets the metadata for the end date. 
     *
     *  @return metadata for the end date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getEndDateMetadata();


    /**
     *  Sets the end date. 
     *
     *  @param  date the new end date 
     *  @throws org.osid.InvalidArgumentException <code> date </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setEndDate(org.osid.calendaring.DateTime date);


    /**
     *  Removes the end date. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEndDate();


    /**
     *  Gets the metadata for the budget deadline. 
     *
     *  @return metadata for the budget deadline 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getBudgetDeadlineMetadata();


    /**
     *  Sets the budget deadline. 
     *
     *  @param  date the new budget deadline 
     *  @throws org.osid.InvalidArgumentException <code> date </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setBudgetDeadline(org.osid.calendaring.DateTime date);


    /**
     *  Removes the budget deadline. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBudgetDeadline();


    /**
     *  Gets the metadata for the posting deadline. 
     *
     *  @return metadata for the posting deadline 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getPostingDeadlineMetadata();


    /**
     *  Sets the posting deadline. 
     *
     *  @param  date the new posting deadline 
     *  @throws org.osid.InvalidArgumentException <code> date </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setPostingDeadline(org.osid.calendaring.DateTime date);


    /**
     *  Removes the posting deadline. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPostingDeadline();


    /**
     *  Gets the metadata for the closing date. 
     *
     *  @return metadata for the closing date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getClosingMetadata();


    /**
     *  Sets the closing date. 
     *
     *  @param  date the new closting date 
     *  @throws org.osid.InvalidArgumentException <code> date </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setClosing(org.osid.calendaring.DateTime date);


    /**
     *  Removes the closting date. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearClosing();


    /**
     *  Gets the <code> FiscalPeriodFormRecord </code> corresponding to the 
     *  given fiscal period record <code> Type. </code> 
     *
     *  @param  fiscalPeriodRecordType a fiscal period record type 
     *  @return the fiscal period form record 
     *  @throws org.osid.NullArgumentException <code> fiscalPeriodRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(fiscalPeriodRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.records.FiscalPeriodFormRecord getFiscalPeriodFormRecord(org.osid.type.Type fiscalPeriodRecordType)
        throws org.osid.OperationFailedException;
}
