//
// org.osid.financials.FiscalPeriodLookupSession
//
//     The OSID Java specification for org.osid.financials.FiscalPeriodLookupSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.financials;


/**
 *  <p>This session defines methods for retrieving fiscal periods. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated business view: All fiscal period methods in this session 
 *      operate, retrieve and pertain to fiscal periods defined explicitly in 
 *      the current business. Using an isolated view is useful for managing 
 *      <code> FiscalPeriods </code> with the <code> FiscalPeriodAdminSession. 
 *      </code> </li> 
 *      <li> federated business view: All fiscal period lookup methods in this 
 *      session operate, retrieve and pertain to all fiscal periods defined in 
 *      this business and any other fiscal periods implicitly available in 
 *      this business through business inheritence. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedBusinessView() </code> and <code> 
 *  useIsolatedBusinessView() </code> behave as a radio group and one should 
 *  be selected before invoking any lookup methods. </p>
 */

public interface FiscalPeriodLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Business </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Business Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBusinessId();


    /**
     *  Gets the <code> Business </code> associated with this session. 
     *
     *  @return the business 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.Business getBusiness()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> FiscalPeriod </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupFiscalPeriods();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeFiscalPeriodView();


    /**
     *  A complete view of the <code> FiscalPeriod </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryFiscalPeriodView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include fiscal periods in catalogs which are children of this catalog 
     *  in the business hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedBusinessView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this business only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedBusinessView();


    /**
     *  Gets the <code> FiscalPeriod </code> specified by its <code> Id. 
     *  </code> In plenary mode, the exact <code> Id </code> is found or a 
     *  <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  FiscalPeriod </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> FiscalPeriod </code> and retained for 
     *  compatibility. 
     *
     *  @param  fiscalPeriodId the <code> Id </code> of the <code> 
     *          FiscalPeriod </code> to retrieve 
     *  @return the returned <code> FiscalPeriod </code> 
     *  @throws org.osid.NotFoundException no <code> FiscalPeriod </code> 
     *          found with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> fiscalPeriodId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.FiscalPeriod getFiscalPeriod(org.osid.id.Id fiscalPeriodId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> FiscalPeriodList </code> corresponding to the given 
     *  <code> IdList. </code> In plenary mode, the returned list contains all 
     *  of the fiscal periods specified in the <code> Id </code> list, in the 
     *  order of the list, including duplicates, or an error results if an 
     *  <code> Id </code> in the supplied list is not found or inaccessible. 
     *  Otherwise, inaccessible <code> FiscalPeriods </code> may be omitted 
     *  from the list and may present the elements in any order including 
     *  returning a unique set. 
     *
     *  @param  fiscalPeriodIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> FiscalPeriod </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> fiscalPeriodIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.FiscalPeriodList getFiscalPeriodsByIds(org.osid.id.IdList fiscalPeriodIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> FiscalPeriodList </code> corresponding to the given 
     *  fiscal period genus <code> Type </code> which does not include fiscal 
     *  periods of types derived from the specified <code> Type. </code> In 
     *  plenary mode, the returned list contains all known fiscal periods or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  fiscal periods that are accessible through this session. 
     *
     *  @param  fiscalPeriodGenusType a fiscal period genus type 
     *  @return the returned <code> FiscalPeriod </code> list 
     *  @throws org.osid.NullArgumentException <code> fiscalPeriodGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.FiscalPeriodList getFiscalPeriodsByGenusType(org.osid.type.Type fiscalPeriodGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> FiscalPeriodList </code> corresponding to the given 
     *  fiscal period genus <code> Type </code> and include any additional 
     *  fiscal periods with genus types derived from the specified <code> 
     *  Type. </code> In plenary mode, the returned list contains all known 
     *  fiscal periods or an error results. Otherwise, the returned list may 
     *  contain only those fiscal periods that are accessible through this 
     *  session. 
     *
     *  @param  fiscalPeriodGenusType a fiscal period genus type 
     *  @return the returned <code> FiscalPeriod </code> list 
     *  @throws org.osid.NullArgumentException <code> fiscalPeriodGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.FiscalPeriodList getFiscalPeriodsByParentGenusType(org.osid.type.Type fiscalPeriodGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> FiscalPeriodList </code> containing the given fiscal 
     *  period record <code> Type. </code> In plenary mode, the returned list 
     *  contains all known fiscal periods or an error results. Otherwise, the 
     *  returned list may contain only those fiscal periods that are 
     *  accessible through this session. 
     *
     *  @param  fiscalPeriodRecordType a fiscal period record type 
     *  @return the returned <code> FiscalPeriod </code> list 
     *  @throws org.osid.NullArgumentException <code> fiscalPeriodRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.FiscalPeriodList getFiscalPeriodsByRecordType(org.osid.type.Type fiscalPeriodRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> FiscalPeriodList </code> containing the given date 
     *  <code> . </code> In plenary mode, the returned list contains all known 
     *  fiscal periods or an error results. Otherwise, the returned list may 
     *  contain only those fiscal periods that are accessible through this 
     *  session. 
     *
     *  @param  date a date 
     *  @return the returned <code> FiscalPeriod </code> list 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.FiscalPeriodList getFiscalPeriodsByDate(org.osid.calendaring.DateTime date)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> FiscalPeriods. </code> In plenary mode, the returned 
     *  list contains all known fiscal periods or an error results. Otherwise, 
     *  the returned list may contain only those fiscal periods that are 
     *  accessible through this session. 
     *
     *  @return a list of <code> FiscalPeriods </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.FiscalPeriodList getFiscalPeriods()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
