//
// org.osid.financials.FiscalPeriodQueryInspector
//
//     The OSID Java specification for org.osid.financials.FiscalPeriodQueryInspector.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.financials;


/**
 *  <p>The query inspectors provide a means of accessing the match terms of a 
 *  query. These interfaces are used to examine the actual query terms used in 
 *  a search or that may be used to create a smart catalog. Query inspectors 
 *  may be converted to <code> OsidQuery </code> interfaces for reuse or 
 *  modification in the search sessions. </p>
 */

public interface FiscalPeriodQueryInspector
    extends org.osid.OsidObjectQueryInspector {


    /**
     *  Gets the display label query terms. 
     *
     *  @return the display label terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.StringTerm[] getDisplayLabelTerms();


    /**
     *  Gets the fiscal year query terms. 
     *
     *  @return the fiscal year terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IntegerRangeTerm[] getFiscalYearTerms();


    /**
     *  Gets the start date query terms. 
     *
     *  @return the start date query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DateTimeRangeTerm[] getStartDateTerms();


    /**
     *  Gets the end date query terms. 
     *
     *  @return the end date query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DateTimeRangeTerm[] getEndDateTerms();


    /**
     *  Gets the duration query terms. 
     *
     *  @return the duration query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DurationRangeTerm[] getDurationTerms();


    /**
     *  Gets the budget deadline query terms. 
     *
     *  @return the budget deadline query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DateTimeRangeTerm[] getBudgetDeadlineTerms();


    /**
     *  Gets the posting deadline query terms. 
     *
     *  @return the posting deadline query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DateTimeRangeTerm[] getPostingDeadlineTerms();


    /**
     *  Gets the closing query terms. 
     *
     *  @return the closing query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DateTimeRangeTerm[] getClosingTerms();


    /**
     *  Gets the business <code> Id </code> query terms. 
     *
     *  @return the business <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getBusinessIdTerms();


    /**
     *  Gets the business query terms. 
     *
     *  @return the business query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.BusinessQueryInspector[] getBusinessTerms();


    /**
     *  Gets the fiscal period query inspector record corresponding to the 
     *  given <code> FiscalPeriod </code> record <code> Type. </code> Multiple 
     *  record retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  fiscalPeriodRecordType a fiscal period record type 
     *  @return the fiscal period query inspector record 
     *  @throws org.osid.NullArgumentException <code> fiscalPeriodRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(fiscalPeriodRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.records.FiscalPeriodQueryInspectorRecord getFiscalPeriodQueryInspectorRecord(org.osid.type.Type fiscalPeriodRecordType)
        throws org.osid.OperationFailedException;
}
