//
// org.osid.financials.FiscalPeriodSmartBusinessSession
//
//     The OSID Java specification for org.osid.financials.FiscalPeriodSmartBusinessSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.financials;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. A <code> FiscalPeriodQuery </code> can be retrieved from this 
 *  session and mapped to this <code> Business </code> to create a virtual 
 *  collection of <code> FiscalPeriods. </code> The fiscal periods may be 
 *  sequenced using the <code> FiscalPeriodSearchOrder </code> from this 
 *  session. </p> 
 *  
 *  <p> This <code> Business </code> has a default query that matches any 
 *  fiscal period and a default search order that specifies no sequencing. The 
 *  queries may be examined using a <code> FiscalPeriodQueryInspector. </code> 
 *  The query may be modified by converting the inspector back to a <code> 
 *  FiscalPeriodQuery. </code> </p>
 */

public interface FiscalPeriodSmartBusinessSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Business </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Business Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBusinessId();


    /**
     *  Gets the <code> Business </code> associated with this session. 
     *
     *  @return the business 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.Business getBusiness()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart businesses. A return of true does 
     *  not guarantee successful assessment. A return of false indicates that 
     *  it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart business management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartBusinesses();


    /**
     *  Gets a fiscal period query. 
     *
     *  @return the fiscal period query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.FiscalPeriodQuery getFiscalPeriodQuery();


    /**
     *  Gets a fiscal period search order. 
     *
     *  @return the fiscal period search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.FiscalPeriodSearchOrder getFiscalPeriodSearchOrder();


    /**
     *  Applies a fiscal period query to this business. 
     *
     *  @param  fiscalPeriodQuery the fiscal period query 
     *  @throws org.osid.NullArgumentException <code> fiscalPeriodQuery 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> fiscalPeriodQuery </code> 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyFiscalPeriodQuery(org.osid.financials.FiscalPeriodQuery fiscalPeriodQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a fiscal period query inspector for this business. 
     *
     *  @return the fiscal period query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.FiscalPeriodQueryInspector inspectFiscalPeriodQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a fiscal period search order to this business. 
     *
     *  @param  fiscalPeriodSearchOrder the fiscal period search order 
     *  @throws org.osid.NullArgumentException <code> fiscalPeriodSearchOrder 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> fiscalPeriodSearchOrder 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyFiscalPeriodSequencing(org.osid.financials.FiscalPeriodSearchOrder fiscalPeriodSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a fiscal period query from an inspector. 
     *
     *  @param  fiscalPeriodQueryInspector a query inspector 
     *  @return the fiscal period query 
     *  @throws org.osid.NullArgumentException <code> 
     *          fiscalPeriodQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          fiscalPeriodQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.FiscalPeriodQuery getFiscalPeriodQueryFromInspector(org.osid.financials.FiscalPeriodQueryInspector fiscalPeriodQueryInspector);
}
