//
// org.osid.financials.Summary
//
//     The OSID Java specification for org.osid.financials.Summary.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.financials;


/**
 *  <p>A <code> Summary </code> represents a financial summary of an <code> 
 *  Account </code> in a time period. </p>
 */

public interface Summary
    extends org.osid.OsidCompendium {


    /**
     *  Gets the <code> Id </code> of the account. 
     *
     *  @return the account <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAccountId();


    /**
     *  Gets the account. 
     *
     *  @return the account 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.Account getAccount()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of the fiscal period 
     *
     *  @return the fiscal period <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFiscalPeriodId();


    /**
     *  Gets the fiscal period 
     *
     *  @return the fiscal period 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.FiscalPeriod getFiscalPeriod()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the credits for this fiscal period. 
     *
     *  @return the credits 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.Currency getCredits();


    /**
     *  Gets the debits for this fiscal period. 
     *
     *  @return the debits 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.Currency getDebits();


    /**
     *  Tests if this the account on this activity has a budget for this time 
     *  period. 
     *
     *  @return <code> true </code> if a budget is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isBudgeted();


    /**
     *  Gets the budget. 
     *
     *  @return the budget 
     *  @throws org.osid.IllegalStateException <code> isBudgeted() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.Currency getBudget();


    /**
     *  Tests if this the account on this activity has a forecast for this 
     *  time period. 
     *
     *  @return <code> true </code> if a forecast is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasForecast();


    /**
     *  Gets the forecast 
     *
     *  @return the forecast 
     *  @throws org.osid.IllegalStateException <code> hasForecast() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.Currency getForecast();


    /**
     *  Gets the summary record corresponding to the given <code> Summary 
     *  </code> record <code> Type. </code> This method is used to retrieve an 
     *  object implementing the requested record. The <code> summaryRecordType 
     *  </code> may be the <code> Type </code> returned in <code> 
     *  getRecordTypes() </code> or any of its parents in a <code> Type 
     *  </code> hierarchy where <code> hasRecordType(summaryRecordType) 
     *  </code> is <code> true </code> . 
     *
     *  @param  summaryRecordType the type of summary record to retrieve 
     *  @return the summary record 
     *  @throws org.osid.NullArgumentException <code> summaryRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(summaryRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.records.SummaryRecord getSummaryRecord(org.osid.type.Type summaryRecordType)
        throws org.osid.OperationFailedException;
}
