//
// org.osid.financials.SummarySearchOrder
//
//     The OSID Java specification for org.osid.financials.SummarySearchOrder.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.financials;


/**
 *  <p>An interface for specifying the ordering of search results. </p>
 */

public interface SummarySearchOrder
    extends org.osid.OsidCompendiumSearchOrder {


    /**
     *  Specifies a preference for ordering the result set by the account. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByAccount(org.osid.SearchOrderStyle style);


    /**
     *  Tests if an <code> AccountSearchOrder </code> is available. 
     *
     *  @return <code> true </code> if an account search order is available, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAccountSearchOrder();


    /**
     *  Gets the account search order. 
     *
     *  @return the account search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAccountSearchOrder() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAccountSearchOrder() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.financials.AccountSearchOrder getAccountSearchOrder();


    /**
     *  Specifies a preference for ordering the result set by the fiscal 
     *  period. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByFiscalPeriod(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a <code> FiscalPeriodSearchOrder </code> is available. 
     *
     *  @return <code> true </code> if a fiscal period search order is 
     *          available, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFiscalPeriodSearchOrder();


    /**
     *  Gets the fiscal period search order. 
     *
     *  @return the fiscal period search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsFiscalPeriodSearchOrder() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFiscalPeriodSearchOrder() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.financials.FiscalPeriodSearchOrder getFiscalPeriodSearchOrder();


    /**
     *  Specifies a preference for ordering the result set by the credits. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByCredits(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the debits. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByDebits(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the balance. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByBalance(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the budget 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByBudget(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the delta. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByDelta(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the forecast. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByForecast(org.osid.SearchOrderStyle style);


    /**
     *  Gets the fiscal period search order record corresponding to the given 
     *  fiscal period record <code> Type. </code> Multiple retrievals return 
     *  the same underlying object. 
     *
     *  @param  summaryRecordType a summary record type 
     *  @return the summary search order record 
     *  @throws org.osid.NullArgumentException <code> summaryRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(summaryRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.records.SummarySearchOrderRecord getSummarySearchOrderRecord(org.osid.type.Type summaryRecordType)
        throws org.osid.OperationFailedException;
}
