//
// org.osid.financials.budgeting.BudgetBusinessAssignmentSession
//
//     The OSID Java specification for org.osid.financials.budgeting.BudgetBusinessAssignmentSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.financials.budgeting;


/**
 *  <p>This session provides methods to re-assign <code> Budgets </code> to 
 *  <code> Business </code> objects A <code> Budget </code> may appear in 
 *  multiple <code> Business </code> objects and removing the last reference 
 *  to a <code> Budget </code> is the equivalent of deleting it. Each <code> 
 *  Business </code> may have its own authorizations governing who is allowed 
 *  to operate on it. </p> 
 *  
 *  <p> Adding a reference of a <code> Budget </code> to another <code> 
 *  Business </code> is not a copy operation (eg: does not change its <code> 
 *  Id </code> ). </p>
 */

public interface BudgetBusinessAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter budget/business mappings. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignBudgets();


    /**
     *  Tests if this user can alter budget/business mappings. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @param  businessId the <code> Id </code> of the <code> Business 
     *          </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> businessId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignBudgetToBusiness(org.osid.id.Id businessId);


    /**
     *  Gets a list of businesses including and under the given business node 
     *  in which any budget can be assigned. 
     *
     *  @param  businessId the <code> Id </code> of the <code> Business 
     *          </code> 
     *  @return list of assignable business <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> businessId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableBusinessIds(org.osid.id.Id businessId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of businesses including and under the given business node 
     *  in which a specific budget can be assigned. 
     *
     *  @param  businessId the <code> Id </code> of the <code> Business 
     *          </code> 
     *  @param  budgetId the <code> Id </code> of the <code> Budget </code> 
     *  @return list of assignable business <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> businessId </code> or 
     *          <code> budgetId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableBusinessIdsForBudget(org.osid.id.Id businessId, 
                                                                org.osid.id.Id budgetId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> Budget </code> to a <code> Business. </code> 
     *
     *  @param  budgetId the <code> Id </code> of the <code> Budget </code> 
     *  @param  businessId the <code> Id </code> of the <code> Business 
     *          </code> 
     *  @throws org.osid.AlreadyExistsException <code> budgetId </code> is 
     *          already assigned to <code> businessId </code> 
     *  @throws org.osid.NotFoundException <code> budgetId </code> or <code> 
     *          businessId </code> not found 
     *  @throws org.osid.NullArgumentException <code> budgetId </code> or 
     *          <code> businessId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignBudgetToBusiness(org.osid.id.Id budgetId, 
                                       org.osid.id.Id businessId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> Budget </code> from a <code> Business. </code> 
     *
     *  @param  budgetId the <code> Id </code> of the <code> Budget </code> 
     *  @param  businessId the <code> Id </code> of the <code> Business 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> budgetId </code> or <code> 
     *          businessId </code> not found or <code> budgetId </code> not 
     *          assigned to <code> businessId </code> 
     *  @throws org.osid.NullArgumentException <code> budgetId </code> or 
     *          <code> businessId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignBudgetFromBusiness(org.osid.id.Id budgetId, 
                                           org.osid.id.Id businessId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Moves a <code> Budget </code> from one <code> Business </code> to 
     *  another. Mappings to other <code> Businesses </code> are unaffected. 
     *
     *  @param  budgetId the <code> Id </code> of the <code> Budget </code> 
     *  @param  fromBusinessId the <code> Id </code> of the current <code> 
     *          Business </code> 
     *  @param  toBusinessId the <code> Id </code> of the destination <code> 
     *          Business </code> 
     *  @throws org.osid.NotFoundException <code> budgetId, fromBusinessId, 
     *          </code> or <code> toBusinessId </code> not found or <code> 
     *          budgetId </code> not mapped to <code> fromBusinessId </code> 
     *  @throws org.osid.NullArgumentException <code> budgetId, 
     *          fromBusinessId, </code> or <code> toBusinessId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void reassignBudgetToBusiness(org.osid.id.Id budgetId, 
                                         org.osid.id.Id fromBusinessId, 
                                         org.osid.id.Id toBusinessId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
