//
// org.osid.financials.budgeting.BudgetEntryNotificationSession
//
//     The OSID Java specification for org.osid.financials.budgeting.BudgetEntryNotificationSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.financials.budgeting;


/**
 *  <p>This session defines methods to receive notifications on adds/changes 
 *  to <code> BudgetEntry </code> objects in this <code> Business. </code> 
 *  This also includes existing budget entries that may appear or disappear 
 *  due to changes in the <code> Business </code> hierarchy, This session is 
 *  intended for consumers needing to synchronize their state with this 
 *  service without the use of polling. Notifications are cancelled when this 
 *  session is closed. </p> 
 *  
 *  <p> The two views defined in this session correspond to the views in the 
 *  <code> BudgetEntryLookupSession. </code> </p>
 */

public interface BudgetEntryNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Business </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Business Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBusinessId();


    /**
     *  Gets the <code> Business </code> associated with this session. 
     *
     *  @return the business 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.Business getBusiness()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can register for <code> BudgetEntry </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForBudgetEntryNotifications();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include budget entries in catalogs which are children of this catalog 
     *  in the business hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedBusinessView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts notifications to this business only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedBusinessView();


    /**
     *  Reliable notifications are desired. In reliable mode, notifications 
     *  are to be acknowledged using <code> 
     *  acknowledgeBudgetEntryNotification() </code> . 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void reliableBudgetEntryNotifications();


    /**
     *  Unreliable notifications are desired. In unreliable mode, 
     *  notifications do not need to be acknowledged. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void unreliableBudgetEntryNotifications();


    /**
     *  Acknowledge a budget entry notification. 
     *
     *  @param  notificationId the <code> Id </code> of the notification 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void acknowledgeBudgetEntryNotification(org.osid.id.Id notificationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new budget entries. <code> 
     *  BudgetEntryReceiver.newBudgetEntries() </code> is invoked when a new 
     *  <code> BudgetEntry </code> appears in this business. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewBudgetEntries()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new budget entries for the given budget. 
     *  <code> BudgetEntryReceiver.newBudgetEntries() </code> is invoked when 
     *  a new <code> BudgetEntry </code> appears in this business. 
     *
     *  @param  budgetId the <code> Id </code> of the <code> Budget </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> budgetId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewBudgetEntriesForBudget(org.osid.id.Id budgetId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new budget entries for the given 
     *  account. <code> BudgetEntryReceiver.newBudgetEntries() </code> is 
     *  invoked when a new <code> BudgetEntry </code> appears in this 
     *  business. 
     *
     *  @param  accountId the <code> Id </code> of the <code> Account </code> 
     *          to monitor 
     *  @throws org.osid.NullArgumentException <code> accountId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewBudgetEntriesForAccount(org.osid.id.Id accountId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated budget entries. <code> 
     *  BudgetEntryReceiver.changedBudgetEntries() </code> is invoked when a 
     *  budget entry in this business is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedBudgetEntries()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated budget entries for the given 
     *  budget. <code> BudgetEntryReceiver.changedBudgetEntries() </code> is 
     *  invoked when the specified budget entry in this business is changed. 
     *
     *  @param  budgetId the <code> Id </code> of the <code> Budget </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> budgetId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedBudgetEntriesForBudget(org.osid.id.Id budgetId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated budget entries for the given 
     *  account. <code> BudgetEntryReceiver.changedBudgetEntries() </code> is 
     *  invoked when the specified budget entry in this business is changed. 
     *
     *  @param  accountId the <code> Id </code> of the <code> Account </code> 
     *          to monitor 
     *  @throws org.osid.NullArgumentException <code> accountId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedBudgetEntriesForAccount(org.osid.id.Id accountId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated budget entries. <code> 
     *  BudgetEntryReceiver.changedBudgetEntries() </code> is invoked when the 
     *  specified budget entry in this business is changed. 
     *
     *  @param  budgetEntryId the <code> Id </code> of the <code> BudgetEntry 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> budgetEntryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedBudgetEntry(org.osid.id.Id budgetEntryId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted budget entries. <code> 
     *  BudgetEntryReceiver.deletedBudgetEntries() </code> is invoked when a 
     *  budget entry is deleted or removed from this business. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedBudgetEntries()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted budget entries for the given 
     *  budget. <code> BudgetEntryReceiver.deletedBudgetEntries() </code> is 
     *  invoked when the specified budget entry is deleted or removed from 
     *  this business. 
     *
     *  @param  budgetId the <code> Id </code> of the <code> Budget </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> budgetId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedBudgetEntriesForBudget(org.osid.id.Id budgetId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted budget entries for the given 
     *  acount. <code> BudgetEntryReceiver.deletedBudgetEntries() </code> is 
     *  invoked when the specified budget entry is deleted or removed from 
     *  this business. 
     *
     *  @param  accountId the <code> Id </code> of the <code> Account </code> 
     *          to monitor 
     *  @throws org.osid.NullArgumentException <code> accountId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedBudgetEntriesForAccount(org.osid.id.Id accountId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted budget entries. <code> 
     *  BudgetEntryReceiver.deletedBudgetEntries() </code> is invoked when the 
     *  specified budget entry is deleted or removed from this business. 
     *
     *  @param  budgetEntryId the <code> Id </code> of the <code> BudgetEntry 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> budgetEntryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedBudgetEntry(org.osid.id.Id budgetEntryId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
