//
// org.osid.financials.budgeting.BudgetEntrySearchOrder
//
//     The OSID Java specification for org.osid.financials.budgeting.BudgetEntrySearchOrder.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.financials.budgeting;


/**
 *  <p>An interface for specifying the ordering of search results. </p>
 */

public interface BudgetEntrySearchOrder
    extends org.osid.OsidRelationshipSearchOrder {


    /**
     *  Specifies a preference for ordering the result set by budget. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByBudget(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a budget search order is available. 
     *
     *  @return <code> true </code> if a budget search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBudgetSearchOrder();


    /**
     *  Gets the budget order. 
     *
     *  @return the budget search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBudgetSearchOrder() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBudgetSearchOrder() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.financials.budgeting.BudgetSearchOrder getBudgetSearchOrder();


    /**
     *  Specifies a preference for ordering the result set by account. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByAccount(org.osid.SearchOrderStyle style);


    /**
     *  Tests if an account search order is available. 
     *
     *  @return <code> true </code> if an search account order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAccountSearchOrder();


    /**
     *  Gets the account order. 
     *
     *  @return the account search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAccountSearchOrder() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAccountSearchOrder() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.financials.AccountSearchOrder getAccountSearchOrder();


    /**
     *  Specifies a preference for ordering the result set by the amount. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByAmount(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the debit flag. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByDebit(org.osid.SearchOrderStyle style);


    /**
     *  Gets the budget entry search order record corresponding to the given 
     *  budget entry record <code> Type. </code> Multiple retrievals return 
     *  the same underlying object. 
     *
     *  @param  budgetEntryRecordType a budget entry record type 
     *  @return the budget entry search order record 
     *  @throws org.osid.NullArgumentException <code> budgetEntryRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(budgetEntryRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.budgeting.records.BudgetEntrySearchOrderRecord getBudgetEntrySearchOrderRecord(org.osid.type.Type budgetEntryRecordType)
        throws org.osid.OperationFailedException;
}
