//
// org.osid.financials.budgeting.FinancialsBudgetingProfile
//
//     The OSID Java specification for org.osid.financials.budgeting.FinancialsBudgetingProfile.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.financials.budgeting;


/**
 *  <p>The financials profile describes the interoperability among financials 
 *  management services. </p>
 */

public interface FinancialsBudgetingProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any business federation is exposed. Federation is exposed 
     *  when a specific business may be identified, selected and used to 
     *  create a lookup or admin session. Federation is not exposed when a set 
     *  of catalogs appears as a single catalog. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if looking up budgets is supported. 
     *
     *  @return <code> true </code> if budget lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBudgetLookup();


    /**
     *  Tests if querying budgets is supported. 
     *
     *  @return <code> true </code> if budget query is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBudgetQuery();


    /**
     *  Tests if searching budgets is supported. 
     *
     *  @return <code> true </code> if budget search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBudgetSearch();


    /**
     *  Tests if budget <code> </code> administrative service is supported. 
     *
     *  @return <code> true </code> if budget administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBudgetAdmin();


    /**
     *  Tests if a budget <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if budget notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBudgetNotification();


    /**
     *  Tests if a budget cataloging service is supported. 
     *
     *  @return <code> true </code> if budget catalog is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBudgetBusiness();


    /**
     *  Tests if a budget cataloging service is supported. A cataloging 
     *  service maps budgets to catalogs. 
     *
     *  @return <code> true </code> if budget cataloging is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBudgetBusinessAssignment();


    /**
     *  Tests if a budget smart business session is available. 
     *
     *  @return <code> true </code> if a budget smart business session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBudgetSmartBusiness();


    /**
     *  Tests if looking up budget entries is supported. 
     *
     *  @return <code> true </code> if budget entry lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBudgetEntryLookup();


    /**
     *  Tests if querying budget entries is supported. 
     *
     *  @return <code> true </code> if budget entry query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBudgetEntryQuery();


    /**
     *  Tests if searching budget entries is supported. 
     *
     *  @return <code> true </code> if budget entry search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBudgetEntrySearch();


    /**
     *  Tests if budget entry administrative service is supported. 
     *
     *  @return <code> true </code> if budget entry administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBudgetEntryAdmin();


    /**
     *  Tests if an entry <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if budget entry notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBudgetEntryNotification();


    /**
     *  Tests if a budget entry cataloging service is supported. 
     *
     *  @return <code> true </code> if budget entry catalog is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBudgetEntryBusiness();


    /**
     *  Tests if a budget entry cataloging service is supported. 
     *
     *  @return <code> true </code> if budget entry cataloging is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBudgetEntryBusinessAssignment();


    /**
     *  Tests if a budget entry smart business session is available. 
     *
     *  @return <code> true </code> if a budget entry smart business session 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBudgetEntrySmartBusiness();


    /**
     *  Tests for the availability of a financials budgeting batch service. 
     *
     *  @return <code> true </code> if a financials budgeting batch service is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFinancialsBudgetingBatch();


    /**
     *  Gets the supported <code> Budget </code> record types. 
     *
     *  @return a list containing the supported <code> Budget </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getBudgetRecordTypes();


    /**
     *  Tests if the given <code> Budget </code> record type is supported. 
     *
     *  @param  budgetRecordType a <code> Type </code> indicating a <code> 
     *          Budget </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> budgetRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBudgetRecordType(org.osid.type.Type budgetRecordType);


    /**
     *  Gets the supported <code> Budget </code> search record types. 
     *
     *  @return a list containing the supported <code> Budget </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getBudgetSearchRecordTypes();


    /**
     *  Tests if the given <code> Budget </code> search record type is 
     *  supported. 
     *
     *  @param  budgetSearchRecordType a <code> Type </code> indicating a 
     *          <code> Budget </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> budgetSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBudgetSearchRecordType(org.osid.type.Type budgetSearchRecordType);


    /**
     *  Gets the supported <code> BudgetEntry </code> record types. 
     *
     *  @return a list containing the supported <code> BudgetEntry </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getBudgetEntryRecordTypes();


    /**
     *  Tests if the given <code> BudgetEntry </code> record type is 
     *  supported. 
     *
     *  @param  budgetEntryRecordType a <code> Type </code> indicating a 
     *          <code> BudgetEntry </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> budgetEntryRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBudgetEntryRecordType(org.osid.type.Type budgetEntryRecordType);


    /**
     *  Gets the supported <code> BudgetEntry </code> search record types. 
     *
     *  @return a list containing the supported <code> BudgetEntry </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getBudgetEntrySearchRecordTypes();


    /**
     *  Tests if the given <code> BudgetEntry </code> search record type is 
     *  supported. 
     *
     *  @param  budgetEntrySearchRecordType a <code> Type </code> indicating a 
     *          <code> BudgetEntry </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          budgetEntrySearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBudgetEntrySearchRecordType(org.osid.type.Type budgetEntrySearchRecordType);
}
