//
// org.osid.financials.budgeting.batch.BudgetBatchAdminSession
//
//     The OSID Java specification for org.osid.financials.budgeting.batch.BudgetBatchAdminSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.financials.budgeting.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Budgets </code> in 
 *  bulk. The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Budget, </code> a <code> BudgetForm </code> is requested using <code> 
 *  getBudgetFormsForCreate() </code> specifying the desired activities, 
 *  fiscal periods, and record <code> Types </code> or none if no record 
 *  <code> Types </code> are needed. Each of the returned <code> BudgetForms 
 *  </code> will indicate that it is to be used with a create operation and 
 *  can be used to examine metdata or validate data prior to creation. Once a 
 *  <code> BudgetForm </code> is submiited to a create operation, it cannot be 
 *  reused with another create operation unless the first operation was 
 *  unsuccessful. Each <code> BudgetForm </code> corresponds to an attempted 
 *  transaction. </p> 
 *  
 *  <p> The <code> BudgetForms </code> returned from <code> 
 *  getBudgetFormsForCreate() </code> may be linked to the originating request 
 *  through the peer <code> Ids </code> of the <code> BudgetForm. </code> In 
 *  the case where there may be duplicates, any <code> BudgetForm </code> of 
 *  the same peer <code> Ids </code> may be used for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> BudgetForms </code> are submitted for create, a 
 *  <code> CreateResponse </code> is returned for each <code> BudgetForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire create operation are returned from <code> createBudgets(), 
 *  </code> errors specific to an individual <code> BudgetForm </code> are 
 *  indicated in the corresponding <code> CreateResponse. </code> <code> 
 *  CreateResponses </code> may be linked to the originating <code> BudgetForm 
 *  </code> through the <code> BudgetForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> BudgetForms </code> are requested to the <code> 
 *  Budget </code> <code> Id </code> that is to be updated using <code> 
 *  getBudgetFormsForUpdate() </code> where the reference <code> Id </code> in 
 *  the <code> BudgetForm </code> may be used to link the request. Similarly, 
 *  the <code> BudgetForm </code> has metadata about the data that can be 
 *  updated and it can perform validation before submitting the update. The 
 *  <code> BudgetForm </code> can only be used once for a successful update 
 *  and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> BudgetForms </code> are submitted for update, 
 *  an <code> UpdateResponse </code> is returned for each <code> BudgetForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire update operation are returned from <code> updateBudgets(), 
 *  </code> errors specific to an individual <code> BudgetForm </code> are 
 *  indicated in the corresponding <code> UpdateResponse. </code> <code> 
 *  UpdateResponses </code> may be linked to the originating <code> BudgetForm 
 *  </code> through the <code> BudgetForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> Budgets </code> in bulk. To unmap 
 *  a <code> Budget </code> from the current <code> Business, </code> the 
 *  <code> BudgetBusinessAssignmentSession </code> should be used. These 
 *  delete operations attempt to remove the <code> Budget </code> itself thus 
 *  removing it from all known <code> Business </code> catalogs. Bulk delete 
 *  operations return the results in <code> DeleteResponses. </code> </p>
 */

public interface BudgetBatchAdminSession
    extends org.osid.financials.budgeting.BudgetAdminSession {


    /**
     *  Gets the budget forms for creating a bunch of new budgets. A new form 
     *  is returned for each supplied activity and fiscal period pair. 
     *
     *  @param  peers a list of activities and fiscal periods 
     *  @param  budgetRecordTypes array of budget record types to be included 
     *          in each create operation or an empty list if none 
     *  @return the budget forms 
     *  @throws org.osid.NotFoundException an <code> activityId </code> or 
     *          <code> fiscalPeriodId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> peers </code> or <code> 
     *          budgetRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.budgeting.batch.BudgetBatchFormList getBudgetFormsForCreate(org.osid.financials.budgeting.batch.BudgetPeerList peers, 
                                                                                           org.osid.type.Type[] budgetRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Budgets. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  budgetForms the budget forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> budgetForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createBudgets(org.osid.financials.budgeting.batch.BudgetBatchFormList budgetForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the budget forms for updating an existing set of budgets. A new 
     *  budget form should be requested for each update transaction. 
     *
     *  @param  budgetIds the <code> Ids </code> of the <code> Budget </code> 
     *  @return the budget form 
     *  @throws org.osid.NotFoundException a <code> budgetId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> budgetIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.budgeting.batch.BudgetBatchFormList getBudgetFormsForUpdate(org.osid.id.IdList budgetIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing budgets. This method returns an error if the entire 
     *  operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  budgetForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> budgetForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateBudgets(org.osid.financials.budgeting.batch.BudgetBatchFormList budgetForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Budgets </code> in this <code> Business </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllBudgets()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes budgets for the given <code> Ids. </code> 
     *
     *  @param  budgetIds the <code> Ids </code> of the budgets to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> budgetIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteBudgets(org.osid.id.IdList budgetIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes budgets for the given activity. 
     *
     *  @param  activityId the <code> Id </code> of an activity 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> activityId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteBudgetsForActivity(org.osid.id.Id activityId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes budgets for the given fiscal period. 
     *
     *  @param  fiscalPeriodId the <code> Id </code> of a fiscal period 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> fiscalPeriodId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteBudgetsForFiscalPeriod(org.osid.id.Id fiscalPeriodId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes budgets expired before the given date. 
     *
     *  @param  date a date 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteIneffectiveBudgetsByDate(org.osid.calendaring.DateTime date)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Budget </code> for the purpose 
     *  of creating compatibility. The primary <code> Id </code> of the <code> 
     *  Budget </code> is determined by the provider. The new <code> Id 
     *  </code> is an alias to the primary <code> Id. </code> If the alias is 
     *  a pointer to another budget, it is reassigned to the given budget 
     *  <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasBudgets(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
