//
// org.osid.financials.posting.FinancialsPostingProfile
//
//     The OSID Java specification for org.osid.financials.posting.FinancialsPostingProfile.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.financials.posting;


/**
 *  <p>The financials profile describes the interoperability among financials 
 *  management services. </p>
 */

public interface FinancialsPostingProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any business federation is exposed. Federation is exposed 
     *  when a specific business may be identified, selected and used to 
     *  create a lookup or admin session. Federation is not exposed when a set 
     *  of catalogs appears as a single catalog. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if looking up posts is supported. 
     *
     *  @return <code> true </code> if post lookup is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPostLookup();


    /**
     *  Tests if querying posts is supported. 
     *
     *  @return <code> true </code> if post query is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPostQuery();


    /**
     *  Tests if searching posts is supported. 
     *
     *  @return <code> true </code> if post search is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPostSearch();


    /**
     *  Tests if post <code> </code> administrative service is supported. 
     *
     *  @return <code> true </code> if post administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPostAdmin();


    /**
     *  Tests if a post <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if post notification is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPostNotification();


    /**
     *  Tests if a post cataloging service is supported. 
     *
     *  @return <code> true </code> if post catalog is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPostBusiness();


    /**
     *  Tests if a post cataloging service is supported. A cataloging service 
     *  maps posts to catalogs. 
     *
     *  @return <code> true </code> if post cataloging is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPostBusinessAssignment();


    /**
     *  Tests if a post smart business session is available. 
     *
     *  @return <code> true </code> if a post smart business session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPostSmartBusiness();


    /**
     *  Tests if looking up post entries is supported. 
     *
     *  @return <code> true </code> if post entry lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPostEntryLookup();


    /**
     *  Tests if querying post entries is supported. 
     *
     *  @return <code> true </code> if post entry query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPostEntryQuery();


    /**
     *  Tests if searching post entries is supported. 
     *
     *  @return <code> true </code> if post entry search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPostEntrySearch();


    /**
     *  Tests if post entry administrative service is supported. 
     *
     *  @return <code> true </code> if post entry administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPostEntryAdmin();


    /**
     *  Tests if an entry <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if post entry notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPostEntryNotification();


    /**
     *  Tests if an post entry cataloging service is supported. 
     *
     *  @return <code> true </code> if post entry catalog is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPostEntryBusiness();


    /**
     *  Tests if an post entry cataloging service is supported. A cataloging 
     *  service maps post entries to catalogs. 
     *
     *  @return <code> true </code> if post entry cataloging is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPostEntryBusinessAssignment();


    /**
     *  Tests if an post entry smart business session is available. 
     *
     *  @return <code> true </code> if an post entry smart business session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPostEntrySmartBusiness();


    /**
     *  Tests if a posting batch service is available. 
     *
     *  @return <code> true </code> if a posting batch service is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFinancialsPostingBatch();


    /**
     *  Gets the supported <code> Post </code> record types. 
     *
     *  @return a list containing the supported <code> Post </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getPostRecordTypes();


    /**
     *  Tests if the given <code> Post </code> record type is supported. 
     *
     *  @param  postRecordType a <code> Type </code> indicating an <code> Post 
     *          </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> postRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPostRecordType(org.osid.type.Type postRecordType);


    /**
     *  Gets the supported <code> Post </code> search record types. 
     *
     *  @return a list containing the supported <code> Post </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getPostSearchRecordTypes();


    /**
     *  Tests if the given <code> Post </code> search record type is 
     *  supported. 
     *
     *  @param  postSearchRecordType a <code> Type </code> indicating an 
     *          <code> Post </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> postSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPostSearchRecordType(org.osid.type.Type postSearchRecordType);


    /**
     *  Gets the supported <code> PostEntry </code> record types. 
     *
     *  @return a list containing the supported <code> PostEntry </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getPostEntryRecordTypes();


    /**
     *  Tests if the given <code> PostEntry </code> record type is supported. 
     *
     *  @param  postEntryRecordType a <code> Type </code> indicating an <code> 
     *          PostEntry </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> postEntryRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPostEntryRecordType(org.osid.type.Type postEntryRecordType);


    /**
     *  Gets the supported <code> PostEntry </code> search record types. 
     *
     *  @return a list containing the supported <code> PostEntry </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getPostEntrySearchRecordTypes();


    /**
     *  Tests if the given <code> PostEntry </code> search record type is 
     *  supported. 
     *
     *  @param  postEntrySearchRecordType a <code> Type </code> indicating an 
     *          <code> PostEntry </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          postEntrySearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPostEntrySearchRecordType(org.osid.type.Type postEntrySearchRecordType);
}
