//
// org.osid.financials.posting.PostEntry
//
//     The OSID Java specification for org.osid.financials.posting.PostEntry.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.financials.posting;


/**
 *  <p>A <code> PostEntry </code> is a debit or a credit made to an <code> 
 *  Account </code> and <code> Activity. </code> </p>
 */

public interface PostEntry
    extends org.osid.OsidObject,
            org.osid.Subjugateable {


    /**
     *  Gets the post <code> Id </code> to which this entry belongs. 
     *
     *  @return the payer <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPostId();


    /**
     *  Gets the post to which this entry belongs. 
     *
     *  @return the post 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.posting.Post getPost()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the G/L account <code> Id </code> to which this entry applies. 
     *
     *  @return the account <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAccountId();


    /**
     *  Gets the G/L account to which this entry applies. 
     *
     *  @return the account 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.Account getAccount()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the financial activity <code> Id </code> to which this entry 
     *  applies. 
     *
     *  @return the activity <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getActivityId();


    /**
     *  Gets the financial activity to which this entry applies. 
     *
     *  @return the activity 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.Activity getActivity()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the amount. 
     *
     *  @return the amount 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.Currency getAmount();


    /**
     *  Tests if the amount is a debit or a credit. 
     *
     *  @return <code> true </code> if this entry amount is a debit, <code> 
     *          false </code> if it is a credit 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isDebit();


    /**
     *  Gets the post entry record corresponding to the given <code> PostEntry 
     *  </code> record <code> Type. </code> This method is used to retrieve an 
     *  object implementing the requested record. The <code> 
     *  postEntryRecordType </code> may be the <code> Type </code> returned in 
     *  <code> getRecordTypes() </code> or any of its parents in a <code> Type 
     *  </code> hierarchy where <code> hasRecordType(postEntryRecordType) 
     *  </code> is <code> true </code> . 
     *
     *  @param  postEntryRecordType the type of post entry record to retrieve 
     *  @return the post entry record 
     *  @throws org.osid.NullArgumentException <code> postEntryRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(postEntryRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.posting.records.PostEntryRecord getPostEntryRecord(org.osid.type.Type postEntryRecordType)
        throws org.osid.OperationFailedException;
}
