//
// org.osid.financials.posting.PostForm
//
//     The OSID Java specification for org.osid.financials.posting.PostForm.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.financials.posting;


/**
 *  <p>This is the form for creating and updating <code> Posts. </code> Like 
 *  all <code> OsidForm </code> objects, various data elements may be set here 
 *  for use in the create and update methods in the <code> PostAdminSession. 
 *  </code> For each data element that may be set, metadata may be examined to 
 *  provide display hints or data constraints. </p>
 */

public interface PostForm
    extends org.osid.OsidObjectForm,
            org.osid.OsidAggregateableForm {


    /**
     *  Gets the metadata for the fiscal period. 
     *
     *  @return metadata for the fiscal period 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getFiscalPeriodMetadata();


    /**
     *  Sets the fiscal period. 
     *
     *  @param  fiscalPeriodId the new fiscal period 
     *  @throws org.osid.InvalidArgumentException <code> fiscalPeriodId 
     *          </code> is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> fiscalPeriodId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setFiscalPeriod(org.osid.id.Id fiscalPeriodId);


    /**
     *  Removes the fiscal period. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFiscalPeriod();


    /**
     *  Gets the metadata for the date. 
     *
     *  @return metadata for the date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getDateMetadata();


    /**
     *  Sets the date. 
     *
     *  @param  date the new date 
     *  @throws org.osid.InvalidArgumentException <code> date </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setDate(org.osid.calendaring.DateTime date);


    /**
     *  Removes the date. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDate();


    /**
     *  Gets the metadata for the corrected post. 
     *
     *  @return metadata for the corrected post 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getCorrectedPostMetadata();


    /**
     *  Sets the corrected post. 
     *
     *  @param  postId the new corrected post 
     *  @throws org.osid.InvalidArgumentException <code> postId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> postId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setCorrectedPost(org.osid.id.Id postId);


    /**
     *  Removes the corrected post. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCorrectedPost();


    /**
     *  Gets the <code> PostFormRecord </code> corresponding to the given post 
     *  record <code> Type. </code> 
     *
     *  @param  postRecordType a post record type 
     *  @return the post form record 
     *  @throws org.osid.NullArgumentException <code> postRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(postRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.posting.records.PostFormRecord getPostFormRecord(org.osid.type.Type postRecordType)
        throws org.osid.OperationFailedException;
}
