//
// org.osid.financials.posting.PostQuery
//
//     The OSID Java specification for org.osid.financials.posting.PostQuery.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.financials.posting;


/**
 *  <p>This is the query for searching posts. Each method match specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface PostQuery
    extends org.osid.OsidObjectQuery,
            org.osid.OsidAggregateableQuery {


    /**
     *  Sets the fiscal period <code> Id </code> for this query. 
     *
     *  @param  fiscalPeriodId a fiscal period <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> foscalPeriodId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchFiscalPeriodId(org.osid.id.Id fiscalPeriodId, 
                                    boolean match);


    /**
     *  Clears the fiscal period <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFiscalPeriodIdTerms();


    /**
     *  Tests if a <code> FiscalPeriod </code> is available. 
     *
     *  @return <code> true </code> if a fiscal period query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFiscalPeriodQuery();


    /**
     *  Gets the query for a fiscal period. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the fiscal period query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsFiscalPeriodQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFiscalPeriodQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.financials.FiscalPeriodQuery getFiscalPeriodQuery();


    /**
     *  Matches any fiscal period. 
     *
     *  @param  match <code> true </code> to match posts with any fiscal 
     *          period, <code> false </code> to match posts with no fiscal 
     *          period 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyFiscalPeriod(boolean match);


    /**
     *  Clears the fiscal period terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFiscalPeriodTerms();


    /**
     *  Matches posts that have been posted. 
     *
     *  @param  match <code> true </code> to match posted posts <code> false 
     *          </code> to match unposted posts 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchPosted(boolean match);


    /**
     *  Clears the posted terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPostedTerms();


    /**
     *  Matches the date between the given range inclusive. 
     *
     *  @param  low start of range 
     *  @param  high end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> low </code> is 
     *          greater than <code> high </code> 
     *  @throws org.osid.NullArgumentException <code> low </code> or <code> 
     *          high </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDate(org.osid.calendaring.DateTime low, 
                          org.osid.calendaring.DateTime high, boolean match);


    /**
     *  Matches items that have any date set. 
     *
     *  @param  match <code> true </code> to match items with any date, <code> 
     *          false </code> to match items with no date 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDate(boolean match);


    /**
     *  Clears the date terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDateTerms();


    /**
     *  Sets the post entry <code> Id </code> for this query to match posts 
     *  that have a related post entries. 
     *
     *  @param  postEntryId a post entry <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> postEntryId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchPostEntryId(org.osid.id.Id postEntryId, boolean match);


    /**
     *  Clears the post entry <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPostEntryIdTerms();


    /**
     *  Tests if a <code> PostEntryQuery </code> is available for the 
     *  location. 
     *
     *  @return <code> true </code> if a post entry query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPostEntryQuery();


    /**
     *  Gets the query for a post entries. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the post entry query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPostEntryQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPostEntryQuery() </code> is <code> true. </code> 
     */

    public org.osid.financials.posting.PostEntryQuery getPostEntryQuery();


    /**
     *  Matches any posts with post entries. 
     *
     *  @param  match <code> true </code> to match posts with any post entry, 
     *          <code> false </code> to match posts with no entries 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyPostEntry(boolean match);


    /**
     *  Clears the post entry terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPostEntryTerms();


    /**
     *  Sets the post entry <code> Id </code> for this query to match posts 
     *  that have a corrected post. 
     *
     *  @param  postId a post <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> postId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCorrectedPostId(org.osid.id.Id postId, boolean match);


    /**
     *  Clears the corrected post <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCorrectedPostIdTerms();


    /**
     *  Tests if a <code> PostQuery </code> is available. 
     *
     *  @return <code> true </code> if a post query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCorrectedPostQuery();


    /**
     *  Gets the query for a corrected posts. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the post query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCorrectedPostQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCorrectedPostQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.financials.posting.PostQuery getCorrectedPostQuery();


    /**
     *  Matches any posts with corrected posts. 
     *
     *  @param  match <code> true </code> to match posts with any corrected 
     *          post, <code> false </code> to match posts with no corrected 
     *          posts 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCorrectedPost(boolean match);


    /**
     *  Clears the corrected post terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCorrectedPostTerms();


    /**
     *  Sets the business <code> Id </code> for this query to match posts 
     *  assigned to businesses. 
     *
     *  @param  businessId the business <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> businessId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBusinessId(org.osid.id.Id businessId, boolean match);


    /**
     *  Clears the business <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBusinessIdTerms();


    /**
     *  Tests if a <code> BusinessQuery </code> is available. 
     *
     *  @return <code> true </code> if a business query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBusinessQuery();


    /**
     *  Gets the query for a business. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the business query 
     *  @throws org.osid.UnimplementedException <code> supportsBusinessQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBusinessQuery() </code> is <code> true. </code> 
     */

    public org.osid.financials.BusinessQuery getBusinessQuery();


    /**
     *  Clears the business terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBusinessTerms();


    /**
     *  Gets the post query record corresponding to the given <code> Post 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @param  postRecordType a post record type 
     *  @return the post query record 
     *  @throws org.osid.NullArgumentException <code> postRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(postRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.posting.records.PostQueryRecord getPostQueryRecord(org.osid.type.Type postRecordType)
        throws org.osid.OperationFailedException;
}
