//
// org.osid.financials.posting.batch.PostEntryBatchAdminSession
//
//     The OSID Java specification for org.osid.financials.posting.batch.PostEntryBatchAdminSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.financials.posting.batch;


/**
 *  <p>This session creates, updates, and deletes <code> PostEntries </code> 
 *  in bulk. The data for create and update is provided by the consumer via 
 *  the form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  PostEntry, </code> a <code> PostEntryForm </code> is requested using 
 *  <code> getPostEntryFormsForCreate() </code> specifying the desired post 
 *  entry peers and record <code> Types </code> or none if no record <code> 
 *  Types </code> are needed. Each of the returned <code> PostEntryForms 
 *  </code> will indicate that it is to be used with a create operation and 
 *  can be used to examine metdata or validate data prior to creation. Once a 
 *  <code> PostEntryForm </code> is submiited to a create operation, it cannot 
 *  be reused with another create operation unless the first operation was 
 *  unsuccessful. Each <code> PostEntryForm </code> corresponds to an 
 *  attempted transaction. </p> 
 *  
 *  <p> The <code> PostEntryForms </code> returned from <code> 
 *  getPostEntryFormsForCreate() </code> may be linked to the originating 
 *  request through the peer <code> Ids </code> of the <code> PostEntryForm. 
 *  </code> In the case where there may be duplicates, any <code> 
 *  PostEntryForm </code> of the same peer <code> Ids </code> may be used for 
 *  a create operation. </p> 
 *  
 *  <p> Once a batch of <code> PostEntryForms </code> are submitted for 
 *  create, a <code> CreateResponse </code> is returned for each <code> 
 *  PostEntryForm, </code> although the ordering is not defined. Only errors 
 *  that pertain to the entire create operation are returned from <code> 
 *  createPostEntries(), </code> errors specific to an individual <code> 
 *  PostEntryForm </code> are indicated in the corresponding <code> 
 *  CreateResponse. </code> <code> CreateResponses </code> may be linked to 
 *  the originating <code> PostEntryForm </code> through the <code> 
 *  PostEntryForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> PostEntryForms </code> are requested to the <code> 
 *  PostEntry </code> <code> Id </code> that is to be updated using <code> 
 *  getPostEntryFormsForUpdate() </code> where the reference <code> Id </code> 
 *  in the <code> PostEntryForm </code> may be used to link the request. 
 *  Similarly, the <code> PostEntryForm </code> has metadata about the data 
 *  that can be updated and it can perform validation before submitting the 
 *  update. The <code> PostEntryForm </code> can only be used once for a 
 *  successful update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> PostEntryForms </code> are submitted for 
 *  update, an <code> UpdateResponse </code> is returned for each <code> 
 *  PostEntryForm, </code> although the ordering is not defined. Only errors 
 *  that pertain to the entire update operation are returned from <code> 
 *  updatePostEntries(), </code> errors specific to an individual <code> 
 *  PostEntryForm </code> are indicated in the corresponding <code> 
 *  UpdateResponse. </code> <code> UpdateResponses </code> may be linked to 
 *  the originating <code> PostEntryForm </code> through the <code> 
 *  PostEntryForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> PostEntries </code> in bulk. To 
 *  unmap a <code> PostEntry </code> from the current <code> Business, </code> 
 *  the <code> PostEntryBusinessAssignmentSession </code> should be used. 
 *  These delete operations attempt to remove the <code> PostEntry </code> 
 *  itself thus removing it from all known <code> Business </code> catalogs. 
 *  Bulk delete operations return the results in <code> DeleteResponses. 
 *  </code> </p>
 */

public interface PostEntryBatchAdminSession
    extends org.osid.financials.posting.PostEntryAdminSession {


    /**
     *  Gets the post entry forms for creating a bunch of new posts. A form is 
     *  returned for each supplied post. 
     *
     *  @param  postIds a list of post <code> Ids </code> 
     *  @param  postRecordTypes array of post entry record types to be 
     *          included in each create operation or an empty list if none 
     *  @return the post entry forms 
     *  @throws org.osid.NotFoundException a <code> postId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> peers </code> or <code> 
     *          postRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.posting.batch.PostEntryBatchFormList getPostEntryFormsForCreate(org.osid.id.IdList postIds, 
                                                                                               org.osid.type.Type[] postRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> PostEntries. </code> This method returns 
     *  an error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  postEntryForms the post entry forms 
     *  @return the create responses 
     *  @throws org.osid.NotFoundException <code> postEntryForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createPostEntries(org.osid.financials.posting.batch.PostEntryBatchFormList postEntryForms)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the post entry forms for updating an existing set of posts. A new 
     *  post entry form should be requested for each update transaction. 
     *
     *  @param  postEntryIds the <code> Ids </code> of the <code> PostEntry 
     *          </code> 
     *  @return the post entry form 
     *  @throws org.osid.NotFoundException a <code> postEntryId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> postEntryIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.posting.batch.PostEntryBatchFormList getPostEntryFormsForUpdate(org.osid.id.IdList postEntryIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing posts. This method returns an error if the entire 
     *  operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  postEntryForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> postEntryForms </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updatePostEntries(org.osid.financials.posting.batch.PostEntryBatchFormList postEntryForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> PostEntries </code> in this <code> Business </code> 
     *  . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllPostEntries()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes post entries for the given <code> Ids. </code> 
     *
     *  @param  postEntryIds the <code> Ids </code> of the post entries to 
     *          delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> postEntryIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deletePostEntries(org.osid.id.IdList postEntryIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes post entries for the given post. 
     *
     *  @param  postId the <code> Id </code> of a post 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> postId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deletePostEntriesForPost(org.osid.id.Id postId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> PostEntry </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> PostEntry </code> is determined by the provider. The new 
     *  <code> Id </code> is an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another post entry, it is reassigned to the 
     *  given post entry <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasPostEntries(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
