//
// org.osid.forum.ForumProxyManager
//
//     The OSID Java specification for org.osid.forum.ForumProxyManager.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.forum;


/**
 *  <p>The reply manager provides access to forum sessions and provides 
 *  interoperability tests for various aspects of this service. Methods in 
 *  this manager accept a <code> Proxy </code> for passing information from a 
 *  server environment. The sessions included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> PostLookupSession: </code> a session to retrieve posts 
 *      </li> 
 *      <li> <code> PostQuerySession: </code> a session to query posts </li> 
 *      <li> <code> PostSearchSession: </code> a session to search for posts 
 *      </li> 
 *      <li> <code> PostAdminSession: </code> a session to create, update and 
 *      delete posts </li> 
 *      <li> <code> PostNotificationSession: </code> a session to receive 
 *      notifications for changes in posts </li> 
 *      <li> <code> PostForumSession: </code> a session to lookup post forum 
 *      mappings </li> 
 *      <li> <code> PostForumAssignmentSession: </code> a session to manage 
 *      post forum mappings </li> 
 *      <li> <code> PostSmartForumSession: </code> a session to manage smart 
 *      forums of posts </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> ReplyLookupSession: </code> a session to lookup replies 
 *      </li> 
 *      <li> <code> ReplyAdminSession: </code> a session to manage replies 
 *      </li> 
 *      <li> <code> ReplyNotificationSession: </code> a session to subscribe 
 *      to notifications of reply changes </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> ForumLookupSession: </code> a session to retrieve forums 
 *      </li> 
 *      <li> <code> ForumQuerySession: </code> a session to query forums </li> 
 *      <li> <code> ForumSearchSession: </code> a session to search for forums 
 *      </li> 
 *      <li> <code> ForumAdminSession: </code> a session to create, update and 
 *      delete forums </li> 
 *      <li> <code> ForumNotificationSession: </code> a session to receive 
 *      notifications for changes in forums </li> 
 *      <li> <code> ForumHierarchySession: </code> a session to traverse 
 *      hierarchies of forums </li> 
 *      <li> <code> ForumHierarchyDesignSession: </code> a session to manage 
 *      hierarchies of forums </li> 
 *  </ul>
 *  
 *  
 *  <p> The forum manager also provides a profile for determing the supported 
 *  search types supported by this service. </p>
 */

public interface ForumProxyManager
    extends org.osid.OsidProxyManager,
            org.osid.forum.ForumProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the post lookup 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PostLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsPostLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPostLookup() </code> is <code> true. </code> 
     */

    public org.osid.forum.PostLookupSession getPostLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the post lookup 
     *  service for the given forum. 
     *
     *  @param  forumId the <code> Id </code> of the <code> Forum </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PostLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Forum </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> forumId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsPostLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPostLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.forum.PostLookupSession getPostLookupSessionForForum(org.osid.id.Id forumId, 
                                                                         org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the post query 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PostQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsPostQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPostQuery() </code> is <code> true. </code> 
     */

    public org.osid.forum.PostQuerySession getPostQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the post query 
     *  service for the given forum. 
     *
     *  @param  forumId the <code> Id </code> of the <code> Forum </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PostQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Post </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> forumId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsPostQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPostQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.forum.PostQuerySession getPostQuerySessionForForum(org.osid.id.Id forumId, 
                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the post search 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PostSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsPostSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPostSearch() </code> is <code> true. </code> 
     */

    public org.osid.forum.PostSearchSession getPostSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the post search 
     *  service for the given forum. 
     *
     *  @param  forumId the <code> Id </code> of the <code> Forum </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PostSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Post </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> forumId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsPostSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPostSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.forum.PostSearchSession getPostSearchSessionForForum(org.osid.id.Id forumId, 
                                                                         org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the post 
     *  administrative service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PostAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsPostAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPostAdmin() </code> is <code> true. </code> 
     */

    public org.osid.forum.PostAdminSession getPostAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the post 
     *  administration service for the given forum. 
     *
     *  @param  forumId the <code> Id </code> of the <code> Forum </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PostAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Post </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> forumId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsPostAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPostAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.forum.PostAdminSession getPostAdminSessionForForum(org.osid.id.Id forumId, 
                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the post 
     *  notification service. 
     *
     *  @param  postReceiver the receiver 
     *  @param  proxy a proxy 
     *  @return a <code> PostNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> postReceiver </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPostNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPostNotification() </code> is <code> true. </code> 
     */

    public org.osid.forum.PostNotificationSession getPostNotificationSession(org.osid.forum.PostReceiver postReceiver, 
                                                                             org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the post 
     *  notification service for the given forum. 
     *
     *  @param  postReceiver the receiver 
     *  @param  forumId the <code> Id </code> of the <code> Forum </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PostNotificationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Post </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> postReceiver, forumId 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPostNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPostNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.forum.PostNotificationSession getPostNotificationSessionForForum(org.osid.forum.PostReceiver postReceiver, 
                                                                                     org.osid.id.Id forumId, 
                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving post to forum mappings. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PostForumSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsPostForum() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPostForum() </code> is <code> true. </code> 
     */

    public org.osid.forum.PostForumSession getPostForumSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning post to forum mappings. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PostForumAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPostForumAssignment() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPostForumAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.forum.PostForumAssignmentSession getPostForumAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for managing dynamic post forums for the given forum. 
     *
     *  @param  forumId the <code> Id </code> of a forum 
     *  @param  proxy a proxy 
     *  @return <code> forumId </code> not found 
     *  @throws org.osid.NotFoundException <code> forumId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.NullArgumentException <code> forumId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPostSmartForum() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPostSmartForum() </code> is <code> true. </code> 
     */

    public org.osid.forum.PostSmartForumSession getPostSmartForumSession(org.osid.id.Id forumId, 
                                                                         org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the reply lookup 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ReplyLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsReplyLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsReplyLookup() </code> is <code> true. </code> 
     */

    public org.osid.forum.ReplyLookupSession getReplyLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the reply lookup 
     *  service for the given forum. 
     *
     *  @param  forumId the <code> Id </code> of the <code> Forum </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ReplyLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Forum </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> forumId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsReplyLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsReplyLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.forum.ReplyLookupSession getReplyLookupSessionForForum(org.osid.id.Id forumId, 
                                                                           org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the reply 
     *  administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ReplyAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsReplyAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsReplyAdmin() </code> is <code> true. </code> 
     */

    public org.osid.forum.ReplyAdminSession getReplyAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the reply 
     *  administration service for the given forum. 
     *
     *  @param  forumId the <code> Id </code> of the <code> Forum </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ReplyAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Forum </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> forumId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsReplyAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsReplyAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.forum.ReplyAdminSession getReplyAdminSessionForForum(org.osid.id.Id forumId, 
                                                                         org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the reply 
     *  notification service. 
     *
     *  @param  replyReceiver the receiver 
     *  @param  proxy a proxy 
     *  @return a <code> ReplyNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> replyReceiver </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsReplyNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsReplyNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.forum.ReplyNotificationSession getReplyNotificationSession(org.osid.forum.ReplyReceiver replyReceiver, 
                                                                               org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the reply 
     *  notification service for the given forum. 
     *
     *  @param  replyReceiver the receiver 
     *  @param  forumId the <code> Id </code> of the <code> Forum </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ReplyNotificationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Forum </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> replyReceiver, forumId, 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsReplyNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsReplyNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.forum.ReplyNotificationSession getReplyNotificationSessionForForum(org.osid.forum.ReplyReceiver replyReceiver, 
                                                                                       org.osid.id.Id forumId, 
                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the forum lookup 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ForumLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsForumLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsForumLookup() </code> is <code> true. </code> 
     */

    public org.osid.forum.ForumLookupSession getForumLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the forum query 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ForumQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsForumQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsForumQuery() </code> is <code> true. </code> 
     */

    public org.osid.forum.ForumQuerySession getForumQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the forum search 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ForumSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsForumSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsForumSearch() </code> is <code> true. </code> 
     */

    public org.osid.forum.ForumSearchSession getForumSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the forum 
     *  administrative service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ForumAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsForumAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsForumAdmin() </code> is <code> true. </code> 
     */

    public org.osid.forum.ForumAdminSession getForumAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the forum 
     *  notification service. 
     *
     *  @param  forumReceiver the receiver 
     *  @param  proxy a proxy 
     *  @return a <code> ForumNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> forumReceiver </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsForumNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsForumNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.forum.ForumNotificationSession getForumNotificationSession(org.osid.forum.ForumReceiver forumReceiver, 
                                                                               org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the forum 
     *  hierarchy service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ForumHierarchySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsForumHierarchy() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsForumHierarchy() </code> is <code> true. </code> 
     */

    public org.osid.forum.ForumHierarchySession getForumHierarchySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the forum 
     *  hierarchy design service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ForumHierarchyDesignSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsForumHierarchyDesign() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsForumHierarchyDesign() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.forum.ForumHierarchyDesignSession getForumHierarchyDesignSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a <code> ForumBatchProxyManager. </code> 
     *
     *  @return a <code> ForumBatchProxyManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsForumBatch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsForumBatch() </code> is <code> true. </code> 
     */

    public org.osid.forum.batch.ForumBatchProxyManager getForumBatchProxyManager()
        throws org.osid.OperationFailedException;
}
