//
// org.osid.forum.PostForm
//
//     The OSID Java specification for org.osid.forum.PostForm.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.forum;


/**
 *  <p>This is the form for creating and updating <code> Posts. </code> Like 
 *  all <code> OsidForm </code> objects, various data elements may be set here 
 *  for use in the create and update methods in the <code> PostAdminSession. 
 *  </code> For each data element that may be set, metadata may be examined to 
 *  provide display hints or data constraints. </p>
 */

public interface PostForm
    extends org.osid.OsidObjectForm {


    /**
     *  Gets the metadata for the timestamp. 
     *
     *  @return metadata for the timestamp 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getTimestampMetadata();


    /**
     *  Sets the timestamp. 
     *
     *  @param  timestamp the new timestamp 
     *  @throws org.osid.InvalidArgumentException <code> timestamp </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> timestamp </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setTimestamp(org.osid.calendaring.DateTime timestamp);


    /**
     *  Clears the poster. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTimestamp();


    /**
     *  Gets the metadata for the poster. 
     *
     *  @return metadata for the poster 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getPosterMetadata();


    /**
     *  Sets the poster. 
     *
     *  @param  resourceId the new poster 
     *  @throws org.osid.InvalidArgumentException <code> resourceId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setPoster(org.osid.id.Id resourceId);


    /**
     *  Clears the poster. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPoster();


    /**
     *  Gets the metadata for the subject line. 
     *
     *  @return metadata for the subject line 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getSubjectLineMetadata();


    /**
     *  Sets the subject line. 
     *
     *  @param  subjectLine the new subject line 
     *  @throws org.osid.InvalidArgumentException <code> subjectLine </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> subjectLine </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setSubjectLine(String subjectLine);


    /**
     *  Clears the subject line. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSubjectLine();


    /**
     *  Gets the metadata for the text. 
     *
     *  @return metadata for the text 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getTextMetadata();


    /**
     *  Sets the text. 
     *
     *  @param  text the new text 
     *  @throws org.osid.InvalidArgumentException <code> text </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> text </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setText(String text);


    /**
     *  Clears the text. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearText();


    /**
     *  Gets the <code> PostFormRecord </code> corresponding to the given post 
     *  record <code> Type. </code> 
     *
     *  @param  postRecordType the post record type 
     *  @return the post form record 
     *  @throws org.osid.NullArgumentException <code> postRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(postRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.forum.records.PostFormRecord getPostFormRecord(org.osid.type.Type postRecordType)
        throws org.osid.OperationFailedException;
}
