//
// org.osid.forum.PostLookupSession
//
//     The OSID Java specification for org.osid.forum.PostLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.forum;


/**
 *  <p>This session provides methods for retrieving <code> Post </code> 
 *  objects. The <code> Post </code> represents a collection of replies. </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated forum view: All reply methods in this session operate, 
 *      retrieve and pertain to posts defined explicitly in the current forum. 
 *      Using an isolated view is useful for managing posts with the <code> 
 *      PostAdminSession. </code> </li> 
 *      <li> federated forum view: All post lookup methods in this session 
 *      operate, retrieve and pertain to all posts defined in this forum and 
 *      any other forums implicitly available in this forum through forum 
 *      inheritence. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods useFederatedForumView() and useIsolatedForumView() behave 
 *  as a radio group and one should be selected before invoking any lookup 
 *  methods. </p>
 */

public interface PostLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Forum </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Forum Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getForumId();


    /**
     *  Gets the <code> Forum </code> associated with this session. 
     *
     *  @return the forum 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.forum.Forum getForum()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Post </code> lookups. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not offer lookup operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupPosts();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativePostView();


    /**
     *  A complete view of the <code> Post </code> returns is desired. Methods 
     *  will return what is requested or result in an error. This view is used 
     *  when greater precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryPostView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include posts in forums which are children of this forum in the forum 
     *  hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedForumView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this forum only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedForumView();


    /**
     *  Gets the <code> Post </code> specified by its <code> Id. </code> In 
     *  plenary mode, the exact <code> Id </code> is found or a <code> 
     *  NOT_FOUND </code> results. Otherwise, the returned <code> Post </code> 
     *  may have a different <code> Id </code> than requested, such as the 
     *  case where a duplicate <code> Id </code> was assigned to a <code> Post 
     *  </code> and retained for compatibility. 
     *
     *  @param  postId <code> Id </code> of the <code> Post </code> 
     *  @return the post 
     *  @throws org.osid.NotFoundException <code> postId </code> not found 
     *  @throws org.osid.NullArgumentException <code> postId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.forum.Post getPost(org.osid.id.Id postId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PostList </code> corresponding to the given <code> 
     *  IdList. </code> In plenary mode, the returned list contains all of the 
     *  posts specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Posts </code> may be omitted from the list and may 
     *  present the elements in any order including returning a unique set. 
     *
     *  @param  postIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Post </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> postIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.forum.PostList getPostsByIds(org.osid.id.IdList postIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PostList </code> corresponding to the given post genus 
     *  <code> Type </code> which does not include posts of genus types 
     *  derived from the specified <code> Type. </code> In plenary mode, the 
     *  returned list contains all known posts or an error results. Otherwise, 
     *  the returned list may contain only those posts that are accessible 
     *  through this session. 
     *
     *  @param  postGenusType a post genus type 
     *  @return the returned <code> Post </code> list 
     *  @throws org.osid.NullArgumentException <code> postGenusType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.forum.PostList getPostsByGenusType(org.osid.type.Type postGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PostList </code> corresponding to the given post genus 
     *  <code> Type </code> and include any additional posts with genus types 
     *  derived from the specified <code> Type. </code> In plenary mode, the 
     *  returned list contains all known posts or an error results. Otherwise, 
     *  the returned list may contain only those posts that are accessible 
     *  through this session. 
     *
     *  @param  postGenusType a post genus type 
     *  @return the returned <code> Post </code> list 
     *  @throws org.osid.NullArgumentException <code> postGenusType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.forum.PostList getPostsByParentGenusType(org.osid.type.Type postGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PostList </code> containing the given post record <code> 
     *  Type. </code> In plenary mode, the returned list contains all known 
     *  posts or an error results. Otherwise, the returned list may contain 
     *  only those posts that are accessible through this session. 
     *
     *  @param  postRecordType a post record type 
     *  @return the returned <code> Post </code> list 
     *  @throws org.osid.NullArgumentException <code> postRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.forum.PostList getPostsByRecordType(org.osid.type.Type postRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PostList </code> in the given date range inclusive. 
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  posts or an error results. Otherwise, the returned list may contain 
     *  only those posts that are accessible through this session. 
     *
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Post </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.forum.PostList getPostsByDate(org.osid.calendaring.DateTime from, 
                                                  org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PostList </code> for the given poster. <code> </code> In 
     *  plenary mode, the returned list contains all known posts or an error 
     *  results. Otherwise, the returned list may contain only those posts 
     *  that are accessible through this session. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @return the returned <code> Post </code> list 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.forum.PostList getPostsForPoster(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PostList </code> by the given poster and in the given 
     *  date range inclusive. <code> </code> In plenary mode, the returned 
     *  list contains all known posts or an error results. Otherwise, the 
     *  returned list may contain only those posts that are accessible through 
     *  this session. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Post </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, from </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.forum.PostList getPostsByDateForPoster(org.osid.id.Id resourceId, 
                                                           org.osid.calendaring.DateTime from, 
                                                           org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Posts. </code> In plenary mode, the returned list 
     *  contains all known posts or an error results. Otherwise, the returned 
     *  list may contain only those posts that are accessible through this 
     *  session. 
     *
     *  @return a list of <code> Posts </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.forum.PostList getPosts()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
