//
// org.osid.forum.ReplyLookupSession
//
//     The OSID Java specification for org.osid.forum.ReplyLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.forum;


/**
 *  <p>This session defines methods for retrieving replies. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated forum view: All reply methods in this session operate, 
 *      retrieve and pertain to replies defined explicitly in the current 
 *      forum. Using an isolated view is useful for managing replies with the 
 *      <code> ReplyAdminSession. </code> </li> 
 *      <li> federated forum view: All reply lookup methods in this session 
 *      operate, retrieve and pertain to all replies defined in this forum and 
 *      any other forums implicitly available in this forum through forum 
 *      inheritence. </li> 
 *      <li> sequestered reply viiew: All reply methods suppress sequestered 
 *      replies. </li> 
 *      <li> unsequestered reply view: All reply methods return all replies. 
 *      </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedForumView() </code> and <code> 
 *  useIsolatedForumView() </code> behave as a radio group and one should be 
 *  selected before invoking any lookup methods. </p>
 */

public interface ReplyLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Forum </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Forum Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getForumId();


    /**
     *  Gets the <code> Forum </code> associated with this session. 
     *
     *  @return the forum 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.forum.Forum getForum()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can lookup replies. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer these operations. 
     *
     *  @return <code> false </code> if reply lookup methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupReplies();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeReplyView();


    /**
     *  A complete view of the <code> Reply </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryReplyView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include replies in forums which are children of this forum in the 
     *  forum hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedForumView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this forum only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedForumView();


    /**
     *  The returns from the lookup methods omit sequestered replies. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useSequesteredReplyView();


    /**
     *  All replies are returned including sequestered replies. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useUnsequesteredReplyView();


    /**
     *  Gets the <code> Reply </code> specified by its <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Reply </code> may have a different <code> Id </code> than requested, 
     *  such as the case where a duplicate <code> Id </code> was assigned to a 
     *  <code> Reply </code> and retained for compatibility. 
     *  
     *  In sequestered mode, no sequestered replies are returned. In 
     *  unsequestered mode, all replies are returned. 
     *
     *  @param  replyId the <code> Id </code> of the <code> Reply </code> to 
     *          retrieve 
     *  @return the returned <code> Reply </code> 
     *  @throws org.osid.NotFoundException no <code> Reply </code> found with 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> replyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.forum.Reply getReply(org.osid.id.Id replyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ReplyList </code> corresponding to the given <code> 
     *  IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  replies specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible replies may be omitted from the list and may present the 
     *  elements in any order including returning a unique set. 
     *  
     *  In sequestered mode, no sequestered replies are returned. In 
     *  unsequestered mode, all replies are returned. 
     *
     *  @param  replyIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Reply list </code> 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> replyIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.forum.ReplyList getRepliesByIds(org.osid.id.IdList replyIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ReplyList </code> corresponding to the given reply genus 
     *  <code> Type </code> which does not include replies of genus types 
     *  derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  replies or an error results. Otherwise, the returned list may contain 
     *  only those replies that are accessible through this session. 
     *  
     *  In sequestered mode, no sequestered replies are returned. In 
     *  unsequestered mode, all replies are returned. 
     *
     *  @param  replyGenusType a reply genus type 
     *  @return the returned <code> Reply </code> list 
     *  @throws org.osid.NullArgumentException <code> replyGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.forum.ReplyList getRepliesByGenusType(org.osid.type.Type replyGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ReplyList </code> corresponding to the given reply genus 
     *  <code> Type </code> and include any additional replies with genus 
     *  types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  replies or an error results. Otherwise, the returned list may contain 
     *  only those replies that are accessible through this session. 
     *  
     *  In sequestered mode, no sequestered replies are returned. In 
     *  unsequestered mode, all replies are returned. 
     *
     *  @param  replyGenusType a reply genus type 
     *  @return the returned <code> Post </code> list 
     *  @throws org.osid.NullArgumentException <code> postGenusType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.forum.ReplyList getRepliesByParentGenusType(org.osid.type.Type replyGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ReplyList </code> containing the given reply record 
     *  <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  replies or an error results. Otherwise, the returned list may contain 
     *  only those replies that are accessible through this session. 
     *  
     *  In sequestered mode, no sequestered replies are returned. In 
     *  unsequestered mode, all replies are returned. 
     *
     *  @param  replyRecordType a reply record type 
     *  @return the returned <code> Post </code> list 
     *  @throws org.osid.NullArgumentException <code> replyRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.forum.ReplyList getRepliesByRecordType(org.osid.type.Type replyRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all replies corresponding to the given date range 
     *  inclusive <code> . </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  replies or an error results. Otherwise, the returned list may contain 
     *  only those replies that are accessible through this session. 
     *  
     *  In sequestered mode, no sequestered replies are returned. In 
     *  unsequestered mode, all replies are returned. 
     *
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> ReplyList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.forum.ReplyList getRepliesByDate(org.osid.calendaring.DateTime from, 
                                                     org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all replies corresponding to a post <code> Id. </code> 
     *  
     *  In plenary mode, the returned list contains all known replies or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  replies that are accessible through this session. 
     *  
     *  In sequestered mode, no sequestered replies are returned. In 
     *  unsequestered mode, all replies are returned. 
     *
     *  @param  postId the <code> Id </code> of the post 
     *  @return the returned <code> ReplyList </code> 
     *  @throws org.osid.NullArgumentException <code> postId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.forum.ReplyList getRepliesForPost(org.osid.id.Id postId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all replies corresponding to post <code> Id </code> in 
     *  the given daterange inclusive. 
     *  
     *  In plenary mode, the returned list contains all known replies or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  replis that are accessible through this session. 
     *  
     *  In sequestered mode, no sequestered replies are returned. In 
     *  unsequestered mode, all replies are returned. 
     *
     *  @param  postId the <code> Id </code> of the post 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> ReplyList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> postId, from </code> or 
     *          <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.forum.ReplyList getRepliesByDateForPost(org.osid.id.Id postId, 
                                                            org.osid.calendaring.DateTime from, 
                                                            org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all replies corresponding to a poster. 
     *  
     *  In plenary mode, the returned list contains all known replies or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  replies that are accessible through this session. 
     *  
     *  In sequestered mode, no sequestered replies are returned. In 
     *  unsequestered mode, all replies are returned. 
     *
     *  @param  resourceId the resource <code> Id </code> 
     *  @return the returned <code> ReplyList </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.forum.ReplyList getRepliesForPoster(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all replies corresponding to a post <code> Id </code> 
     *  for the given poster within the date range inclusive. 
     *  
     *  In plenary mode, the returned list contains all known replies or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  replies that are accessible through this session. 
     *  
     *  In sequestered mode, no sequestered replies are returned. In 
     *  unsequestered mode, all replies are returned. 
     *
     *  @param  resourceId the resource <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> ReplyList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, from </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.forum.ReplyList getRepliesByDateForPoster(org.osid.id.Id resourceId, 
                                                              org.osid.calendaring.DateTime from, 
                                                              org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all replies corresponding to a post <code> Id </code> 
     *  and poster. 
     *  
     *  In plenary mode, the returned list contains all known replies or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  replies that are accessible through this session. 
     *  
     *  In sequestered mode, no sequestered replies are returned. In 
     *  unsequestered mode, all replies are returned. 
     *
     *  @param  postId the <code> Id </code> of the post 
     *  @param  resourceId the resource <code> Id </code> 
     *  @return the returned <code> ReplyList </code> 
     *  @throws org.osid.NullArgumentException <code> postId </code> or <code> 
     *          resourceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.forum.ReplyList getRepliesForPostAndPoster(org.osid.id.Id postId, 
                                                               org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all replies corresponding to a post <code> Id </code> 
     *  and poster within the given daterange incluisve. 
     *  
     *  In plenary mode, the returned list contains all known replies or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  replies that are accessible through this session. 
     *  
     *  In sequestered mode, no sequestered replies are returned. In 
     *  unsequestered mode, all replies are returned. 
     *
     *  @param  postId the <code> Id </code> of the post 
     *  @param  resourceId the resource <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> ReplyList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> postId, resourceId, from 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.forum.ReplyList getRepliesByDateForPostAndPoster(org.osid.id.Id postId, 
                                                                     org.osid.id.Id resourceId, 
                                                                     org.osid.calendaring.DateTime from, 
                                                                     org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all replies. 
     *  
     *  In plenary mode, the returned list contains all known replies or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  replies that are accessible through this session. 
     *  
     *  In sequestered mode, no sequestered replies are returned. In 
     *  unsequestered mode, all replies are returned. 
     *
     *  @return the returned <code> ReplyList </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.forum.ReplyList getReplies()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
