//
// org.osid.forum.batch.ReplyBatchAdminSession
//
//     The OSID Java specification for org.osid.forum.batch.ReplyBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.forum.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Replies </code> in 
 *  bulk. The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Reply, </code> a <code> ReplyForm </code> is requested using <code> 
 *  getReplyFormsForCreate() </code> specifying the desired post and record 
 *  <code> Types </code> or none if no record <code> Types </code> are needed. 
 *  Each of the returned <code> ReplyForms </code> will indicate that it is to 
 *  be used with a create operation and can be used to examine metdata or 
 *  validate data prior to creation. Once a <code> ReplyForm </code> is 
 *  submiited to a create operation, it cannot be reused with another create 
 *  operation unless the first operation was unsuccessful. Each <code> 
 *  ReplyForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> ReplyForms </code> returned from <code> 
 *  getReplyFormsForCreate() </code> may be linked to the originating request 
 *  through the peer <code> Ids </code> of the <code> ReplyForm. </code> In 
 *  the case where there may be duplicates, any <code> ReplyForm </code> of 
 *  the same peer <code> Ids </code> may be used for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> ReplyForms </code> are submitted for create, a 
 *  <code> CreateResponse </code> is returned for each <code> ReplyForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire create operation are returned from <code> createReplies(), 
 *  </code> errors specific to an individual <code> ReplyForm </code> are 
 *  indicated in the corresponding <code> CreateResponse. </code> <code> 
 *  CreateResponses </code> may be linked to the originating <code> ReplyForm 
 *  </code> through the <code> ReplyForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> ReplyForms </code> are requested to the <code> 
 *  Reply </code> <code> Id </code> that is to be updated using <code> 
 *  getReplyFormsForUpdate() </code> where the reference <code> Id </code> in 
 *  the <code> ReplyForm </code> may be used to link the request. Similarly, 
 *  the <code> ReplyForm </code> has metadata about the data that can be 
 *  updated and it can perform validation before submitting the update. The 
 *  <code> ReplyForm </code> can only be used once for a successful update and 
 *  cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> ReplyForms </code> are submitted for update, an 
 *  <code> UpdateResponse </code> is returned for each <code> ReplyForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire update operation are returned from <code> updateReplies(), 
 *  </code> errors specific to an individual <code> ReplyForm </code> are 
 *  indicated in the corresponding <code> UpdateResponse. </code> <code> 
 *  UpdateResponses </code> may be linked to the originating <code> ReplyForm 
 *  </code> through the <code> ReplyForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> Replies </code> in bulk. To unmap 
 *  a <code> Reply </code> from the current <code> Forum, </code> the <code> 
 *  ReplyForumAssignmentSession </code> should be used. These delete 
 *  operations attempt to remove the <code> Reply </code> itself thus removing 
 *  it from all known <code> Forum </code> catalogs. Bulk delete operations 
 *  return the results in <code> DeleteResponses. </code> </p>
 */

public interface ReplyBatchAdminSession
    extends org.osid.forum.ReplyAdminSession {


    /**
     *  Gets the reply forms for creating a bunch of new replies. A form is 
     *  returned for each supplied post or reply. 
     *
     *  @param  postIds the post or reply <code> Ids </code> 
     *  @param  replyRecordTypes array of reply record types to be included in 
     *          each create operation or an empty list if none 
     *  @return the reply forms 
     *  @throws org.osid.NotFoundException a <code> postId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> postIds </code> or 
     *          <code> replyRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.forum.batch.ReplyBatchFormList getReplyFormsForCreate(org.osid.id.IdList postIds, 
                                                                          org.osid.type.Type[] replyRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Replies. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  replyForms the reply forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> replyForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createReplies(org.osid.forum.batch.ReplyBatchFormList replyForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the reply forms for updating an existing set of replies. A new 
     *  reply form should be requested for each update transaction. 
     *
     *  @param  replyIds the <code> Ids </code> of the <code> Reply </code> 
     *  @return the reply form 
     *  @throws org.osid.NotFoundException a <code> replyId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> replyIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.forum.batch.ReplyBatchFormList getReplyFormsForUpdate(org.osid.id.IdList replyIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing replies. This method returns an error if the entire 
     *  operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  replyForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> replyForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateReplies(org.osid.forum.batch.ReplyBatchFormList replyForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Replies </code> in this <code> Forum </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllReplies()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes replies for the given <code> Ids. </code> 
     *
     *  @param  replyIds the <code> Ids </code> of the replies to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> replyIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteReplies(org.osid.id.IdList replyIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes replies for the given post. 
     *
     *  @param  postId an <code> Id </code> of a post 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> postId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteRepliesForPost(org.osid.id.Id postId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes replies for the given poster. 
     *
     *  @param  resourceId an <code> Id </code> of a resource 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteRepliesByPoster(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes replies under the given reply. 
     *
     *  @param  replyId an <code> Id </code> of a reply 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> replyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteChildReplies(org.osid.id.Id replyId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Reply </code> for the purpose of 
     *  creating compatibility. The primary <code> Id </code> of the <code> 
     *  Reply </code> is determined by the provider. The new <code> Id </code> 
     *  is an alias to the primary <code> Id. </code> If the alias is a 
     *  pointer to another reply, it is reassigned to the given reply <code> 
     *  Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasReplies(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
