//
// org.osid.grading.GradeEntry
//
//     The OSID Java specification for org.osid.grading.GradeEntry.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading;


/**
 *  <p>A <code> GradeEntry </code> represents an entry in a <code> Gradebook. 
 *  </code> </p>
 */

public interface GradeEntry
    extends org.osid.OsidRelationship {


    /**
     *  Gets the <code> Id </code> of the <code> GradebookColumn. </code> 
     *
     *  @return the <code> Id </code> of the <code> GradebookColumn </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getGradebookColumnId();


    /**
     *  Gets the <code> GradebookColumn. </code> 
     *
     *  @return the <code> GradebookColumn </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradebookColumn getGradebookColumn()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of the key resource of this entry. The key 
     *  resource may be a student or other applicable key to identify a row of 
     *  grading entries. 
     *
     *  @return <code> Id </code> of the key resource 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getKeyResourceId();


    /**
     *  Gets the key resource of this entry. The key resource may be a student 
     *  or other applicable key to identify a row of grading entries. 
     *
     *  @return the key resource 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getKeyResource()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this is a calculated entry. 
     *
     *  @return <code> true </code> if this entry is a calculated entry, 
     *          <code> false </code> otherwise. If <code> true, </code> then 
     *          <code> overridesCalculatedEntry() </code> must be <code> 
     *          false. </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isDerived();


    /**
     *  Tests if this is a manual entry that overrides a calculated entry. 
     *
     *  @return <code> true </code> if this entry overrides a calculated 
     *          entry, <code> false </code> otherwise. If <code> true, </code> 
     *          then <code> isDerived() </code> must be <code> false. </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean overridesCalculatedEntry();


    /**
     *  Gets the calculated entry <code> Id </code> this entry overrides. 
     *
     *  @return the calculated entry <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> overridesDerivedEntry() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getOverriddenCalculatedEntryId();


    /**
     *  Gets the calculated entry this entry overrides. 
     *
     *  @return the calculated entry 
     *  @throws org.osid.IllegalStateException <code> 
     *          overridesCalculatedEntry() </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeEntry getOverriddenCalculatedEntry()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this is entry should be ignored in any averaging, scaling or 
     *  curve calculation. 
     *
     *  @return <code> true </code> if this entry is ignored, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isIgnoredForCalculations();


    /**
     *  Tests if a grade or score has been assigned to this entry. Generally, 
     *  an entry is created with a grade or score. 
     *
     *  @return <code> true </code> if a grade has been assigned, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isGraded();


    /**
     *  Gets the grade <code> Id </code> in this entry if the grading system 
     *  is based on grades. 
     *
     *  @return the grade <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> isGraded() </code> is 
     *          <code> false </code> or <code> GradeSystem.isBasedOnGrades() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getGradeId();


    /**
     *  Gets the grade in this entry if the grading system is based on grades. 
     *
     *  @return the grade 
     *  @throws org.osid.IllegalStateException <code> isGraded() </code> is 
     *          <code> false </code> or <code> GradeSystem.isBasedOnGrades() 
     *          </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.Grade getGrade()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the score in this entry if the grading system is not based on 
     *  grades. 
     *
     *  @return the score 
     *  @throws org.osid.IllegalStateException <code> isGraded() </code> is 
     *          <code> false </code> or <code> GradeSystem.isBasedOnGrades() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getScore();


    /**
     *  Gets the time the gradeable object was graded. 
     *
     *  @return the timestamp of the grading entry 
     *  @throws org.osid.IllegalStateException <code> isGraded() </code> is 
     *          <code> false </code> or <code> isDerived() </code> is <code> 
     *          true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getTimeGraded();


    /**
     *  Gets the <code> Id </code> of the <code> Resource </code> that created 
     *  this entry. 
     *
     *  @return the <code> Id </code> of the <code> Resource </code> 
     *  @throws org.osid.IllegalStateException <code> isGraded() </code> is 
     *          <code> false </code> or <code> isDerived() </code> is <code> 
     *          true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getGraderId();


    /**
     *  Gets the <code> Resource </code> that created this entry. 
     *
     *  @return the <code> Resource </code> 
     *  @throws org.osid.IllegalStateException <code> isGraded() is false or 
     *          isDerived() is true </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getGrader()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of the <code> Agent </code> that created 
     *  this entry. 
     *
     *  @return the <code> Id </code> of the <code> Agent </code> 
     *  @throws org.osid.IllegalStateException <code> isGraded() </code> is 
     *          <code> false </code> or <code> isDerived() </code> is <code> 
     *          true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getGradingAgentId();


    /**
     *  Gets the <code> Agent </code> that created this entry. 
     *
     *  @return the <code> Agent </code> 
     *  @throws org.osid.IllegalStateException <code> isGraded() is false or 
     *          isDerived() is true </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.Agent getGradingAgent()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the grade entry record corresponding to the given <code> 
     *  GradeEntry </code> record <code> Type. </code> This method is used to 
     *  retrieve an object implementing the requested record. The <code> 
     *  gradeEntryRecordType </code> may be the <code> Type </code> returned 
     *  in <code> getRecordTypes() </code> or any of its parents in a <code> 
     *  Type </code> hierarchy where <code> 
     *  hasRecordType(gradeEntryRecordType) </code> is <code> true </code> . 
     *
     *  @param  gradeEntryRecordType the type of the record to retrieve 
     *  @return the grade entry record 
     *  @throws org.osid.NullArgumentException <code> gradeEntryRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(gradeEntryRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.records.GradeEntryRecord getGradeEntryRecord(org.osid.type.Type gradeEntryRecordType)
        throws org.osid.OperationFailedException;
}
