//
// org.osid.grading.GradeEntryAdminSession
//
//     The OSID Java specification for org.osid.grading.GradeEntryAdminSession.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading;


/**
 *  <p>This session creates, updates, and deletes <code> GradeEntries. </code> 
 *  The data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  GradeEntry, </code> a <code> GradeEntryForm </code> is requested using 
 *  <code> getGradeEntryFormForCreate() </code> specifying the desired record 
 *  <code> Types </code> or none if no record <code> Types </code> are needed. 
 *  The returned <code> GradeEntryForm </code> will indicate that it is to be 
 *  used with a create operation and can be used to examine metdata or 
 *  validate data prior to creation. Once the <code> GradeEntryForm </code> is 
 *  submiited to a create operation, it cannot be reused with another create 
 *  operation unless the first operation was unsuccessful. Each <code> 
 *  GradeEntryForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> GradeEntryForms </code> are requested to the 
 *  <code> GradeEntry </code> <code> Id </code> that is to be updated using 
 *  <code> getGradeEntryFormForUpdate(). </code> Similarly, the <code> 
 *  GradeEntryForm </code> has metadata about the data that can be updated and 
 *  it can perform validation before submitting the update. The <code> 
 *  GradeEntryForm </code> can only be used once for a successful update and 
 *  cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> GradeEntries. </code> To unmap a 
 *  <code> GradeEntry </code> from the current <code> Gradebook, </code> the 
 *  <code> GradeEntryGradebookAssignmentSession </code> should be used. These 
 *  delete operations attempt to remove the <code> GradeEntry </code> itself 
 *  thus removing it from all known <code> Gradebook </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface GradeEntryAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Gradebook </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Gradebook Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getGradebookId();


    /**
     *  Gets the <code> Gradebook </code> associated with this session. 
     *
     *  @return the <code> Gradebook </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.Gradebook getGradebook()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create grade entries. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known creating a grade entry will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer create operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> GradeEntry </code> creation is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateGradeEntries();


    /**
     *  Tests if this user can create a single <code> GradeEntry </code> using 
     *  the desired record types. While <code> 
     *  GradingManager.getGradeEntryRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> GradeEntry. </code> 
     *  Providing an empty array tests if a <code> GradeEntry </code> can be 
     *  created with no records. 
     *
     *  @param  gradeEntryRecordTypes array of grade entry record types 
     *  @return <code> true </code> if <code> GradeEntry </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> gradeEntryRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateGradeEntryWithRecordTypes(org.osid.type.Type[] gradeEntryRecordTypes);


    /**
     *  Gets the grade entry form for creating new grade entries. A new form 
     *  should be requested for each create transaction. 
     *
     *  @param  gradebookColumnId the gradebook column 
     *  @param  resourceId the key resource 
     *  @param  gradeEntryRecordTypes array of grade entry record types 
     *  @return the grade entry form 
     *  @throws org.osid.NotFoundException <code> gradebookColumnId or 
     *          resourceId </code> not found 
     *  @throws org.osid.NullArgumentException <code> gradebookColumnId, 
     *          resourceId, </code> or <code> gradeEntryRecordTypes </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeEntryForm getGradeEntryFormForCreate(org.osid.id.Id gradebookColumnId, 
                                                                      org.osid.id.Id resourceId, 
                                                                      org.osid.type.Type[] gradeEntryRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> GradeEntry. </code> 
     *
     *  @param  gradeEntryForm the form for this <code> GradeEntry </code> 
     *  @return the new <code> GradeEntry </code> 
     *  @throws org.osid.IllegalStateException <code> gradeEntryForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> gradeEntryForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> gradeEntryForm </code> 
     *          did not originate from <code> getGradeEntryFormForCreate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeEntry createGradeEntry(org.osid.grading.GradeEntryForm gradeEntryForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can override grade entries calculated from another. 
     *  A return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known creating a grade entry will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer create operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> GradeEntry </code> override is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canOverridecalculatedGradeEntries();


    /**
     *  Gets the grade entry form for overriding calculated grade entries. A 
     *  new form should be requested for each create transaction. 
     *
     *  @param  gradeEntryId the <code> Id </code> of the grade entry to be 
     *          overridden 
     *  @param  gradeEntryRecordTypes array of grade entry record types 
     *  @return the grade entry form 
     *  @throws org.osid.AlreadyExistsException <code> gradeEntryId </code> is 
     *          already overridden 
     *  @throws org.osid.NotFoundException <code> gradeEntryId </code> not 
     *          found or <code> gradeEntryId </code> is not a calculated entry 
     *  @throws org.osid.NullArgumentException <code> gradeEntryId </code> or 
     *          <code> gradeEntryRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeEntryForm getGradeEntryFormForOverride(org.osid.id.Id gradeEntryId, 
                                                                        org.osid.type.Type[] gradeEntryRecordTypes)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new overriding <code> GradeEntry. </code> 
     *
     *  @param  gradeEntryForm the form for this <code> GradeEntry </code> 
     *  @return the new <code> GradeEntry </code> 
     *  @throws org.osid.IllegalStateException <code> gradeEntryForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> gradeEntryForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> gradeEntryForm </code> 
     *          did not originate from <code> getGradeEntryFormForOverride() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeEntry overrideCalculatedGradeEntry(org.osid.grading.GradeEntryForm gradeEntryForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update grade entries. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known updating a <code> GradeEntry </code> will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer update operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if grade entry modification is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateGradeEntries();


    /**
     *  Gets the grade entry form for updating an existing entry. A new grade 
     *  entry form should be requested for each update transaction. 
     *
     *  @param  gradeEntryId the <code> Id </code> of the <code> GradeEntry 
     *          </code> 
     *  @return the grade entry form 
     *  @throws org.osid.NotFoundException <code> gradeEntryId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> gradeEntryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeEntryForm getGradeEntryFormForUpdate(org.osid.id.Id gradeEntryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing grade entry. 
     *
     *  @param  gradeEntryForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> gradeEntryForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> gradeEntryForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> gradeEntryForm </code> 
     *          did not originate from <code> getGradeEntryFormForUpdate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateGradeEntry(org.osid.grading.GradeEntryForm gradeEntryForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete grade entries. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known deleting a <code> GradeEntry </code> will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer delete operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> GradeEntry </code> deletion is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteGradeEntries();


    /**
     *  Deletes the <code> GradeEntry </code> identified by the given <code> 
     *  Id. </code> 
     *
     *  @param  gradeEntryId the <code> Id </code> of the <code> GradeEntry 
     *          </code> to delete 
     *  @throws org.osid.NotFoundException a <code> GradeEntry </code> was not 
     *          found identified by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> gradeEntryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteGradeEntry(org.osid.id.Id gradeEntryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  GradeEntries. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> GradeEntry </code> aliasing is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageGradeEntryAliases();


    /**
     *  Adds an <code> Id </code> to a <code> GradeEntry </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> GradeEntry </code> is determined by the provider. The new 
     *  <code> Id </code> performs as an alias to the primary <code> Id. 
     *  </code> If the alias is a pointer to another grade entry, it is 
     *  reassigned to the given grade entry <code> Id. </code> 
     *
     *  @param  gradeEntryId the <code> Id </code> of a <code> GradeEntry 
     *          </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> gradeEntryId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> gradeEntryId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasGradeEntry(org.osid.id.Id gradeEntryId, 
                                org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
