//
// org.osid.grading.GradeEntryQueryInspector
//
//     The OSID Java specification for org.osid.grading.GradeEntryQueryInspector.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading;


/**
 *  <p>This is the query inspector for examining grade entry queries. </p>
 */

public interface GradeEntryQueryInspector
    extends org.osid.OsidRelationshipQueryInspector {


    /**
     *  Gets the gradebook column <code> Id </code> terms. 
     *
     *  @return the gradebook column <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getGradebookColumnIdTerms();


    /**
     *  Gets the gradebook column terms. 
     *
     *  @return the gradebook column terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradebookColumnQueryInspector[] getGradebookColumnTerms();


    /**
     *  Gets the key resource <code> Id </code> terms. 
     *
     *  @return the key resource <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getKeyResourceIdTerms();


    /**
     *  Gets the key resource terms. 
     *
     *  @return the key resource terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceQueryInspector[] getKeyResourceTerms();


    /**
     *  Gets the derived terms. 
     *
     *  @return the derived terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.BooleanTerm[] getDerivedTerms();


    /**
     *  Gets the overridden calculated grade entry <code> Id </code> terms. 
     *
     *  @return the overridden grade entry <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getOverriddenGradeEntryIdTerms();


    /**
     *  Gets the overriden derived grade terms. 
     *
     *  @return the overridden grade entry terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeEntryQueryInspector[] getOverriddenGradeEntryTerms();


    /**
     *  Gets the ignored for caluclation entries terms. 
     *
     *  @return the ignored for calculation terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.BooleanTerm[] getIgnoredForCalculationsTerms();


    /**
     *  Gets the grade <code> Id </code> terms. 
     *
     *  @return the grade <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getGradeIdTerms();


    /**
     *  Gets the grade terms. 
     *
     *  @return the grade terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeQueryInspector[] getGradeTerms();


    /**
     *  Gets the score terms. 
     *
     *  @return the score terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DecimalRangeTerm[] getScoreTerms();


    /**
     *  Gets the time graded terms. 
     *
     *  @return the time graded terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DateTimeRangeTerm[] getTimeGradedTerms();


    /**
     *  Gets the grader <code> Id </code> terms. 
     *
     *  @return the grader <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getGraderIdTerms();


    /**
     *  Gets the grader terms. 
     *
     *  @return the grader terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceQueryInspector[] getGraderTerms();


    /**
     *  Gets the grading agent <code> Id </code> terms. 
     *
     *  @return the grading agent <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getGradingAgentIdTerms();


    /**
     *  Gets the grading agent terms. 
     *
     *  @return the grading agent terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.AgentQueryInspector[] getGradingAgentTerms();


    /**
     *  Gets the gradebook <code> Id </code> terms. 
     *
     *  @return the gradebook <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getGradebookIdTerms();


    /**
     *  Gets the gradebook terms. 
     *
     *  @return the gradebook terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradebookQueryInspector[] getGradebookTerms();


    /**
     *  Gets the grade entry query inspector record corresponding to the given 
     *  <code> GradeEntry </code> record <code> Type. </code> 
     *
     *  @param  gradeEntryRecordType a grade entry record type 
     *  @return the grade entry query inspector record 
     *  @throws org.osid.NullArgumentException <code> gradeEntryRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(gradeEntryRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.records.GradeEntryQueryInspectorRecord getGradeEntryQueryInspectorRecord(org.osid.type.Type gradeEntryRecordType)
        throws org.osid.OperationFailedException;
}
