//
// org.osid.grading.GradeEntrySearchOrder
//
//     The OSID Java specification for org.osid.grading.GradeEntrySearchOrder.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading;


/**
 *  <p>An interface for specifying the ordering of search results. </p>
 */

public interface GradeEntrySearchOrder
    extends org.osid.OsidRelationshipSearchOrder {


    /**
     *  Specified a preference for ordering results by the gradebook column. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByGradebookColumn(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a <code> GradebookColumnSearchOrder </code> is available. 
     *
     *  @return <code> true </code> if a gradebook column search order is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradebookColumnSearchOrder();


    /**
     *  Gets the search order for a gradebook column. 
     *
     *  @return the gradebook column search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradebookColumnSearchOrder() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradebookColumnSearchOrder() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.grading.GradebookColumnSearchOrder getGradebookColumnSearchOrder();


    /**
     *  Specified a preference for ordering results by the key resource. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByKeyResource(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a <code> ResourceSearchOrder </code> is available. 
     *
     *  @return <code> true </code> if a key resource search order is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsKeyResourceSearchOrder();


    /**
     *  Gets the search order for a resource. 
     *
     *  @return the key resource search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsKeyResourceSearchOrder() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsKeyResourceSearchOrder() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resource.ResourceSearchOrder getKeyResourceSearchOrder();


    /**
     *  Specified a preference for ordering results by the derived entries. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByDerived(org.osid.SearchOrderStyle style);


    /**
     *  Specified a preference for ordering results by the ignore for 
     *  calculations flag. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByIgnoredForCalculations(org.osid.SearchOrderStyle style);


    /**
     *  Specified a preference for ordering results by the grade or score. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByGrade(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a <code> GradeSearchOrder </code> is available. 
     *
     *  @return <code> true </code> if a grade search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradeSearchOrder();


    /**
     *  Gets the search order for a grade. 
     *
     *  @return the grade search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradeSearchOrder() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradeSearchOrder() </code> is <code> true. </code> 
     */

    public org.osid.grading.GradeSearchOrder getGradeSearchOrder();


    /**
     *  Specified a preference for ordering results by the time graded. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByTimeGraded(org.osid.SearchOrderStyle style);


    /**
     *  Specified a preference for ordering results by the grader. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByGrader(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a <code> ResourceSearchOrder </code> is available for grader 
     *  resources. 
     *
     *  @return <code> true </code> if a resource search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGraderSearchOrder();


    /**
     *  Gets the search order for a grader. 
     *
     *  @return the resource search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGraderSearchOrder() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGraderSearchOrder() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resource.ResourceSearchOrder getGraderSearchOrder();


    /**
     *  Specified a preference for ordering results by the grading agent. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByGradingAgent(org.osid.SearchOrderStyle style);


    /**
     *  Tests if an <code> AgentSearchOrder </code> is available fo grading 
     *  agents. 
     *
     *  @return <code> true </code> if an agent search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradingAgentSearchOrder();


    /**
     *  Gets the search order for a grading agent. 
     *
     *  @return the agent search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradingAgentSearchOrder() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradingAgentSearchOrder() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.authentication.AgentSearchOrder getGradingAgentSearchOrder();


    /**
     *  Gets the grade entry search order record corresponding to the given 
     *  grade entry record <code> Type. </code> Multiple retrievals return the 
     *  same underlying object. 
     *
     *  @param  gradeEntryRecordType a grade entry record type 
     *  @return the grade entry search order record 
     *  @throws org.osid.NullArgumentException <code> gradeEntryRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(gradeEntryRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.records.GradeEntrySearchOrderRecord getGradeEntrySearchOrderRecord(org.osid.type.Type gradeEntryRecordType)
        throws org.osid.OperationFailedException;
}
