//
// org.osid.grading.GradeSystemQuery
//
//     The OSID Java specification for org.osid.grading.GradeSystemQuery.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading;


/**
 *  <p>This is the query for searching grade systems. Each method match 
 *  request produces an <code> AND </code> term while multiple invocations of 
 *  a method produces a nested <code> OR. </code> </p>
 */

public interface GradeSystemQuery
    extends org.osid.OsidObjectQuery,
            org.osid.OsidAggregateableQuery {


    /**
     *  Matches grade systems based on grades. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBasedOnGrades(boolean match);


    /**
     *  Clears the grade <code> based </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBasedOnGradesTerms();


    /**
     *  Sets the grade <code> Id </code> for this query. 
     *
     *  @param  gradeId a grade <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for negative match 
     *  @throws org.osid.NullArgumentException <code> gradeId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchGradeId(org.osid.id.Id gradeId, boolean match);


    /**
     *  Clears the grade <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGradeIdTerms();


    /**
     *  Tests if a <code> GradeQuery </code> is available for querying grades. 
     *
     *  @return <code> true </code> if a grade query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradeQuery();


    /**
     *  Gets the query for a grade. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the grade query 
     *  @throws org.osid.UnimplementedException <code> supportsGradeQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradeQuery() </code> is <code> true. </code> 
     */

    public org.osid.grading.GradeQuery getGradeQuery();


    /**
     *  Matches grade systems with any grade. 
     *
     *  @param  match <code> true </code> to match grade systems with any 
     *          grade, <code> false </code> to match systems with no grade 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyGrade(boolean match);


    /**
     *  Clears the grade terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGradeTerms();


    /**
     *  Matches grade systems whose low end score falls in the specified range 
     *  inclusive. 
     *
     *  @param  start low end of range 
     *  @param  end high end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for negative match 
     *  @throws org.osid.InvalidArgumentException <code> end </code> is less 
     *          than <code> start </code> 
     *  @throws org.osid.NullArgumentException <code> gradeId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchLowestNumericScore(java.math.BigDecimal start, 
                                        java.math.BigDecimal end, 
                                        boolean match);


    /**
     *  Clears the lowest numeric score terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLowestNumericScoreTerms();


    /**
     *  Matches grade systems numeric score increment is between the specified 
     *  range inclusive. 
     *
     *  @param  start low end of range 
     *  @param  end high end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for negative match 
     *  @throws org.osid.InvalidArgumentException <code> end </code> is less 
     *          than <code> start </code> 
     *  @throws org.osid.NullArgumentException <code> gradeId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchNumericScoreIncrement(java.math.BigDecimal start, 
                                           java.math.BigDecimal end, 
                                           boolean match);


    /**
     *  Clears the numeric score increment terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearNumericScoreIncrementTerms();


    /**
     *  Matches grade systems whose high end score falls in the specified 
     *  range inclusive. 
     *
     *  @param  start low end of range 
     *  @param  end high end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for negative match 
     *  @throws org.osid.InvalidArgumentException <code> end </code> is less 
     *          than <code> start </code> 
     *  @throws org.osid.NullArgumentException <code> gradeId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchHighestNumericScore(java.math.BigDecimal start, 
                                         java.math.BigDecimal end, 
                                         boolean match);


    /**
     *  Clears the highest numeric score terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearHighestNumericScoreTerms();


    /**
     *  Sets the gradebook column <code> Id </code> for this query. 
     *
     *  @param  gradebookColumnId a gradebook column <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for negative match 
     *  @throws org.osid.NullArgumentException <code> gradebookColumnId 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchGradebookColumnId(org.osid.id.Id gradebookColumnId, 
                                       boolean match);


    /**
     *  Clears the gradebook column <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGradebookColumnIdTerms();


    /**
     *  Tests if a <code> GradebookColumnQuery </code> is available. 
     *
     *  @return <code> true </code> if a gradebook column query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradebookColumnQuery();


    /**
     *  Gets the query for a gradebook column. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the gradebook column query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradebookColumnQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradebookColumnQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.grading.GradebookColumnQuery getGradebookColumnQuery();


    /**
     *  Matches grade systems assigned to any gradebook column. 
     *
     *  @param  match <code> true </code> to match grade systems mapped to any 
     *          column, <code> false </code> to match systems mapped to no 
     *          columns 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyGradebookColumn(boolean match);


    /**
     *  Clears the gradebook column terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGradebookColumnTerms();


    /**
     *  Sets the gradebook <code> Id </code> for this query. 
     *
     *  @param  gradebookId a gradebook <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for negative match 
     *  @throws org.osid.NullArgumentException <code> gradebookId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchGradebookId(org.osid.id.Id gradebookId, boolean match);


    /**
     *  Clears the gradebook <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGradebookIdTerms();


    /**
     *  Tests if a <code> GradebookQuery </code> is available . 
     *
     *  @return <code> true </code> if a gradebook query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradebookQuery();


    /**
     *  Gets the query for a gradebook. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the gradebook query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradebookQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradebookQuery() </code> is <code> true. </code> 
     */

    public org.osid.grading.GradebookQuery getGradebookQuery();


    /**
     *  Clears the gradebook terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGradebookTerms();


    /**
     *  Gets the grade system query record corresponding to the given <code> 
     *  GradeSystem </code> record <code> Type. </code> Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @param  gradeSystemRecordType a grade system record type 
     *  @return the grade system query record 
     *  @throws org.osid.NullArgumentException <code> gradeSystemRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(gradeSystemRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.records.GradeSystemQueryRecord getGradeSystemQueryRecord(org.osid.type.Type gradeSystemRecordType)
        throws org.osid.OperationFailedException;
}
