//
// org.osid.grading.GradeSystemSmartGradebookSession
//
//     The OSID Java specification for org.osid.grading.GradeSystemSmartGradebookSession.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. A <code> GradeSystemQuery </code> can be retrieved from this 
 *  session and mapped to this <code> Gradebook </code> to create a virtual 
 *  collection of <code> GradeSystems. </code> The entries may be sequenced 
 *  using the <code> GradeSystemSearchOrder </code> from this session. </p> 
 *  
 *  <p> This <code> Gradebook </code> has a default query that matches any 
 *  grade system and a default search order that specifies no sequencing. The 
 *  queries may be examined using a <code> GradeSystemQueryInspector. </code> 
 *  The query may be modified by converting the inspector back to a <code> 
 *  GradeSystemQuery. </code> </p>
 */

public interface GradeSystemSmartGradebookSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Gradebook </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Gradebook Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getGradebookId();


    /**
     *  Gets the <code> Gradebook </code> associated with this session. 
     *
     *  @return the <code> Gradebook </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.Gradebook getGradebook()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart gradebooks. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer smart operations. 
     *
     *  @return <code> false </code> if smart gradebook methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartGradebooks();


    /**
     *  Gets a grade system query. 
     *
     *  @return the grade system query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeSystemQuery getGradeSystemQuery();


    /**
     *  Gets a grade system search order. 
     *
     *  @return the grade system search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeSystemSearchOrder getGradeSystemSearchOrder();


    /**
     *  Applies a grade system query to this gradebook. 
     *
     *  @param  gradeSystemQuery the grade system query 
     *  @throws org.osid.NullArgumentException <code> gradeSystemQuery </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> gradeSystemQuery </code> 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyGradeSystemQuery(org.osid.grading.GradeSystemQuery gradeSystemQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a grade system query inspector for this gradebook. 
     *
     *  @return the grade system query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeSystemQueryInspector inspectGradeSystemQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a grade system search order to this gradebook. 
     *
     *  @param  gradeSystemSearchOrder the grade system search order 
     *  @throws org.osid.NullArgumentException <code> gradeSystemSearchOrder 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> gradeSystemSearchOrder 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyGradeSystemSequencing(org.osid.grading.GradeSystemSearchOrder gradeSystemSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a grade system query from an inspector. 
     *
     *  @param  gradeSystemQueryInspector a grade system query inspector 
     *  @return the grade system query 
     *  @throws org.osid.NullArgumentException <code> 
     *          gradeSystemQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> gradeSystemQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeSystemQuery getGradeSystemQueryFromInspector(org.osid.grading.GradeSystemQueryInspector gradeSystemQueryInspector);
}
