//
// org.osid.grading.GradebookAdminSession
//
//     The OSID Java specification for org.osid.grading.GradebookAdminSession.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading;


/**
 *  <p>This session creates, updates, and deletes <code> Gradebooks. </code> 
 *  The data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Gradebook, </code> a <code> GradebookForm </code> is requested using 
 *  <code> getGradebookFormForCreate() </code> specifying the desired record 
 *  <code> Types </code> or none if no record <code> Types </code> are needed. 
 *  The returned <code> GradebookForm </code> will indicate that it is to be 
 *  used with a create operation and can be used to examine metdata or 
 *  validate data prior to creation. Once the <code> GradebookForm </code> is 
 *  submiited to a create operation, it cannot be reused with another create 
 *  operation unless the first operation was unsuccessful. Each <code> 
 *  GradebookForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> GradebookForms </code> are requested to the <code> 
 *  Gradebook </code> <code> Id </code> that is to be updated using <code> 
 *  getGradebookFormForUpdate(). </code> Similarly, the <code> GradebookForm 
 *  </code> has metadata about the data that can be updated and it can perform 
 *  validation before submitting the update. The <code> GradebookForm </code> 
 *  can only be used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Gradebooks. </code> </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface GradebookAdminSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can create <code> Gradebooks. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> Gradebook </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not wish to offer create operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Gradebook </code> creation is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateGradebooks();


    /**
     *  Tests if this user can create a single <code> Gradebook </code> using 
     *  the desired record types. While <code> 
     *  GradingManager.getGradebookRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> Gradebook. </code> 
     *  Providing an empty array tests if a <code> Gradebook </code> can be 
     *  created with no records. 
     *
     *  @param  gradebookRecordTypes array of gradebook record types 
     *  @return <code> true </code> if <code> Gradebook </code> creation using 
     *          the specified <code> Types </code> is supported, <code> false 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> gradebookRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateGradebookWithRecordTypes(org.osid.type.Type[] gradebookRecordTypes);


    /**
     *  Gets the gradebook form for creating new gradebooks. A new form should 
     *  be requested for each create transaction. 
     *
     *  @param  gradebookRecordTypes array of gradebook record types 
     *  @return the gradebook form 
     *  @throws org.osid.NullArgumentException <code> gradebookRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradebookForm getGradebookFormForCreate(org.osid.type.Type[] gradebookRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Gradebook. </code> 
     *
     *  @param  gradebookForm the form for this <code> Gradebook </code> 
     *  @return the new <code> Gradebook </code> 
     *  @throws org.osid.IllegalStateException <code> gradebookForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> gradebookForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> gradebookForm </code> did 
     *          not originate from <code> getGradebookFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.Gradebook createGradebook(org.osid.grading.GradebookForm gradebookForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Gradebooks. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> Gradebook </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not wish to offer update operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Gradebook </code> modification 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateGradebooks();


    /**
     *  Gets the gradebook form for updating an existing gradebook. A new 
     *  gradebook form should be requested for each update transaction. 
     *
     *  @param  gradebookId the <code> Id </code> of the <code> Gradebook 
     *          </code> 
     *  @return the gradebook form 
     *  @throws org.osid.NotFoundException <code> gradebookId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> gradebookId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradebookForm getGradebookFormForUpdate(org.osid.id.Id gradebookId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing gradebook. 
     *
     *  @param  gradebookForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> gradebookForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> gradebookForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> gradebookForm did not 
     *          originate from getGradebookFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateGradebook(org.osid.grading.GradebookForm gradebookForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete gradebooks. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known deleting a <code> Gradebook </code> will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer delete operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Gradebook </code> deletion is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteGradebooks();


    /**
     *  Deletes a <code> Gradebook. </code> 
     *
     *  @param  gradebookId the <code> Id </code> of the <code> Gradebook 
     *          </code> to remove 
     *  @throws org.osid.NotFoundException <code> gradebookId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> gradebookId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteGradebook(org.osid.id.Id gradebookId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Gradebooks. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Gradebook </code> aliasing is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageGradebookAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Gradebook </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Gradebook </code> is determined by the provider. The new 
     *  <code> Id </code> performs as an alias to the primary <code> Id 
     *  </code> . If the alias is a pointer to another gradebook, it is 
     *  reassigned to the given gradebook <code> Id. </code> 
     *
     *  @param  gradebookId the <code> Id </code> of a <code> Gradebook 
     *          </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> gradebookId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> gradebookId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasGradebook(org.osid.id.Id gradebookId, 
                               org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
