//
// org.osid.grading.GradebookColumnNotificationSession
//
//     The OSID Java specification for org.osid.grading.GradebookColumnNotificationSession.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading;


/**
 *  <p>This session defines methods to receive asynchronous notifications on 
 *  adds/changes to <code> GradebookColumn </code> objects. This session is 
 *  intended for consumers needing to synchronize their state with this 
 *  service without the use of polling. Notifications are cancelled when this 
 *  session is closed. </p> 
 *  
 *  <p> The views defined in this session correspond to the views in the 
 *  <code> GradebookColumnLookupSession. </code> </p>
 */

public interface GradebookColumnNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Gradebook </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Gradebook Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getGradebookId();


    /**
     *  Gets the <code> Gradebook </code> associated with this session. 
     *
     *  @return the <code> Gradebook </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.Gradebook getGradebook()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can register for <code> GradebookColumn </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForGradebookColumnNotifications();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include notifications for gradebook columns in gradebooks which are 
     *  children of this gradebook in the gradebook hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedGradebookView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts notifications to this gradebook only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedGradebookView();


    /**
     *  Register for notifications of new gradebook columns. <code> 
     *  GradebookColumnReceiver.newGradebookColumns() </code> is invoked when 
     *  a new column is created. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewGradebookColumns()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated gradebook columns. <code> 
     *  GradebookColumnReceiver.changedGradebookColumns() </code> is invoked 
     *  when a gradebook column is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedGradebookColumns()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated gradebook column. <code> 
     *  GradebookColumnReceiver.changedGradebookColumns() </code> is invoked 
     *  when the specified gradebook column is changed. 
     *
     *  @param  gradebookColumnId the <code> Id </code> of the <code> 
     *          GradebookColumn </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> gradebookColumnId is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedGradebookColumn(org.osid.id.Id gradebookColumnId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted gradebook columns. <code> 
     *  GradebookColumnReceiver.deletedGradebookColumns() </code> is invoked 
     *  when a gradebook column is removed from this gradebook. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedGradebookColumns()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted gradebook column. <code> 
     *  GradebookColumnReceiver.deletedGradebookColumns() </code> is invoked 
     *  when the specified column is removed from thia gradebook. 
     *
     *  @param  gradebookColumnId the <code> Id </code> of the <code> 
     *          GradebookColumn </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> gradebookColumnId is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedGradebookColumn(org.osid.id.Id gradebookColumnId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
