//
// org.osid.grading.GradebookColumnQuery
//
//     The OSID Java specification for org.osid.grading.GradebookColumnQuery.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading;


/**
 *  <p>This is the query for searching gradings. Each method match request 
 *  produces an <code> AND </code> term while multiple invocations of a method 
 *  produces a nested <code> OR. </code> </p>
 */

public interface GradebookColumnQuery
    extends org.osid.OsidObjectQuery {


    /**
     *  Sets the grade system <code> Id </code> for this query. 
     *
     *  @param  gradeSystemId a grade system <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> gradeSystemId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchGradeSystemId(org.osid.id.Id gradeSystemId, boolean match);


    /**
     *  Clears the grade system <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGradeSystemIdTerms();


    /**
     *  Tests if a <code> GradeSystemQuery </code> is available for querying 
     *  grade systems. 
     *
     *  @return <code> true </code> if a grade system query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradeSystemQuery();


    /**
     *  Gets the query for a grade system. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the grade system query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradeSystemQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradeSystemQuery() </code> is <code> true. </code> 
     */

    public org.osid.grading.GradeSystemQuery getGradeSystemQuery();


    /**
     *  Matches gradebook columns with any grade system assigned. 
     *
     *  @param  match <code> true </code> to match columns with any grade 
     *          system, <code> false </code> to match columns with no grade 
     *          system 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyGradeSystem(boolean match);


    /**
     *  Clears the grade system terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGradeSystemTerms();


    /**
     *  Sets the grade entry <code> Id </code> for this query. 
     *
     *  @param  gradeEntryId a grade entry <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> gradeEntryId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchGradeEntryId(org.osid.id.Id gradeEntryId, boolean match);


    /**
     *  Clears the grade entry <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGradeEntryIdTerms();


    /**
     *  Tests if a <code> GradeEntryQuery </code> is available for querying 
     *  grade entries. 
     *
     *  @return <code> true </code> if a grade entry query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradeEntryQuery();


    /**
     *  Gets the query for a grade entry. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the grade entry query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradeEntryQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradeEntryQuery() </code> is <code> true. </code> 
     */

    public org.osid.grading.GradeEntryQuery getGradeEntryQuery();


    /**
     *  Matches gradebook columns with any grade entry assigned. 
     *
     *  @param  match <code> true </code> to match columns with any grade 
     *          entry, <code> false </code> to match columns with no grade 
     *          entries 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyGradeEntry(boolean match);


    /**
     *  Clears the grade entry terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGradeEntryTerms();


    /**
     *  Tests if a <code> GradebookColumnSummaryQuery </code> is available for 
     *  querying grade systems. 
     *
     *  @return <code> true </code> if a gradebook column summary query 
     *          interface is available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradebookColumnSummaryQuery();


    /**
     *  Gets the query interface for a gradebook column summary. Multiple 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @return the gradebook column summary query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradebookColumnSummaryQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradebookColumnSummaryQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.grading.GradebookColumnSummaryQuery getGradebookColumnSummaryQuery();


    /**
     *  Clears the gradebook column summary terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGradebookColumnSummaryTerms();


    /**
     *  Sets the gradebook <code> Id </code> for this query. 
     *
     *  @param  gradebookId a gradebook <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> gradebookId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchGradebookId(org.osid.id.Id gradebookId, boolean match);


    /**
     *  Clears the gradebook <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGradebookIdTerms();


    /**
     *  Tests if a <code> GradebookQuery </code> is available for querying 
     *  grade systems. 
     *
     *  @return <code> true </code> if a gradebook query interface is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradebookQuery();


    /**
     *  Gets the query interface for a gradebook. Multiple retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @return the gradebook query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradebookQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradebookQuery() </code> is <code> true. </code> 
     */

    public org.osid.grading.GradebookQuery getGradebookQuery();


    /**
     *  Clears the gradebook terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGradebookTerms();


    /**
     *  Gets the gradebook column query record corresponding to the given 
     *  <code> GradebookColumn </code> record <code> Type. </code> Multiple 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  gradebookColumnRecordType a gradebook column record type 
     *  @return the gradebook column query record 
     *  @throws org.osid.NullArgumentException <code> 
     *          gradebookColumnRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(gradebookColumnRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.records.GradebookColumnQueryRecord getGradebookColumnQueryRecord(org.osid.type.Type gradebookColumnRecordType)
        throws org.osid.OperationFailedException;
}
