//
// org.osid.grading.GradebookColumnSummaryQueryInspector
//
//     The OSID Java specification for org.osid.grading.GradebookColumnSummaryQueryInspector.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading;


/**
 *  <p>This is the query inspector for examining gradebook column summary 
 *  queries. </p>
 */

public interface GradebookColumnSummaryQueryInspector
    extends org.osid.OsidRuleQueryInspector {


    /**
     *  Gets the gradebook column <code> Id </code> terms. 
     *
     *  @return the gradebook column <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getGradebookColumnIdTerms();


    /**
     *  Gets the gradebook column terms. 
     *
     *  @return the gradebookc column terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradebookColumnQueryInspector[] getGradebookColumnTerms();


    /**
     *  Gets the mean terms. 
     *
     *  @return the mean terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DecimalRangeTerm[] getMeanTerms();


    /**
     *  Gets the minimum mean terms. 
     *
     *  @return the minimum mean terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DecimalTerm[] getMinimumMeanTerms();


    /**
     *  Gets the median terms. 
     *
     *  @return the median terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DecimalRangeTerm[] getMedianTerms();


    /**
     *  Gets the minimum median terms. 
     *
     *  @return the minimum median terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DecimalTerm[] getMinimumMedianTerms();


    /**
     *  Gets the mode terms. 
     *
     *  @return the mode terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DecimalRangeTerm[] getModeTerms();


    /**
     *  Gets the minimum mode terms. 
     *
     *  @return the minimum mode terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DecimalTerm[] getMinimumModeTerms();


    /**
     *  Gets the rms terms. 
     *
     *  @return the rms terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DecimalRangeTerm[] getRMSTerms();


    /**
     *  Gets the minimum rms terms. 
     *
     *  @return the minimum rms terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DecimalTerm[] getMinimumRMSTerms();


    /**
     *  Gets the standard deviation terms. 
     *
     *  @return the standard deviation terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DecimalRangeTerm[] getStandardDeviationTerms();


    /**
     *  Gets the minimum standard deviation terms. 
     *
     *  @return the minimum standard deviation terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DecimalTerm[] getMinimumStandardDeviationTerms();


    /**
     *  Gets the sum terms. 
     *
     *  @return the sum terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DecimalRangeTerm[] getSumTerms();


    /**
     *  Gets the minimum sum terms. 
     *
     *  @return the minimum sum terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DecimalTerm[] getMinimumSumTerms();


    /**
     *  Gets the gradebook <code> Id </code> terms. 
     *
     *  @return the gradebook <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getGradebookIdTerms();


    /**
     *  Gets the gradebook terms. 
     *
     *  @return the gradebook terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradebookQueryInspector[] getGradebookTerms();


    /**
     *  Gets the gradebook column summary query inspector record corresponding 
     *  to the given <code> GradebookColumnSummary </code> record <code> Type. 
     *  </code> 
     *
     *  @param  gradebookColumnSummaryRecordType a gradebook column summry 
     *          record type 
     *  @return the gradebook column summary query inspector record 
     *  @throws org.osid.NullArgumentException <code> 
     *          gradebookColumnSummaryRecordType </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(gradebookColumnSummaryRecordRecordType) </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.records.GradebookColumnSummaryQueryInspectorRecord getGradebookColumnSummaryQueryInspectorRecord(org.osid.type.Type gradebookColumnSummaryRecordType)
        throws org.osid.OperationFailedException;
}
