//
// org.osid.grading.GradebookNotificationSession
//
//     The OSID Java specification for org.osid.grading.GradebookNotificationSession.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading;


/**
 *  <p>This session defines methods to receive notifications on adds/changes 
 *  to <code> Gradebook </code> objects. This session is intended for 
 *  consumers needing to synchronize their state with this service without the 
 *  use of polling. Notifications are cancelled when this session is closed. 
 *  </p>
 */

public interface GradebookNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can register for <code> Gradebook </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForGradebookNotifications();


    /**
     *  Register for notifications of new gradebooks. <code> 
     *  GradebookReceiver.newGradebooks() </code> is invoked when a new <code> 
     *  Gradebook </code> is created. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewGradebooks()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification if an ancestor is added to the specified 
     *  gradebook in the gradebook hierarchy. <code> 
     *  GradebookReceiver.newGradebookAncestor() </code> is invoked when the 
     *  specified gradebook experiences an addition in ancestry. 
     *
     *  @param  gradebookId the <code> Id </code> of the gradebook to monitor 
     *  @throws org.osid.NullArgumentException <code> gradebookId is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewGradebookAncestors(org.osid.id.Id gradebookId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification if a descendant is added to the specified 
     *  gradebook in the gradebook hierarchy. <code> 
     *  GradebookReceiver.newGradebookDescendant() </code> is invoked when the 
     *  specified gradebook experiences an addition in descendants. 
     *
     *  @param  gradebookId the <code> Id </code> of the gradebook to monitor 
     *  @throws org.osid.NullArgumentException <code> gradebookId is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewGradebookDescendants(org.osid.id.Id gradebookId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated gradebooks. <code> 
     *  GradebookReceiver.changedGradebooks() </code> is invoked when a 
     *  gradebook is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedGradebooks()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated gradebook. <code> 
     *  GradebookReceiver.changedGradebooks() </code> is invoked when the 
     *  specified gradebook is changed. 
     *
     *  @param  gradebookId the <code> Id </code> of the gradebook to monitor 
     *  @throws org.osid.NullArgumentException <code> gradebookId is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedGradebook(org.osid.id.Id gradebookId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted gradebooks. <code> 
     *  GradebookReceiver.deletedGradebooks() </code> is invoked when a 
     *  calenedar is deleted. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedGradebooks()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted gradebook. <code> 
     *  GradebookReceiver.deletedGradebooks() </code> is invoked when the 
     *  specified gradebook is deleted. 
     *
     *  @param  gradebookId the <code> Id </code> of the gradebook to monitor 
     *  @throws org.osid.NullArgumentException <code> gradebookId is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedGradebook(org.osid.id.Id gradebookId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification if an ancestor is removed from the 
     *  specified gradebook in the gradebook hierarchy. <code> 
     *  GradebookReceiver.deletedGradebookAncestor() </code> is invoked when 
     *  the specified gradebook experiences a removal of an ancestor. 
     *
     *  @param  gradebookId the <code> Id </code> of the gradebook to monitor 
     *  @throws org.osid.NullArgumentException <code> gradebookId is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedGradebookAncestors(org.osid.id.Id gradebookId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification if a descendant is removed from fthe 
     *  specified gradebook in the calndar hierarchy. <code> 
     *  GradebookReceiver.deletedGradebookDescednant() </code> is invoked when 
     *  the specified gradebook experiences a removal of one of its 
     *  descendants. 
     *
     *  @param  gradebookId the <code> Id </code> of the gradebook to monitor 
     *  @throws org.osid.NullArgumentException <code> gradebookId is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedGradebookDescendants(org.osid.id.Id gradebookId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
