//
// org.osid.grading.GradebookSearchSession
//
//     The OSID Java specification for org.osid.grading.GradebookSearchSession.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading;


/**
 *  <p>This session provides methods for searching among <code> Gradebook 
 *  </code> objects. The search query is constructed using the <code> 
 *  GradebookQuery. </code> </p> 
 *  
 *  <p> <code> getGradebooksByQuery() </code> is the basic search method and 
 *  returns a list of <code> Gradebook </code> objects.A more advanced search 
 *  may be performed with <code> getGradebooksBySearch(). </code> It accepts a 
 *  <code> GradebookSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getGradebooksBySearch() </code> returns a <code> 
 *  GradebookSearchResults </code> that can be used to access the resulting 
 *  <code> GradebookList </code> or be used to perform a search within the 
 *  result set through <code> GradebookSearch. </code> </p> 
 *  
 *  <p> Gradebooks may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> GradebookQuery. 
 *  </code> </p>
 */

public interface GradebookSearchSession
    extends org.osid.grading.GradebookQuerySession {


    /**
     *  Gets a gradebook search. 
     *
     *  @return a gradebook search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradebookSearch getGradebookSearch();


    /**
     *  Gets a gradebook search order. The <code> GradebookSearchOrder </code> 
     *  is supplied to a <code> GradebookSearch </code> to specify the 
     *  ordering of results. 
     *
     *  @return the gradebook search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradebookSearchOrder getGradebookSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  gradebookQuery the gradebook query 
     *  @param  gradebookSearch the gradebook search 
     *  @return the gradebook search results 
     *  @throws org.osid.NullArgumentException <code> gradebookQuery </code> 
     *          or <code> gradebookSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> gradebookQuery </code> or 
     *          <code> gradebookSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradebookSearchResults getGradebooksBySearch(org.osid.grading.GradebookQuery gradebookQuery, 
                                                                         org.osid.grading.GradebookSearch gradebookSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a gradebook query from an inspector. The inspector is available 
     *  from an <code> GradenookSearchResults. </code> 
     *
     *  @param  gradebookQueryInspector a gradebook query inspector 
     *  @return the gradebook query 
     *  @throws org.osid.NullArgumentException <code> gradebookQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> gradebookQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradebookQuery getGradebookQueryFromInspector(org.osid.grading.GradebookQueryInspector gradebookQueryInspector);
}
