//
// org.osid.grading.GradingProfile
//
//     The OSID Java specification for org.osid.grading.GradingProfile.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading;


/**
 *  <p>The <code> GradingProfile </code> describes the interoperability among 
 *  grading services. </p>
 */

public interface GradingProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if federation is visible. 
     *
     *  @return <code> true </code> if visible federation is supported <code> 
     *          , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if a grade system lookup service is supported. 
     *
     *  @return true if grade system lookup is supported, false otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradeSystemLookup();


    /**
     *  Tests if a grade system query service is supported. 
     *
     *  @return <code> true </code> if grade system query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradeSystemQuery();


    /**
     *  Tests if a grade system search service is supported. 
     *
     *  @return <code> true </code> if grade system search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradeSystemSearch();


    /**
     *  Tests if a grade system administrative service is supported. 
     *
     *  @return <code> true </code> if grade system admin is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradeSystemAdmin();


    /**
     *  Tests if grade system notification is supported. Messages may be sent 
     *  when grade entries are created, modified, or deleted. 
     *
     *  @return <code> true </code> if grade system notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradeSystemNotification();


    /**
     *  Tests if a grade system to gradebook lookup session is available. 
     *
     *  @return <code> true </code> if grade system gradebook lookup session 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradeSystemGradebook();


    /**
     *  Tests if a grade system to gradebook assignment session is available. 
     *
     *  @return <code> true </code> if grade system gradebook assignment is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradeSystemGradebookAssignment();


    /**
     *  Tests if a grade system smart gradebook session is available. 
     *
     *  @return <code> true </code> if grade system smart gradebook is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradeSystemSmartGradebook();


    /**
     *  Tests if a grade entry lookup service is supported. 
     *
     *  @return true if grade entry lookup is supported, false otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradeEntryLookup();


    /**
     *  Tests if a grade entry query service is supported. 
     *
     *  @return true if grade entry query is supported, false otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradeEntryQuery();


    /**
     *  Tests if a grade entry search service is supported. 
     *
     *  @return <code> true </code> if grade entry search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradeEntrySearch();


    /**
     *  Tests if a grade entry administrative service is supported. 
     *
     *  @return <code> true </code> if grade entry admin is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradeEntryAdmin();


    /**
     *  Tests if grade entry notification is supported. 
     *
     *  @return <code> true </code> if grade entry notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradeEntryNotification();


    /**
     *  Tests if a gradebook column lookup service is supported. 
     *
     *  @return true if gradebook column lookup is supported, false otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradebookColumnLookup();


    /**
     *  Tests if a gradebook column query service is supported. 
     *
     *  @return <code> true </code> if grade system query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradebookColumnQuery();


    /**
     *  Tests if a gradebook column search service is supported. 
     *
     *  @return <code> true </code> if grade system search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradebookColumnSearch();


    /**
     *  Tests if a gradebook column administrative service is supported. 
     *
     *  @return <code> true </code> if gradebook column admin is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradebookColumnAdmin();


    /**
     *  Tests if gradebook column notification is supported. Messages may be 
     *  sent when grade entries are created, modified, or deleted. 
     *
     *  @return <code> true </code> if gradebook column notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradebookColumnNotification();


    /**
     *  Tests if a gradebook column to gradebook lookup session is available. 
     *
     *  @return <code> true </code> if gradebook column gradebook lookup 
     *          session is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradebookColumnGradebook();


    /**
     *  Tests if a gradebook column to gradebook assignment session is 
     *  available. 
     *
     *  @return <code> true </code> if gradebook column gradebook assignment 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradebookColumnGradebookAssignment();


    /**
     *  Tests if a gradebook column smart gradebookt session is available. 
     *
     *  @return <code> true </code> if gradebook column amsrt gradebook is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradebookColumnSmartGradebook();


    /**
     *  Tests if a gradebook lookup service is supported. 
     *
     *  @return <code> true </code> if gradebook lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradebookLookup();


    /**
     *  Tests if a gradebook query service is supported. 
     *
     *  @return <code> true </code> if gradebook query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradebookQuery();


    /**
     *  Tests if a gradebook search service is supported. 
     *
     *  @return <code> true </code> if gradebook search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradebookSearch();


    /**
     *  Tests if a gradebook administrative service is supported. 
     *
     *  @return <code> true </code> if gradebook admin is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradebookAdmin();


    /**
     *  Tests if gradebook notification is supported. Messages may be sent 
     *  when gradebooks are created, modified, or deleted. 
     *
     *  @return <code> true </code> if gradebook notification is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradebookNotification();


    /**
     *  Tests if a gradebook hierarchy traversal is supported. 
     *
     *  @return <code> true </code> if a gradebook hierarchy traversal is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradebookHierarchy();


    /**
     *  Tests if gradebook hierarchy design is supported. 
     *
     *  @return <code> true </code> if a gradebook hierarchy design is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradebookHierarchyDesign();


    /**
     *  Tests if a grading batch service is supported. 
     *
     *  @return <code> true </code> if a grading batch service is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradingBatch();


    /**
     *  Tests if a grading calculation service is supported. 
     *
     *  @return <code> true </code> if a grading calculation service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradingCalculation();


    /**
     *  Tests if a grade system transform service is supported. 
     *
     *  @return <code> true </code> if a grading transform service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradingTransform();


    /**
     *  Gets the supported <code> Grade </code> record types. 
     *
     *  @return a list containing the supported <code> Grade </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getGradeRecordTypes();


    /**
     *  Tests if the given <code> Grade </code> record type is supported. 
     *
     *  @param  gradeRecordType a <code> Type </code> indicating a <code> 
     *          Grade </code> record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> gradeRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradeRecordType(org.osid.type.Type gradeRecordType);


    /**
     *  Gets the supported <code> GradeSystem </code> record types. 
     *
     *  @return a list containing the supported <code> GradeSystem </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getGradeSystemRecordTypes();


    /**
     *  Tests if the given <code> GradeSystem </code> record type is 
     *  supported. 
     *
     *  @param  gradeSystemRecordType a <code> Type </code> indicating a 
     *          <code> GradeSystem </code> record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> gradeSystemRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradeSystemRecordType(org.osid.type.Type gradeSystemRecordType);


    /**
     *  Gets the supported <code> GradeSystem </code> search record types. 
     *
     *  @return a list containing the supported <code> GradeSystem </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getGradeSystemSearchRecordTypes();


    /**
     *  Tests if the given <code> GradeSystem </code> search record type is 
     *  supported. 
     *
     *  @param  gradeSystemSearchRecordType a <code> Type </code> indicating a 
     *          <code> GradeSystem </code> search record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          gradeSystemSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradeSystemSearchRecordType(org.osid.type.Type gradeSystemSearchRecordType);


    /**
     *  Gets the supported <code> GradeEntry </code> record types. 
     *
     *  @return a list containing the supported <code> GradeEntry </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getGradeEntryRecordTypes();


    /**
     *  Tests if the given <code> GradeEntry </code> record type is supported. 
     *
     *  @param  gradeEntryRecordType a <code> Type </code> indicating a <code> 
     *          GradeEntry </code> record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> gradeEntryRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradeEntryRecordType(org.osid.type.Type gradeEntryRecordType);


    /**
     *  Gets the supported <code> GradeEntry </code> search record types. 
     *
     *  @return a list containing the supported <code> GradeEntry </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getGradeEntrySearchRecordTypes();


    /**
     *  Tests if the given <code> GradeEntry </code> search record type is 
     *  supported. 
     *
     *  @param  gradeEntrySearchRecordType a <code> Type </code> indicating a 
     *          <code> GradeEntry </code> search record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          gradeEntrySearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradeEntrySearchRecordType(org.osid.type.Type gradeEntrySearchRecordType);


    /**
     *  Gets the supported <code> GradebookColumn </code> record types. 
     *
     *  @return a list containing the supported <code> GradebookColumn </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getGradebookColumnRecordTypes();


    /**
     *  Tests if the given <code> GradebookColumn </code> record type is 
     *  supported. 
     *
     *  @param  gradebookColumnRecordType a <code> Type </code> indicating a 
     *          <code> GradebookColumn </code> type 
     *  @return <code> true </code> if the given gradebook column record 
     *          <code> Type </code> is supported, <code> false </code> 
     *          otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          gradebookColumnRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradebookColumnRecordType(org.osid.type.Type gradebookColumnRecordType);


    /**
     *  Gets the supported gradebook column search record types. 
     *
     *  @return a list containing the supported <code> GradebookColumn </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getGradebookColumnSearchRecordTypes();


    /**
     *  Tests if the given gradebook column search record type is supported. 
     *
     *  @param  gradebookColumnSearchRecordType a <code> Type </code> 
     *          indicating a <code> GradebookColumn </code> search record type 
     *  @return <code> true </code> if the given search record <code> Type 
     *          </code> is supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          gradebookColumnSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradebookColumnSearchRecordType(org.osid.type.Type gradebookColumnSearchRecordType);


    /**
     *  Gets the supported <code> GradebookColumnSummary </code> record types. 
     *
     *  @return a list containing the supported <code> GradebookColumnSummary 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getGradebookColumnSummaryRecordTypes();


    /**
     *  Tests if the given <code> GradebookColumnSummary </code> record type 
     *  is supported. 
     *
     *  @param  gradebookColumnSummaryRecordType a <code> Type </code> 
     *          indicating a <code> GradebookColumnSummary </code> type 
     *  @return <code> true </code> if the given gradebook column summary 
     *          record <code> Type </code> is supported, <code> false </code> 
     *          otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          gradebookColumnRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradebookColumnSummaryRecordType(org.osid.type.Type gradebookColumnSummaryRecordType);


    /**
     *  Gets the supported <code> Gradebook </code> record types. 
     *
     *  @return a list containing the supported <code> Gradebook </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getGradebookRecordTypes();


    /**
     *  Tests if the given <code> Gradebook </code> record type is supported. 
     *
     *  @param  gradebookRecordType a <code> Type </code> indicating a <code> 
     *          Gradebook </code> type 
     *  @return <code> true </code> if the given gradebook record <code> Type 
     *          </code> is supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> gradebookRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradebookRecordType(org.osid.type.Type gradebookRecordType);


    /**
     *  Gets the supported gradebook search record types. 
     *
     *  @return a list containing the supported <code> Gradebook </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getGradebookSearchRecordTypes();


    /**
     *  Tests if the given gradebook search record type is supported. 
     *
     *  @param  gradebookSearchRecordType a <code> Type </code> indicating a 
     *          <code> Gradebook </code> search record type 
     *  @return <code> true </code> if the given search record <code> Type 
     *          </code> is supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          gradebookSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradebookSearchRecordType(org.osid.type.Type gradebookSearchRecordType);
}
