//
// org.osid.grading.batch.GradeEntryBatchAdminSession
//
//     The OSID Java specification for org.osid.grading.batch.GradeEntryBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading.batch;


/**
 *  <p>This session creates, updates, and deletes <code> GradeEntries </code> 
 *  in bulk. The data for create and update is provided by the consumer via 
 *  the form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  GradeEntry, </code> a <code> GradeEntryForm </code> is requested using 
 *  <code> getGradeEntryFormsForCreate() </code> specifying the desired 
 *  gradebook column, resource, and record <code> Types </code> or none if no 
 *  record <code> Types </code> are needed. Each of the returned <code> 
 *  GradeEntryForms </code> will indicate that it is to be used with a create 
 *  operation and can be used to examine metdata or validate data prior to 
 *  creation. Once a <code> GradeEntryForm </code> is submiited to a create 
 *  operation, it cannot be reused with another create operation unless the 
 *  first operation was unsuccessful. Each <code> GradeEntryForm </code> 
 *  corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> GradeEntryForms </code> returned from <code> 
 *  getGradeEntryFormsForCreate() </code> may be linked to the originating 
 *  request through the peer <code> Ids </code> of the <code> GradeEntryForm. 
 *  </code> In the case where there may be duplicates, any <code> 
 *  GradeEntryForm </code> of the same peer <code> Ids </code> may be used for 
 *  a create operation. </p> 
 *  
 *  <p> Once a batch of <code> GradeEntryForms </code> are submitted for 
 *  create, a <code> CreateResponse </code> is returned for each <code> 
 *  GradeEntryForm, </code> although the ordering is not defined. Only errors 
 *  that pertain to the entire create operation are returned from <code> 
 *  createGradeEntries(), </code> errors specific to an individual <code> 
 *  GradeEntryForm </code> are indicated in the corresponding <code> 
 *  CreateResponse. </code> <code> CreateResponses </code> may be linked to 
 *  the originating <code> GradeEntryForm </code> through the <code> 
 *  GradeEntryForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> GradeEntryForms </code> are requested to the 
 *  <code> GradeEntry </code> <code> Id </code> that is to be updated using 
 *  <code> getGradeEntryFormsForUpdate() </code> where the reference <code> Id 
 *  </code> in the <code> GradeEntryForm </code> may be used to link the 
 *  request. Similarly, the <code> GradeEntryForm </code> has metadata about 
 *  the data that can be updated and it can perform validation before 
 *  submitting the update. The <code> GradeEntryForm </code> can only be used 
 *  once for a successful update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> GradeEntryForms </code> are submitted for 
 *  update, an <code> UpdateResponse </code> is returned for each <code> 
 *  GradeEntryForm, </code> although the ordering is not defined. Only errors 
 *  that pertain to the entire update operation are returned from <code> 
 *  updateGradeEntries(), </code> errors specific to an individual <code> 
 *  GradeEntryForm </code> are indicated in the corresponding <code> 
 *  UpdateResponse. </code> <code> UpdateResponses </code> may be linked to 
 *  the originating <code> GradeEntryForm </code> through the <code> 
 *  GradeEntryForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> GradeEntries </code> in bulk. To 
 *  unmap a <code> GradeEntry </code> from the current <code> Gradebook, 
 *  </code> the <code> GradeEntryGradebookAssignmentSession </code> should be 
 *  used. These delete operations attempt to remove the <code> GradeEntry 
 *  </code> itself thus removing it from all known <code> Gradebook </code> 
 *  catalogs. Bulk delete operations return the results in <code> 
 *  DeleteResponses. </code> </p>
 */

public interface GradeEntryBatchAdminSession
    extends org.osid.grading.GradeEntryAdminSession {


    /**
     *  Gets the grade entry forms for creating a bunch of new grade entries. 
     *  A form is returned for each gradebook column and resource pair. 
     *
     *  @param  peers the relationship peers 
     *  @param  gradeEntryRecordTypes array of grade entry record types to be 
     *          included in each create operation or an empty list if none 
     *  @return the grade entry forms 
     *  @throws org.osid.NotFoundException a <code> gradebookColumnId </code> 
     *          or <code> resourceId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> peers </code> or <code> 
     *          gradeEntryRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.batch.GradeEntryBatchFormList getGradeEntryFormsForCreate(org.osid.grading.batch.GradeEntryPeerList peers, 
                                                                                      org.osid.type.Type[] gradeEntryRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> GradeEntries. </code> This method returns 
     *  an error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  gradeEntryForms the grade entry forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> gradeEntryForms </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createGradeEntries(org.osid.grading.batch.GradeEntryBatchFormList gradeEntryForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the grade entry forms for updating an existing set of grade 
     *  entries. A new grade entry form should be requested for each update 
     *  transaction. 
     *
     *  @param  gradeEntryIds the <code> Ids </code> of the <code> GradeEntry 
     *          </code> 
     *  @return the grade entry forms 
     *  @throws org.osid.NotFoundException a <code> gradeEntryId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> gradeEntryIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.batch.GradeEntryBatchFormList getGradeEntryFormsForUpdate(org.osid.id.IdList gradeEntryIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing grade entries. This method returns an error if the 
     *  entire operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  gradeEntryForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> gradeEntryForms </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateGradeEntries(org.osid.grading.batch.GradeEntryBatchFormList gradeEntryForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> GradeEntries </code> in this <code> Gradebook 
     *  </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllGradeEntries()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes grade entries for the given <code> Ids. </code> 
     *
     *  @param  gradeEntryIds the <code> Ids </code> of the grade entries to 
     *          delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> gradeEntryIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteGradeEntries(org.osid.id.IdList gradeEntryIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes grade entries for the given resource. 
     *
     *  @param  resourceId the <code> Id </code> of a resource 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteGradeEntriesForResource(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes grade entries for the given column. 
     *
     *  @param  gradebookColumnId the <code> Id </code> of a work 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> gradebookColumnId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteGradeEntriesForGradebookColumn(org.osid.id.Id gradebookColumnId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes grade entries expired before the given date. 
     *
     *  @param  date a date 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteIneffectiveGradeEntriesByDate(org.osid.calendaring.DateTime date)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> GradeEntry </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> GradeEntry </code> is determined by the provider. The new 
     *  <code> Id </code> is an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another grade entry, it is reassigned to the 
     *  given grade entry <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasGradeEntries(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
