//
// org.osid.grading.batch.GradebookBatchAdminSession
//
//     The OSID Java specification for org.osid.grading.batch.GradebookBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Gradebooks </code> in 
 *  bulk. The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Gradebook, </code> a <code> GradebookForm </code> is requested using 
 *  <code> getGradebookFormsForCreate() </code> specifying the desired record 
 *  <code> Types </code> or none if no record <code> Types </code> are needed. 
 *  Each of the returned <code> GradebookForms </code> will indicate that it 
 *  is to be used with a create operation and can be used to examine metdata 
 *  or validate data prior to creation. Once a <code> GradebookForm </code> is 
 *  submiited to a create operation, it cannot be reused with another create 
 *  operation unless the first operation was unsuccessful. Each <code> 
 *  GradebookForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> GradebookForms </code> returned from <code> 
 *  getGradebookFormForCreate() </code> may be linked to the originating 
 *  request through the peer <code> Ids </code> of the <code> GradebookForm 
 *  </code> In the case where there may be duplicates, any <code> 
 *  GradebookForm </code> of the same peer <code> Ids </code> may be used for 
 *  a create operation. </p> 
 *  
 *  <p> Once a batch of <code> GradebookForm </code> are submitted for create, 
 *  a <code> CreateResponse </code> is returned for each <code> GradebookForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire create operation are returned from <code> createGradebooks(), 
 *  </code> errors specific to an individual <code> GradebookForm </code> are 
 *  indicated in the corresponding <code> CreateResponse. </code> <code> 
 *  CreateResponses </code> may be linked to the originating <code> 
 *  GradebookForm </code> through the <code> GradebookForm </code> <code> Id 
 *  </code> . </p> 
 *  
 *  <p> For updates, <code> GradebookForm </code> are requested to the <code> 
 *  Gradebook </code> <code> Id </code> that is to be updated using <code> 
 *  getGradebookFormsForUpdate() </code> where the reference <code> Id </code> 
 *  in the <code> Gradebook </code> may be used to link the request. 
 *  Similarly, the <code> Gradebook </code> has metadata about the data that 
 *  can be updated and it can perform validation before submitting the update. 
 *  The <code> Gradebook </code> can only be used once for a successful update 
 *  and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> GradebookForms </code> are submitted for 
 *  update, an <code> UpdateResponse </code> is returned for each <code> 
 *  GradebookForm, </code> although the ordering is not defined. Only errors 
 *  that pertain to the entire update operation are returned from <code> 
 *  updateGradebooks(), </code> errors specific to an individual <code> 
 *  GradebookForm </code> are indicated in the corresponding <code> 
 *  UpdateResponse. </code> <code> UpdateResponses </code> may be linked to 
 *  the originating <code> GradebookForm </code> through the <code> 
 *  GradebookForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> Gradebooks </code> in bulk. Bulk 
 *  delete operations return the results in <code> DeleteResponses. </code> 
 *  </p>
 */

public interface GradebookBatchAdminSession
    extends org.osid.grading.GradebookAdminSession {


    /**
     *  Gets the gradebook forms for creating a bunch of new gradebooks. 
     *
     *  @param  number the number of forms to retrieve 
     *  @param  gradebookRecordTypes array of gradebook record types to be 
     *          included in each create operation or an empty list if none 
     *  @return the gradebook forms 
     *  @throws org.osid.NullArgumentException <code> gradebookRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.batch.GradebookBatchFormList getGradebookFormsForCreate(long number, 
                                                                                    org.osid.type.Type[] gradebookRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Gradebooks. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  gradebookForms the gradebook forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> gradebookForms </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createGradebooks(org.osid.grading.batch.GradebookBatchFormList gradebookForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the gradebook forms for updating an existing set of gradebooks. A 
     *  new gradebook form should be requested for each update transaction. 
     *
     *  @param  gradebookIds the <code> Ids </code> of the <code> Gradebook 
     *          </code> 
     *  @return the gradebook forms 
     *  @throws org.osid.NotFoundException a <code> gradebookId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> gradebookIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.batch.GradebookBatchFormList getGradebookFormsForUpdate(org.osid.id.IdList gradebookIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing gradebooks. This method returns an error if the 
     *  entire operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  gradebookForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> gradebookForms </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateGradebooks(org.osid.grading.batch.GradebookBatchFormList gradebookForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Gradebooks. </code> 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllGradebooks()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes gradebooks for the given <code> Ids. </code> 
     *
     *  @param  gradebookIds the <code> Ids </code> of the gradebooks to 
     *          delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> gradebookIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteGradebooks(org.osid.id.IdList gradebookIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Gradebook </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Gradebook </code> is determined by the provider. The new 
     *  <code> Id </code> is an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another gradebook, it is reassigned to the given 
     *  gradebook <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasGradebooks(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
