//
// org.osid.grading.calculation.GradebookColumnCalculationAdminSession
//
//     The OSID Java specification for org.osid.grading.calculation.GradebookColumnCalculationAdminSession.
//
// Copyright (C) 2010 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading.calculation;


/**
 *  <p>This session creates, updates, and deletes <code> 
 *  GradebookColumnCalculations. </code> The data for create and update is 
 *  provided by the consumer via the form object. <code> OsidForms </code> are 
 *  requested for each create or update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  GradebookColumnCalculation, </code> a <code> 
 *  GradebookColumnCalculationForm </code> is requested using <code> 
 *  getGradebookColumnCalculationFormForCreate() </code> specifying the 
 *  desired record <code> Types </code> or none if no record <code> Types 
 *  </code> are needed. The returned <code> GradebookColumnCalculationForm 
 *  </code> will indicate that it is to be used with a create operation and 
 *  can be used to examine metdata or validate data prior to creation. Once 
 *  the <code> GradebookColumnCalculationForm </code> is submiited to a create 
 *  operation, it cannot be reused with another create operation unless the 
 *  first operation was unsuccessful. Each <code> 
 *  GradebookColumnCalculationForm </code> corresponds to an attempted 
 *  transaction. </p> 
 *  
 *  <p> For updates, <code> GradebookColumnCalculationForms </code> are 
 *  requested to the <code> GradebookColumnCalculation </code> <code> Id 
 *  </code> that is to be updated using <code> 
 *  getGradebookColumnCalculationFormForUpdate(). </code> Similarly, the 
 *  <code> GradebookColumnCalculationForm </code> has metadata about the data 
 *  that can be updated and it can perform validation before submitting the 
 *  update. The <code> GradebookColumnCalculationForm </code> can only be used 
 *  once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> GradebookColumnCalculations. 
 *  </code> </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface GradebookColumnCalculationAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Gradebook </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Gradebook Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getGradebookId();


    /**
     *  Gets the <code> Gradebook </code> associated with this session. 
     *
     *  @return the <code> Gradebook </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.Gradebook getGradebook()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create gradebook column calculationss. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a gradebook column will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer create operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> GradebookColumnCalculation 
     *          </code> creation is not authorized, <code> true </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateGradebookColumnCalculations();


    /**
     *  Tests if this user can create a single <code> 
     *  GradebookColumnCalculation </code> using the desired record types. 
     *  While <code> 
     *  GradingCalculationManager.getGradebookColumnCalculationRecordTypes() 
     *  </code> can be used to examine which records are supported, this 
     *  method tests which record(s) are required for creating a specific 
     *  <code> GradebookColumnCalculation. </code> Providing an empty array 
     *  tests if a <code> GradebookColumnCalculation </code> can be created 
     *  with no records. 
     *
     *  @param  gradebookColumnRecordCalculationTypes array of gradebook 
     *          column calculation record types 
     *  @return <code> true </code> if <code> GradebookColumnCalculation 
     *          </code> creation using the specified record <code> Types 
     *          </code> is supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          gradebookColumnRecordCalculationTypes </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateGradebookColumnCalculationWithRecordTypes(org.osid.type.Type[] gradebookColumnRecordCalculationTypes);


    /**
     *  Gets the gradebook column calculation form for creating new gradebook 
     *  columns. A new form should be requested for each create transaction. 
     *
     *  @param  gradebookColumnId the <code> Id </code> for the <code> 
     *          GradebookColumn </code> 
     *  @param  gradebookColumnRecordCalculationTypes array of gradebook 
     *          column calculation record types 
     *  @return the gradebook column calculation form 
     *  @throws org.osid.AlreadyExistsException <code> gradebookColumnId 
     *          </code> already has a calculation 
     *  @throws org.osid.NotFoundException <code> gradebookColumnId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> gradebokColumnId </code> 
     *          or <code> gradebookColumnRecordCalculationTypes </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.calculation.GradebookColumnCalculationForm getGradebookColumnCalculationFormForCreate(org.osid.id.Id gradebookColumnId, 
                                                                                                                  org.osid.type.Type[] gradebookColumnRecordCalculationTypes)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> GradebookColumnCalculation. </code> 
     *
     *  @param  gradebookColumnCalculationForm the form containing the 
     *          elements to be updated 
     *  @return the new <code> GradebookColumnCalculation </code> 
     *  @throws org.osid.IllegalStateException <code> 
     *          gradebookColumnCalculationForm </code> already used in a 
     *          create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> 
     *          gradebookColumnCalculationForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> 
     *          gradebookColumnCalculationForm </code> did not originate from 
     *          <code> getGradebookColumnCalculationFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.calculation.GradebookColumnCalculation createGradebookColumnCalculation(org.osid.grading.calculation.GradebookColumnCalculationForm gradebookColumnCalculationForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update gradebook column calculations. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> 
     *  GradebookColumnCalculation </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer update operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if gradebook column calculation 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateGradebookColumnCalculations();


    /**
     *  Gets the gradebook column calculation form for updating an existing 
     *  gradebook column. A new gradebook column form should be requested for 
     *  each update transaction. 
     *
     *  @param  gradebookColumnCalculationId the <code> Id </code> of the 
     *          <code> GradebookColumnCalculation </code> 
     *  @return the gradebook column calculation form 
     *  @throws org.osid.NotFoundException <code> gradebookColumnCalculationId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          gradebookColumnCalculationId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.calculation.GradebookColumnCalculationForm getGradebookColumnCalculationFormForUpdate(org.osid.id.Id gradebookColumnCalculationId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Updates an existing gradebook column calculation. 
     *
     *  @param  gradebookColumnCalculationForm the form containing the 
     *          elements to be updated 
     *  @throws org.osid.IllegalStateException <code> 
     *          gradebookColumnCalculationForm </code> already used in a 
     *          update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> 
     *          gradebookColumnCalculationForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> 
     *          gradebookColumnCalculationForm </code> did not originate from 
     *          <code> getGradebookColumnCalculationFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateGradebookColumnCalculation(org.osid.grading.calculation.GradebookColumnCalculationForm gradebookColumnCalculationForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete gradebook column calculations. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> 
     *  GradebookColumnCalculation </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer delete operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> GradebookColumnCalculation 
     *          </code> deletion is not authorized, <code> true </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteGradebookColumnCalculations();


    /**
     *  Deletes the <code> GradebookColumnCalculation </code> identified by 
     *  the given <code> Id. </code> 
     *
     *  @param  gradebookColumnCalculationId the <code> Id </code> of the 
     *          <code> GradebookColumnCalculation </code> to delete 
     *  @throws org.osid.NotFoundException a <code> GradebookColumnCalculation 
     *          </code> was not found identified by the given <code> Id 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          gradebookColumnCalculationId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteGradebookColumnCalculation(org.osid.id.Id gradebookColumnCalculationId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
