//
// org.osid.grading.calculation.GradebookColumnCalculationForm
//
//     The OSID Java specification for org.osid.grading.calculation.GradebookColumnCalculationForm.
//
// Copyright (C) 2010 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading.calculation;


/**
 *  <p>This is the form for creating and updating <code> 
 *  GradebookColumnCalculations. </code> Like all <code> OsidForm </code> 
 *  objects, various data elements may be set here for use in the create and 
 *  update methods in the <code> GradebookColumnCalculationSession. </code> 
 *  For each data element that may be set, metadata may be examined to provide 
 *  display hints or data constraints. </p>
 */

public interface GradebookColumnCalculationForm
    extends org.osid.OsidObjectForm {


    /**
     *  Gets the metadata for the input gradebook columns. 
     *
     *  @return metadata for the input gradebook columns 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getInputGradebookColumnsMetadata();


    /**
     *  Sets the input gradebook columns. 
     *
     *  @param  gradebookColumnIds the new input gradebook columns 
     *  @throws org.osid.InvalidArgumentException <code> gradebookColumnIds 
     *          </code> is invalid 
     *  @throws org.osid.NoAccessException <code> gradebookColumnIds </code> 
     *          cannot be modified 
     *  @throws org.osid.NullArgumentException <code> gradebookColumnIds 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setInputGradebookColumns(org.osid.grading.calculation.CalculationOperation gradebookColumnIds);


    /**
     *  Clears the Input gradebook columns. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearInputGradebookColumns();


    /**
     *  Gets the metadata for the calculation operation. 
     *
     *  @return metadata for the calculation operation 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getOperationMetadata();


    /**
     *  Sets the operation. 
     *
     *  @param  operation the new calculation operation 
     *  @throws org.osid.InvalidArgumentException <code> operation </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> operation </code> cannot be 
     *          modified 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setOperation(org.osid.grading.calculation.CalculationOperation operation);


    /**
     *  Gets the metadata for the tweaked center. 
     *
     *  @return metadata for the tweaked center 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getTweakedCenterMetadata();


    /**
     *  Sets the tweaked center. 
     *
     *  @param  center the new tweaked center 
     *  @throws org.osid.InvalidArgumentException <code> center </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> center </code> cannot be 
     *          modified 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setTweakedCenter(java.math.BigDecimal center);


    /**
     *  Clears the tweaked center. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTweakedCenter();


    /**
     *  Gets the metadata for the tweaked standard deviation. 
     *
     *  @return metadata for the standard deviation 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getTweakedStandardDeviation();


    /**
     *  Sets the tweaked standard deviation. 
     *
     *  @param  standardDeviation the new tweaked standard deviation 
     *  @throws org.osid.InvalidArgumentException <code> standardDeviation 
     *          </code> is invalid 
     *  @throws org.osid.NoAccessException <code> standardDeviation </code> 
     *          cannot be modified 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setTweakedStandardDeviation(java.math.BigDecimal standardDeviation);


    /**
     *  Clears the tweaked standard deviation. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTweakedStandarDeviation();


    /**
     *  Gets the <code> GradebookColumnCalculationFormRecord </code> 
     *  corresponding to the given gradebook column calculation record <code> 
     *  Type. </code> 
     *
     *  @param  gradebookColumnCalculationRecordType the gradeboo column 
     *          calculation record type 
     *  @return the gradebook column calculation form record 
     *  @throws org.osid.NullArgumentException <code> 
     *          gradebookColumnCalculationRecordType </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(gradebookColumnCalculationRecordType) </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.calculation.records.GradebookColumnCalculationFormRecord getGradebookColumnCalculationFormRecord(org.osid.type.Type gradebookColumnCalculationRecordType)
        throws org.osid.OperationFailedException;
}
