/**
 * <p>The Open Service Interface Definitions for the org.osid.grading.calculation
 * service.</p>
 * 
 * <p>The Grading Calculation OSID defines a service to apply calculations to 
 * <code> GradebookColumns </code> . </p> 
 * <h4> GradebookColumnCalculations </h4> 
 * 
 * <p> A <code> GradebookColumnCalculation </code> is an <code> OsidRule 
 * </code> that is created on a <code> GradebookColumn </code> to override a 
 * all manual <code> GradeEntry </code> with a rule. The rule has one or more 
 * input <code> GradebookColumns </code> on which to calculate a result for 
 * the entries in the target GradebookCol;umn. </p> 
 * 
 * <p> <code> GradebookColumnCalculations </code> define several baked-in 
 * rules such as averages and standard deviation. More exotic calculations can 
 * be done through the attached <code> GradebookColumnCalculationRecord 
 * </code> or through an associated reusable <code> Rule </code> . </p> 
 * 
 * <p> For example, a <code> Gradebook </code> may have one <code> 
 * GradebookColumn </code> for each quiz of four scores. A fifth <code> 
 * GradebookColumn </code> can be created to attach a <code> 
 * GradebookColumnCalculation </code> to average to four input quiz scores. 
 * The sixth <code> GradebookColumn </code> may contain the input final exam 
 * scores and the seventh <code> GradebookColumn </code> defined for a custom 
 * <code> GradebookColumnCalculation </code> that weights the seventh column 
 * by 60% and the fifth column by 40% before averaging them. An eighth <code> 
 * GradebookColumn </code> may be created for an alternate <code> GradeSystem 
 * </code> (A-F) with an empty <code> GradebookColumnCalculation </code> that 
 * takes the final score in the seventh column and transforms it to a letter 
 * grade for grading submission at the end of the term. </p> 
 * <h4> Gradebook Cataloging </h4> 
 * 
 * <p> <code> GradebookColumnCalculations </code> are indirectly referenceable 
 * through the <code> Gradebook </code> to which the associated <code> 
 * GradebookColumn </code> reisdes. <code> GradebookColumnCalculations </code> 
 * do not have a complete independent service pattern since they are directly 
 * attached to a single <code> GradebookColumn. </code> Reusable calculations 
 * are achieved through reusable <code> Rules </code> . </p>
 * 
 * <br/><hr/><br/>
 * 
 * <p>Copyright &copy; 2010 Ingeenscus. All Rights Reserved. </p>
 * 
 * <p>This Work is being provided by the copyright holder(s) subject to the 
 * following license. By obtaining, using and/or copying this Work, you agree 
 * that you have read, understand, and will comply with the following terms 
 * and conditions. </p> 
 * 
 * <p> Permission to use, copy and distribute unmodified versions of this 
 * Work, for any purpose, without fee or royalty is hereby granted, provided 
 * that you include the above copyright notices and the terms of this license 
 * on ALL copies of the Work or portions thereof. </p> 
 * 
 * <p> You may nodify or create Derivatives of this Work only for your 
 * internal purposes. You shall not distribute or transfer any such Derivative 
 * of this Work to any location or to any third party. For the purposes of 
 * this license, "Derivative" shall mean any derivative of the Work as defined 
 * in the United States Copyright Act of 1976, such as a translation or 
 * modification. </p> 
 * 
 * <p> This Work and the information contained herein is provided on an "AS 
 * IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT 
 * NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR 
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT 
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN 
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN 
 * CONNECTION WITH THE WORK OR THE USE OR OTHER DEALINGS IN THE WORK. </p> 
 * 
 * <p> The export of software employing encryption technology may require a 
 * specific license from the United States Government. It is the 
 * responsibility of any person or organization contemplating export to obtain 
 * such a license before exporting this Work. </p>
 */

package org.osid.grading.calculation;
