//
// org.osid.grading.transform.GradeSystemTransform
//
//     The OSID Java specification for org.osid.grading.transform.GradeSystemTransform.
//
// Copyright (C) 2002-2010 Massachusetts Institute of Technology. All Rights 
// Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis. The Massachusetts Institute of Technology, the Open 
//     Knowledge Initiative, and THE AUTHORS DISCLAIM ALL WARRANTIES, EXPRESS 
//     OR IMPLIED, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, 
//     FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO PACKAGE 
//     SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES 
//     OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR 
//     OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE 
//     USE OR OTHER DEALINGS IN THE WORK. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notice and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, Derivative shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization comtemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading.transform;


/**
 *  <p>A <code> GradeSystemTransform </code> represents a translation between 
 *  two grade systems. The transform is directional such that a translation 
 *  between the source and target may not equal a translation between the 
 *  target and the source grade systems. </p>
 */

public interface GradeSystemTransform
    extends org.osid.OsidRule {


    /**
     *  Gets the source <code> GradeSystem Id. </code> 
     *
     *  @return the source grade system <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getSourceGradeSystemId();


    /**
     *  Gets the source <code> GradeSystem. </code> 
     *
     *  @return the source grade system 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeSystem getSourceGradeSystem()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the target <code> GradeSystem Id. </code> 
     *
     *  @return the target grade system <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getTargetGradeSystemId();


    /**
     *  Gets the target <code> GradeSystem. </code> 
     *
     *  @return the target grade system 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeSystem getTargetGradeSystem()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this transformation is based on normalization of the input 
     *  scores. 
     *
     *  @return <code> true </code> of a normalization is performed, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean normalizesInputScores();


    /**
     *  Gets any one-to-one mapping of grades. 
     *
     *  @return the grade maps 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.transform.GradeMapList getGradeMaps();


    /**
     *  Gets the grade system transform record corresponding to the given 
     *  <code> GradeSystemTransform </code> record <code> Type. </code> This 
     *  method is used to retrieve an object implementing the requested 
     *  record. The <code> gradeSystemTransformRecordType </code> may be the 
     *  <code> Type </code> returned in <code> getRecordTypes() </code> or any 
     *  of its parents in a <code> Type </code> hierarchy where <code> 
     *  hasRecordType(gradeSystemTransformRecordType) </code> is <code> true 
     *  </code> . 
     *
     *  @param  gradeSystemTransformRecordType the type of the record to 
     *          retrieve 
     *  @return the grade system transform record 
     *  @throws org.osid.NullArgumentException <code> 
     *          gradeSystemTransformRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(gradeSystemTransformRecordType) </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.transform.records.GradeSystemTransformRecord getGradeSystemTransformRecord(org.osid.type.Type gradeSystemTransformRecordType)
        throws org.osid.OperationFailedException;
}
