//
// org.osid.grading.transform.GradeSystemTransformationSession
//
//     The OSID Java specification for org.osid.grading.transform.GradeSystemTransformationSession.
//
// Copyright (C) 2002-2010 Massachusetts Institute of Technology. All Rights 
// Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis. The Massachusetts Institute of Technology, the Open 
//     Knowledge Initiative, and THE AUTHORS DISCLAIM ALL WARRANTIES, EXPRESS 
//     OR IMPLIED, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, 
//     FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO PACKAGE 
//     SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES 
//     OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR 
//     OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE 
//     USE OR OTHER DEALINGS IN THE WORK. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notice and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, Derivative shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization comtemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading.transform;


/**
 *  <p>The session defines methods for translating <code> Grades </code> and 
 *  scores among <code> GradeSystems. </code> This session provides a means 
 *  for moving across grade systems but does not perform an articulation based 
 *  on content or a specific qualifier. </p>
 */

public interface GradeSystemTransformationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Gradebook </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Gradebook Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getSourceGradeSystemId();


    /**
     *  Gets the <code> Gradebook </code> associated with this session. 
     *
     *  @return the <code> Gradebook </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.Gradebook getSourceGradeSystem()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Gradebook </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Gradebook Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getTargetGradeSystemId();


    /**
     *  Gets the <code> Gradebook </code> associated with this session. 
     *
     *  @return the <code> Gradebook </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.Gradebook getTargetGradeSystem()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform grade transformations. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if grade transformation methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canTransformGradeSystems();


    /**
     *  Gets the score equivalent between the source and target grade systems. 
     *
     *  @param  score a score from the source grade system 
     *  @return the target score 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public java.math.BigDecimal transformScore(java.math.BigDecimal score)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the grade equivalent between the source and target grade systems. 
     *
     *  @param  gradeId <code> Id </code> of a <code> Grade </code> from the 
     *          source grade system 
     *  @return the target grade 
     *  @throws org.osid.NotFoundException no transformation rule found for 
     *          <code> gradeId </code> 
     *  @throws org.osid.NullArgumentException <code> gradeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.grading.Grade transformGrade(org.osid.id.Id gradeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
