//
// org.osid.grading.transform.GradingTransformProfile
//
//     The OSID Java specification for org.osid.grading.transform.GradingTransformProfile.
//
// Copyright (C) 2002-2010 Massachusetts Institute of Technology. All Rights 
// Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis. The Massachusetts Institute of Technology, the Open 
//     Knowledge Initiative, and THE AUTHORS DISCLAIM ALL WARRANTIES, EXPRESS 
//     OR IMPLIED, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, 
//     FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO PACKAGE 
//     SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES 
//     OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR 
//     OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE 
//     USE OR OTHER DEALINGS IN THE WORK. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notice and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, Derivative shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization comtemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading.transform;


/**
 *  <p>The <code> GradingTransformProfile </code> describes the 
 *  interoperability among grading transform services. </p>
 */

public interface GradingTransformProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if federation is visible. 
     *
     *  @return <code> true </code> if visible federation is supported <code> 
     *          , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if a grade system transformation service is supported. 
     *
     *  @return true if grade system transformation is supported, false 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradeSystemTransformation();


    /**
     *  Tests if a grade system transform lookup service is supported. 
     *
     *  @return true if grade system transform lookup is supported, false 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradeSystemTransformLookup();


    /**
     *  Tests if a grade system transform admin service is supported. 
     *
     *  @return <code> true </code> if grade system transform admin is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradeSystemTransformAdmin();


    /**
     *  Tests if a grade system transform notification service is supported. 
     *
     *  @return <code> true </code> if grade system transform notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradeSystemTransformNotification();


    /**
     *  Gets the supported <code> GradeSystemTransform </code> record types. 
     *
     *  @return a list containing the supported <code> GradeSystemTransform 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getGradeSystemTransformRecordTypes();


    /**
     *  Tests if the given <code> GradeSystemTransform </code> record type is 
     *  supported. 
     *
     *  @param  gradeSystemTransformRecordType a <code> Type </code> 
     *          indicating a <code> GradeSystemTransform </code> record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          gradeSystemTransformRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradeSystemTransformRecordType(org.osid.type.Type gradeSystemTransformRecordType);
}
