//
// org.osid.hierarchy.HierarchyAdminSession
//
//     The OSID Java specification for org.osid.hierarchy.HierarchyAdminSession.
//
// Copyright (C) 2002,2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.hierarchy;


/**
 *  <p>This session creates, updates, and deletes <code> Hierarchies. </code> 
 *  The data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Hierarchy, </code> a <code> HierarchyForm </code> is requested using 
 *  <code> getHierarchyFormForCreate() </code> specifying the desired record 
 *  <code> Types </code> or none if no record <code> Types </code> are needed. 
 *  The returned <code> HierarchyForm </code> will indicate that it is to be 
 *  used with a create operation and can be used to examine metdata or 
 *  validate data prior to creation. Once the <code> HierarchyForm </code> is 
 *  submiited to a create operation, it cannot be reused with another create 
 *  operation unless the first operation was unsuccessful. Each <code> 
 *  HierarchyForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> HierarchyForms </code> are requested to the <code> 
 *  Hierarchy </code> <code> Id </code> that is to be updated using <code> 
 *  getHierarchyFormForUpdate(). </code> Similarly, the <code> HierarchyForm 
 *  </code> has metadata about the data that can be updated and it can perform 
 *  validation before submitting the update. The <code> HierarchyForm </code> 
 *  can only be used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Hierarchies. </code> </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface HierarchyAdminSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can create <code> Hierarchy </code> objects. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known creating a <code> Hierarchy 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may not wish to offer create 
     *  operations to unauthorized users. 
     *
     *  @return <code> false </code> if <code> Hierarchy </code> creation is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateHierarchies();


    /**
     *  Tests if this user can create a single <code> Hierarchy </code> using 
     *  the desired record types. While <code> 
     *  HierarchyManager.getHierarchyRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> Hierarchy. </code> 
     *  Providing an empty array tests if a <code> Hierarchy </code> can be 
     *  created with no records. 
     *
     *  @param  hierarchyRecordTypes array of hierarchy record types 
     *  @return <code> true </code> if <code> Hierarchy </code> creation using 
     *          the specified <code> Types </code> is supported, <code> false 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> hierarchyRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateHierarchyWithRecordTypes(org.osid.type.Type[] hierarchyRecordTypes);


    /**
     *  Gets the hierarchy form for creating new hierarchies. A new form 
     *  should be requested for each create transaction. This method is used 
     *  for creating new hierarchies, where only the <code> Hierarchy </code> 
     *  <code> Type </code> is known. 
     *
     *  @param  hierarchyRecordTypes array of hierarchy record types 
     *  @return the hierarchy form 
     *  @throws org.osid.NullArgumentException <code> hierarchyRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hierarchy.HierarchyForm getHierarchyFormForCreate(org.osid.type.Type[] hierarchyRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Hierarchy. </code> 
     *
     *  @param  hierarchyForm the form for this <code> Hierarchy </code> 
     *  @return the new <code> Hierarchy </code> 
     *  @throws org.osid.IllegalStateException <code> hierarchyForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> hierarchyForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> hierarchyForm </code> did 
     *          not originate from <code> getHierarchyFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hierarchy.Hierarchy createHierarchy(org.osid.hierarchy.HierarchyForm hierarchyForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Hierarchy </code> objects. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known updating a <code> Hierarchy 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may not wish to offer update 
     *  operations to unauthorized users. 
     *
     *  @return <code> false </code> if <code> Hierarchy </code> modification 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateHierarchies();


    /**
     *  Gets the hierarchy form for updating an existing hierarchy. A new 
     *  hierarchy form should be requested for each update transaction. 
     *
     *  @param  hierarchyId the <code> Id </code> of the <code> Hierarchy 
     *          </code> 
     *  @return the hierarchy form 
     *  @throws org.osid.NotFoundException <code> hierarchyId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> hierarchyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hierarchy.HierarchyForm getHierarchyFormForUpdate(org.osid.id.Id hierarchyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing hierarchy. 
     *
     *  @param  hierarchyForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> hierarchyForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> hierarchyId </code> or 
     *          <code> hierarchyForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> hierarchyForm </code> did 
     *          not originate from <code> getHierarchyFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateHierarchy(org.osid.hierarchy.HierarchyForm hierarchyForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> Hierarchy </code> objects. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known deleting a <code> Hierarchy 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may not wish to offer delete 
     *  operations to unauthorized users. 
     *
     *  @return <code> false </code> if <code> Hierarchy </code> deletion is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteHierarchies();


    /**
     *  Deletes a <code> Hierarchy. </code> 
     *
     *  @param  hierarchyId the <code> Id </code> of the <code> Hierarchy 
     *          </code> to remove 
     *  @throws org.osid.NotFoundException <code> hierarchyId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> hierarchyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteHierarchy(org.osid.id.Id hierarchyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Hierarchy </code> objects. A return of true does not guarantee 
     *  successful authorization. A return of false indicates that it is known 
     *  changing an alias will result in a <code> PERMISSION_DENIED. </code> 
     *  This is intended as a hint to an application that may opt not to offer 
     *  alias operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Hierarchy </code> aliasing is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageHierarchyAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Hierarchy </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Hierarchy </code> is determined by the provider. The new 
     *  <code> Id </code> performs as an alias to the primary <code> Id. 
     *  </code> If the alias is a pointer to another vault it is reassigned to 
     *  the given vault <code> Id. </code> 
     *
     *  @param  hierarchyId the <code> Id </code> of an <code> Hierarchy 
     *          </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> hierarchyId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> hierarchyId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasHierarchy(org.osid.id.Id hierarchyId, 
                               org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
