//
// org.osid.hierarchy.HierarchyProfile
//
//     The OSID Java specification for org.osid.hierarchy.HierarchyProfile.
//
// Copyright (C) 2002,2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.hierarchy;


/**
 *  <p>The hierarchy profile describes the interoperability among hierarchy 
 *  services. </p>
 */

public interface HierarchyProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if federation is visible. Visible federation allows for 
     *  selecting among multiple hierarchies. 
     *
     *  @return <code> true </code> if visible federation is supported <code> 
     *          , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if hierarchy traversal is supported. 
     *
     *  @return <code> true </code> if hierarchy traversal is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsHierarchyTraversal();


    /**
     *  Tests if hierarchy design is supported. 
     *
     *  @return <code> true </code> if hierarchy design is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsHierarchyDesign();


    /**
     *  Tests if hierarchy sequencing is supported. 
     *
     *  @return <code> true </code> if hierarchy sequencing is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsHierarchySequencing();


    /**
     *  Tests if hierarchy structure notification is supported. 
     *
     *  @return <code> true </code> if hierarchy structure notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsHierarchyStructureNotification();


    /**
     *  Tests if a hierarchy lookup is supported. 
     *
     *  @return <code> true </code> if hierarchy lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsHierarchyLookup();


    /**
     *  Tests if a hierarchy query is supported. 
     *
     *  @return <code> true </code> if hierarchy query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsHierarchyQuery();


    /**
     *  Tests if a hierarchy search is supported. 
     *
     *  @return <code> true </code> if hierarchy search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsHierarchySearch();


    /**
     *  Tests if a hierarchy administration is supported. 
     *
     *  @return <code> true </code> if hierarchy administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsHierarchyAdmin();


    /**
     *  Tests if hierarchy notification is supported. Messages may be sent 
     *  when hierarchies are created, modified, or deleted. 
     *
     *  @return <code> true </code> if hierarchy notification is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsHierarchyNotification();


    /**
     *  Gets the supported <code> Hierarchy </code> types. 
     *
     *  @return a list containing the supported <code> Hierarchy </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getHierarchyRecordTypes();


    /**
     *  Tests if the given <code> Hierarchy </code> record type is supported. 
     *
     *  @param  hierarchyRecordType a <code> Type </code> indicating a <code> 
     *          Hierarchy </code> record type 
     *  @return <code> true </code> if the given record Type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> hierarchyRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsHierarchyRecordType(org.osid.type.Type hierarchyRecordType);


    /**
     *  Gets the supported <code> Hierarchy </code> search record types. 
     *
     *  @return a list containing the supported <code> Hierarchy </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getHierarchySearchRecordTypes();


    /**
     *  Tests if the given <code> Hierarchy </code> search record type is 
     *  supported. 
     *
     *  @param  hierarchySearchRecordType a <code> Type </code> indicating a 
     *          <code> Hierarchy </code> search record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          hierarchySearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsHierarchySearchRecordType(org.osid.type.Type hierarchySearchRecordType);
}
