//
// org.osid.hierarchy.HierarchySearchSession
//
//     The OSID Java specification for org.osid.hierarchy.HierarchySearchSession.
//
// Copyright (C) 2002,2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.hierarchy;


/**
 *  <p>This session provides methods for searching among <code> Hierarchy 
 *  </code> objects. The search query is constructed using the <code> 
 *  HierarchyQuery. </code> </p> 
 *  
 *  <p> <code> getHierarchiesByQuery() </code> is the basic search method and 
 *  returns a list of <code> Hierarchy </code> objects. A more advanced search 
 *  may be performed with <code> getHierarchiesBySearch(). </code> It accepts 
 *  a <code> HierarchySearch </code> in addition to the query for the purpose 
 *  of specifying additional options affecting the entire search, such as 
 *  ordering. <code> getHierarchiesBySearch() </code> returns a <code> 
 *  HierarchySearchResults </code> that can be used to access the resulting 
 *  <code> HierarchyList </code> or be used to perform a search within the 
 *  result set through <code> HierarchySearch. </code> </p> 
 *  
 *  <p> Hierarchies may have a query record indicated by their respective 
 *  record types. The query record query is accessed via the <code> 
 *  HierarchuQuery. </code> </p>
 */

public interface HierarchySearchSession
    extends org.osid.hierarchy.HierarchyQuerySession {


    /**
     *  Gets a hierarchy search. 
     *
     *  @return the hierarchy search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hierarchy.HierarchySearch getHierarchySearch();


    /**
     *  Gets a hierarchy search order. The <code> HierarchySearchOrder </code> 
     *  is supplied to a <code> HierarchySearch </code> to specify the 
     *  ordering of results. 
     *
     *  @return the hierarchy search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hierarchy.HierarchySearchOrder getHierarchySearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  hierarchyQuery the hierarchy query 
     *  @param  hierarchySearch the hierarchy search 
     *  @return the hierarchy search results 
     *  @throws org.osid.NullArgumentException <code> hierarchyQuery </code> 
     *          or <code> hierarchySearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> hierarchyQuery </code> or 
     *          <code> hierarchySearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hierarchy.HierarchySearchResults getHierarchiesBySearch(org.osid.hierarchy.HierarchyQuery hierarchyQuery, 
                                                                            org.osid.hierarchy.HierarchySearch hierarchySearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a hierarchy query from an inspector. The inspector is available 
     *  from a <code> HierarchySearchResults. </code> 
     *
     *  @param  hierarchyQueryInspector a hierarchy query inspector 
     *  @return the hierarchy query 
     *  @throws org.osid.NullArgumentException <code> hierarchyQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> hierarchyQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hierarchy.HierarchyQuery getHierarchyQueryFromInspector(org.osid.hierarchy.HierarchyQueryInspector hierarchyQueryInspector);
}
