//
// org.osid.hold.BlockSearchResults
//
//     The OSID Java specification for org.osid.hold.BlockSearchResults.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.hold;


/**
 *  <p>This interface provides a means to capture results of a search. </p>
 */

public interface BlockSearchResults
    extends org.osid.OsidSearchResults {


    /**
     *  Gets the block list resulting from a search. 
     *
     *  @return the block list 
     *  @throws org.osid.IllegalStateException list already retrieved 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.BlockList getBlocks();


    /**
     *  Gets the inspector for the query to examine the terms used in the 
     *  search. 
     *
     *  @return the block query inspector 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.BlockQueryInspector getBlockQueryInspector();


    /**
     *  Gets the block search results record corresponding to the given block 
     *  search record <code> Type. </code> This method is used to retrieve an 
     *  object implementing the requested record. 
     *
     *  @param  blockSearchRecordType a block search record type 
     *  @return the block search results record 
     *  @throws org.osid.NullArgumentException <code> blockSearchRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(blockSearchRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.records.BlockSearchResultsRecord getBlockSearchResultsRecord(org.osid.type.Type blockSearchRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
