//
// org.osid.hold.BlockSearchSession
//
//     The OSID Java specification for org.osid.hold.BlockSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.hold;


/**
 *  <p>This session provides methods for searching among <code> Block </code> 
 *  objects. The search query is constructed using the <code> BlockQuery. 
 *  </code> </p> 
 *  
 *  <p> <code> getBlocksByQuery() </code> is the basic search method and 
 *  returns a list of <code> Blocks. </code> A more advanced search may be 
 *  performed with <code> getBlocksBySearch(). </code> It accepts a <code> 
 *  BlockSearch </code> in addition to the query for the purpose of specifying 
 *  additional options affecting the entire search, such as ordering. <code> 
 *  getBlocksBySearch() </code> returns a <code> BlockSearchResults </code> 
 *  that can be used to access the resulting <code> BlockList </code> or be 
 *  used to perform a search within the result set through <code> BlockSearch. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated oubliette view: searches include blocks in oubliettes 
 *      of which this oubliette is an ancestor in the oubliette hierarchy 
 *      </li> 
 *      <li> isolated oubliette view: searches are restricted to blocks in 
 *      this oubliette </li> 
 *  </ul>
 *  
 *  
 *  <p> Blocks may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> BlockQuery. </code> 
 *  </p>
 */

public interface BlockSearchSession
    extends org.osid.hold.BlockQuerySession {


    /**
     *  Gets a block search. 
     *
     *  @return the block search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.BlockSearch getBlockSearch();


    /**
     *  Gets a block search order. The <code> BlockSearchOrder </code> is 
     *  supplied to a <code> BlockSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the block search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.BlockSearchOrder getBlockSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  blockQuery the block query 
     *  @param  blockSearch the block search 
     *  @return the block search results 
     *  @throws org.osid.NullArgumentException <code> blockQuery </code> or 
     *          <code> blockSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> blockQuery </code> or 
     *          <code> blockSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.BlockSearchResults getBlocksBySearch(org.osid.hold.BlockQuery blockQuery, 
                                                              org.osid.hold.BlockSearch blockSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a block query from an inspector. The inspector is available from 
     *  a <code> BlockSearchResults. </code> 
     *
     *  @param  blockQueryInspector a block query inspector 
     *  @return the block query 
     *  @throws org.osid.NullArgumentException <code> blockQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> blockQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.BlockQuery getBlockQueryFromInspector(org.osid.hold.BlockQueryInspector blockQueryInspector);
}
