//
// org.osid.hold.BlockSession
//
//     The OSID Java specification for org.osid.hold.BlockSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.hold;


/**
 *  <p>This is the basic session for checking blocks. </p> 
 *  
 *  <ul>
 *      <li> isolated oubliette view: All issue methods in this session 
 *      operate, retrieve and pertain to availabilities defined explicitly in 
 *      the current oubliette. Using an isolated view is useful for managing 
 *      <code> Availabilities </code> with the <code> IssueAdminSession. 
 *      </code> </li> 
 *      <li> federated oubliette view: All issue lookup methods in this 
 *      session operate, retrieve and pertain to all availabilities defined in 
 *      this oubliette and any other availabilities implicitly available in 
 *      this oubliette through oubliette inheritence. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedOublietteView() </code> and <code> 
 *  useIsolatedOublietteView() </code> behave as a radio group and one should 
 *  be selected before invoking any lookup methods. </p>
 */

public interface BlockSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Oubliette </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Oubliette Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getOublietteId();


    /**
     *  Gets the <code> Oubliette </code> associated with this session. 
     *
     *  @return the oubliette 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.Oubliette getOubliette()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Block </code> checks. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not offer lookup operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if block methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAccessBlocks();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include availabilities in foundries which are children of this 
     *  oubliette in the oubliette hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedOublietteView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this oubliette only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedOublietteView();


    /**
     *  Determines if the given resource is blocked. A resource is blocked if 
     *  an active <code> Hold </code> for the given agent exists for an <code> 
     *  Issue </code> maped to the given <code> Block. </code> 
     *
     *  @param  agentId the <code> Id </code> of an <code> Agent </code> 
     *  @param  blockId the <code> Id </code> of a <code> Block </code> 
     *  @return <code> true </code> if the user is blocked, <code> false 
     *          </code> othersise 
     *  @throws org.osid.NotFoundException <code> blockId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> agentId </code> or 
     *          <code> blockId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          making request 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isBlocked(org.osid.id.Id agentId, org.osid.id.Id blockId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
