//
// org.osid.hold.HoldLookupSession
//
//     The OSID Java specification for org.osid.hold.HoldLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.hold;


/**
 *  <p>This session provides methods for retrieving <code> Hold </code> 
 *  relationships. </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated oubliette view: All hold methods in this session 
 *      operate, retrieve and pertain to holds defined explicitly in the 
 *      current oubliette. Using an isolated view is useful for managing 
 *      <code> Holds </code> with the <code> HoldAdminSession. </code> </li> 
 *      <li> federated oubliette view: All hold methods in this session 
 *      operate, retrieve and pertain to all holds defined in this oubliette 
 *      and any other holds implicitly available in this oubliette through 
 *      oubliette inheritence. </li> 
 *      <li> effective hold view: All hold lookup methods return holds where 
 *      the current date falls in between the effective dates inclusive. </li> 
 *      <li> any effective hold view: Holds of any effective date are returned 
 *      from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedOublietteView() </code> and <code> 
 *  useIsolatedOublietteView() </code> behave as a radio group and one should 
 *  be selected before invoking any lookup methods. </p>
 */

public interface HoldLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Oubliette </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Oubliette Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getOublietteId();


    /**
     *  Gets the <code> Oubliette </code> associated with this session. 
     *
     *  @return the oubliette 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.Oubliette getOubliette()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Hold </code> lookups. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupHolds();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeHoldView();


    /**
     *  A complete view of the <code> Hold </code> returns is desired. Methods 
     *  will return what is requested or result in an error. This view is used 
     *  when greater precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryHoldView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include holds in oubliettes which are children of this oubliette in 
     *  the oubliette hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedOublietteView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this oubliette only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedOublietteView();


    /**
     *  Only holds whose effective dates are current are returned by methods 
     *  in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useEffectiveHoldView();


    /**
     *  All holds of any effective dates are returned by methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyEffectiveHoldView();


    /**
     *  Gets the <code> Hold </code> specified by its <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Hold </code> may have a different <code> Id </code> than requested, 
     *  such as the case where a duplicate <code> Id </code> was assigned to a 
     *  <code> Hold </code> and retained for compatibility. 
     *  
     *  In effective mode, holds are returned that are currently effective. In 
     *  any effective mode, effective holds and those currently expired are 
     *  returned. 
     *
     *  @param  holdId <code> Id </code> of the <code> Hold </code> 
     *  @return the hold 
     *  @throws org.osid.NotFoundException <code> holdId </code> not found 
     *  @throws org.osid.NullArgumentException <code> holdId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.hold.Hold getHold(org.osid.id.Id holdId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> HoldList </code> corresponding to the given <code> 
     *  IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  holds specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Holds </code> may be omitted from the list and may 
     *  present the elements in any order including returning a unique set. 
     *  
     *  In effective mode, holds are returned that are currently effective. In 
     *  any effective mode, effective holds and those currently expired are 
     *  returned. 
     *
     *  @param  holdIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Hold </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> holdIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.HoldList getHoldsByIds(org.osid.id.IdList holdIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> HoldList </code> corresponding to the given hold genus 
     *  <code> Type </code> which does not include holds of genus types 
     *  derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  holds or an error results. Otherwise, the returned list may contain 
     *  only those holds that are accessible through this session. 
     *  
     *  In effective mode, holds are returned that are currently effective. In 
     *  any effective mode, effective holds and those currently expired are 
     *  returned. 
     *
     *  @param  holdGenusType a hold genus type 
     *  @return the returned <code> Hold </code> list 
     *  @throws org.osid.NullArgumentException <code> holdGenusType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.HoldList getHoldsByGenusType(org.osid.type.Type holdGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> HoldList </code> corresponding to the given hold genus 
     *  <code> Type </code> and include any additional holds with genus types 
     *  derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  holds or an error results. Otherwise, the returned list may contain 
     *  only those holds that are accessible through this session. 
     *  
     *  In effective mode, holds are returned that are currently effective. In 
     *  any effective mode, effective holds and those currently expired are 
     *  returned. 
     *
     *  @param  holdGenusType a hold genus type 
     *  @return the returned <code> Hold </code> list 
     *  @throws org.osid.NullArgumentException <code> holdGenusType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.HoldList getHoldsByParentGenusType(org.osid.type.Type holdGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> HoldList </code> containing the given hold record <code> 
     *  Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  holds or an error results. Otherwise, the returned list may contain 
     *  only those holds that are accessible through this session. 
     *  
     *  In effective mode, holds are returned that are currently effective. In 
     *  any effective mode, effective holds and those currently expired are 
     *  returned. 
     *
     *  @param  holdRecordType a hold record type 
     *  @return the returned <code> Hold </code> list 
     *  @throws org.osid.NullArgumentException <code> holdRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.HoldList getHoldsByRecordType(org.osid.type.Type holdRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of holds for a resource, including any holds for agents 
     *  related to the resource, and effective during the entire given date 
     *  range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known holds or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  holds that are accessible through this session. 
     *  
     *  In effective mode, holds are returned that are currently effective. In 
     *  any effective mode, effective holds and those currently expired are 
     *  returned. 
     *
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Hold </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.HoldList getHoldsOnDate(org.osid.calendaring.DateTime from, 
                                                 org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of holds for a resource including any holds for agents 
     *  related to the resource. 
     *  
     *  In plenary mode, the returned list contains all known holds or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  holds that are accessible through this session. 
     *  
     *  In effective mode, holds are returned that are currently effective. In 
     *  any effective mode, effective holds and those currently expired are 
     *  returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @return the returned <code> Hold </code> list 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.HoldList getHoldsForResource(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of holds for a resource, including any holds for agents 
     *  related to the resource, and effective during the entire given date 
     *  range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known holds or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  holds that are accessible through this session. 
     *  
     *  In effective mode, holds are returned that are currently effective. In 
     *  any effective mode, effective holds and those currently expired are 
     *  returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Hold </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, from, 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.HoldList getHoldsForResourceOnDate(org.osid.id.Id resourceId, 
                                                            org.osid.calendaring.DateTime from, 
                                                            org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of holds for an agent. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  holds or an error results. Otherwise, the returned list may contain 
     *  only those holds that are accessible through this session. 
     *  
     *  In effective mode, holds are returned that are currently effective. In 
     *  any effective mode, effective holds and those currently expired are 
     *  returned. 
     *
     *  @param  agentId an agent <code> Id </code> 
     *  @return the returned <code> Hold </code> list 
     *  @throws org.osid.NullArgumentException <code> agentId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.HoldList getHoldsForAgent(org.osid.id.Id agentId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of holds for an agent and effective during the entire 
     *  given date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known holds or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  holds that are accessible through this session. In both cases, the 
     *  order of the set is by the start of the effective date. 
     *  
     *  In effective mode, holds are returned that are currently effective. In 
     *  any effective mode, effective holds and those currently expired are 
     *  returned. 
     *
     *  @param  agentId an agent <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Hold </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> agentId, from, </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.HoldList getHoldsForAgentOnDate(org.osid.id.Id agentId, 
                                                         org.osid.calendaring.DateTime from, 
                                                         org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of holds for an issue. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  holds or an error results. Otherwise, the returned list may contain 
     *  only those holds that are accessible through this session. 
     *  
     *  In effective mode, holds are returned that are currently effective. In 
     *  any effective mode, effective holds and those currently expired are 
     *  returned. 
     *
     *  @param  issueId an issue <code> Id </code> 
     *  @return the returned C <code> ommission </code> list 
     *  @throws org.osid.NullArgumentException <code> issueid </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.HoldList getHoldsForIssue(org.osid.id.Id issueId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of holds for an issue and effective during the entire 
     *  given date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known holds or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  holds that are accessible through this session. 
     *  
     *  In effective mode, holds are returned that are currently effective. In 
     *  any effective mode, effective holds and those currently expired are 
     *  returned. 
     *
     *  @param  issueId an issue <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned C <code> ommission </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> issueId, from, </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.HoldList getHoldsForIssueOnDate(org.osid.id.Id issueId, 
                                                         org.osid.calendaring.DateTime from, 
                                                         org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of holds for a resource and issue including any holds for 
     *  agents related to the resource. 
     *  
     *  In plenary mode, the returned list contains all known holds or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  holds that are accessible through this session. 
     *  
     *  In effective mode, holds are returned that are currently effective. In 
     *  any effective mode, effective holds and those currently expired are 
     *  returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  issueId an issue <code> Id </code> 
     *  @return the returned C <code> ommission </code> list 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> or 
     *          <code> issueid </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.HoldList getHoldsForResourceAndIssue(org.osid.id.Id resourceId, 
                                                              org.osid.id.Id issueId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of holds for a resource, including any holds for agents 
     *  related to the resource, and issue and effective during the entire 
     *  given date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known holds or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  holds that are accessible through this session. 
     *  
     *  In effective mode, holds are returned that are currently effective. In 
     *  any effective mode, effective holds and those currently expired are 
     *  returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  issueId an issue <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned C <code> ommission </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, issueId, 
     *          from, </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.HoldList getHoldsForResourceAndIssueOnDate(org.osid.id.Id resourceId, 
                                                                    org.osid.id.Id issueId, 
                                                                    org.osid.calendaring.DateTime from, 
                                                                    org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of holds for an agent. 
     *  
     *  In plenary mode, the returned list contains all known holds or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  holds that are accessible through this session. 
     *  
     *  In effective mode, holds are returned that are currently effective. In 
     *  any effective mode, effective holds and those currently expired are 
     *  returned. 
     *
     *  @param  agentId an agent <code> Id </code> 
     *  @param  issueId an issue <code> Id </code> 
     *  @return the returned C <code> ommission </code> list 
     *  @throws org.osid.NullArgumentException <code> agentId </code> or 
     *          <code> issueid </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.HoldList getHoldsForAgentAndIssue(org.osid.id.Id agentId, 
                                                           org.osid.id.Id issueId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of holds for an agent and issue and effective during the 
     *  entire given date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known holds or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  holds that are accessible through this session. 
     *  
     *  In effective mode, holds are returned that are currently effective. In 
     *  any effective mode, effective holds and those currently expired are 
     *  returned. 
     *
     *  @param  agentId an agent <code> Id </code> 
     *  @param  issueId an issue <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned C <code> ommission </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> agentId, issueId, from, 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.HoldList getHoldsForAgentAndIssueOnDate(org.osid.id.Id agentId, 
                                                                 org.osid.id.Id issueId, 
                                                                 org.osid.calendaring.DateTime from, 
                                                                 org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Holds. </code> 
     *  
     *  In plenary mode, the returned list contains all known holds or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  holds that are accessible through this session. 
     *  
     *  In effective mode, holds are returned that are currently effective. In 
     *  any effective mode, effective holds and those currently expired are 
     *  returned. 
     *
     *  @return a list of <code> Holds </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.HoldList getHolds()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
