//
// org.osid.hold.OublietteQuery
//
//     The OSID Java specification for org.osid.hold.OublietteQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.hold;


/**
 *  <p>This is the query for searching oubliettes. Each method match specifies 
 *  an <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface OublietteQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Sets the effort <code> Id </code> for this query to match oubliettes 
     *  containing blocks. 
     *
     *  @param  blockId the block <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> blockId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBlockId(org.osid.id.Id blockId, boolean match);


    /**
     *  Clears the block query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBlockIdTerms();


    /**
     *  Tests if a <code> BlockQuery </code> is available. 
     *
     *  @return <code> true </code> if a block query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBlockQuery();


    /**
     *  Gets the query for a block. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the block query 
     *  @throws org.osid.UnimplementedException <code> supportsBlockQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBlockQuery() </code> is <code> true. </code> 
     */

    public org.osid.hold.BlockQuery getBlockQuery();


    /**
     *  Matches oubliettes that have any block. 
     *
     *  @param  match <code> true </code> to match oubliettes with any block, 
     *          <code> false </code> to match oubliettes with no block 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyBlock(boolean match);


    /**
     *  Clears the block query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBlockTerms();


    /**
     *  Sets the issue <code> Id </code> for this query to match oubliettes 
     *  that have a related issue. 
     *
     *  @param  issueId a issue <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for negative match 
     *  @throws org.osid.NullArgumentException <code> issueId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchIssueId(org.osid.id.Id issueId, boolean match);


    /**
     *  Clears the issue <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearIssueIdTerms();


    /**
     *  Tests if a <code> IssueQuery </code> is available. 
     *
     *  @return <code> true </code> if a issue query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsIssueQuery();


    /**
     *  Gets the query for a issue. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the issue query 
     *  @throws org.osid.UnimplementedException <code> supportsIssueQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsIssueQuery() </code> is <code> true. </code> 
     */

    public org.osid.hold.IssueQuery getIssueQuery();


    /**
     *  Matches oubliettes that have any issue. 
     *
     *  @param  match <code> true </code> to match oubliettes with any issue, 
     *          <code> false </code> to match oubliettes with no issue 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyIssue(boolean match);


    /**
     *  Clears the issue query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearIssueTerms();


    /**
     *  Sets the hold <code> Id </code> for this query. 
     *
     *  @param  holdId the hold <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> holdId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchHoldId(org.osid.id.Id holdId, boolean match);


    /**
     *  Clears the hold <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearHoldIdTerms();


    /**
     *  Tests if a <code> HoldQuery </code> is available. 
     *
     *  @return <code> true </code> if a hold query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsHoldQuery();


    /**
     *  Gets the query for a hold. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the hold query 
     *  @throws org.osid.UnimplementedException <code> supportsHoldQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsHoldQuery() </code> is <code> true. </code> 
     */

    public org.osid.hold.HoldQuery getHoldQuery();


    /**
     *  Matches oubliettes referenced by any hold. 
     *
     *  @param  match <code> true </code> to match oubliettes with any holds, 
     *          <code> false </code> to match oubliettes with no holds 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyHold(boolean match);


    /**
     *  Clears the hold query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearHoldTerms();


    /**
     *  Sets the oubliette <code> Id </code> for this query to match 
     *  oubliettes that have the specified oubliette as an ancestor. 
     *
     *  @param  oublietteId an oubliette <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for negative match 
     *  @throws org.osid.NullArgumentException <code> oublietteId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorOublietteId(org.osid.id.Id oublietteId, 
                                         boolean match);


    /**
     *  Clears the ancestor oubliette <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorOublietteIdTerms();


    /**
     *  Tests if an <code> OublietteQuery </code> is available. 
     *
     *  @return <code> true </code> if an oubliette query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorOublietteQuery();


    /**
     *  Gets the query for an oubliette. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the oubliette query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorOublietteQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorOublietteQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.hold.OublietteQuery getAncestorOublietteQuery();


    /**
     *  Matches oubliettes with any ancestor. 
     *
     *  @param  match <code> true </code> to match oubliettes with any 
     *          ancestor, <code> false </code> to match root oubliettes 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorOubliette(boolean match);


    /**
     *  Clears the ancestor oubliette query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorOublietteTerms();


    /**
     *  Sets the oubliette <code> Id </code> for this query to match 
     *  oubliettes that have the specified oubliette as a descendant. 
     *
     *  @param  oublietteId an oubliette <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for negative match 
     *  @throws org.osid.NullArgumentException <code> oublietteId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantOublietteId(org.osid.id.Id oublietteId, 
                                           boolean match);


    /**
     *  Clears the descendant oubliette <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantOublietteIdTerms();


    /**
     *  Tests if an <code> OublietteQuery </code> is available. 
     *
     *  @return <code> true </code> if an oubliette query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantOublietteQuery();


    /**
     *  Gets the query for an oubliette/ Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the oubliette query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantOublietteQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantOublietteQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.hold.OublietteQuery getDescendantOublietteQuery();


    /**
     *  Matches oubliettes with any descendant. 
     *
     *  @param  match <code> true </code> to match oubliettes with any 
     *          descendant, <code> false </code> to match leaf oubliettes 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantOubliette(boolean match);


    /**
     *  Clears the descendant oubliette query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantOublietteTerms();


    /**
     *  Gets the oubliette query record corresponding to the given <code> 
     *  Oubliette </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  oublietteRecordType an oubliette record type 
     *  @return the oubliette query record 
     *  @throws org.osid.NullArgumentException <code> oublietteRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(oublietteRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.records.OublietteQueryRecord getOublietteQueryRecord(org.osid.type.Type oublietteRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
