//
// org.osid.hold.OublietteSearchSession
//
//     The OSID Java specification for org.osid.hold.OublietteSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.hold;


/**
 *  <p>This session provides methods for searching among <code> Oubliette 
 *  </code> objects. The search query is constructed using the <code> 
 *  OublietteQuery. </code> </p> 
 *  
 *  <p> <code> getOublietteByQuery() </code> is the basic search method and 
 *  returns a list of <code> Oubliettes. </code> A more advanced search may be 
 *  performed with <code> getOublietteBySearch(). </code> It accepts a <code> 
 *  OublietteSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getOublietteBySearch() </code> returns a <code> 
 *  OublietteSearchResults </code> that can be used to access the resulting 
 *  <code> OublietteList </code> or be used to perform a search within the 
 *  result set through <code> OublietteSearch. </code> </p> 
 *  
 *  <p> Oubliettes may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> OublietteQuery. 
 *  </code> </p>
 */

public interface OublietteSearchSession
    extends org.osid.hold.OublietteQuerySession {


    /**
     *  Gets an oubliette search. 
     *
     *  @return the oubliette search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.OublietteSearch getOublietteSearch();


    /**
     *  Gets an oubliette search order. The <code> OublietteSearchOrder 
     *  </code> is supplied to a <code> OublietteSearch </code> to specify the 
     *  ordering of results. 
     *
     *  @return the oubliette search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.OublietteSearchOrder getOublietteSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  oublietteQuery the oubliette query 
     *  @param  oublietteSearch the oubliette search 
     *  @return the oubliette search results 
     *  @throws org.osid.NullArgumentException <code> oublietteQuery </code> 
     *          or <code> oublietteSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> oublietteQuery </code> or 
     *          <code> oublietteSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.OublietteSearchResults getOublietteBySearch(org.osid.hold.OublietteQuery oublietteQuery, 
                                                                     org.osid.hold.OublietteSearch oublietteSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an oubliette query from an inspector. The inspector is available 
     *  from a <code> OublietteSearchResults. </code> 
     *
     *  @param  oublietteQueryInspector an oubliette query inspector 
     *  @return the oubliette query 
     *  @throws org.osid.NullArgumentException <code> oublietteQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> oublietteQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.OublietteQuery getOublietteQueryFromInspector(org.osid.hold.OublietteQueryInspector oublietteQueryInspector);
}
