//
// org.osid.hold.batch.BlockBatchAdminSession
//
//     The OSID Java specification for org.osid.hold.batch.BlockBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.hold.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Blocks </code> in 
 *  bulk. The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Block, </code> a <code> BlockForm </code> is requested using <code> 
 *  getBlockFormsForCreate() </code> specifying the desired record <code> 
 *  Types </code> or none if no record <code> Types </code> are needed. Each 
 *  of the returned <code> BlockForms </code> will indicate that it is to be 
 *  used with a create operation and can be used to examine metdata or 
 *  validate data prior to creation. Once a <code> BlockForm </code> is 
 *  submiited to a create operation, it cannot be reused with another create 
 *  operation unless the first operation was unsuccessful. Each <code> 
 *  BlockForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> BlockForms </code> returned from <code> 
 *  getBlockFormsForCreate() </code> may be linked to the originating request 
 *  through the peer <code> Ids </code> of the <code> BlockForm. </code> In 
 *  the case where there may be duplicates, any <code> BlockForm </code> of 
 *  the same peer <code> Ids </code> may be used for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> BlockForms </code> are submitted for create, a 
 *  <code> CreateResponse </code> is returned for each <code> BlockForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire create operation are returned from <code> createBlocks(), 
 *  </code> errors specific to an individual <code> BlockForm </code> are 
 *  indicated in the corresponding <code> CreateResponse. </code> <code> 
 *  CreateResponses </code> may be linked to the originating <code> BlockForm 
 *  </code> through the <code> BlockForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> BlockForms </code> are requested to the <code> 
 *  Block </code> <code> Id </code> that is to be updated using <code> 
 *  getBlockFormsForUpdate() </code> where the reference <code> Id </code> in 
 *  the <code> BlockForm </code> may be used to link the request. Similarly, 
 *  the <code> BlockForm </code> has metadata about the data that can be 
 *  updated and it can perform validation before submitting the update. The 
 *  <code> BlockForm </code> can only be used once for a successful update and 
 *  cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> BlockForms </code> are submitted for update, an 
 *  <code> UpdateResponse </code> is returned for each <code> BlockForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire update operation are returned from <code> updateBlocks(), 
 *  </code> errors specific to an individual <code> BlockForm </code> are 
 *  indicated in the corresponding <code> UpdateResponse. </code> <code> 
 *  UpdateResponses </code> may be linked to the originating <code> BlockForm 
 *  </code> through the <code> BlockForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> Blocks </code> in bulk. To unmap a 
 *  <code> Block </code> from the current <code> Oubliette, </code> the <code> 
 *  BlockOublietteAssignmentSession </code> should be used. These delete 
 *  operations attempt to remove the <code> Block </code> itself thus removing 
 *  it from all known <code> Oubliette </code> catalogs. Bulk delete 
 *  operations return the results in <code> DeleteResponses. </code> </p>
 */

public interface BlockBatchAdminSession
    extends org.osid.hold.BlockAdminSession {


    /**
     *  Gets the block forms for creating a bunch of new blocks. A BlockForm 
     *  is returned for each hold <code> Id. </code> 
     *
     *  @param  number the number of forms to retrieve 
     *  @param  blockRecordTypes array of block record types to be included in 
     *          each create operation or an empty list if none 
     *  @return the block forms 
     *  @throws org.osid.NullArgumentException <code> blockRecordTypes </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.batch.BlockBatchFormList getBlockFormsForCreate(long number, 
                                                                         org.osid.type.Type[] blockRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Blocks. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  blockForms the block forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> blockForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createBlocks(org.osid.hold.batch.BlockBatchFormList blockForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the block forms for updating an existing set of blocks. A new 
     *  block form should be requested for each update transaction. 
     *
     *  @param  blockIds the <code> Ids </code> of the <code> Block </code> 
     *  @return the block form 
     *  @throws org.osid.NotFoundException a <code> blockId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> blockIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.batch.BlockBatchFormList getBlockFormsForUpdate(org.osid.id.IdList blockIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing blocks. This method returns an error if the entire 
     *  operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  blockForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> blockForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateBlocks(org.osid.hold.batch.BlockBatchFormList blockForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Blocks </code> in this <code> Oubliette </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllBlocks()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes blocks for the given <code> Ids. </code> 
     *
     *  @param  blockIds the <code> Ids </code> of the blocks to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> blockIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteBlocks(org.osid.id.IdList blockIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Block </code> for the purpose of 
     *  creating compatibility. The primary <code> Id </code> of the <code> 
     *  Block </code> is determined by the provider. The new <code> Id </code> 
     *  is an alias to the primary <code> Id. </code> If the alias is a 
     *  pointer to another block, it is reassigned to the given block <code> 
     *  Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasBlocks(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
