//
// org.osid.hold.batch.HoldBatchAdminSession
//
//     The OSID Java specification for org.osid.hold.batch.HoldBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.hold.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Holds </code> in 
 *  bulk. The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Hold, </code> a <code> HoldForm </code> is requested using <code> 
 *  getHoldFormsForCreate() </code> specifying the desired issue and record 
 *  <code> Types </code> or none if no record <code> Types </code> are needed. 
 *  Each of the returned <code> HoldForms </code> will indicate that it is to 
 *  be used with a create operation and can be used to examine metdata or 
 *  validate data prior to creation. Once a <code> HoldForm </code> is 
 *  submiited to a create operation, it cannot be reused with another create 
 *  operation unless the first operation was unsuccessful. Each <code> 
 *  HoldForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> HoldForms </code> returned from <code> 
 *  getHoldFormsForCreate() </code> may be linked to the originating request 
 *  through the peer <code> Ids </code> of the <code> HoldForm. </code> In the 
 *  case where there may be duplicates, any <code> HoldForm </code> of the 
 *  same peer <code> Ids </code> may be used for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> HoldForms </code> are submitted for create, a 
 *  <code> CreateResponse </code> is returned for each <code> HoldForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire create operation are returned from <code> createHolds(), 
 *  </code> errors specific to an individual <code> HoldForm </code> are 
 *  indicated in the corresponding <code> CreateResponse. </code> <code> 
 *  CreateResponses </code> may be linked to the originating <code> HoldForm 
 *  </code> through the <code> HoldForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> HoldForms </code> are requested to the <code> Hold 
 *  </code> <code> Id </code> that is to be updated using <code> 
 *  getHoldFormsForUpdate() </code> where the reference <code> Id </code> in 
 *  the <code> HoldForm </code> may be used to link the request. Similarly, 
 *  the <code> HoldForm </code> has metadata about the data that can be 
 *  updated and it can perform validation before submitting the update. The 
 *  <code> HoldForm </code> can only be used once for a successful update and 
 *  cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> HoldForms </code> are submitted for update, an 
 *  <code> UpdateResponse </code> is returned for each <code> HoldForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire update operation are returned from <code> updateHolds(), 
 *  </code> errors specific to an individual <code> HoldForm </code> are 
 *  indicated in the corresponding <code> UpdateResponse. </code> <code> 
 *  UpdateResponses </code> may be linked to the originating <code> HoldForm 
 *  </code> through the <code> HoldForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> Holds </code> in bulk. To unmap a 
 *  <code> Hold </code> from the current <code> Oubliette, </code> the <code> 
 *  HoldOublietteAssignmentSession </code> should be used. These delete 
 *  operations attempt to remove the <code> Hold </code> itself thus removing 
 *  it from all known <code> Oubliette </code> catalogs. Bulk delete 
 *  operations return the results in <code> DeleteResponses. </code> </p>
 */

public interface HoldBatchAdminSession
    extends org.osid.hold.HoldAdminSession {


    /**
     *  Gets the hold forms for creating a bunch of new holds. A form is 
     *  returned for each supplied agent and issue pair. 
     *
     *  @param  peers the hold peers 
     *  @param  holdRecordTypes array of hold record types to be included in 
     *          each create operation or an empty list if none 
     *  @return the hold forms 
     *  @throws org.osid.NotFoundException an <code> issueId </code> or <code> 
     *          agentId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> peers </code> or <code> 
     *          holdRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.batch.HoldBatchFormList getHoldFormsForCreateForAgents(org.osid.hold.batch.HoldAgentPeerList peers, 
                                                                                org.osid.type.Type[] holdRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the hold forms for creating a bunch of new holds. A form is 
     *  returned for each supplied resource and issue pair. 
     *
     *  @param  peers the hold peers 
     *  @param  holdRecordTypes array of hold record types to be included in 
     *          each create operation or an empty list if none 
     *  @return the hold forms 
     *  @throws org.osid.NotFoundException an <code> issueId </code> or <code> 
     *          resourceId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> peers </code> or <code> 
     *          holdRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.batch.HoldBatchFormList getHoldFormsForCreateForResources(org.osid.hold.batch.HoldResourcePeerList peers, 
                                                                                   org.osid.type.Type[] holdRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Holds. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  holdForms the hold forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> holdForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createHolds(org.osid.hold.batch.HoldBatchFormList holdForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the hold forms for updating an existing set of holds. A new hold 
     *  form should be requested for each update transaction. 
     *
     *  @param  holdIds the <code> Ids </code> of the <code> Hold </code> 
     *  @return the hold form 
     *  @throws org.osid.NotFoundException a <code> holdId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> holdIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.batch.HoldBatchFormList getHoldFormsForUpdate(org.osid.id.IdList holdIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing holds. This method returns an error if the entire 
     *  operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  holdForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> holdForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateHolds(org.osid.hold.batch.HoldBatchFormList holdForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Holds </code> in this <code> Oubliette </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllHolds()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes holds for the given <code> Ids. </code> 
     *
     *  @param  holdIds the <code> Ids </code> of the holds to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> holdIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteHolds(org.osid.id.IdList holdIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes holds for the given issue. 
     *
     *  @param  issueId the <code> Id </code> of an issue 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> issueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteHoldsForIssue(org.osid.id.Id issueId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes holds for the given agent. 
     *
     *  @param  agentId the <code> Id </code> of an agent 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> agentId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteHoldsForAgent(org.osid.id.Id agentId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes holds for the given resource and any holds for agents related 
     *  to the given resource. 
     *
     *  @param  resourceId the <code> Id </code> of a resource 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteHoldsForResource(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes holds expired before the given date. 
     *
     *  @param  date a date 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteIneffectiveHoldsByDate(org.osid.calendaring.DateTime date)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Hold </code> for the purpose of 
     *  creating compatibility. The primary <code> Id </code> of the <code> 
     *  Hold </code> is determined by the provider. The new <code> Id </code> 
     *  is an alias to the primary <code> Id. </code> If the alias is a 
     *  pointer to another hold, it is reassigned to the given hold <code> Id. 
     *  </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasHolds(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
