//
// org.osid.hold.rules.HoldEnablerRuleApplicationSession
//
//     The OSID Java specification for org.osid.hold.rules.HoldEnablerRuleApplicationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.hold.rules;


/**
 *  <p>This session provides methods to apply <code> HoldEnablers </code> to 
 *  <code> Holds. </code> A <code> Hold </code> with multiple <code> 
 *  HoldEnablers </code> means any positive rule evaluation across the 
 *  enablers result in an effective <code> Hold. </code> </p>
 */

public interface HoldEnablerRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Oubliette </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Oubliette Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getOublietteId();


    /**
     *  Gets the <code> Oubliette </code> associated with this session. 
     *
     *  @return the oubliette 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.Oubliette getOubliette()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter hold enabler/hold mappings. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignHoldEnablers();


    /**
     *  Adds an existing <code> HoldEnabler </code> to a <code> Hold. </code> 
     *
     *  @param  holdEnablerId the <code> Id </code> of the <code> HoldEnabler 
     *          </code> 
     *  @param  holdId the <code> Id </code> of the <code> Hold </code> 
     *  @throws org.osid.AlreadyExistsException <code> holdEnablerId </code> 
     *          is already applied to <code> holdId </code> 
     *  @throws org.osid.NotFoundException <code> holdEnablerId </code> or 
     *          <code> holdId </code> not found 
     *  @throws org.osid.NullArgumentException <code> holdEnablerId </code> or 
     *          <code> holdId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignHoldEnablerToHold(org.osid.id.Id holdEnablerId, 
                                        org.osid.id.Id holdId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> HoldEnabler </code> from a <code> Hold. </code> 
     *
     *  @param  holdEnablerId the <code> Id </code> of the <code> HoldEnabler 
     *          </code> 
     *  @param  holdId the <code> Id </code> of the <code> Hold </code> 
     *  @throws org.osid.NotFoundException <code> holdEnablerId </code> or 
     *          <code> holdId </code> not found or <code> holdEnablerId 
     *          </code> is not applied to <code> holdId </code> 
     *  @throws org.osid.NullArgumentException <code> holdEnablerId </code> or 
     *          <code> holdId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignHoldEnablerFromHold(org.osid.id.Id holdEnablerId, 
                                            org.osid.id.Id holdId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> HoldEnablers. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known sequencing operations will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> HoldEnabler </code> ordering is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceHoldEnablers();


    /**
     *  Reorders hold enablers for a hold by moving the specified hold enabler 
     *  in front of a reference hold enabler. 
     *
     *  @param  holdEnablerId the <code> Id </code> of a <code> HoldEnabler 
     *          </code> 
     *  @param  holdId the <code> Id </code> of a <code> Hold </code> 
     *  @param  referenceId the reference hold enabler <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> holdEnablerId, holdId, 
     *          </code> or <code> referenceId </code> not found or, <code> 
     *          holdEnablerId </code> or <code> referenceId </code> not 
     *          related to <code> holdId </code> 
     *  @throws org.osid.NullArgumentException <code> holdEnablerId, holdId, 
     *          </code> or <code> referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveHoldEnablerAhead(org.osid.id.Id holdEnablerId, 
                                     org.osid.id.Id holdId, 
                                     org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders hold enablers for a hold by moving the specified hold enabler 
     *  behind a reference hold enabler. 
     *
     *  @param  holdEnablerId the <code> Id </code> of a <code> HoldEnabler 
     *          </code> 
     *  @param  holdId the <code> Id </code> of a <code> Hold </code> 
     *  @param  referenceId the reference hold enabler <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> holdEnablerId, holdId, 
     *          </code> or <code> referenceId </code> not found or, <code> 
     *          holdEnablerId </code> or <code> referenceId </code> not 
     *          related to <code> holdId </code> 
     *  @throws org.osid.NullArgumentException <code> holdEnablerId, holdId, 
     *          </code> or <code> referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveHoldEnablerBehind(org.osid.id.Id holdEnablerId, 
                                      org.osid.id.Id holdId, 
                                      org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of hold enablers for a hold. 
     *
     *  @param  holdEnablerId the <code> Ids </code> for a set of <code> 
     *          HoldEnablers </code> 
     *  @param  holdId the <code> Id </code> of a <code> Hold </code> 
     *  @throws org.osid.NotFoundException <code> holdId </code> not found or, 
     *          a <code> holdnEnablerId </code> not related to <code> holdId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> holdEnablerIds </code> 
     *          or <code> holdId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderHoldEnablers(org.osid.id.Id[] holdEnablerId, 
                                  org.osid.id.Id holdId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
