//
// org.osid.hold.rules.HoldRulesProfile
//
//     The OSID Java specification for org.osid.hold.rules.HoldRulesProfile.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.hold.rules;


/**
 *  <p>The hold rules profile describes the interoperability among hold rules 
 *  services. </p>
 */

public interface HoldRulesProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any broker federation is exposed. Federation is exposed when 
     *  a specific broker may be identified, selected and used to create a 
     *  lookup or admin session. Federation is not exposed when a set of 
     *  brokers appears as a single broker. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if looking up hold enablers is supported. 
     *
     *  @return <code> true </code> if hold enabler lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsHoldEnablerLookup();


    /**
     *  Tests if querying hold enablers is supported. 
     *
     *  @return <code> true </code> if hold enabler query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsHoldEnablerQuery();


    /**
     *  Tests if searching hold enablers is supported. 
     *
     *  @return <code> true </code> if hold enabler search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsHoldEnablerSearch();


    /**
     *  Tests if a hold enabler administrative service is supported. 
     *
     *  @return <code> true </code> if hold enabler administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsHoldEnablerAdmin();


    /**
     *  Tests if a hold enabler notification service is supported. 
     *
     *  @return <code> true </code> if hold enabler notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsHoldEnablerNotification();


    /**
     *  Tests if a hold enabler oubliette lookup service is supported. 
     *
     *  @return <code> true </code> if an oubliette enabler hold lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsHoldEnablerOubliette();


    /**
     *  Tests if a hold enabler oubliette service is supported. 
     *
     *  @return <code> true </code> if hold enabler oubliette assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsHoldEnablerOublietteAssignment();


    /**
     *  Tests if a hold enabler hold lookup service is supported. 
     *
     *  @return <code> true </code> if a hold enabler hold service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsHoldEnablerSmartHold();


    /**
     *  Tests if a hold enabler rule lookup service is supported. 
     *
     *  @return <code> true </code> if a hold enabler rule lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsHoldEnablerRuleLookup();


    /**
     *  Tests if a hold enabler rule application service is supported. 
     *
     *  @return <code> true </code> if hold enabler rule application service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsHoldEnablerRuleApplication();


    /**
     *  Gets the supported <code> HoldEnabler </code> record types. 
     *
     *  @return a list containing the supported <code> HoldEnabler </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getHoldEnablerRecordTypes();


    /**
     *  Tests if the given <code> HoldEnabler </code> record type is 
     *  supported. 
     *
     *  @param  holdEnablerRecordType a <code> Type </code> indicating a 
     *          <code> HoldEnabler </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> holdEnablerRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsHoldEnablerRecordType(org.osid.type.Type holdEnablerRecordType);


    /**
     *  Gets the supported <code> HoldEnabler </code> search record types. 
     *
     *  @return a list containing the supported <code> HoldEnabler </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getHoldEnablerSearchRecordTypes();


    /**
     *  Tests if the given <code> HoldEnabler </code> search record type is 
     *  supported. 
     *
     *  @param  holdEnablerSearchRecordType a <code> Type </code> indicating a 
     *          <code> HoldEnabler </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          holdEnablerSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsHoldEnablerSearchRecordType(org.osid.type.Type holdEnablerSearchRecordType);
}
