//
// org.osid.id.IdForm
//
//     The OSID Java specification for org.osid.id.IdForm.
//
// Copyright (C) 2002, 2006 Massachusetts Institute of Technology. All Rights 
// Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.id;


/**
 *  <p>This form provides a means of creating an <code> Id. </code> </p>
 */

public interface IdForm
    extends org.osid.OsidForm {


    /**
     *  Gets the metadata for the authority. 
     *
     *  @return metadata for the authority 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getAuthorityMetadata();


    /**
     *  Sets the authority. 
     *
     *  @param  authority the authority 
     *  @throws org.osid.InvalidArgumentException <code> authority </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> authority </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> authority </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setAuthority(String authority);


    /**
     *  Clears the authority. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAuthority();


    /**
     *  Gets the metadata for the identifier namespace. 
     *
     *  @return metadata for the namespace 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getIdentifierNamespaceMetadata();


    /**
     *  Seta the identifier namespace. 
     *
     *  @param  namespace the namespace 
     *  @throws org.osid.InvalidArgumentException <code> namespace </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> namespace </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> namespace </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setIdentifierNamespace(String namespace);


    /**
     *  Clears the identifier namespace. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearIdentifierNamespace();


    /**
     *  Gets the metadata for the identifier prefix. 
     *
     *  @return metadata for the prefix 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getIdentifierPrefixMetadata();


    /**
     *  Seta the identifier prefix. An identifier will be generated with this 
     *  prefix. 
     *
     *  @param  prefix the prefix 
     *  @throws org.osid.InvalidArgumentException <code> prefix </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> prefix </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> prefix </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setIdentifierPrefix(String prefix);


    /**
     *  Clears the identifier prefix. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearIdentifierPrefix();


    /**
     *  Gets the metadata for the identifier suffix. 
     *
     *  @return metadata for the suffix 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getIdentifierSuffixMetadata();


    /**
     *  Seta the identifier prefix. An identifier will be generated with this 
     *  suffix. 
     *
     *  @param  suffix the suffix 
     *  @throws org.osid.InvalidArgumentException <code> suffix </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> suffix </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> suffix </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setIdentifierSuffix(String suffix);


    /**
     *  Clears the identifier suffix. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearIdentifierSuffix();


    /**
     *  Gets the metadata for the identifier. 
     *
     *  @return metadata for the identifier 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getIdentifierMetadata();


    /**
     *  Seta the identifier. 
     *
     *  @param  identifier the identifier 
     *  @throws org.osid.InvalidArgumentException <code> identifier </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> identifier </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> identifier </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setIdentifier(String identifier);


    /**
     *  Clears the identifier. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearIdentifier();
}
