//
// org.osid.id.IdLookupSession
//
//     The OSID Java specification for org.osid.id.IdLookupSession.
//
// Copyright (C) 2002, 2006 Massachusetts Institute of Technology. All Rights 
// Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.id;


/**
 *  <p>This session is for retrieving <code> Id </code> objects. <code> 
 *  getIds() </code> retrieves all known <code> Ids. </code> The existence of 
 *  a single identifier can be confirmed through the <code> getId() </code> 
 *  method, or it can be used as a means of <code> Id </code> translation. 
 *  </p>
 */

public interface IdLookupSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can perform <code> Id </code> lookups. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupIds();


    /**
     *  Gets an <code> Id. </code> This method serves to get the principal 
     *  <code> Id </code> if the given <code> Id </code> Is an alias. 
     *
     *  @param  id an <code> Id </code> 
     *  @return the <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> id </code> is not found 
     *  @throws org.osid.NullArgumentException <code> id </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getId(org.osid.id.Id id)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of <code> Ids. </code> This method serves to get the 
     *  principal <code> Ids </code> if different from the given <code> Ids. 
     *  </code> 
     *
     *  @param  ids a list of <code> Ids </code> 
     *  @return a list of <code> Ids </code> 
     *  @throws org.osid.NotFoundException an <code> id </code> is not found 
     *  @throws org.osid.NullArgumentException <code> ids </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getIdsByIds(org.osid.id.IdList ids)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets <code> Ids </code> by the given authority. 
     *
     *  @param  authority an authority 
     *  @return a list of <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> authority </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getIdsByAuthority(String authority)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets <code> Ids </code> by the given authority and namespace. 
     *
     *  @param  authority an authority 
     *  @param  namespace a namespace 
     *  @return a list of <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> authority </code> or 
     *          <code> namespace </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getIdsByAuthorityAndNamespace(String authority, 
                                                            String namespace)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Ids. </code> 
     *
     *  @return the list of all <code> Ids </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getIds()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if the two <code> Ids </code> are equivalent. Two <code> Ids 
     *  </code> are equivalent if they identify the same object. If one of the 
     *  <code> Ids </code> is not known, they are not equivalent. 
     *
     *  @param  id an <code> Id </code> 
     *  @param  equivalentId an <code> Id </code> 
     *  @return <code> true </code> if the <code> Ids </code> are equivalent, 
     *          false otherwise 
     *  @throws org.osid.NullArgumentException <code> null </code> argument 
     *          provided 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isEquivalent(org.osid.id.Id id, org.osid.id.Id equivalentId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of <code> Id </code> aliases of an <code> Id. </code> 
     *
     *  @param  id an <code> Id </code> 
     *  @return a list of alias <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> id </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getIdAliases(org.osid.id.Id id)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of <code> Id </code> aliases in a authority for an <code> 
     *  Id. </code> 
     *
     *  @param  id an <code> Id </code> 
     *  @param  authority an authority 
     *  @return a list of alias <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> id </code> or <code> 
     *          authority </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getIdAliasesByAuthority(org.osid.id.Id id, 
                                                      String authority)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of <code> Id </code> aliases in a namespace for an <code> 
     *  Id. </code> 
     *
     *  @param  id an <code> Id </code> 
     *  @param  authority an authority 
     *  @param  namespace a namespace 
     *  @return a list of alias <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> id, authority, </code> 
     *          or <code> namespace </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getIdAliasesByAuthorityAndNamespace(org.osid.id.Id id, 
                                                                  String authority, 
                                                                  String namespace)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
