//
// org.osid.id.IdProxyManager
//
//     The OSID Java specification for org.osid.id.IdProxyManager.
//
// Copyright (C) 2002, 2006 Massachusetts Institute of Technology. All Rights 
// Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.id;


/**
 *  <p>This manager provides access to the available sessions of the Id 
 *  service. Methods in this manager support the passing of a <code> Proxy 
 *  </code> object for the purpose of pasisng information from a server 
 *  envrionment. </p> 
 *  
 *  <p> <code> Ids </code> are created through the <code> IdAdminSession 
 *  </code> which provides the means for creating a unique identifier. The 
 *  <code> IdBrowserSession </code> can be used for mapping one <code> Id 
 *  </code> to another in addition to getting a list of the assigned 
 *  identifiers. </p>
 */

public interface IdProxyManager
    extends org.osid.OsidProxyManager,
            org.osid.id.IdProfile {


    /**
     *  Gets the session associated with the id lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> IdLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsIdLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsIdLookup() </code> is <code> true. </code> 
     */

    public org.osid.id.IdLookupSession getIdLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session associated with the id issue service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> IdIssueSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsIdIssue() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsIdIssue() </code> is <code> true. </code> 
     */

    public org.osid.id.IdIssueSession getIdIssueSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session associated with the id administrative service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> IdAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsIdAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsIdAdmin() </code> is <code> true. </code> 
     */

    public org.osid.id.IdAdminSession getIdAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets an <code> IdnProxyManager. </code> 
     *
     *  @return an <code> IdBatchProxyManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsIdBatch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsIdBatch() </code> is <code> true. </code> 
     */

    public org.osid.id.batch.IdBatchProxyManager getIdBatchProxyManager()
        throws org.osid.OperationFailedException;
}
