//
// org.osid.inquiry.AcknowledgementNotificationSession
//
//     The OSID Java specification for org.osid.inquiry.AcknowledgementNotificationSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN INPUT OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inquiry;


/**
 *  <p>This session defines methods to receive notifications on adds/changes 
 *  to <code> Inquiry </code> objects in this <code> Inquest </code> for 
 *  resources related to the authenticated agent. This also includes existing 
 *  inquiries that may appear or disappear due to changes in the <code> 
 *  Inquest </code> hierarchy, This session is intended for consumers needing 
 *  to synchronize their state with this service without the use of polling. 
 *  Notifications are cancelled when this session is closed. </p>
 */

public interface AcknowledgementNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Inquest </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Inquest Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getInquestId();


    /**
     *  Gets the <code> Inquest </code> associated with this session. 
     *
     *  @return the inquest 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.Inquest getInquest()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can register for <code> Inquiry </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForInquiryNotifications();


    /**
     *  Register for notifications of new inquiries needing responses for 
     *  resources related to the authenticated agent. <code> 
     *  InquiryReceiver.newInquiries() </code> is invoked when a new <code> 
     *  Inquiry </code> appears in this inquest. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewInquiries()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new inquiries needing responses for the 
     *  given audit <code> Id </code> for resources related to the 
     *  authenticated agent. <code> InquiryReceiver.newInquiries() </code> is 
     *  invoked when a new <code> Inquiry </code> needs a response. 
     *
     *  @param  auditId the <code> Id </code> of the audit to monitor 
     *  @throws org.osid.NullArgumentException <code> auditId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewInquiriesToAcknowledge(org.osid.id.Id auditId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
