//
// org.osid.inquiry.AcknowledgementSession
//
//     The OSID Java specification for org.osid.inquiry.AcknowledgementSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN INPUT OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inquiry;


/**
 *  <p>This session defines methods for evaluating and responding to inquiries 
 *  for users. </p>
 */

public interface AcknowledgementSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Inquest </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Inquest Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getInquestId();


    /**
     *  Gets the <code> Inquest </code> associated with this session. 
     *
     *  @return the inquest 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.Inquest getInquest()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Inquiry </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canGetMyInquiries();


    /**
     *  Gets the inquiries needing a response for the resource related to this 
     *  agent. 
     *
     *  @param  auditId the <code> Id </code> of an <code> Audit </code> 
     *  @return the returned <code> InquiryList </code> 
     *  @throws org.osid.NullArgumentException <code> auditId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.InquiryList getMyInquiries(org.osid.id.Id auditId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create responses. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known creating a <code> Response </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer create operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Response </code> creation is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRespond();


    /**
     *  Tests if this user can create a single <code> Response </code> using 
     *  the desired record types. While <code> 
     *  ControlManager.getResponseRecordTypes() </code> can be used to examine 
     *  which records are supported, this method tests which record(s) are 
     *  required for creating a specific <code> Response. </code> Providing an 
     *  empty array tests if a <code> Response </code> can be created with no 
     *  records. 
     *
     *  @param  responseRecordTypes array of response record types 
     *  @return <code> true </code> if <code> Response </code> creation using 
     *          the specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> responseRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateResponseWithRecordTypes(org.osid.type.Type[] responseRecordTypes);


    /**
     *  Gets the response form for creating new responses from this agent. A 
     *  new form should be requested for each create transaction. 
     *
     *  @param  inquiryId the <code> Id </code> for the inquiry 
     *  @param  responseRecordTypes array of response record types 
     *  @return the response form 
     *  @throws org.osid.NotFoundException <code> inquiryId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> inquiryId </code> or 
     *          <code> responseRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.ResponseForm getResponseForm(org.osid.id.Id inquiryId, 
                                                         org.osid.type.Type[] responseRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Response </code> from this agent. 
     *
     *  @param  responseForm the form for this <code> Response </code> 
     *  @return the new <code> Response </code> 
     *  @throws org.osid.IllegalStateException <code> responseForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> responseForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> responseForm </code> did 
     *          not originate from <code> getResponseFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.Response respond(org.osid.inquiry.ResponseForm responseForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
