//
// org.osid.inquiry.AuditAdminSession
//
//     The OSID Java specification for org.osid.inquiry.AuditAdminSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN INPUT OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inquiry;


/**
 *  <p>This session creates, updates, and deletes <code> Audits. </code> The 
 *  data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create an 
 *  <code> Audit, </code> an <code> AuditForm </code> is requested using 
 *  <code> getAuditFormForCreate() </code> specifying the desired record 
 *  <code> Types </code> or none if no record <code> Types </code> are needed. 
 *  The returned <code> AuditForm </code> will indicate that it is to be used 
 *  with a create operation and can be used to examine metdata or validate 
 *  data prior to creation. Once the <code> AuditForm </code> is submiited to 
 *  a create operation, it cannot be reused with another create operation 
 *  unless the first operation was unsuccessful. Each <code> AuditForm </code> 
 *  corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> AuditForms </code> are requested to the <code> 
 *  Audit </code> <code> Id </code> that is to be updated using <code> 
 *  getAuditFormForUpdate(). </code> Similarly, the <code> AuditForm </code> 
 *  has metadata about the data that can be updated and it can perform 
 *  validation before submitting the update. The <code> AuditForm </code> can 
 *  only be used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Audits. </code> To unmap an <code> 
 *  Audit </code> from the current <code> Inquest, </code> the <code> 
 *  AuditInquestAssignmentSession </code> should be used. These delete 
 *  operations attempt to remove the <code> Audit </code> itself thus removing 
 *  it from all known <code> Inquest </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface AuditAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Inquest </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Inquest Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getInquestId();


    /**
     *  Gets the <code> Inquest </code> associated with this session. 
     *
     *  @return the inquest 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.Inquest getInquest()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create audits. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known creating an <code> Audit </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer create operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Audit </code> creation is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAudit();


    /**
     *  Tests if this user can create a single <code> Audit </code> using the 
     *  desired record types. While <code> 
     *  ControlManager.getAuditRecordTypes() </code> can be used to examine 
     *  which records are supported, this method tests which record(s) are 
     *  required for creating a specific <code> Audit. </code> Providing an 
     *  empty array tests if an <code> Audit </code> can be created with no 
     *  records. 
     *
     *  @param  auditRecordTypes array of audit record types 
     *  @return <code> true </code> if <code> Audit </code> creation using the 
     *          specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> auditRecordTypes </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAuditWithRecordTypes(org.osid.type.Type[] auditRecordTypes);


    /**
     *  Gets the audit form for creating new audits. A new form should be 
     *  requested for each create transaction. 
     *
     *  @param  auditRecordTypes array of audit record types 
     *  @return the audit form 
     *  @throws org.osid.NullArgumentException <code> auditRecordTypes </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.AuditForm getAuditFormForCreate(org.osid.type.Type[] auditRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Audit. </code> 
     *
     *  @param  auditForm the form for this <code> Audit </code> 
     *  @return the new <code> Audit </code> 
     *  @throws org.osid.IllegalStateException <code> auditForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> auditForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> auditForm </code> did not 
     *          originate from <code> getAuditFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.Audit createAudit(org.osid.inquiry.AuditForm auditForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update audits. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known updating an <code> Audit </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer update operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Audit </code> modification is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateAudits();


    /**
     *  Gets the audit form for updating an existing audit. A new audit form 
     *  should be requested for each update transaction. 
     *
     *  @param  auditId the <code> Id </code> of the <code> Audit </code> 
     *  @return the audit form 
     *  @throws org.osid.NotFoundException <code> auditId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> auditId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.AuditForm getAuditFormForUpdate(org.osid.id.Id auditId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing audit. 
     *
     *  @param  auditForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> auditForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> auditForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> auditForm </code> did not 
     *          originate from <code> getAuditFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateAudit(org.osid.inquiry.AuditForm auditForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete audits. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known deleting an <code> Audit </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer delete operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Audit </code> deletion is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteAudits();


    /**
     *  Deletes an <code> Audit. </code> 
     *
     *  @param  auditId the <code> Id </code> of the <code> Audit </code> to 
     *          remove 
     *  @throws org.osid.NotFoundException <code> auditId </code> not found 
     *  @throws org.osid.NullArgumentException <code> auditId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteAudit(org.osid.id.Id auditId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for audits. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known changing an alias will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer alias operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Audit </code> aliasing is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageAuditAliases();


    /**
     *  Adds an <code> Id </code> to an <code> Audit </code> for the purpose 
     *  of creating compatibility. The primary <code> Id </code> of the <code> 
     *  Audit </code> is determined by the provider. The new <code> Id </code> 
     *  performs as an alias to the primary <code> Id </code> . If the alias 
     *  is a pointer to another audit, it is reassigned to the given audit 
     *  <code> Id. </code> 
     *
     *  @param  auditId the <code> Id </code> of an <code> Audit </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> auditId </code> not found 
     *  @throws org.osid.NullArgumentException <code> auditId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasAudit(org.osid.id.Id auditId, org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
