//
// org.osid.inquiry.AuditInquestAssignmentSession
//
//     The OSID Java specification for org.osid.inquiry.AuditInquestAssignmentSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN INPUT OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inquiry;


/**
 *  <p>This session provides methods to re-assign <code> Audit </code> to 
 *  <code> Inquest </code> mappings. An <code> Audit </code> may appear in 
 *  multiple <code> Inquest </code> objects and removing the last reference to 
 *  an <code> Audit </code> is the equivalent of deleting it. Each <code> 
 *  Inquest </code> may have its own authorizations governing who is allowed 
 *  to operate on it. </p> 
 *  
 *  <p> Adding a reference of an <code> Audit </code> to another <code> 
 *  Inquest </code> is not a copy operation (eg: does not change its <code> Id 
 *  </code> ). </p>
 */

public interface AuditInquestAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter audit/inquest mappings. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignAudits();


    /**
     *  Tests if this user can alter audit/inquest mappings. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @param  inquestId the <code> Id </code> of the <code> Inquest </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> inquestId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignAuditsToInquest(org.osid.id.Id inquestId);


    /**
     *  Gets a list of inquests including and under the given inquest node in 
     *  which any audit can be assigned. 
     *
     *  @param  inquestId the <code> Id </code> of the <code> Inquest </code> 
     *  @return list of assignable inquest <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> inquestId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableInquestIds(org.osid.id.Id inquestId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of inquests including and under the given inquest node in 
     *  which a specific audit can be assigned. 
     *
     *  @param  inquestId the <code> Id </code> of the <code> Inquest </code> 
     *  @param  auditId the <code> Id </code> of the <code> Audit </code> 
     *  @return list of assignable inquest <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> inquestId </code> or 
     *          <code> auditId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableInquestIdsForAudit(org.osid.id.Id inquestId, 
                                                              org.osid.id.Id auditId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> Audit </code> to a <code> Inquest. </code> 
     *
     *  @param  auditId the <code> Id </code> of the <code> Audit </code> 
     *  @param  inquestId the <code> Id </code> of the <code> Inquest </code> 
     *  @throws org.osid.AlreadyExistsException <code> auditId </code> is 
     *          already assigned to <code> inquestId </code> 
     *  @throws org.osid.NotFoundException <code> auditId </code> or <code> 
     *          inquestId </code> not found 
     *  @throws org.osid.NullArgumentException <code> auditId </code> or 
     *          <code> inquestId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignAuditToInquest(org.osid.id.Id auditId, 
                                     org.osid.id.Id inquestId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes an <code> Audit </code> from an <code> Inquest. </code> 
     *
     *  @param  auditId the <code> Id </code> of the <code> Audit </code> 
     *  @param  inquestId the <code> Id </code> of the <code> Inquest </code> 
     *  @throws org.osid.NotFoundException <code> auditId </code> or <code> 
     *          inquestId </code> not found or <code> auditId </code> not 
     *          assigned to <code> inquestId </code> 
     *  @throws org.osid.NullArgumentException <code> auditId </code> or 
     *          <code> inquestId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignAuditFromInquest(org.osid.id.Id auditId, 
                                         org.osid.id.Id inquestId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Moves an <code> Inquiry </code> from one <code> Inquest </code> to 
     *  another. Mappings to other <code> Inquests </code> are unaffected. 
     *
     *  @param  auditId the <code> Id </code> of the <code> Audit </code> 
     *  @param  fromInquestId the <code> Id </code> of the current <code> 
     *          Inquest </code> 
     *  @param  toInquestId the <code> Id </code> of the destination <code> 
     *          Inquest </code> 
     *  @throws org.osid.NotFoundException <code> auditId, fromInquestId, 
     *          </code> or <code> toInquestId </code> not found or <code> 
     *          auditiId </code> not mapped to <code> fromInquestId </code> 
     *  @throws org.osid.NullArgumentException <code> auditId, fromInquestId, 
     *          </code> or <code> toInquestId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void reassignAuditToInquest(org.osid.id.Id auditId, 
                                       org.osid.id.Id fromInquestId, 
                                       org.osid.id.Id toInquestId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
