//
// org.osid.inquiry.AuditSmartInquestSession
//
//     The OSID Java specification for org.osid.inquiry.AuditSmartInquestSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN INPUT OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inquiry;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. An <code> AuditQuery </code> can be retrieved from this session 
 *  and mapped to this <code> Inquest </code> to create a virtual collection 
 *  of audits. The audits may be sequenced using the <code> AuditSearchOrder 
 *  </code> from this session. </p> 
 *  
 *  <p> This <code> Inquest </code> has a default query that matches any audit 
 *  and a default search order that specifies no sequencing. The queries may 
 *  be examined using an <code> AuditQueryInspector. </code> The query may be 
 *  modified by converting the inspector back to an <code> AuditQuery. </code> 
 *  </p>
 */

public interface AuditSmartInquestSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Inquest </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Inquest Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getInquestId();


    /**
     *  Gets the <code> Inquest </code> associated with this session. 
     *
     *  @return the inquest 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.Inquest getInquest()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart inquests. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart inquest management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartInquests();


    /**
     *  Gets an audit query. 
     *
     *  @return the audit query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.AuditQuery getAuditQuery();


    /**
     *  Gets an audit search order. 
     *
     *  @return the audit search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.AuditSearchOrder getAuditSearchOrder();


    /**
     *  Applies an audit query to this inquest. 
     *
     *  @param  auditQuery the audit query 
     *  @throws org.osid.NullArgumentException <code> auditQuery </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> auditQuery </code> not of 
     *          this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyAuditQuery(org.osid.inquiry.AuditQuery auditQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an audit query inspector for this inquest. 
     *
     *  @return the audit query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.AuditQueryInspector inspecAuditQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies an audit search order to this inquest. 
     *
     *  @param  auditSearchOrder the audit search order 
     *  @throws org.osid.NullArgumentException <code> auditSearchOrder </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> auditSearchOrder </code> 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyAuditSequencing(org.osid.inquiry.AuditSearchOrder auditSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an audit query from an inspector. 
     *
     *  @param  auditQueryInspector an audit query inspector 
     *  @return the audit query 
     *  @throws org.osid.NullArgumentException <code> auditQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> auditQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.AuditQuery getAuditQueryFromInspector(org.osid.inquiry.AuditQueryInspector auditQueryInspector);
}
