//
// org.osid.inquiry.InquiryForm
//
//     The OSID Java specification for org.osid.inquiry.InquiryForm.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN INPUT OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inquiry;


/**
 *  <p>This is the form for creating and updating <code> Inquiries. </code> 
 *  Like all <code> OsidForm </code> objects, various data elements may be set 
 *  here for use in the create and update methods in the <code> 
 *  InquiryAdminSession. </code> For each data element that may be set, 
 *  metadata may be examined to provide display hints or data constraints. 
 *  </p>
 */

public interface InquiryForm
    extends org.osid.OsidRuleForm,
            org.osid.OsidSubjugateableForm {


    /**
     *  Gets the metadata for the question. 
     *
     *  @return metadata for the question 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getQuestionMetadata();


    /**
     *  Sets the question. 
     *
     *  @param  question the new question 
     *  @throws org.osid.InvalidArgumentException <code> question </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> question </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setQuestion(String question);


    /**
     *  Removes the question. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearQuestion();


    /**
     *  Gets the metadata for the required flag. 
     *
     *  @return metadata for the required flag 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getRequiredMetadata();


    /**
     *  Sets the required flag. 
     *
     *  @param  required <code> true </code> is the inquiry requires a 
     *          response, <code> false </code> if optional 
     *  @throws org.osid.InvalidArgumentException <code> required </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setRequired(boolean required);


    /**
     *  Removes the required flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRequired();


    /**
     *  Gets the metadata for the affirmation required flag. 
     *
     *  @return metadata for the required flag 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getAffirmationRequiredMetadata();


    /**
     *  Sets the affirmation required flag. 
     *
     *  @param  required <code> true </code> if a positive response is 
     *          required, <code> false </code> if a negative response is also 
     *          acceptable 
     *  @throws org.osid.InvalidArgumentException <code> required </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setAffirmationRequired(boolean required);


    /**
     *  Removes the affirmation required flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAffirmationRequired();


    /**
     *  Gets the metadata for the needs one response flag. 
     *
     *  @return metadata for the needs one response flag 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getNeedsOneResponseMetadata();


    /**
     *  Sets the needs one response flag. 
     *
     *  @param  one <code> true </code> if only one effective response is 
     *          needed,, <code> false </code> if the inquiry should be 
     *          performed each time 
     *  @throws org.osid.InvalidArgumentException <code> one </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setNeedsOneResponse(boolean one);


    /**
     *  Removes the needs one response flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearNeedsOneResponse();


    /**
     *  Gets the <code> InquiryFormRecord </code> corresponding to the given 
     *  inquiry record <code> Type. </code> 
     *
     *  @param  inquiryRecordType an inquiry record type 
     *  @return the inquiry form record 
     *  @throws org.osid.NullArgumentException <code> inquiryRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(inquiryRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.records.InquiryFormRecord getInquiryFormRecord(org.osid.type.Type inquiryRecordType)
        throws org.osid.OperationFailedException;
}
