//
// org.osid.inquiry.InquiryLookupSession
//
//     The OSID Java specification for org.osid.inquiry.InquiryLookupSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN INPUT OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inquiry;


/**
 *  <p>This session provides methods for retrieving <code> Inquiry </code> 
 *  objects. The <code> Inquiry </code> represents a fixed connection between 
 *  two <code> Inquiries. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated inquest view: All inquiry methods in this session 
 *      operate, retrieve and pertain to inquiries defined explicitly in the 
 *      current inquest. Using an isolated view is useful for managing <code> 
 *      Inquiries </code> with the <code> InquiryAdminSession. </code> </li> 
 *      <li> federated inquest view: All inquiry methods in this session 
 *      operate, retrieve and pertain to all inquiries defined in this inquest 
 *      and any other inquiries implicitly available in this inquest through 
 *      inquest inheritence. </li> 
 *      <li> active inquiry view: active inquiries are returned from methods 
 *      in this session </li> 
 *      <li> any status inquiry view: active and inactive inquiries are 
 *      returned from methods in this session </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedInquestView() </code> and <code> 
 *  useIsolatedInquestView() </code> behave as a radio group and one should be 
 *  selected before invoking any lookup methods. </p>
 */

public interface InquiryLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Inquest </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Inquest Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getInquestId();


    /**
     *  Gets the <code> Inquest </code> associated with this session. 
     *
     *  @return the inquest 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.Inquest getInquest()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Inquiry </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupInquiries();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeInquiryView();


    /**
     *  A complete view of the <code> Inquiry </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryInquiryView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include inquiries in inquests which are children of this inquest in 
     *  the inquest hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedInquestView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this inquest only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedInquestView();


    /**
     *  Only active inquiries are returned by methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveInquiryView();


    /**
     *  All inquiries of any active or inactive status are returned by methods 
     *  in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusInquiryView();


    /**
     *  Gets the <code> Inquiry </code> specified by its <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Inquiry </code> may have a different <code> Id </code> than requested, 
     *  such as the case where a duplicate <code> Id </code> was assigned to 
     *  an <code> Inquiry </code> and retained for compatibility. 
     *  
     *  In active mode, inquiries are returned that are currently active. In 
     *  any status mode, both active and inactive inquiries are returned. 
     *
     *  @param  inquiryId <code> Id </code> of the <code> Inquiry </code> 
     *  @return the inquiry 
     *  @throws org.osid.NotFoundException <code> inquiryId </code> not found 
     *  @throws org.osid.NullArgumentException <code> inquiryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.inquiry.Inquiry getInquiry(org.osid.id.Id inquiryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> InquiryList </code> corresponding to the given <code> 
     *  IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  inquiries specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Inquiries </code> may be omitted from the list and 
     *  may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In active mode, inquiries are returned that are currently active. In 
     *  any status mode, both active and inactive inquiries are returned. 
     *
     *  @param  inquiryIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Inquiry </code> list 
     *  @throws org.osid.NotFoundException an <code> Id </code> was not found 
     *  @throws org.osid.NullArgumentException <code> inquiryIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.InquiryList getInquiriesByIds(org.osid.id.IdList inquiryIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> InquiryList </code> corresponding to the given inquiry 
     *  genus <code> Type </code> which does not include inquiries of genus 
     *  types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  inquiries or an error results. Otherwise, the returned list may 
     *  contain only those inquiries that are accessible through this session. 
     *  
     *  In active mode, inquiries are returned that are currently active. In 
     *  any status mode, both active and inactive inquiries are returned. 
     *
     *  @param  inquiryGenusType an inquiry genus type 
     *  @return the returned <code> Inquiry </code> list 
     *  @throws org.osid.NullArgumentException <code> inquiryGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.InquiryList getInquiriesByGenusType(org.osid.type.Type inquiryGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> InquiryList </code> corresponding to the given inquiry 
     *  genus <code> Type </code> and include any additional inquiries with 
     *  genus types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  inquiries or an error results. Otherwise, the returned list may 
     *  contain only those inquiries that are accessible through this session. 
     *  
     *  In effective mode, inquiries are returned that are currently 
     *  effective. In any effective mode, effective inquiries and those 
     *  currently expired are returned. 
     *
     *  @param  inquiryGenusType an inquiry genus type 
     *  @return the returned <code> Inquiry </code> list 
     *  @throws org.osid.NullArgumentException <code> inquiryGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.InquiryList getInquiriesByParentGenusType(org.osid.type.Type inquiryGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> InquiryList </code> containing the given inquiry record 
     *  <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  inquiries or an error results. Otherwise, the returned list may 
     *  contain only those inquiries that are accessible through this session. 
     *  
     *  In active mode, inquiries are returned that are currently active. In 
     *  any status mode, both active and inactive inquiries are returned. 
     *
     *  @param  inquiryRecordType an inquiry record type 
     *  @return the returned <code> Inquiry </code> list 
     *  @throws org.osid.NullArgumentException <code> inquiryRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.InquiryList getInquiriesByRecordType(org.osid.type.Type inquiryRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of inquiries for a supplied audit. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  inquiries or an error results. Otherwise, the returned list may 
     *  contain only those inquiries that are accessible through this session. 
     *  
     *  In active mode, inquiries are returned that are currently active. In 
     *  any status mode, both active and inactive inquiries are returned. 
     *
     *  @param  auditId an audit <code> Id </code> 
     *  @return the returned <code> Inquiry </code> list 
     *  @throws org.osid.NullArgumentException <code> auditId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.InquiryList getInquiriesForAudit(org.osid.id.Id auditId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Inquiries. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  inquiries or an error results. Otherwise, the returned list may 
     *  contain only those inquiries that are accessible through this session. 
     *  
     *  In active mode, inquiries are returned that are currently active. In 
     *  any status mode, both active and inactive inquiries are returned. 
     *
     *  @return a list of <code> Inquiries </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.InquiryList getInquiries()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
