//
// org.osid.inquiry.InquiryProxyManager
//
//     The OSID Java specification for org.osid.inquiry.InquiryProxyManager.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN INPUT OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inquiry;


/**
 *  <p>The inquiry proxy manager provides access to inquiry sessions and 
 *  provides interoperability tests for various aspects of this service. 
 *  Methods in this manager pass a <code> Proxy </code> for passing 
 *  information from server environments. The sessions included in this 
 *  manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> AcknowledgementSession: </code> a session for getting and 
 *      responding to inquiries for authenticated agent </li> 
 *      <li> <code> AcknowledgementNotificationSession: </code> a session for 
 *      subscribing to new inquiries for the authenticated agent </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> InquiryLookupSession: </code> a session to retrieve 
 *      inquiries </li> 
 *      <li> <code> InquiryQuerySession: </code> a session to query for 
 *      inquiriess </li> 
 *      <li> <code> InquirySearchSession: </code> a session to search for 
 *      inquiries </li> 
 *      <li> <code> InquiryAdminSession: </code> a session to create and 
 *      delete inquiries </li> 
 *      <li> <code> InquiryNotificationSession: </code> a session to receive 
 *      notifications pertaining to inquiry changes </li> 
 *      <li> <code> InquiryInquestSession: </code> a session to look up 
 *      inquiry inquest mappings </li> 
 *      <li> <code> InquiryInquestAssignmentSession: </code> a session to 
 *      manage inquiry to inquest mappings </li> 
 *      <li> <code> InquirySmartInquestSession: </code> a session to manage 
 *      dynamic inquests of inquiries </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> AuditLookupSession: </code> a session to retrieve audits 
 *      </li> 
 *      <li> <code> AuditQuerySession: </code> a session to query for audits 
 *      </li> 
 *      <li> <code> AuditSearchSession: </code> a session to search for audits 
 *      </li> 
 *      <li> <code> AuditAdminSession: </code> a session to create and delete 
 *      audits </li> 
 *      <li> <code> AuditNotificationSession: </code> a session to receive 
 *      notifications pertaining to audit changes </li> 
 *      <li> <code> AuditInquestSession: </code> a session to look up audit 
 *      inquest mappings </li> 
 *      <li> <code> AuditInquestAssignmentSession: </code> a session to manage 
 *      audit to inquest mappings </li> 
 *      <li> <code> AuditSmartInquestSession: </code> a session to manage 
 *      dynamic inquests of audits </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> ResponseLookupSession: </code> a session to retrieve 
 *      responses </li> 
 *      <li> <code> ResponseQuerySession: </code> a session to query for 
 *      responses </li> 
 *      <li> <code> ResponseSearchSession: </code> a session to search for 
 *      responses </li> 
 *      <li> <code> ResponseAdminSession: </code> a session to create and 
 *      delete responses </li> 
 *      <li> <code> ResponseNotificationSession: </code> a session to receive 
 *      notifications pertaining to response changes </li> 
 *      <li> <code> ResponseInquestsSession: </code> a session to look up 
 *      response inquests mappings </li> 
 *      <li> <code> ResponseInquestAssignmentSession: </code> a session to 
 *      manage response to inquest mappings </li> 
 *      <li> <code> ResponseSmartInquestSession: </code> a session to manage 
 *      dynamic inquests of responses </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> InquestLookupSession: </code> a session to retrieve 
 *      inquests </li> 
 *      <li> <code> InquestQuerySession: </code> a session to search for 
 *      inquests </li> 
 *      <li> <code> InquestSearchSession: </code> a session to search for 
 *      inquests </li> 
 *      <li> <code> InquestAdminSession: </code> a session to create and 
 *      delete inquests </li> 
 *      <li> <code> InquestNotificationSession: </code> a session to receive 
 *      notifications pertaining to inquest changes </li> 
 *      <li> <code> InquestHierarchySession: </code> a session to traverse a 
 *      hierarchy of inquest </li> 
 *      <li> <code> InquestHierarchyDesignSession: </code> a session to manage 
 *      an inquest hierarchy </li> 
 *  </ul>
 *  
 */

public interface InquiryProxyManager
    extends org.osid.OsidProxyManager,
            org.osid.inquiry.InquiryProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the 
     *  acknowledgement service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AcknowledgementSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAcknowledgemen() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAcknowledgemen() </code> is <code> true. </code> 
     */

    public org.osid.inquiry.AcknowledgementSession getAcknowledgementSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the 
     *  acknowledgement service for the given inquest. 
     *
     *  @param  inquestId the <code> Id </code> of the <code> Inquest </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AcknowledgementSession </code> 
     *  @throws org.osid.NotFoundException no <code> Inquest </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> inquestId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAcknowledgemen() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAcknowledgemen() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.inquiry.AcknowledgementSession getAcknowledgementSessionForInquest(org.osid.id.Id inquestId, 
                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the 
     *  acknowledgement notification service for resources related to the 
     *  authenticated agent. 
     *
     *  @param  inquiryReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return an <code> AcknowledgementNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> inquiryReceiver </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAcknowledgemenNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAcknowledgemenNotification() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.inquiry.AcknowledgementNotificationSession getAcknowledgementNotificationSession(org.osid.inquiry.InquiryReceiver inquiryReceiver, 
                                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the 
     *  acknowledgement notification service for the given inquest for 
     *  resources related to the authenticated agent. 
     *
     *  @param  inquiryReceiver the notification callback 
     *  @param  inquestId the <code> Id </code> of the <code> Inquest </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AcknowledgementNotificationSession </code> 
     *  @throws org.osid.NotFoundException no inquest found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> inquiryReceiver, 
     *          inquestId </code> or <code> proxy </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAcknowledgemenNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAcknowledgementNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.inquiry.AcknowledgementNotificationSession getAcknowledgementNotificationSessionForInquest(org.osid.inquiry.InquiryReceiver inquiryReceiver, 
                                                                                                               org.osid.id.Id inquestId, 
                                                                                                               org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the inquiry lookup 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> InquiryLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsInquiryLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInquiryLookup() </code> is <code> true. </code> 
     */

    public org.osid.inquiry.InquiryLookupSession getInquiryLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the inquiry lookup 
     *  service for the given inquest. 
     *
     *  @param  inquestId the <code> Id </code> of the <code> Inquest </code> 
     *  @param  proxy a proxy 
     *  @return an <code> InquiryLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Inquest </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> inquestId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsInquiryLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInquiryLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.inquiry.InquiryLookupSession getInquiryLookupSessionForInquest(org.osid.id.Id inquestId, 
                                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the inquiry query 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> InquiryQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsInquiryQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInquiryQuery() </code> is <code> true. </code> 
     */

    public org.osid.inquiry.InquiryQuerySession getInquiryQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the inquiry query 
     *  service for the given inquest. 
     *
     *  @param  inquestId the <code> Id </code> of the <code> Inquest </code> 
     *  @param  proxy a proxy 
     *  @return an <code> InquiryQuerySession </code> 
     *  @throws org.osid.NotFoundException no inquest found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> inquestId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsInquiryQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInquiryQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.inquiry.InquiryQuerySession getInquiryQuerySessionForInquest(org.osid.id.Id inquestId, 
                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the inquiry search 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> InquirySearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsInquirySearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInquirySearch() </code> is <code> true. </code> 
     */

    public org.osid.inquiry.InquirySearchSession getInquirySearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the inquiry search 
     *  service for the given inquest. 
     *
     *  @param  inquestId the <code> Id </code> of the <code> Inquest </code> 
     *  @param  proxy a proxy 
     *  @return an <code> InquirySearchSession </code> 
     *  @throws org.osid.NotFoundException no inquest found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> inquestId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsInquirySearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInquirySearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.inquiry.InquirySearchSession getInquirySearchSessionForInquest(org.osid.id.Id inquestId, 
                                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the inquiry 
     *  administration service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> InquiryAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsInquiryAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInquiryAdmin() </code> is <code> true. </code> 
     */

    public org.osid.inquiry.InquiryAdminSession getInquiryAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the inquiry 
     *  administration service for the given inquest. 
     *
     *  @param  inquestId the <code> Id </code> of the inquest 
     *  @param  proxy a proxy 
     *  @return an <code> InquiryAdminSession </code> 
     *  @throws org.osid.NotFoundException no inquest found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> inquestId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsInquiryAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInquiryAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.inquiry.InquiryAdminSession getInquiryAdminSessionForInquest(org.osid.id.Id inquestId, 
                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the inquiry 
     *  notification service. 
     *
     *  @param  inquiryReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return an <code> InquiryNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> inquiryReceiver </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInquiryNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInquiryNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.InquiryNotificationSession getInquiryNotificationSession(org.osid.inquiry.InquiryReceiver inquiryReceiver, 
                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the inquiry 
     *  notification service for the given inquest. 
     *
     *  @param  inquiryReceiver the notification callback 
     *  @param  inquestId the <code> Id </code> of the <code> Inquest </code> 
     *  @param  proxy a proxy 
     *  @return an <code> InquiryNotificationSession </code> 
     *  @throws org.osid.NotFoundException no inquest found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> inquiryReceiver, 
     *          inquestId, </code> or <code> proxy </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInquiryNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInquiryNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.inquiry.InquiryNotificationSession getInquiryNotificationSessionForInquest(org.osid.inquiry.InquiryReceiver inquiryReceiver, 
                                                                                               org.osid.id.Id inquestId, 
                                                                                               org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup inquiry/inquest 
     *  mappings. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> InquiryInquestSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInquiryInquest() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInquiryInquest() </code> is <code> true. </code> 
     */

    public org.osid.inquiry.InquiryInquestSession getInquiryInquestSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning 
     *  inquiries to inquests. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> InquiryInquestAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInquiryInquestAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInquiryInquestAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.InquiryInquestAssignmentSession getInquiryInquestAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage inquiry smart inquests. 
     *
     *  @param  inquestId the <code> Id </code> of the <code> Inquest </code> 
     *  @param  proxy a proxy 
     *  @return an <code> InquirySmartInquestSession </code> 
     *  @throws org.osid.NotFoundException no inquest found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> inquestId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInquirySmartInquest() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInquirySmartInquest() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.InquirySmartInquestSession getInquirySmartInquestSession(org.osid.id.Id inquestId, 
                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the audit lookup 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuditLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAuditLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuditLookup() </code> is <code> true. </code> 
     */

    public org.osid.inquiry.AuditLookupSession getAuditLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the audit lookup 
     *  service for the given inquest. 
     *
     *  @param  inquestId the <code> Id </code> of the <code> Inquest </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuditLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Inquest </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> inquestId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAuditLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuditLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.inquiry.AuditLookupSession getAuditLookupSessionForInquest(org.osid.id.Id inquestId, 
                                                                               org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the audit query 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuditQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAuditQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuditQuery() </code> is <code> true. </code> 
     */

    public org.osid.inquiry.AuditQuerySession getAuditQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the audit query 
     *  service for the given inquest. 
     *
     *  @param  inquestId the <code> Id </code> of the <code> Inquest </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuditQuerySession </code> 
     *  @throws org.osid.NotFoundException no inquest found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> inquestId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAuditQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuditQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.inquiry.AuditQuerySession getAuditQuerySessionForInquest(org.osid.id.Id inquestId, 
                                                                             org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the audit search 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuditSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAuditSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuditSearch() </code> is <code> true. </code> 
     */

    public org.osid.inquiry.AuditSearchSession getAuditSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the audit search 
     *  service for the given inquest. 
     *
     *  @param  inquestId the <code> Id </code> of the <code> Inquest </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuditSearchSession </code> 
     *  @throws org.osid.NotFoundException no inquest found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> inquestId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAuditSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuditSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.inquiry.AuditSearchSession getAuditSearchSessionForInquest(org.osid.id.Id inquestId, 
                                                                               org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the audit 
     *  administration service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuditAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAuditAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuditAdmin() </code> is <code> true. </code> 
     */

    public org.osid.inquiry.AuditAdminSession getAuditAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the audit 
     *  administration service for the given inquest. 
     *
     *  @param  inquestId the <code> Id </code> of the inquest 
     *  @param  proxy a proxy 
     *  @return an <code> AuditAdminSession </code> 
     *  @throws org.osid.NotFoundException no inquest found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> inquestId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAuditAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuditAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.inquiry.AuditAdminSession getAuditAdminSessionForInquest(org.osid.id.Id inquestId, 
                                                                             org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the audit 
     *  notification service. 
     *
     *  @param  auditReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return an <code> AuditNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> auditReceiver </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuditNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuditNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.AuditNotificationSession getAuditNotificationSession(org.osid.inquiry.AuditReceiver auditReceiver, 
                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the audit 
     *  notification service for the given inquest. 
     *
     *  @param  auditReceiver the notification callback 
     *  @param  inquestId the <code> Id </code> of the <code> Inquest </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuditNotificationSession </code> 
     *  @throws org.osid.NotFoundException no inquest found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> auditReceiver, inquestId 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuditNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuditNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.inquiry.AuditNotificationSession getAuditNotificationSessionForInquest(org.osid.inquiry.AuditReceiver auditReceiver, 
                                                                                           org.osid.id.Id inquestId, 
                                                                                           org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup audit/inquest mappings. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuditInquestSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAuditInquest() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuditInquest() </code> is <code> true. </code> 
     */

    public org.osid.inquiry.AuditInquestSession getAuditInquestSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning audits 
     *  to inquests. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuditInquestAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuditInquestAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuditInquestAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.AuditInquestAssignmentSession getAuditInquestAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage audit smart inquests. 
     *
     *  @param  inquestId the <code> Id </code> of the inquest 
     *  @param  proxy a proxy 
     *  @return an <code> AuditSmartInquestSession </code> 
     *  @throws org.osid.NotFoundException no inquest found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> inquestId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuditSmartInquest() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuditSmartInquest() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.AuditSmartInquestSession getAuditSmartInquestSession(org.osid.id.Id inquestId, 
                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the response 
     *  lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ResponseLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResponseLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResponseLookup() </code> is <code> true. </code> 
     */

    public org.osid.inquiry.ResponseLookupSession getResponseLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the response 
     *  lookup service for the given inquest. 
     *
     *  @param  inquestId the <code> Id </code> of the inquest 
     *  @param  proxy a proxy 
     *  @return a <code> ResponseLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Inquest </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> inquestId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResponseLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResponseLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.ResponseLookupSession getResponseLookupSessionForInquest(org.osid.id.Id inquestId, 
                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the response query 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ResponseQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsResponseQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResponseQuery() </code> is <code> true. </code> 
     */

    public org.osid.inquiry.ResponseQuerySession getResponseQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the response query 
     *  service for the given inquest. 
     *
     *  @param  inquestId the <code> Id </code> of the <code> Inquest </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ResponseQuerySession </code> 
     *  @throws org.osid.NotFoundException no inquest found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> inquestId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsResponseQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResponseQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.ResponseQuerySession getResponseQuerySessionForInquest(org.osid.id.Id inquestId, 
                                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the response 
     *  search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ResponseSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResponseSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResponseSearch() </code> is <code> true. </code> 
     */

    public org.osid.inquiry.ResponseSearchSession getResponseSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the response 
     *  search service for the given inquest. 
     *
     *  @param  inquestId the <code> Id </code> of the <code> Inquest </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ResponseSearchSession </code> 
     *  @throws org.osid.NotFoundException no inquest found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> inquestId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResponseSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResponseSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.ResponseSearchSession getResponseSearchSessionForInquest(org.osid.id.Id inquestId, 
                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the response 
     *  administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ResponseAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsResponseAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResponseAdmin() </code> is <code> true. </code> 
     */

    public org.osid.inquiry.ResponseAdminSession getResponseAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the response 
     *  administration service for the given input. 
     *
     *  @param  inputId the <code> Id </code> of the <code> Input </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ResponseAdminSession </code> 
     *  @throws org.osid.NotFoundException no input found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> inputId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsResponseAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResponseAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.ResponseAdminSession getResponseAdminSessionForInput(org.osid.id.Id inputId, 
                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the response 
     *  notification service. 
     *
     *  @param  responseReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> ResponseNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> responseReceiver </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResponseNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResponseNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.ResponseNotificationSession getResponseNotificationSession(org.osid.inquiry.ResponseReceiver responseReceiver, 
                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the response 
     *  notification service for the given inquest. 
     *
     *  @param  responseReceiver the notification callback 
     *  @param  inquestId the <code> Id </code> of the <code> Inquest </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ResponseNotificationSession </code> 
     *  @throws org.osid.NotFoundException no inquest found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> responseReceiver, 
     *          </code> <code> inquestId </code> or <code> proxy </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResponseNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResponseNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.ResponseNotificationSession getResponseNotificationSessionForInquest(org.osid.inquiry.ResponseReceiver responseReceiver, 
                                                                                                 org.osid.id.Id inquestId, 
                                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup response/inquest 
     *  mappings. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ResponseInquestSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResponseInquest() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResponseInquest() </code> is <code> true. </code> 
     */

    public org.osid.inquiry.ResponseInquestSession getResponseInquestSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning 
     *  responses to inquests. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ResponseInquestAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResponseInquestAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResponseInquestAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.inquiry.ResponseInquestAssignmentSession getResponseInquestAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage locatin smart inquests. 
     *
     *  @param  inquestId the <code> Id </code> of the <code> Inquest </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ResponseSmartInquestSession </code> 
     *  @throws org.osid.NotFoundException no inquest found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> inquestId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResponseSmartInquest() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResponseSmartInquest() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.ResponseSmartInquestSession getResponseSmartInquestSession(org.osid.id.Id inquestId, 
                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the inquest lookup 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> InquestLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsInquestLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInquestLookup() </code> is <code> true. </code> 
     */

    public org.osid.inquiry.InquestLookupSession getInquestLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the inquest query 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> InquestQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsInquestQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInquestQuery() </code> is <code> true. </code> 
     */

    public org.osid.inquiry.InquestQuerySession getInquestQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the inquest search 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> InquestSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsInquestSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInquestSearch() </code> is <code> true. </code> 
     */

    public org.osid.inquiry.InquestSearchSession getInquestSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the inquest 
     *  administrative service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> InquestAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsInquestAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInquestAdmin() </code> is <code> true. </code> 
     */

    public org.osid.inquiry.InquestAdminSession getInquestAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the inquest 
     *  notification service. 
     *
     *  @param  inquestReceiver the notification callback 
     *  @param  proxy an proxy 
     *  @return an <code> InquestNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> inquestReceiver </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInquestNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInquestNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.InquestNotificationSession getInquestNotificationSession(org.osid.inquiry.InquestReceiver inquestReceiver, 
                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the inquest 
     *  hierarchy service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> InquestHierarchySession </code> for inquests 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInquestHierarchy() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInquestHierarchy() </code> is <code> true. </code> 
     */

    public org.osid.inquiry.InquestHierarchySession getInquestHierarchySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the inquest 
     *  hierarchy design service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> HierarchyDesignSession </code> for inquests 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInquestHierarchyDesign() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInquestHierarchyDesign() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.InquestHierarchyDesignSession getInquestHierarchyDesignSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> InquiryBatchProxyManager. </code> 
     *
     *  @return an <code> InquiryBatchProxyManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsInquiryBatch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInquiryBatch() </code> is <code> true. </code> 
     */

    public org.osid.inquiry.batch.InquiryBatchProxyManager getInquiryBatchProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> InquiryRulesProxyManager. </code> 
     *
     *  @return an <code> InquiryRulesProxyManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsInquiryRules() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInquiryRules() </code> is <code> true. </code> 
     */

    public org.osid.inquiry.rules.InquiryRulesProxyManager getInquiryRulesProxyManager()
        throws org.osid.OperationFailedException;
}
