//
// org.osid.inquiry.InquirySmartInquestSession
//
//     The OSID Java specification for org.osid.inquiry.InquirySmartInquestSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN INPUT OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inquiry;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. Sn <code> InquiryQuery </code> can be retrieved from this 
 *  session and inquestped to this <code> Inquest </code> to create a virtual 
 *  collection of <code> Inquiries. </code> The inquiries may be sequenced 
 *  using the <code> InquirySearchOrder </code> from this session. </p> 
 *  
 *  <p> This <code> Inquest </code> has a default query that matches any 
 *  inquiry and a default search order that specifies no sequencing. The 
 *  queries may be examined using an <code> InquiryQueryInspector. </code> The 
 *  query may be modified by converting the inspector back to an <code> 
 *  InquiryQuery. </code> </p>
 */

public interface InquirySmartInquestSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Inquest </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Inquest Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getInquestId();


    /**
     *  Gets the <code> Inquest </code> associated with this session. 
     *
     *  @return the inquest 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.Inquest getInquest()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart inquests. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart inquest management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartInquests();


    /**
     *  Gets an inquiry query. 
     *
     *  @return the inquiry query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.InquiryQuery getInquiryQuery();


    /**
     *  Gets an inquiry search order. 
     *
     *  @return the inquiry search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.InquirySearchOrder getInquirySearchOrder();


    /**
     *  Applies an inquiry query to this inquest. 
     *
     *  @param  inquiryQuery the inquiry query 
     *  @throws org.osid.NullArgumentException <code> inquiryQuery </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> inquiryQuery </code> not 
     *          of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyInquiryQuery(org.osid.inquiry.InquiryQuery inquiryQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an inquiry query inspector for this inquest. 
     *
     *  @return the inquiry query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.InquiryQueryInspector inspectInquiryQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies an inquiry search order to this inquest. 
     *
     *  @param  inquirySearchOrder the inquiry search order 
     *  @throws org.osid.NullArgumentException <code> inquirySearchOrder 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> inquirySearchOrder 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyInquirySequencing(org.osid.inquiry.InquirySearchOrder inquirySearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an inquiry query from an inspector. 
     *
     *  @param  inquiryQueryInspector an inquiry query inspector 
     *  @return the inquiry query 
     *  @throws org.osid.NullArgumentException <code> inquiryQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> inquiryQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.InquiryQuery getInquiryQueryFromInspector(org.osid.inquiry.InquiryQueryInspector inquiryQueryInspector);
}
