//
// org.osid.inquiry.batch.ResponseBatchAdminSession
//
//     The OSID Java specification for org.osid.inquiry.batch.ResponseBatchAdminSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inquiry.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Responses </code> in 
 *  bulk. The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Response, </code> a <code> ResponseForm </code> is requested using <code> 
 *  getResponseFormsForCreate() </code> specifying the desired inquiry, 
 *  resource, and record <code> Types </code> or none if no record <code> 
 *  Types </code> are needed. Each of the returned <code> ResponseForms 
 *  </code> will indicate that it is to be used with a create operation and 
 *  can be used to examine metdata or validate data prior to creation. Once a 
 *  <code> ResponseForm </code> is submiited to a create operation, it cannot 
 *  be reused with another create operation unless the first operation was 
 *  unsuccessful. Each <code> ResponseForm </code> corresponds to an attempted 
 *  transaction. </p> 
 *  
 *  <p> The <code> ResponseForms </code> returned from <code> 
 *  getResponseFormsForCreate() </code> may be linked to the originating 
 *  request through the peer <code> Ids </code> of the <code> ResponseForm. 
 *  </code> In the case where there may be duplicates, any <code> ResponseForm 
 *  </code> of the same peer <code> Ids </code> may be used for a create 
 *  operation. </p> 
 *  
 *  <p> Once a batch of <code> ResponseForm </code> are submitted for create, 
 *  a <code> CreateResponse </code> is returned for each <code> ResponseForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire create operation are returned from <code> createResponses(), 
 *  </code> errors specific to an individual <code> ResponseForm </code> are 
 *  indicated in the corresponding <code> CreateResponse. </code> <code> 
 *  CreateResponses </code> may be linked to the originating <code> 
 *  ResponseForm </code> through the <code> ResponseForm </code> <code> Id 
 *  </code> . </p> 
 *  
 *  <p> For updates, <code> ResponseForms </code> are requested to the <code> 
 *  Response </code> <code> Id </code> that is to be updated using <code> 
 *  getResponseFormsForUpdate() </code> where the reference <code> Id </code> 
 *  in the <code> ResponseForm </code> may be used to link the request. 
 *  Similarly, the <code> ResponseForm </code> has metadata about the data 
 *  that can be updated and it can perform validation before submitting the 
 *  update. The <code> ResponseForm </code> can only be used once for a 
 *  successful update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> ResponseForms </code> are submitted for update, 
 *  an <code> UpdateResponse </code> is returned for each <code> ResponseForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire update operation are returned from <code> updateResponses(), 
 *  </code> errors specific to an individual <code> ResponseForm </code> are 
 *  indicated in the corresponding <code> UpdateResponse. </code> <code> 
 *  UpdateResponses </code> may be linked to the originating <code> 
 *  ResponseForm </code> through the <code> ResponseForm </code> <code> Id. 
 *  </code> </p> 
 *  
 *  <p> The delete operations delete <code> Responses </code> in bulk. To 
 *  unmap a <code> Response </code> from the current <code> Inquiry, </code> 
 *  the <code> ResponseInquiryAssignmentSession </code> should be used. These 
 *  delete operations attempt to remove the <code> Response </code> itself 
 *  thus removing it from all known <code> Inquiry </code> catalogs. Bulk 
 *  delete operations return the results in <code> DeleteResponses. </code> 
 *  </p>
 */

public interface ResponseBatchAdminSession
    extends org.osid.inquiry.ResponseAdminSession {


    /**
     *  Gets the response forms for creating a bunch of new responses. A form 
     *  is retrieved for each inquiry and resource pair. 
     *
     *  @param  peers list of inquiry resource peers 
     *  @param  responseRecordTypes array of response record types to be 
     *          included in each create operation or an empty list if none 
     *  @return the response forms 
     *  @throws org.osid.NotFoundException an <code> inquiryId </code> or 
     *          <code> resourceId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> peers </code> or <code> 
     *          responseRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.batch.ResponseBatchFormList getResponseFormsForCreate(org.osid.inquiry.batch.ResponsePeerList peers, 
                                                                                  org.osid.type.Type[] responseRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Responses. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  responseForms the response forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> responseForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createResponses(org.osid.inquiry.batch.ResponseBatchFormList responseForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the response forms for updating an existing set of responses. A 
     *  new response form should be requested for each update transaction. 
     *
     *  @param  responseIds the <code> Ids </code> of the <code> Response 
     *          </code> 
     *  @return the response form 
     *  @throws org.osid.NotFoundException a <code> responseId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> responseIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.batch.ResponseBatchFormList getResponseFormsForUpdate(org.osid.id.IdList responseIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing responses. This method returns an error if the entire 
     *  operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  responseForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> responseForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateResponses(org.osid.inquiry.batch.ResponseBatchFormList responseForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Responses </code> in this <code> Inquiry. </code> 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllResponses()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes responses for the given <code> Ids. </code> 
     *
     *  @param  responseIds the <code> Ids </code> of the responses to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> responseIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteResponses(org.osid.id.IdList responseIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes responses for the given <code> Inquiry. </code> 
     *
     *  @param  inquiryId an inquiry <code> Id </code> 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> inquiryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteResponsesForInquiry(org.osid.id.Id inquiryId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes responses for the given <code> Resource. </code> 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteResponsesForResource(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes responses expired before the given date. 
     *
     *  @param  date a date 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteIneffectiveResponsesByDate(org.osid.calendaring.DateTime date)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Response </code> for the purpose 
     *  of creating compatibility. The primary <code> Id </code> of the <code> 
     *  Response </code> is determined by the provider. The new <code> Id 
     *  </code> is an alias to the primary <code> Id. </code> If the alias is 
     *  a pointer to another response, it is reassigned to the given response 
     *  <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasResponses(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
