//
// org.osid.inquiry.rules.AuditEnablerSearchSession
//
//     The OSID Java specification for org.osid.inquiry.rules.AuditEnablerSearchSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN INQUIRY OF CONTRACT, TORT OR OTHERWISE, 
//     ARISING FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inquiry.rules;


/**
 *  <p>This session provides methods for searching among <code> AuditEnabler 
 *  </code> objects. The search query is constructed using the <code> 
 *  AuditEnableryQuery. </code> </p> 
 *  
 *  <p> <code> getAuditEnablersByQuery() </code> is the basic search method 
 *  and returns a list of <code> AuditEnablers. </code> A more advanced search 
 *  may be performed with <code> getAuditEnablersBySearch(). </code> It 
 *  accepts an <code> AuditEnablerSearch </code> in addition to the query for 
 *  the purpose of specifying additional options affecting the entire search, 
 *  such as inquiry. <code> getAuditEnablersBySearch() </code> returns an 
 *  <code> AuditEnablerSearchResults </code> that can be used to access the 
 *  resulting <code> AuditEnablerList </code> or be used to perform a search 
 *  within the result set through <code> AuditEnablerSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated inquest view: searches include audit enablers in 
 *      inquests of which this inquest is an ancestor in the inquest hierarchy 
 *      </li> 
 *      <li> isolated inquest view: searches are restricted to audit enablers 
 *      in this inquest </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> AuditEnablers </code> may have a query record indicated by 
 *  their respective record types. The query record is accessed via the <code> 
 *  AuditEnablerQuery. </code> </p>
 */

public interface AuditEnablerSearchSession
    extends org.osid.inquiry.rules.AuditEnablerQuerySession {


    /**
     *  Gets an audit enabler search. 
     *
     *  @return the audit enabler search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.rules.AuditEnablerSearch getAuditEnablerSearch();


    /**
     *  Gets an audit enabler search order. The <code> AuditEnablerSearchOrder 
     *  </code> is supplied to an <code> AuditEnablerSearch </code> to specify 
     *  the ordering of results. 
     *
     *  @return the audit enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.rules.AuditEnablerSearchOrder getAuditEnablerSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  auditEnablerQuery the audit enabler query 
     *  @param  auditEnablerSearch the audit enabler search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> auditEnablerQuery 
     *          </code> or <code> auditEnablerSearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> auditEnablerQuery </code> 
     *          or <code> auditEnablerSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.rules.AuditEnablerSearchResults getAuditEnablersBySearch(org.osid.inquiry.rules.AuditEnablerQuery auditEnablerQuery, 
                                                                                     org.osid.inquiry.rules.AuditEnablerSearch auditEnablerSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an audit enabler query from an inspector. The inspector is 
     *  available from an <code> AuditEnablerSearchResults. </code> 
     *
     *  @param  auditEnablerQueryInspector an audit enabler query inspector 
     *  @return the audit enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          auditEnablerQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          auditEnablerQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.rules.AuditEnablerQuery getAuditEnablerQueryFromInspector(org.osid.inquiry.rules.AuditEnablerQueryInspector auditEnablerQueryInspector);
}
