//
// org.osid.inquiry.rules.InquiryEnablerLookupSession
//
//     The OSID Java specification for org.osid.inquiry.rules.InquiryEnablerLookupSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN INQUIRY OF CONTRACT, TORT OR OTHERWISE, 
//     ARISING FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inquiry.rules;


/**
 *  <p>This session provides methods for retrieving <code> InquiryEnablers. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated inquest view: All inquiry enabler methods in this 
 *      session operate, retrieve and pertain to inquiry enablers defined 
 *      explicitly in the current inquest. Using an isolated view is useful 
 *      for managing <code> InquiryEnablers </code> with the <code> 
 *      InquiryEnablerAdminSession. </code> </li> 
 *      <li> federated inquest view: All inquiry enabler methods in this 
 *      session operate, retrieve and pertain to all inquiry enablers defined 
 *      in this inquest and any other inquiry enablers implicitly available in 
 *      this inquest through inquest inheritence. </li> 
 *      <li> activee inquiry enabler view: All inquiry enabler lookup methods 
 *      return active inquiry enablers. </li> 
 *      <li> any status inquiry enabler view: inquiry enablers of any active 
 *      or inactive status are returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedDistributorView() </code> and <code> 
 *  useIsolatedDistributorView() </code> behave as a radio group and one 
 *  should be selected before invoking the methods in this session. </p>
 */

public interface InquiryEnablerLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Inquest </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Inquest Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getInquestId();


    /**
     *  Gets the <code> Inquest </code> associated with this session. 
     *
     *  @return the inquest 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.Inquest getInquest()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> InquiryEnablers </code> lookups. 
     *  A return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupInquiryEnablers();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeInquiryEnablerView();


    /**
     *  A complete view of the <code> InquiryEnabler </code> returns is 
     *  desired. Methods will return what is requested or result in an error. 
     *  This view is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryInquiryEnablerView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include inquiry enablers in inquests which are children of this 
     *  inquest in the inquest hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedInquestView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this inquest only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedInquestView();


    /**
     *  Only active inquiry enablers are returned by methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveInquiryEnablerView();


    /**
     *  All active and inactive inquiry enablers are returned by methods in 
     *  this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusInquiryEnablerView();


    /**
     *  Gets the <code> InquiryEnabler </code> specified by its <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  InquiryEnabler </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to an <code> InquiryEnabler </code> and retained for 
     *  compatibility. 
     *  
     *  In active mode, inquiry enablers are returned that are currently 
     *  active. In any status mode, active and inactive inquiry enablers are 
     *  returned. 
     *
     *  @param  inquiryEnablerId <code> Id </code> of the <code> 
     *          InquiryEnabler </code> 
     *  @return the inquiry enabler 
     *  @throws org.osid.NotFoundException <code> inquiryEnablerId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> inquiryEnablerId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.inquiry.rules.InquiryEnabler getInquiryEnabler(org.osid.id.Id inquiryEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> InquiryEnablerList </code> corresponding to the given 
     *  <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  inquiry enablers specified in the <code> Id </code> list, in the order 
     *  of the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> InquiryEnablers </code> may be omitted from the 
     *  list and may present the elements in any order including returning a 
     *  unique set. 
     *  
     *  In active mode, inquiry enablers are returned that are currently 
     *  active. In any status mode, active and inactive inquiry enablers are 
     *  returned. 
     *
     *  @param  inquiryEnablerIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> InquiryEnabler </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> inquiryEnablerIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.rules.InquiryEnablerList getInquiryEnablersByIds(org.osid.id.IdList inquiryEnablerIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> InquiryEnablerList </code> corresponding to the given 
     *  inquiry enabler genus <code> Type </code> which does not include 
     *  inquiry enablers of genus types derived from the specified <code> 
     *  Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  inquiry enablers or an error results. Otherwise, the returned list may 
     *  contain only those inquiry enablers that are accessible through this 
     *  session. 
     *  
     *  In active mode, inquiry enablers are returned that are currently 
     *  active. In any status mode, active and inactive inquiry enablers are 
     *  returned. 
     *
     *  @param  inquiryEnablerGenusType an inquiry enabler genus type 
     *  @return the returned <code> InquiryEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> inquiryEnablerGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.rules.InquiryEnablerList getInquiryEnablersByGenusType(org.osid.type.Type inquiryEnablerGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> InquiryEnablerList </code> corresponding to the given 
     *  inquiry enabler genus <code> Type </code> and include any additional 
     *  inquiry enablers with genus types derived from the specified <code> 
     *  Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  inquiry enablers or an error results. Otherwise, the returned list may 
     *  contain only those inquiry enablers that are accessible through this 
     *  session. 
     *  
     *  In active mode, inquiry enablers are returned that are currently 
     *  active. In any status mode, active and inactive inquiry enablers are 
     *  returned. 
     *
     *  @param  inquiryEnablerGenusType an inquiry enabler genus type 
     *  @return the returned <code> InquiryEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> inquiryEnablerGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.rules.InquiryEnablerList getInquiryEnablersByParentGenusType(org.osid.type.Type inquiryEnablerGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> InquiryEnablerList </code> containing the given inquiry 
     *  enabler record <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  inquiry enablers or an error results. Otherwise, the returned list may 
     *  contain only those inquiry enablers that are accessible through this 
     *  session. 
     *  
     *  In active mode, inquiry enablers are returned that are currently 
     *  active. In any status mode, active and inactive inquiry enablers are 
     *  returned. 
     *
     *  @param  inquiryEnablerRecordType an inquiry enabler record type 
     *  @return the returned <code> InquiryEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> inquiryEnablerRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.rules.InquiryEnablerList getInquiryEnablersByRecordType(org.osid.type.Type inquiryEnablerRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> InquiryEnablerList </code> that are effective for the 
     *  entire given date range but not confined to the date range. <code> 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  inquiry enablers or an error results. Otherwise, the returned list may 
     *  contain only those inquiry enablers that are accessible through this 
     *  session. 
     *  
     *  In active mode, inquiry enablers are returned that are currently 
     *  active in addition to being effective during the given date range. In 
     *  any status mode, active and inactive inquiry enablers are returned. 
     *
     *  @param  from a start date 
     *  @param  to an end date 
     *  @return the returned <code> InquiryEnabler </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.rules.InquiryEnablerList getInquiryEnablersOnDate(org.osid.calendaring.DateTime from, 
                                                                              org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> InquiryEnablerList </code> that are effective for the 
     *  entire given date range but not confined to the date range and 
     *  evaluated against the given agent. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  inquiry enablers or an error results. Otherwise, the returned list may 
     *  contain only those inquiry enablers that are accessible through this 
     *  session. 
     *  
     *  In active mode, inquiry enablers are returned that are currently 
     *  active in addition to being effective during the given date range. In 
     *  any status mode, active and inactive inquiry enablers are returned. 
     *
     *  @param  agentId an agent Id 
     *  @param  from a start date 
     *  @param  to an end date 
     *  @return the returned <code> InquiryEnabler </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> agentId, from, </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.rules.InquiryEnablerList getInquiryEnablersOnDateWithAgent(org.osid.id.Id agentId, 
                                                                                       org.osid.calendaring.DateTime from, 
                                                                                       org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> InquiryEnablers. </code> 
     *  
     *  In plenary mode, the returned list contains all known inquiry enablers 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those inquiry enablers that are accessible through this session. 
     *  
     *  In active mode, inquiry enablers are returned that are currently 
     *  active. In any status mode, active and inactive inquiry enablers are 
     *  returned. 
     *
     *  @return the returned <code> InquiryEnabler </code> list 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.rules.InquiryEnablerList getInquiryEnablers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
