//
// org.osid.inquiry.rules.InquiryEnablerNotificationSession
//
//     The OSID Java specification for org.osid.inquiry.rules.InquiryEnablerNotificationSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN INQUIRY OF CONTRACT, TORT OR OTHERWISE, 
//     ARISING FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inquiry.rules;


/**
 *  <p>This session defines methods to receive notifications on adds/changes 
 *  to <code> InquiryEnabler </code> objects in this <code> Inquest. </code> 
 *  This also includes existing <code> InquiryEnablers </code> that may appear 
 *  or disappear due to changes in the <code> Inquest </code> hierarchy, This 
 *  session is intended for consumers needing to synchronize their state with 
 *  this service without the use of polling. Notifications are cancelled when 
 *  this session is closed. </p> 
 *  
 *  <p> The two views defined in this session correspond to the views in the 
 *  <code> InquiryEnablerLookupSession. </code> </p>
 */

public interface InquiryEnablerNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Inquest </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Inquest Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getInquestId();


    /**
     *  Gets the <code> Inquest </code> associated with this session. 
     *
     *  @return the inquest 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.Inquest getInquest()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can register for <code> InquiryEnabler </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForInquiryEnablerNotifications();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include enablers in inquests which are children of this inquest in the 
     *  inquest hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedInquestView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts notifications to this inquest only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedInquestView();


    /**
     *  Reliable notifications are desired. In reliable mode, notifications 
     *  are to be acknowledged using <code> 
     *  acknowledgeInquiryEnablerNotification() </code> . 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void reliableInquiryEnablerNotifications();


    /**
     *  Unreliable notifications are desired. In unreliable mode, 
     *  notifications do not need to be acknowledged. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void unreliableInquiryEnablerNotifications();


    /**
     *  Acknowledge an inquiru enabler notification. 
     *
     *  @param  notificationId the <code> Id </code> of the notification 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void acknowledgeInquiryEnablerNotification(org.osid.id.Id notificationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new inquiry enablers. <code> 
     *  InquiryEnablerReceiver.newInquiryEnablers() </code> is invoked when a 
     *  new <code> InquiryEnabler </code> appears in this inquest. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewInquiryEnablers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated inquiry enablers. <code> 
     *  InquiryEnablerReceiver.changedInquiryEnablers() </code> is invoked 
     *  when an inquiry enabler in this inquest is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedInquiryEnablers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated inquiry enabler. <code> 
     *  ProvisionableReceiver.changedInquiryEnablers() </code> is invoked when 
     *  the specified inquiry enabler in this inquest is changed. 
     *
     *  @param  inquiryEnablerId the <code> Id </code> of the <code> 
     *          InquiryEnabler </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> inquiryEnablerId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedInquiryEnabler(org.osid.id.Id inquiryEnablerId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted inquiry enablers. <code> 
     *  InquiryEnablerReceiver.deletedInquiryEnablers() </code> is invoked 
     *  when an inquiry enabler is deleted or removed from this inquest. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedInquiryEnablers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted inquiry enabler. <code> 
     *  InquiryEnablerReceiver.deletedInquiryEnablers() </code> is invoked 
     *  when the specified inquiry enabler is deleted or removed from this 
     *  inquest. 
     *
     *  @param  inquiryEnablerId the <code> Id </code> of the <code> 
     *          InquiryEnabler </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> inquiryEnablerId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedInquiryEnabler(org.osid.id.Id inquiryEnablerId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
