//
// org.osid.inquiry.rules.InquiryEnablerRuleLookupSession
//
//     The OSID Java specification for org.osid.inquiry.rules.InquiryEnablerRuleLookupSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN INQUIRY OF CONTRACT, TORT OR OTHERWISE, 
//     ARISING FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inquiry.rules;


/**
 *  <p>This session provides methods to retrieve <code> InquiryEnabler </code> 
 *  to <code> Inquiry </code> mappings. An <code> Inquiry </code> with 
 *  multiple <code> InquiryEnablers </code> means any positive rule evaluation 
 *  across the enablers result in an effective <code> Inquiry. </code> </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated inquest view: All methods in this session operate, 
 *      retrieve and pertain inquiry enablers defined explicitly in the 
 *      current inquest </li> 
 *      <li> federated inquest view: All methods in this session operate, 
 *      retrieve and pertain to all inquiry enablers defined in this inquest 
 *      and any other inquiry enablers implicitly available in this inquest 
 *      through inquest inheritence. </li> 
 *  </ul>
 *  
 */

public interface InquiryEnablerRuleLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Inquest </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Inquest Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getInquestId();


    /**
     *  Gets the <code> Inquest </code> associated with this session. 
     *
     *  @return the inquest 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.Inquest getInquest()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform lookups of inquiry enabler/inquiry 
     *  mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known lookup 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if looking up mappings is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupInquiryEnablerRules();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeInquiryEnablerRuleView();


    /**
     *  A complete view of the <code> InquiryEnabler </code> and <code> 
     *  Inquiry </code> returns is desired. Methods will return what is 
     *  requested or result in an error. This view is used when greater 
     *  precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryInquiryEnablerRuleView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include inquiry enablers in inquests which are children of this 
     *  inquest in the inquest hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedInquestView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this inquest only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedInquestView();


    /**
     *  Gets the <code> InquiryEnabler Id </code> associated with an <code> 
     *  Inquiry. </code> 
     *
     *  @param  inquiryId <code> Id </code> of the <code> Inquiry </code> 
     *  @return the inquiry enabler <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> inquiryId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> inquiry </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getInquiryEnablerIdsForInquiry(org.osid.id.Id inquiryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> InquiryEnablers </code> associated with an <code> 
     *  Inquiry. </code> 
     *
     *  @param  inquiryId <code> Id </code> of the <code> Inquiry </code> 
     *  @return the inquiry enablers 
     *  @throws org.osid.NotFoundException <code> inquiryId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> inquiryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.rules.InquiryEnablerList getInquiryEnablersForInquiry(org.osid.id.Id inquiryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Inquiry </code> <code> Ids </code> mapped to an <code> 
     *  InquiryEnabler. </code> 
     *
     *  @param  inquiryEnablerId <code> Id </code> of an <code> InquiryEnabler 
     *          </code> 
     *  @return list of inquiry <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> inquiryEnablerId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> inquiryEnablerId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getInquiryIdsForInquiryEnabler(org.osid.id.Id inquiryEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Inquiries </code> mapped to an <code> InquiryEnabler. 
     *  </code> 
     *
     *  @param  inquiryEnablerId <code> Id </code> of an <code> InquiryEnabler 
     *          </code> 
     *  @return list of inquiries 
     *  @throws org.osid.NotFoundException <code> inquiryEnablerId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> inquiryEnablerId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.InquiryList getInquiriesForInquiryEnabler(org.osid.id.Id inquiryEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
