//
// org.osid.inquiry.rules.InquiryEnablerSearchSession
//
//     The OSID Java specification for org.osid.inquiry.rules.InquiryEnablerSearchSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN INQUIRY OF CONTRACT, TORT OR OTHERWISE, 
//     ARISING FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inquiry.rules;


/**
 *  <p>This session provides methods for searching among <code> InquiryEnabler 
 *  </code> objects. The search query is constructed using the <code> 
 *  InquiryEnableryQuery. </code> </p> 
 *  
 *  <p> <code> getInquiryEnablersByQuery() </code> is the basic search method 
 *  and returns a list of <code> InquiryEnablers. </code> A more advanced 
 *  search may be performed with <code> getInquiryEnablersBySearch(). </code> 
 *  It accepts an <code> InquiryEnablerSearch </code> in addition to the query 
 *  for the purpose of specifying additional options affecting the entire 
 *  search, such as inquiry. <code> getInquiryEnablersBySearch() </code> 
 *  returns an <code> InquiryEnablerSearchResults </code> that can be used to 
 *  access the resulting <code> InquiryEnablerList </code> or be used to 
 *  perform a search within the result set through <code> 
 *  InquiryEnablerSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated inquest view: searches include inquiry enablers in 
 *      inquests of which this inquest is an ancestor in the inquest hierarchy 
 *      </li> 
 *      <li> isolated inquest view: searches are restricted to inquiry 
 *      enablers in this inquest </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> InquiryEnablers </code> may have a query record indicated by 
 *  their respective record types. The query record is accessed via the <code> 
 *  InquiryEnablerQuery. </code> </p>
 */

public interface InquiryEnablerSearchSession
    extends org.osid.inquiry.rules.InquiryEnablerQuerySession {


    /**
     *  Gets an inquiry enabler search. 
     *
     *  @return the inquiry enabler search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.rules.InquiryEnablerSearch getInquiryEnablerSearch();


    /**
     *  Gets an inquiry enabler search order. The <code> 
     *  InquiryEnablerSearchOrder </code> is supplied to an <code> 
     *  InquiryEnablerSearch </code> to specify the ordering of results. 
     *
     *  @return the inquiry enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.rules.InquiryEnablerSearchOrder getInquiryEnablerSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  inquiryEnablerQuery the inquiry enabler query 
     *  @param  inquiryEnablerSearch the inquiry enabler search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> inquiryEnablerQuery 
     *          </code> or <code> inquiryEnablerSearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> inquiryEnablerQuery 
     *          </code> or <code> inquiryEnablerSearch </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.rules.InquiryEnablerSearchResults getInquiryEnablersBySearch(org.osid.inquiry.rules.InquiryEnablerQuery inquiryEnablerQuery, 
                                                                                         org.osid.inquiry.rules.InquiryEnablerSearch inquiryEnablerSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an inquiry enabler query from an inspector. The inspector is 
     *  available from an <code> InquiryEnablerSearchResults. </code> 
     *
     *  @param  inquiryEnablerQueryInspector an inquiry enabler query 
     *          inspector 
     *  @return the inquiry enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          inquiryEnablerQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          inquiryEnablerQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.rules.InquiryEnablerQuery getInquiryEnablerQueryFromInspector(org.osid.inquiry.rules.InquiryEnablerQueryInspector inquiryEnablerQueryInspector);
}
