//
// org.osid.inquiry.rules.InquiryRulesProfile
//
//     The OSID Java specification for org.osid.inquiry.rules.InquiryRulesProfile.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN INQUIRY OF CONTRACT, TORT OR OTHERWISE, 
//     ARISING FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inquiry.rules;


/**
 *  <p>The inquiry rules profile describes the interoperability among inquiry 
 *  rules services. </p>
 */

public interface InquiryRulesProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any broker federation is exposed. Federation is exposed when 
     *  a specific broker may be identified, selected and used to create a 
     *  lookup or admin session. Federation is not exposed when a set of 
     *  brokers appears as a single broker. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if looking up inquiry enablers is supported. 
     *
     *  @return <code> true </code> if inquiry enabler lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInquiryEnablerLookup();


    /**
     *  Tests if querying inquiry enablers is supported. 
     *
     *  @return <code> true </code> if inquiry enabler query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInquiryEnablerQuery();


    /**
     *  Tests if searching inquiry enablers is supported. 
     *
     *  @return <code> true </code> if inquiry enabler search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInquiryEnablerSearch();


    /**
     *  Tests if an inquiry enabler administrative service is supported. 
     *
     *  @return <code> true </code> if inquiry enabler administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInquiryEnablerAdmin();


    /**
     *  Tests if an inquiry enabler notification service is supported. 
     *
     *  @return <code> true </code> if inquiry enabler notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInquiryEnablerNotification();


    /**
     *  Tests if an inquiry enabler inquest lookup service is supported. 
     *
     *  @return <code> true </code> if an inquiry enabler inquest lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInquiryEnablerInquest();


    /**
     *  Tests if an inquiry enabler inquest service is supported. 
     *
     *  @return <code> true </code> if inquiry enabler inquest assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInquiryEnablerInquestAssignment();


    /**
     *  Tests if an inquiry enabler inquest lookup service is supported. 
     *
     *  @return <code> true </code> if an inquiry enabler inquest service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInquiryEnablerSmartInquest();


    /**
     *  Tests if looking up audit enablers is supported. 
     *
     *  @return <code> true </code> if audit enabler lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuditEnablerLookup();


    /**
     *  Tests if querying audit enablers is supported. 
     *
     *  @return <code> true </code> if audit enabler query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuditEnablerQuery();


    /**
     *  Tests if searching audit enablers is supported. 
     *
     *  @return <code> true </code> if audit enabler search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuditEnablerSearch();


    /**
     *  Tests if an audit enabler administrative service is supported. 
     *
     *  @return <code> true </code> if audit enabler administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuditEnablerAdmin();


    /**
     *  Tests if an audit enabler notification service is supported. 
     *
     *  @return <code> true </code> if audit enabler notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuditEnablerNotification();


    /**
     *  Tests if an audit enabler inquest lookup service is supported. 
     *
     *  @return <code> true </code> if an audit enabler inquest lookup service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuditEnablerInquest();


    /**
     *  Tests if an audit enabler inquest service is supported. 
     *
     *  @return <code> true </code> if audit enabler inquest assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuditEnablerInquestAssignment();


    /**
     *  Tests if an audit enabler inquest lookup service is supported. 
     *
     *  @return <code> true </code> if an audit enabler inquest service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuditEnablerSmartInquest();


    /**
     *  Tests if an audit enabler rule lookup service is supported. 
     *
     *  @return <code> true </code> if an audit enabler rule lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuditEnablerRuleLookup();


    /**
     *  Tests if an audit enabler rule application service is supported. 
     *
     *  @return <code> true </code> if audit enabler rule application service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuditEnablerRuleApplication();


    /**
     *  Gets the supported <code> InquiryEnabler </code> record types. 
     *
     *  @return a list containing the supported <code> InquiryEnabler </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getInquiryEnablerRecordTypes();


    /**
     *  Tests if the given <code> InquiryEnabler </code> record type is 
     *  supported. 
     *
     *  @param  inquiryEnablerRecordType a <code> Type </code> indicating an 
     *          <code> InquiryEnabler </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> inquiryEnablerRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInquiryEnablerRecordType(org.osid.type.Type inquiryEnablerRecordType);


    /**
     *  Gets the supported <code> InquiryEnabler </code> search record types. 
     *
     *  @return a list containing the supported <code> InquiryEnabler </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getInquiryEnablerSearchRecordTypes();


    /**
     *  Tests if the given <code> InquiryEnabler </code> search record type is 
     *  supported. 
     *
     *  @param  inquiryEnablerSearchRecordType a <code> Type </code> 
     *          indicating an <code> InquiryEnabler </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          inquiryEnablerSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInquiryEnablerSearchRecordType(org.osid.type.Type inquiryEnablerSearchRecordType);


    /**
     *  Gets the supported <code> AuditEnabler </code> record types. 
     *
     *  @return a list containing the supported <code> AuditEnabler </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAuditEnablerRecordTypes();


    /**
     *  Tests if the given <code> AuditEnabler </code> record type is 
     *  supported. 
     *
     *  @param  auditEnablerRecordType a <code> Type </code> indicating an 
     *          <code> AuditEnabler </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> auditEnablerRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuditEnablerRecordType(org.osid.type.Type auditEnablerRecordType);


    /**
     *  Gets the supported <code> AuditEnabler </code> search record types. 
     *
     *  @return a list containing the supported <code> AuditEnabler </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAuditEnablerSearchRecordTypes();


    /**
     *  Tests if the given <code> AuditEnabler </code> search record type is 
     *  supported. 
     *
     *  @param  auditEnablerSearchRecordType a <code> Type </code> indicating 
     *          an <code> AuditEnabler </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          auditEnablerSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuditEnablerSearchRecordType(org.osid.type.Type auditEnablerSearchRecordType);
}
