//
// org.osid.installation.DepotSearchSession
//
//     The OSID Java specification for org.osid.installation.DepotSearchSession.
//
// Copyright (C) 2006 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.installation;


/**
 *  <p>This session provides methods for searching among <code> Depot </code> 
 *  objects. The search query is constructed using the <code> DepotQuery. 
 *  </code> </p> 
 *  
 *  <p> <code> getDepotsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Depot </code> objects.A more advanced search may 
 *  be performed with <code> getDepotsBySearch(). </code> It accepts a <code> 
 *  DepotSearch </code> in addition to the query for the purpose of specifying 
 *  additional options affecting the entire search, such as ordering. <code> 
 *  getDepotsBySearch() </code> returns a <code> DepotSearchResults </code> 
 *  that can be used to access the resulting <code> DepotList </code> or be 
 *  used to perform a search within the result set through <code> DepotSearch. 
 *  </code> </p> 
 *  
 *  <p> Depots may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> DepotQuery. </code> 
 *  </p>
 */

public interface DepotSearchSession
    extends org.osid.installation.DepotQuerySession {


    /**
     *  Gets a depot search. 
     *
     *  @return a depot search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.DepotSearch getDepotSearch();


    /**
     *  Gets a depot search order. The <code> DepotSearchOrder </code> is 
     *  supplied to a <code> DepotSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the depot search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.DepotSearchOrder getDepotSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  depotQuery the depot query 
     *  @param  depotSearch the depot search 
     *  @return the depot search results 
     *  @throws org.osid.NullArgumentException <code> depotQuery </code> or 
     *          <code> depotSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> depotQuery </code> or 
     *          <code> depotSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.DepotSearchResults getDepotsBySearch(org.osid.installation.DepotQuery depotQuery, 
                                                                      org.osid.installation.DepotSearch depotSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a depot query from an inspector. The inspector is available from 
     *  a <code> DepotSearchResults. </code> 
     *
     *  @param  depotQueryInspector a depot query inspector 
     *  @return the depot query 
     *  @throws org.osid.NullArgumentException <code> depotQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> depotQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.DepotQuery getDepotQueryFromInspector(org.osid.installation.DepotQueryInspector depotQueryInspector);
}
