//
// org.osid.installation.InstallationProfile
//
//     The OSID Java specification for org.osid.installation.InstallationProfile.
//
// Copyright (C) 2006 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.installation;


/**
 *  <p>The <code> InstallationProfile </code> describes the interoperability 
 *  among installation services. </p>
 */

public interface InstallationProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if federation is visible. 
     *
     *  @return <code> true </code> if visible federation is supported <code> 
     *          , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if an installation lookup service is supported. 
     *
     *  @return true if installation lookup is supported, false otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInstallationLookup();


    /**
     *  Tests if an installation query service is supported. 
     *
     *  @return true if installation query is supported, false otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInstallationQuery();


    /**
     *  Tests if an installation search service is supported. 
     *
     *  @return <code> true </code> if installation search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInstallationSearch();


    /**
     *  Tests if an installation management service is supported. 
     *
     *  @return <code> true </code> if package management is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInstallationManagement();


    /**
     *  Tests if an installation update service is supported. 
     *
     *  @return <code> true </code> if package update is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInstallationUpdate();


    /**
     *  Tests if installation notification is supported. Messages may be sent 
     *  when installations are installed or removed. 
     *
     *  @return <code> true </code> if installation notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInstallationNotification();


    /**
     *  Tests if a site lookup service is supported. 
     *
     *  @return true if site lookup is supported, false otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSiteLookup();


    /**
     *  Tests if a package lookup service is supported. A package lookup 
     *  service defines methods to access packages. 
     *
     *  @return true if package lookup is supported, false otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPackageLookup();


    /**
     *  Tests if querying packages is supported. 
     *
     *  @return <code> true </code> if packages query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPackageQuery();


    /**
     *  Tests if a package search service is supported. 
     *
     *  @return <code> true </code> if package search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPackageSearch();


    /**
     *  Tests if a package administrative service is supported. 
     *
     *  @return <code> true </code> if package admin is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPackageAdmin();


    /**
     *  Tests if package notification is supported. Messages may be sent when 
     *  packages are created, modified, or deleted. 
     *
     *  @return <code> true </code> if package notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPackageNotification();


    /**
     *  Tests if a package to depot lookup session is available. 
     *
     *  @return <code> true </code> if package depot lookup session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPackageDepot();


    /**
     *  Tests if a package to depot assignment session is available. 
     *
     *  @return <code> true </code> if package depot assignment is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPackageDepotAssignment();


    /**
     *  Tests if package smart depots are available. 
     *
     *  @return <code> true </code> if package smart depots are supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPackageSmartDepot();


    /**
     *  Tests if a depot lookup service is supported. 
     *
     *  @return <code> true </code> if depot lookup is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDepotLookup();


    /**
     *  Tests if a depot query service is supported. 
     *
     *  @return <code> true </code> if depot query is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDepotQuery();


    /**
     *  Tests if a depot search service is supported. 
     *
     *  @return <code> true </code> if depot search is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDepotSearch();


    /**
     *  Tests if a depot administrative service is supported. 
     *
     *  @return <code> true </code> if depot admin is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDepotAdmin();


    /**
     *  Tests if depot notification is supported. Messages may be sent when 
     *  depots are created, modified, or deleted. 
     *
     *  @return <code> true </code> if depot notification is supported <code> 
     *          , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDepotNotification();


    /**
     *  Tests if a depot hierarchy traversal is supported. 
     *
     *  @return <code> true </code> if a depot hierarchy traversal is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDepotHierarchy();


    /**
     *  Tests if depot hierarchy design is supported. 
     *
     *  @return <code> true </code> if a depot hierarchy design is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDepotHierarchyDesign();


    /**
     *  Tests if an installation batch service is supported. 
     *
     *  @return <code> true </code> if an installation batch service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInstallationBatch();


    /**
     *  Gets the supported <code> Installation </code> record types. 
     *
     *  @return a list containing the supported <code> Installation </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getInstallationRecordTypes();


    /**
     *  Tests if the given <code> Installation </code> record type is 
     *  supported. 
     *
     *  @param  installationRecordType a <code> Type </code> indicating an 
     *          <code> Installation </code> record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> installationRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInstallationRecordType(org.osid.type.Type installationRecordType);


    /**
     *  Gets the supported <code> Installation </code> search record types. 
     *
     *  @return a list containing the supported <code> Installation </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getInstallationSearchRecordTypes();


    /**
     *  Tests if the given <code> Installation </code> search record type is 
     *  supported. 
     *
     *  @param  installationSearchRecordType a <code> Type </code> indicating 
     *          an <code> Installation </code> search record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          installationSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInstallationSearchRecordType(org.osid.type.Type installationSearchRecordType);


    /**
     *  Gets the supported <code> Site </code> record types. 
     *
     *  @return a list containing the supported <code> Site </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSiteRecordTypes();


    /**
     *  Tests if the given <code> Site </code> record type is supported. 
     *
     *  @param  siteRecordType a <code> Type </code> indicating a <code> Site 
     *          </code> record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> siteRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSiteRecordType(org.osid.type.Type siteRecordType);


    /**
     *  Gets the supported <code> Package </code> record types. 
     *
     *  @return a list containing the supported <code> Package </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getPackageRecordTypes();


    /**
     *  Tests if the given <code> Package </code> record type is supported. 
     *
     *  @param  packageRecordType a <code> Type </code> indicating a <code> 
     *          Package </code> record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> packageRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPackageRecordType(org.osid.type.Type packageRecordType);


    /**
     *  Gets the supported <code> Package </code> search record types. 
     *
     *  @return a list containing the supported <code> Package </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getPackageSearchRecordTypes();


    /**
     *  Tests if the given <code> Package </code> search record type is 
     *  supported. 
     *
     *  @param  packageSearchRecordType a <code> Type </code> indicating a 
     *          <code> Package </code> search record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> packageSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPackageSearchRecordType(org.osid.type.Type packageSearchRecordType);


    /**
     *  Gets the supported <code> InstallationContent </code> record types. 
     *
     *  @return a list containing the supported <code> InstallationContent 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getInstallationContentRecordTypes();


    /**
     *  Tests if the given <code> InstallationContent </code> record type is 
     *  supported. 
     *
     *  @param  installationContentRecordType a <code> Type </code> indicating 
     *          an <code> InstallationContent </code> record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          installationContentRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInstallationContentRecordType(org.osid.type.Type installationContentRecordType);


    /**
     *  Gets the supported <code> Depot </code> record types. 
     *
     *  @return a list containing the supported <code> Depot </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getDepotRecordTypes();


    /**
     *  Tests if the given <code> Depot </code> record type is supported. 
     *
     *  @param  depotRecordType a <code> Type </code> indicating a <code> 
     *          Depot </code> type 
     *  @return <code> true </code> if the given depot record <code> Type 
     *          </code> is supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> depotRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDepotRecordType(org.osid.type.Type depotRecordType);


    /**
     *  Gets the supported depot search record types. 
     *
     *  @return a list containing the supported <code> Depot </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getDepotSearchRecordTypes();


    /**
     *  Tests if the given depot search record type is supported. 
     *
     *  @param  depotSearchRecordType a <code> Type </code> indicating a 
     *          <code> Depot </code> search record type 
     *  @return <code> true </code> if the given search record <code> Type 
     *          </code> is supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> depotSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDepotSearchRecordType(org.osid.type.Type depotSearchRecordType);
}
