//
// org.osid.installation.InstallationQuery
//
//     The OSID Java specification for org.osid.installation.InstallationQuery.
//
// Copyright (C) 2006 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.installation;


/**
 *  <p>This is the query for searching installations. Each method match 
 *  request produces an <code> AND </code> term while multiple invocations of 
 *  a method produces a nested <code> OR. </code> </p>
 */

public interface InstallationQuery
    extends org.osid.OsidObjectQuery {


    /**
     *  Sets the site <code> Id </code> for this query. 
     *
     *  @param  siteId a site <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> siteId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSiteId(org.osid.id.Id siteId, boolean match);


    /**
     *  Clears the site <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSiteIdTerms();


    /**
     *  Tests if a <code> SiteQuery </code> is available for querying sites. 
     *
     *  @return <code> true </code> if a site query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSiteQuery();


    /**
     *  Gets the query for a site. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the site query 
     *  @throws org.osid.UnimplementedException <code> supportsSiteQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSiteQuery() </code> is <code> true. </code> 
     */

    public org.osid.installation.SiteQuery getSiteQuery();


    /**
     *  Clears the site query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSiteTerms();


    /**
     *  Sets the package <code> Id </code> for this query. 
     *
     *  @param  packageId a package <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> packageId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchPackageId(org.osid.id.Id packageId, boolean match);


    /**
     *  Clears the package <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPackageIdTerms();


    /**
     *  Tests if a <code> PackageQuery </code> is available for querying 
     *  agents. 
     *
     *  @return <code> true </code> if a package query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPackageQuery();


    /**
     *  Gets the query for a package. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the package query 
     *  @throws org.osid.UnimplementedException <code> supportsPackageQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPackageQuery() </code> is <code> true. </code> 
     */

    public org.osid.installation.PackageQuery getPackageQuery();


    /**
     *  Clears the package query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPackageTerms();


    /**
     *  Matches the install date between the given times inclusive. 
     *
     *  @param  from starting range 
     *  @param  to ending range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is <code> 
     *          less than from </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchInstallDate(org.osid.calendaring.DateTime from, 
                                 org.osid.calendaring.DateTime to, 
                                 boolean match);


    /**
     *  Clears the install date query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearInstallDateTerms();


    /**
     *  Sets the agent <code> Id </code> for this query. 
     *
     *  @param  agentId an agent <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> agentId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAgentId(org.osid.id.Id agentId, boolean match);


    /**
     *  Clears the agent <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAgentIdTerms();


    /**
     *  Tests if an <code> AgentQuery </code> is available for querying 
     *  agents. 
     *
     *  @return <code> true </code> if an agent query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAgentQuery();


    /**
     *  Gets the query for an agent. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the agent query 
     *  @throws org.osid.UnimplementedException <code> supportsAgentQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAgentQuery() </code> is <code> true. </code> 
     */

    public org.osid.authentication.AgentQuery getAgentQuery();


    /**
     *  Clears the agent query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAgentTerms();


    /**
     *  Matches the last checked date between the given times inclusive. 
     *
     *  @param  from starting range 
     *  @param  to ending range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is <code> 
     *          less than from </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchLastCheckDate(org.osid.calendaring.DateTime from, 
                                   org.osid.calendaring.DateTime to, 
                                   boolean match);


    /**
     *  Clears the last check date query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLastCheckDateTerms();


    /**
     *  Gets the installation query record corresponding to the given <code> 
     *  Installation </code> record <code> Type. </code> Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @param  installationRecordType an installation query record type 
     *  @return the installation query record 
     *  @throws org.osid.NullArgumentException <code> installationRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(installationRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.records.InstallationQueryRecord getInstallationQueryRecord(org.osid.type.Type installationRecordType)
        throws org.osid.OperationFailedException;
}
