//
// org.osid.installation.InstallationSearchOrder
//
//     The OSID Java specification for org.osid.installation.InstallationSearchOrder.
//
// Copyright (C) 2006 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.installation;


/**
 *  <p>An interface for specifying the ordering of search results. </p>
 */

public interface InstallationSearchOrder
    extends org.osid.OsidObjectSearchOrder {


    /**
     *  Specified a preference for ordering results by the site. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderBySite(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a <code> SiteSearchOrder </code> is available for sites. 
     *
     *  @return <code> true </code> if a site search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSiteSearchOrder();


    /**
     *  Gets the search order for a site. 
     *
     *  @return the site search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSiteSearchOrder() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSiteSearchOrder() </code> is <code> true. </code> 
     */

    public org.osid.installation.SiteSearchOrder getSiteSearchOrder();


    /**
     *  Specified a preference for ordering results by the package. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByPackage(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a <code> PackageSearchOrder </code> is available for 
     *  packages. 
     *
     *  @return <code> true </code> if a package search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPackageSearchOrder();


    /**
     *  Gets the search order for a package. 
     *
     *  @return the package search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPackageSearchOrder() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPackageSearchOrder() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.installation.PackageSearchOrder getPackageSearchOrder();


    /**
     *  Specified a preference for ordering results by the install date. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByInstallDate(org.osid.SearchOrderStyle style);


    /**
     *  Specified a preference for ordering results by the agent. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByAgent(org.osid.SearchOrderStyle style);


    /**
     *  Tests if an <code> AgenteSearchOrder </code> is available for agents. 
     *
     *  @return <code> true </code> if an agent search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAgentSearchOrder();


    /**
     *  Gets the search order for an agent. 
     *
     *  @return the agent search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAgentSearchOrder() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAgentSearchOrder() </code> is <code> true. </code> 
     */

    public org.osid.authentication.AgentSearchOrder getAgentSearchOrder();


    /**
     *  Specified a preference for ordering results by the last checked date. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByLastCheckDate(org.osid.SearchOrderStyle style);


    /**
     *  Gets the installation search order record corresponding to the given 
     *  installation record <code> Type. </code> Multiple retrievals return 
     *  the same underlying object. 
     *
     *  @param  installationRecordType an installation record type 
     *  @return the installation search order record 
     *  @throws org.osid.NullArgumentException <code> installationRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(installationRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.records.InstallationSearchOrderRecord getInstallationSearchOrderRecord(org.osid.type.Type installationRecordType)
        throws org.osid.OperationFailedException;
}
