//
// org.osid.installation.PackageSearchOrder
//
//     The OSID Java specification for org.osid.installation.PackageSearchOrder.
//
// Copyright (C) 2006 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.installation;


/**
 *  <p>An interface for specifying the ordering of search results. </p>
 */

public interface PackageSearchOrder
    extends org.osid.OsidObjectSearchOrder,
            org.osid.OsidSourceableSearchOrder {


    /**
     *  Specified a preference for ordering results by the version. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByVersion(org.osid.SearchOrderStyle style);


    /**
     *  Specified a preference for ordering results by the copyright. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByCopyright(org.osid.SearchOrderStyle style);


    /**
     *  Specified a preference for ordering results by the license 
     *  acknowledgement flag. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByRequiresLicenseAcknowledgement(org.osid.SearchOrderStyle style);


    /**
     *  Specified a preference for ordering results by the creator. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByCreator(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a <code> ResourceSearchOrder </code> is available for creator 
     *  resources. 
     *
     *  @return <code> true </code> if a creator resource search order is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCreatorSearchOrder();


    /**
     *  Gets the search order for a creator resource. 
     *
     *  @return the resource search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCreatorSearchOrder() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCreatorSearchOrder() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resource.ResourceSearchOrder getCreatorSearchOrder();


    /**
     *  Specified a preference for ordering results by the release date. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByReleaseDate(org.osid.SearchOrderStyle style);


    /**
     *  Specified a preference for ordering results by the url. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByURL(org.osid.SearchOrderStyle style);


    /**
     *  Gets the package search order record corresponding to the given 
     *  package record <code> Type. </code> Multiple retrievals return the 
     *  same underlying object. 
     *
     *  @param  packageRecordType a package record type 
     *  @return the package search order record 
     *  @throws org.osid.NullArgumentException <code> packageRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(packageRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.records.PackageSearchOrderRecord getPackageSearchOrderRecord(org.osid.type.Type packageRecordType)
        throws org.osid.OperationFailedException;
}
