//
// org.osid.installation.SiteQuery
//
//     The OSID Java specification for org.osid.installation.SiteQuery.
//
// Copyright (C) 2006 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.installation;


/**
 *  <p>This is the query for searching installations. Each method match 
 *  request produces an <code> AND </code> term while multiple invocations of 
 *  a method produces a nested <code> OR. </code> </p>
 */

public interface SiteQuery
    extends org.osid.OsidObjectQuery {


    /**
     *  Sets the installation <code> Id </code> for this query. 
     *
     *  @param  installationId a site <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> installationId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchInstallationId(org.osid.id.Id installationId, 
                                    boolean match);


    /**
     *  Clears the installation <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearInstallationIdTerms();


    /**
     *  Tests if an <code> InstallationQuery </code> is available for querying 
     *  installations. 
     *
     *  @return <code> true </code> if an installation query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInstallationQuery();


    /**
     *  Gets the query for an installation. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the site query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInstallationQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInstallationQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.installation.SiteQuery getInstallationQuery();


    /**
     *  Matches sites with any installation. 
     *
     *  @param  match <code> true </code> to match sites with any package, 
     *          <code> false </code> to match sites with no packages 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyInstallation(boolean match);


    /**
     *  Clears the installation query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearInstallationTerms();


    /**
     *  Gets the site query record corresponding to the given <code> Site 
     *  </code> record <code> Type. </code> Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @param  siteRecordType a site query record type 
     *  @return the site query record 
     *  @throws org.osid.NullArgumentException <code> siteRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(siteRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.records.SiteQueryRecord getSiteQueryRecord(org.osid.type.Type siteRecordType)
        throws org.osid.OperationFailedException;
}
