/**
 * <p>The Open Service Interface Definitions for the org.osid.installation
 * service.</p>
 * 
 * <p>The Installation OSID describes two categories of services. One service 
 * is to find, retrieve and manage installation packages in remote 
 * repositories, or <code> Depots. </code> The other service is to manage 
 * installations (downloaded packages) on <code> Sites. </code> Sites are 
 * generally, but not required to be, on local disk. </p> 
 * <h4> Packages </h4> 
 * 
 * <p> <code> Packages </code> define a set of core data and map to an 
 * independently retrieved and managed data stream. The data stream may be an 
 * archive file of a certain format. A <code> Package </code> may include 
 * multiple formats. <code> Packages </code> also may have other packages on 
 * which it depends for operation. Each version of a software package is a 
 * separate <code> Package </code> identified by a separate <code> Id. </code> 
 * Version chains may be defined to communicate newer available versions. </p> 
 * <h4> Installations </h4> 
 * 
 * <p> An installed package on a <code> Site </code> is an <code> 
 * Installation. </code> <code> Installations </code> are similar to <code> 
 * Packages </code> with a different set of core data and no access to the 
 * archive stream. <code> Installations </code> may also have dependencies and 
 * versioning. </p> 
 * 
 * <p> Methods are defined to check for updates available in a <code> Depot 
 * </code> for an <code> Installation, </code> at which time the consumer may 
 * elect to install the new <code> Package </code> <code> Id </code> for the 
 * updated version. Depending on whether a provider keeps the older version 
 * around, delete operations may be available for outdated versions and allow 
 * for dependency management across versions. </p> 
 * 
 * <p> <code> Sites </code> are assumed to be fixed to the runtime environment 
 * and are not manageable through the Installation OSID. As such, <code> Sites 
 * </code> are not modeled as <code> OsidCatalogs </code> and a single <code> 
 * Installation </code> may belong to only one <code> Site. </code> </p> 
 * <h4> Depot Cataloging </h4> 
 * 
 * <p> <code> Packages </code> are organized into <code> Depots </code> for 
 * categorization and federation using the OSID hierarchy pattern. Dynamic 
 * virtual <code> Depots </code> may be created by filtering on various <code> 
 * Package </code> attributes. </p> 
 * <h4> Versions </h4> 
 * 
 * <p> The Installation OSID defines an <code> OsidPrimitive </code> for a 
 * <code> Version. </code> A <code> Version </code> describes a version 
 * number. </p> 
 * <h4> Orchestration </h4> 
 * 
 * <p> The Installation OSID may be orchestrated with a Configuration OSID to 
 * retrieve or manage installation configurations. </p> 
 * <h4> Sub Packages </h4> 
 * 
 * <p> The Installation OSID contains an Installation Batch OSID for managing 
 * <code> Packages </code> and <code> Installations </code> in bulk. </p>
 * 
 * <br/><hr/><br/>
 * 
 * <p>Copyright &copy; 2006 Massachusetts Institute of Technology. </p> 
 * 
 * <p> Copyright &copy; 2009-2010 Ingenescus. All Rights Reserved. </p>
 * 
 * <p>This Work is being provided by the copyright holder(s) subject to the 
 * following license. By obtaining, using and/or copying this Work, you agree 
 * that you have read, understand, and will comply with the following terms 
 * and conditions. </p> 
 * 
 * <p> Permission to use, copy and distribute unmodified versions of this 
 * Work, for any purpose, without fee or royalty is hereby granted, provided 
 * that you include the above copyright notices and the terms of this license 
 * on ALL copies of the Work or portions thereof. </p> 
 * 
 * <p> You may modify or create Derivatives of this Work only for your 
 * internal purposes. You shall not distribute or transfer any such Derivative 
 * of this Work to any location or to any third party. For the purposes of 
 * this license, "Derivative" shall mean any derivative of the Work as defined 
 * in the United States Copyright Act of 1976, such as a translation or 
 * modification. </p> 
 * 
 * <p> This Work and the information contained herein is provided on an "AS 
 * IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT 
 * NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR 
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT 
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN 
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN 
 * CONNECTION WITH THE WORK OR THE USE OR OTHER DEALINGS IN THE WORK. </p> 
 * 
 * <p> The export of software employing encryption technology may require a 
 * specific license from the United States Government. It is the 
 * responsibility of any person or organization contemplating export to obtain 
 * such a license before exporting this Work. </p>
 */

package org.osid.installation;
