//
// org.osid.inventory.InventoryProfile
//
//     The OSID Java specification for org.osid.inventory.InventoryProfile.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inventory;


/**
 *  <p>The inventory profile describes the interoperability of inventory 
 *  services. </p>
 */

public interface InventoryProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if visible federation is supported. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if looking up items is supported. 
     *
     *  @return <code> true </code> if item lookup is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsItemLookup();


    /**
     *  Tests if querying items is supported. 
     *
     *  @return <code> true </code> if item query is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsItemQuery();


    /**
     *  Tests if searching items is supported. 
     *
     *  @return <code> true </code> if item search is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsItemSearch();


    /**
     *  Tests if an item <code> </code> administrative service is supported. 
     *
     *  @return <code> true </code> if item administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsItemAdmin();


    /**
     *  Tests if an item <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if item notification is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsItemNotification();


    /**
     *  Tests if an item cataloging service is supported. 
     *
     *  @return <code> true </code> if item catalog is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsItemWarehouse();


    /**
     *  Tests if an item cataloging service is supported. A cataloging service 
     *  maps items to catalogs. 
     *
     *  @return <code> true </code> if item cataloging is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsItemWarehouseAssignment();


    /**
     *  Tests if an item smart warehouse session is available. 
     *
     *  @return <code> true </code> if an item smart warehouse session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsItemSmartWarehouse();


    /**
     *  Tests if looking up stocks is supported. 
     *
     *  @return <code> true </code> if stock lookup is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStockLookup();


    /**
     *  Tests if querying stocks is supported. 
     *
     *  @return <code> true </code> if stock query is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStockQuery();


    /**
     *  Tests if searching stocks is supported. 
     *
     *  @return <code> true </code> if stock search is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStockSearch();


    /**
     *  Tests if stock administrative service is supported. 
     *
     *  @return <code> true </code> if stock administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStockAdmin();


    /**
     *  Tests if a stock <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if stock notification is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStockNotification();


    /**
     *  Tests if a stock cataloging service is supported. 
     *
     *  @return <code> true </code> if stock catalog is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStockWarehouse();


    /**
     *  Tests if a stock cataloging service is supported. A cataloging service 
     *  maps stocks to catalogs. 
     *
     *  @return <code> true </code> if stock cataloging is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStockWarehouseAssignment();


    /**
     *  Tests if a stock smart warehouse session is available. 
     *
     *  @return <code> true </code> if a stock smart warehouse session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStockSmartWarehouse();


    /**
     *  Tests for the availability of a stock hierarchy traversal service. 
     *
     *  @return <code> true </code> if stock hierarchy traversal is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsStockHierarchy();


    /**
     *  Tests for the availability of a stock hierarchy design service. 
     *
     *  @return <code> true </code> if stock hierarchy design is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStockHierarchyDesign();


    /**
     *  Tests if looking up models is supported. 
     *
     *  @return <code> true </code> if model lookup is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsModelLookup();


    /**
     *  Tests if querying models is supported. 
     *
     *  @return <code> true </code> if model query is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsModelQuery();


    /**
     *  Tests if searching models is supported. 
     *
     *  @return <code> true </code> if model search is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsModelSearch();


    /**
     *  Tests if a stock <code> </code> administrative service is supported. 
     *
     *  @return <code> true </code> if model administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsModelAdmin();


    /**
     *  Tests if a model <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if model notification is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsModelNotification();


    /**
     *  Tests if a model cataloging service is supported. 
     *
     *  @return <code> true </code> if model catalog is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsModelWarehouse();


    /**
     *  Tests if a model cataloging service is supported. A cataloging service 
     *  maps models to catalogs. 
     *
     *  @return <code> true </code> if model cataloging is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsModelWarehouseAssignment();


    /**
     *  Tests if a model smart warehouse session is available. 
     *
     *  @return <code> true </code> if a model smart warehouse session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsModelSmartWarehouse();


    /**
     *  Tests if looking up inventories is supported. 
     *
     *  @return <code> true </code> if inventory lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInventoryLookup();


    /**
     *  Tests if querying inventories is supported. 
     *
     *  @return <code> true </code> if inventory query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInventoryQuery();


    /**
     *  Tests if searching inventories is supported. 
     *
     *  @return <code> true </code> if inventory search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInventorySearch();


    /**
     *  Tests if inventory administrative service is supported. 
     *
     *  @return <code> true </code> if inventory administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInventoryAdmin();


    /**
     *  Tests if an inventory <code> </code> notification service is 
     *  supported. 
     *
     *  @return <code> true </code> if inventory notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInventoryNotification();


    /**
     *  Tests if an inventory cataloging service is supported. 
     *
     *  @return <code> true </code> if inventory catalog is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInventoryWarehouse();


    /**
     *  Tests if an inventory cataloging service is supported. A cataloging 
     *  service maps inventories to catalogs. 
     *
     *  @return <code> true </code> if inventory cataloging is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInventoryWarehouseAssignment();


    /**
     *  Tests if an inventory smart warehouse session is available. 
     *
     *  @return <code> true </code> if an inventory smart warehouse session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInventorySmartWarehouse();


    /**
     *  Tests if looking up warehouses is supported. 
     *
     *  @return <code> true </code> if warehouse lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsWarehouseLookup();


    /**
     *  Tests if searching warehouses is supported. 
     *
     *  @return <code> true </code> if warehouse search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsWarehouseSearch();


    /**
     *  Tests if querying warehouses is supported. 
     *
     *  @return <code> true </code> if warehouse query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsWarehouseQuery();


    /**
     *  Tests if warehouse administrative service is supported. 
     *
     *  @return <code> true </code> if warehouse administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsWarehouseAdmin();


    /**
     *  Tests if a warehouse <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if warehouse notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsWarehouseNotification();


    /**
     *  Tests for the availability of a warehouse hierarchy traversal service. 
     *
     *  @return <code> true </code> if warehouse hierarchy traversal is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsWarehouseHierarchy();


    /**
     *  Tests for the availability of a warehouse hierarchy design service. 
     *
     *  @return <code> true </code> if warehouse hierarchy design is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsWarehouseHierarchyDesign();


    /**
     *  Tests for the availability of a inventory batch service. 
     *
     *  @return <code> true </code> if a inventory batch service is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInventoryBatch();


    /**
     *  Tests for the availability of a inventory shipment service. 
     *
     *  @return <code> true </code> if a inventory shipment service is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInventoryShipment();


    /**
     *  Gets the supported <code> Item </code> record types. 
     *
     *  @return a list containing the supported <code> Item </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getItemRecordTypes();


    /**
     *  Tests if the given <code> Item </code> record type is supported. 
     *
     *  @param  itemRecordType a <code> Type </code> indicating an <code> Item 
     *          </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> itemRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsItemRecordType(org.osid.type.Type itemRecordType);


    /**
     *  Gets the supported <code> Item </code> search record types. 
     *
     *  @return a list containing the supported <code> Item </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getItemSearchRecordTypes();


    /**
     *  Tests if the given <code> Item </code> search record type is 
     *  supported. 
     *
     *  @param  itemSearchRecordType a <code> Type </code> indicating an 
     *          <code> Item </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> itemSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsItemSearchRecordType(org.osid.type.Type itemSearchRecordType);


    /**
     *  Gets the supported <code> Stock </code> record types. 
     *
     *  @return a list containing the supported <code> Stock </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getStockRecordTypes();


    /**
     *  Tests if the given <code> Stock </code> record type is supported. 
     *
     *  @param  stockRecordType a <code> Type </code> indicating an <code> 
     *          Stock </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> stockRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStockRecordType(org.osid.type.Type stockRecordType);


    /**
     *  Gets the supported <code> Stock </code> search record types. 
     *
     *  @return a list containing the supported <code> Stock </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getStockSearchRecordTypes();


    /**
     *  Tests if the given <code> Stock </code> search record type is 
     *  supported. 
     *
     *  @param  stockSearchRecordType a <code> Type </code> indicating an 
     *          <code> Stock </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> stockSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStockSearchRecordType(org.osid.type.Type stockSearchRecordType);


    /**
     *  Gets the supported <code> Model </code> record types. 
     *
     *  @return a list containing the supported <code> Model </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getModelRecordTypes();


    /**
     *  Tests if the given <code> Model </code> record type is supported. 
     *
     *  @param  modelRecordType a <code> Type </code> indicating an <code> 
     *          Model </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> modelRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsModelRecordType(org.osid.type.Type modelRecordType);


    /**
     *  Gets the supported <code> Model </code> search record types. 
     *
     *  @return a list containing the supported <code> Model </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getModelSearchRecordTypes();


    /**
     *  Tests if the given <code> Model </code> search record type is 
     *  supported. 
     *
     *  @param  modelSearchRecordType a <code> Type </code> indicating an 
     *          <code> Model </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> modelSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsModelSearchRecordType(org.osid.type.Type modelSearchRecordType);


    /**
     *  Gets the supported <code> Inventory </code> record types. 
     *
     *  @return a list containing the supported <code> Inventory </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getInventoryRecordTypes();


    /**
     *  Tests if the given <code> Inventory </code> record type is supported. 
     *
     *  @param  inventoryRecordType a <code> Type </code> indicating a <code> 
     *          Inventory </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> inventoryRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInventoryRecordType(org.osid.type.Type inventoryRecordType);


    /**
     *  Gets the supported <code> Inventory </code> search record types. 
     *
     *  @return a list containing the supported <code> Inventory </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getInventorySearchRecordTypes();


    /**
     *  Tests if the given <code> Inventory </code> search record type is 
     *  supported. 
     *
     *  @param  inventorySearchRecordType a <code> Type </code> indicating a 
     *          <code> Inventory </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          inventorySearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInventorySearchRecordType(org.osid.type.Type inventorySearchRecordType);


    /**
     *  Gets the supported <code> Warehouse </code> record types. 
     *
     *  @return a list containing the supported <code> Warehouse </code> types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getWarehouseRecordTypes();


    /**
     *  Tests if the given <code> Warehouse </code> record type is supported. 
     *
     *  @param  warehouseRecordType a <code> Type </code> indicating an <code> 
     *          Warehouse </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> warehouseRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsWarehouseRecordType(org.osid.type.Type warehouseRecordType);


    /**
     *  Gets the supported <code> Warehouse </code> search record types. 
     *
     *  @return a list containing the supported <code> Warehouse </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getWarehouseSearchRecordTypes();


    /**
     *  Tests if the given <code> Warehouse </code> search record type is 
     *  supported. 
     *
     *  @param  warehouseSearchRecordType a <code> Type </code> indicating an 
     *          <code> Warehouse </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          warehousesearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsWarehouseSearchRecordType(org.osid.type.Type warehouseSearchRecordType);
}
