//
// org.osid.inventory.InventoryQuery
//
//     The OSID Java specification for org.osid.inventory.InventoryQuery.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inventory;


/**
 *  <p>This is the query for searching inventories. Each method match 
 *  specifies an <code> AND </code> term while multiple invocations of the 
 *  same method produce a nested <code> OR. </code> </p>
 */

public interface InventoryQuery
    extends org.osid.OsidObjectQuery,
            org.osid.OsidSubjugateableQuery {


    /**
     *  Sets the stock <code> Id </code> for this query. 
     *
     *  @param  stockId the stock <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> stockId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchStockId(org.osid.id.Id stockId, boolean match);


    /**
     *  Clears the stock <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStockIdTerms();


    /**
     *  Tests if a <code> StockQuery </code> is available. 
     *
     *  @return <code> true </code> if a stock query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStockQuery();


    /**
     *  Gets the query for a stocjk. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the stock query 
     *  @throws org.osid.UnimplementedException <code> supportsStockQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStockQuery() </code> is <code> true. </code> 
     */

    public org.osid.inventory.StockQuery getStockQuery();


    /**
     *  Clears the stock terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStockTerms();


    /**
     *  Matches inventories where the given time falls within a denormalized 
     *  inventory date inclusive. 
     *
     *  @param  date a date 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDate(org.osid.calendaring.DateTime date, boolean match);


    /**
     *  Clears the meeting time terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDateTerms();


    /**
     *  Matches inventories with any denormalized date within the given date 
     *  range inclusive. 
     *
     *  @param  start a start date 
     *  @param  end an end date 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> start </code> is 
     *          greater than <code> end </code> 
     *  @throws org.osid.NullArgumentException <code> start </code> or <code> 
     *          end </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDateInclusive(org.osid.calendaring.DateTime start, 
                                   org.osid.calendaring.DateTime end, 
                                   boolean match);


    /**
     *  Clears the date inclusive terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDateInclusiveTerms();


    /**
     *  Matches inventories with a quantity within the given range inclusive. 
     *
     *  @param  start start range 
     *  @param  end end range 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> start </code> is 
     *          greater than <code> end </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchQuantity(java.math.BigDecimal start, 
                              java.math.BigDecimal end, boolean match);


    /**
     *  Clears the quantity terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearQuantityTerms();


    /**
     *  Sets the warehouse <code> Id </code> for this query to match 
     *  inventories assigned to warehouses. 
     *
     *  @param  warehouseId the warehouse <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> warehouseId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchWarehouseId(org.osid.id.Id warehouseId, boolean match);


    /**
     *  Clears the warehouse <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearWarehouseIdTerms();


    /**
     *  Tests if a <code> WarehouseQuery </code> is available. 
     *
     *  @return <code> true </code> if a warehouse query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsWarehouseQuery();


    /**
     *  Gets the query for a warehouse. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the warehouse query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsWarehouseQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsWarehouseQuery() </code> is <code> true. </code> 
     */

    public org.osid.inventory.WarehouseQuery getWarehouseQuery();


    /**
     *  Clears the warehouse terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearWarehouseTerms();


    /**
     *  Gets the inventory query record corresponding to the given <code> 
     *  Inventory </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  inventoryRecordType an inventory record type 
     *  @return the inventory query record 
     *  @throws org.osid.NullArgumentException <code> inventoryRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(inventoryRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.records.InventoryQueryRecord getInventoryQueryRecord(org.osid.type.Type inventoryRecordType)
        throws org.osid.OperationFailedException;
}
