//
// org.osid.inventory.InventorySmartWarehouseSession
//
//     The OSID Java specification for org.osid.inventory.InventorySmartWarehouseSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inventory;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. An <code> InventoryQuery </code> can be retrieved from this 
 *  session and mapped to this <code> Warehouse </code> to create a virtual 
 *  collection of <code> Inventories. </code> The inventories may be sequenced 
 *  using the <code> InventorySearchOrder </code> from this session. </p> 
 *  
 *  <p> This <code> Warehouse </code> has a default query that matches any 
 *  inventory and a default search order that specifies no sequencing. The 
 *  queries may be examined using an <code> InventoryQueryInspector. </code> 
 *  The query may be modified by converting the inspector back to an <code> 
 *  InventoryQuery. </code> </p>
 */

public interface InventorySmartWarehouseSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Warehouse </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Warehouse Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getWarehouseId();


    /**
     *  Gets the <code> Warehouse </code> associated with this session. 
     *
     *  @return the warehouse 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.Warehouse getWarehouse()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart warehouses. A return of true does 
     *  not guarantee successful assessment. A return of false indicates that 
     *  it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart warehouse management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartWarehouses();


    /**
     *  Gets an inventory query. 
     *
     *  @return the inventory query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.InventoryQuery getInventoryQuery();


    /**
     *  Gets an inventory search order. 
     *
     *  @return the inventory search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.InventorySearchOrder getInventorySearchOrder();


    /**
     *  Applies an inventory query to this warehouse. 
     *
     *  @param  inventoryQuery the inventory query 
     *  @throws org.osid.NullArgumentException <code> inventoryQuery </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> inventoryQuery </code> 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyInventoryQuery(org.osid.inventory.InventoryQuery inventoryQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an inventory query inspector for this warehouse. 
     *
     *  @return the inventory query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.InventoryQueryInspector inspectInventoryQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies an inventory search order to this warehouse. 
     *
     *  @param  inventorySearchOrder the inventory search order 
     *  @throws org.osid.NullArgumentException <code> inventorySearchOrder 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> inventorySearchOrder 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyInventorySequencing(org.osid.inventory.InventorySearchOrder inventorySearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an inventory query from an inspector. 
     *
     *  @param  inventoryQueryInspector a query inspector 
     *  @return the inventory query 
     *  @throws org.osid.NullArgumentException <code> inventoryQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> inventoryQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.InventoryQuery getInventoryQueryFromInspector(org.osid.inventory.InventoryQueryInspector inventoryQueryInspector);
}
