//
// org.osid.inventory.Item
//
//     The OSID Java specification for org.osid.inventory.Item.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inventory;


/**
 *  <p>An <code> Item </code> represents a particular item. </p>
 */

public interface Item
    extends org.osid.OsidObject {


    /**
     *  Gets the stock <code> Id </code> to which this item belongs. 
     *
     *  @return a stock <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getStockId();


    /**
     *  Gets the stock to which this item belongs. 
     *
     *  @return a stock 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.Stock getStock()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the property identification number for this item. 
     *
     *  @return a property tag 
     *  @compliance mandatory This method must be implemented. 
     */

    public String getPropertyTag();


    /**
     *  Gets the serial number for this item. 
     *
     *  @return a serial number 
     *  @compliance mandatory This method must be implemented. 
     */

    public String getSerialNumber();


    /**
     *  Gets a display string for the location. 
     *
     *  @return a location descrption 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getLocationDescription();


    /**
     *  Tests if this item has a known location. 
     *
     *  @return <code> true </code> if a location is associated with this 
     *          item, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasLocation();


    /**
     *  Gets the location <code> Id </code> to which this item belongs. 
     *
     *  @return a location <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> hasLocation() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getLocationId();


    /**
     *  Gets the location to which this item belongs. 
     *
     *  @return a location 
     *  @throws org.osid.IllegalStateException <code> hasLocation() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Location getLocation()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this item is a part of another item. 
     *
     *  @return <code> true </code> if this item is a part of another item, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isPart();


    /**
     *  Gets the item <code> Id </code> to which this item belongs. 
     *
     *  @return a item <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> isPart() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getItemId();


    /**
     *  Gets the item to which this item belongs. 
     *
     *  @return a item 
     *  @throws org.osid.IllegalStateException <code> isPart() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.Item getItem()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the item record corresponding to the given <code> Item </code> 
     *  record <code> Type. </code> This method is used to retrieve an object 
     *  implementing the requested record. The <code> itemRecordType </code> 
     *  may be the <code> Type </code> returned in <code> getRecordTypes() 
     *  </code> or any of its parents in a <code> Type </code> hierarchy where 
     *  <code> hasRecordType(itemRecordType) </code> is <code> true </code> . 
     *
     *  @param  itemRecordType the type of item record to retrieve 
     *  @return the item record 
     *  @throws org.osid.NullArgumentException <code> itemRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(itemRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.records.ItemRecord getItemRecord(org.osid.type.Type itemRecordType)
        throws org.osid.OperationFailedException;
}
