//
// org.osid.inventory.ItemLookupSession
//
//     The OSID Java specification for org.osid.inventory.ItemLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inventory;


/**
 *  <p>This session defines methods for retrieving items. An <code> Item 
 *  </code> is a scheduled course listed in a warehouse. An <code> Item 
 *  </code> is derived from a <code> Course </code> and maps to an offering 
 *  time and registered students. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated warehouse view: All item methods in this session 
 *      operate, retrieve and pertain to items defined explicitly in the 
 *      current warehouse. Using an isolated view is useful for managing 
 *      <code> Items </code> with the <code> ItemAdminSession. </code> </li> 
 *      <li> federated warehouse view: All item lookup methods in this session 
 *      operate, retrieve and pertain to all items defined in this warehouse 
 *      and any other itemss implicitly available in this warehouse through 
 *      warehouse inheritence. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedWarehouseView() </code> and <code> 
 *  useIsolatedWarehouseView() </code> behave as a radio group and one should 
 *  be selected before invoking any lookup methods. </p> 
 *  
 *  <p> Items may have an additional records indicated by their respective 
 *  record types. The record may not be accessed through a cast of the <code> 
 *  Item. </code> </p>
 */

public interface ItemLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Warehouse </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Warehouse Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getWarehouseId();


    /**
     *  Gets the <code> Warehouse </code> associated with this session. 
     *
     *  @return the warehouse 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.Warehouse getWarehouse()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Item </code> lookups. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not offer lookup operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupItems();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeItemView();


    /**
     *  A complete view of the <code> Item </code> returns is desired. Methods 
     *  will return what is requested or result in an error. This view is used 
     *  when greater precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryItemView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include items in catalogs which are children of this catalog in the 
     *  warehouse hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedWarehouseView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this warehouse only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedWarehouseView();


    /**
     *  Gets the <code> Item </code> specified by its <code> Id. </code> In 
     *  plenary mode, the exact <code> Id </code> is found or a <code> 
     *  NOT_FOUND </code> results. Otherwise, the returned <code> Item </code> 
     *  may have a different <code> Id </code> than requested, such as the 
     *  case where a duplicate <code> Id </code> was assigned to an <code> 
     *  Item </code> and retained for compatibility. 
     *
     *  @param  itemId the <code> Id </code> of the <code> Item </code> to 
     *          retrieve 
     *  @return the returned <code> Item </code> 
     *  @throws org.osid.NotFoundException no <code> Item </code> found with 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> itemId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.Item getItem(org.osid.id.Id itemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ItemList </code> corresponding to the given <code> 
     *  IdList. </code> In plenary mode, the returned list contains all of the 
     *  items specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Items </code> may be omitted from the list and may 
     *  present the elements in any order including returning a unique set. 
     *
     *  @param  itemIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Item </code> list 
     *  @throws org.osid.NotFoundException an <code> Id </code> was not found 
     *  @throws org.osid.NullArgumentException <code> itemIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.ItemList getItemsByIds(org.osid.id.IdList itemIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ItemList </code> corresponding to the given item genus 
     *  <code> Type </code> which does not include items of types derived from 
     *  the specified <code> Type. </code> In plenary mode, the returned list 
     *  contains all known items or an error results. Otherwise, the returned 
     *  list may contain only those items that are accessible through this 
     *  session. 
     *
     *  @param  itemGenusType an item genus type 
     *  @return the returned <code> Item </code> list 
     *  @throws org.osid.NullArgumentException <code> itemGenusType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.ItemList getItemsByGenusType(org.osid.type.Type itemGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ItemList </code> corresponding to the given item genus 
     *  <code> Type </code> and include any additional items with genus types 
     *  derived from the specified <code> Type. </code> In plenary mode, the 
     *  returned list contains all known items or an error results. Otherwise, 
     *  the returned list may contain only those items that are accessible 
     *  through this session. 
     *
     *  @param  itemGenusType an item genus type 
     *  @return the returned <code> Item </code> list 
     *  @throws org.osid.NullArgumentException <code> itemGenusType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.ItemList getItemsByParentGenusType(org.osid.type.Type itemGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ItemList </code> containing the given item record 
     *  <code> Type. </code> In plenary mode, the returned list contains all 
     *  known items or an error results. Otherwise, the returned list may 
     *  contain only those items that are accessible through this session. 
     *
     *  @param  itemRecordType an item record type 
     *  @return the returned <code> Item </code> list 
     *  @throws org.osid.NullArgumentException <code> itemRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.ItemList getItemsByRecordType(org.osid.type.Type itemRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ItemList </code> for the given stock. In plenary mode, 
     *  the returned list contains all known items or an error results. 
     *  Otherwise, the returned list may contain only those items that are 
     *  accessible through this session. 
     *
     *  @param  stockId a stock <code> Id </code> 
     *  @return the returned <code> Item </code> list 
     *  @throws org.osid.NullArgumentException <code> stockId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.ItemList getItemsByStock(org.osid.id.Id stockId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ItemList </code> for the given property tag. In plenary 
     *  mode, the returned list contains all known items or an error results. 
     *  Otherwise, the returned list may contain only those items that are 
     *  accessible through this session. 
     *
     *  @param  property a property number 
     *  @return the returned <code> Item </code> list 
     *  @throws org.osid.NullArgumentException <code> property </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.ItemList getItemsByPropertyTag(String property)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ItemList </code> for the given serial number. In 
     *  plenary mode, the returned list contains all known items or an error 
     *  results. Otherwise, the returned list may contain only those items 
     *  that are accessible through this session. 
     *
     *  @param  serialNumber a serial number 
     *  @return the returned <code> Item </code> list 
     *  @throws org.osid.NullArgumentException <code> serialNumber </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.ItemList getItemsBySerialNumber(String serialNumber)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ItemList </code> immediately contained within the given 
     *  item. In plenary mode, the returned list contains all known items or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  items that are accessible through this session. 
     *
     *  @param  itemId an item <code> Id </code> 
     *  @return the returned <code> Item </code> list 
     *  @throws org.osid.NullArgumentException <code> itemId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.ItemList getItemParts(org.osid.id.Id itemId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Items. </code> In plenary mode, the returned list 
     *  contains all known items or an error results. Otherwise, the returned 
     *  list may contain only those items that are accessible through this 
     *  session. 
     *
     *  @return a list of <code> Items </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.ItemList getItems()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
