//
// org.osid.inventory.ModelSmartWarehouseSession
//
//     The OSID Java specification for org.osid.inventory.ModelSmartWarehouseSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inventory;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. A <code> ModelQuery </code> can be retrieved from this session 
 *  and mapped to this <code> CoursOfferingeCatalog </code> to create a 
 *  virtual collection of <code> Models. </code> The models may be sequenced 
 *  using the <code> ModelSearchOrder </code> from this session. </p> 
 *  
 *  <p> This <code> Warehouse </code> has a default query that matches any 
 *  model and a default search order that specifies no sequencing. The queries 
 *  may be examined using a <code> ModelQueryInspector. </code> The query may 
 *  be modified by converting the inspector back to a <code> ModelQuery. 
 *  </code> </p>
 */

public interface ModelSmartWarehouseSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Warehouse </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Warehouse Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getWarehouseId();


    /**
     *  Gets the <code> Warehouse </code> associated with this session. 
     *
     *  @return the warehouse 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.Warehouse getWarehouse()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart warehouses. A return of true does 
     *  not guarantee successful assessment. A return of false indicates that 
     *  it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart warehouse management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartWarehouses();


    /**
     *  Gets a model query. 
     *
     *  @return the model query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.ModelQuery getModelQuery();


    /**
     *  Gets a model search order. 
     *
     *  @return the model search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.ModelSearchOrder getModelSearchOrder();


    /**
     *  Applies a model query to this warehouse. 
     *
     *  @param  modelQuery the model query 
     *  @throws org.osid.NullArgumentException <code> modelQuery </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> modelQuery </code> not of 
     *          this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyModelQuery(org.osid.inventory.ModelQuery modelQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a model query inspector for this warehouse. 
     *
     *  @return the model query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.ModelQueryInspector inspectModelQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a model search order to this warehouse. 
     *
     *  @param  modelSearchOrder the model search order 
     *  @throws org.osid.NullArgumentException <code> modelSearchOrder </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> modelSearchOrder </code> 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyModelSequencing(org.osid.inventory.ModelSearchOrder modelSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a model query from an inspector. 
     *
     *  @param  modelQueryInspector a query inspector 
     *  @return the model query 
     *  @throws org.osid.NullArgumentException <code> modelQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> modelQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.ModelQuery getModelQueryFromInspector(org.osid.inventory.ModelQueryInspector modelQueryInspector);
}
