//
// org.osid.inventory.StockQuery
//
//     The OSID Java specification for org.osid.inventory.StockQuery.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inventory;


/**
 *  <p>This is the query for searching stocks. Each method match specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface StockQuery
    extends org.osid.OsidObjectQuery,
            org.osid.OsidFederateableQuery {


    /**
     *  Matches a sku number. 
     *
     *  @param  sku a sku 
     *  @param  stringMatchType a string match type 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> sku </code> or <code> 
     *          stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSKU(String sku, org.osid.type.Type stringMatchType, 
                         boolean match);


    /**
     *  Matches items that have any sku. 
     *
     *  @param  match <code> true </code> to match items with any sku, <code> 
     *          false </code> to match items with no sku 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnySKU(boolean match);


    /**
     *  Clears the sku terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSKUTerms();


    /**
     *  Sets the model <code> Id </code> for this query. 
     *
     *  @param  modelId a model <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> modelId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchModelId(org.osid.id.Id modelId, boolean match);


    /**
     *  Clears the model <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearModelIdTerms();


    /**
     *  Tests if a <code> ModelQuery </code> is available. 
     *
     *  @return <code> true </code> if a model query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsModelQuery();


    /**
     *  Gets the query for an inventory. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the model query 
     *  @throws org.osid.UnimplementedException <code> supportsModelQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsModelQuery() </code> is <code> true. </code> 
     */

    public org.osid.inventory.ModelQuery getModelQuery();


    /**
     *  Matches any related model. 
     *
     *  @param  match <code> true </code> to match stocks with any model, 
     *          <code> false </code> to match stocks with no models 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyModel(boolean match);


    /**
     *  Clears the model terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearModelTerms();


    /**
     *  Matches a location description. 
     *
     *  @param  location a location string 
     *  @param  stringMatchType a string match type 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> location </code> or 
     *          <code> stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchLocationDescription(String location, 
                                         org.osid.type.Type stringMatchType, 
                                         boolean match);


    /**
     *  Matches items that have any location description. 
     *
     *  @param  match <code> true </code> to match stocks with any location 
     *          string, <code> false </code> to match stocks with no location 
     *          string 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyLocationDescription(boolean match);


    /**
     *  Clears the location description terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLocationDescriptionTerms();


    /**
     *  Sets the location <code> Id </code> for this query. 
     *
     *  @param  locationId the location <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> locationId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchLocationId(org.osid.id.Id locationId, boolean match);


    /**
     *  Clears the location <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLocationIdTerms();


    /**
     *  Tests if a <code> LocationQuery </code> is available. 
     *
     *  @return <code> true </code> if a location query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLocationQuery();


    /**
     *  Gets the query for a location. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the location query 
     *  @throws org.osid.UnimplementedException <code> supportsLocationQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLocationQuery() </code> is <code> true. </code> 
     */

    public org.osid.mapping.LocationQuery getLocationQuery();


    /**
     *  Matches items that have any location. 
     *
     *  @param  match <code> true </code> to match stocks with any location, 
     *          <code> false </code> to match stocks with no location 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyLocation(boolean match);


    /**
     *  Clears the location terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLocationTerms();


    /**
     *  Sets the stock <code> Id </code> for this query to match stocks that 
     *  have the specified stock as an ancestor. 
     *
     *  @param  stockId a stock <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> stockId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorStockId(org.osid.id.Id stockId, boolean match);


    /**
     *  Clears the ancestor stock <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorStockIdTerms();


    /**
     *  Tests if a <code> StockQuery </code> is available. 
     *
     *  @return <code> true </code> if a stock query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorStockQuery();


    /**
     *  Gets the query for a stock. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the stock query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorStockQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorStockQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.inventory.StockQuery getAncestorStockQuery();


    /**
     *  Matches stocks with any stock ancestor. 
     *
     *  @param  match <code> true </code> to match stocks with any ancestor, 
     *          <code> false </code> to match root stocks 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorStock(boolean match);


    /**
     *  Clears the ancestor stock query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorStockTerms();


    /**
     *  Sets the stock <code> Id </code> for this query to match stocks that 
     *  have the specified stock as an descendant. 
     *
     *  @param  stockId a stock <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> stockId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantStockId(org.osid.id.Id stockId, boolean match);


    /**
     *  Clears the descendant stock <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantStockIdTerms();


    /**
     *  Tests if a <code> StockQuery </code> is available. 
     *
     *  @return <code> true </code> if a stock query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantStockQuery();


    /**
     *  Gets the query for a stock. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the stock query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantStockQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantStockQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.inventory.StockQuery getDescendantStockQuery();


    /**
     *  Matches stocks with any descendant stock. 
     *
     *  @param  match <code> true </code> to match stocks with any descendant, 
     *          <code> false </code> to match leaf stocks 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantStock(boolean match);


    /**
     *  Clears the descendant stock query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantStockTerms();


    /**
     *  Sets the warehouse <code> Id </code> for this query to match stocks 
     *  assigned to warehouses. 
     *
     *  @param  warehouseId the warehouse <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> warehouseId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchWarehouseId(org.osid.id.Id warehouseId, boolean match);


    /**
     *  Clears the warehouse <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearWarehouseIdTerms();


    /**
     *  Tests if a <code> WarehouseQuery </code> is available. 
     *
     *  @return <code> true </code> if a warehouse query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsWarehouseQuery();


    /**
     *  Gets the query for a warehouse. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the warehouse query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsWarehouseQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsWarehouseQuery() </code> is <code> true. </code> 
     */

    public org.osid.inventory.WarehouseQuery getWarehouseQuery();


    /**
     *  Clears the warehouse terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearWarehouseTerms();


    /**
     *  Gets the stock query record corresponding to the given <code> Stock 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @param  stockRecordType a stock record type 
     *  @return the stock query record 
     *  @throws org.osid.NullArgumentException <code> stockRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(stockRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.records.StockQueryRecord getStockQueryRecord(org.osid.type.Type stockRecordType)
        throws org.osid.OperationFailedException;
}
