//
// org.osid.inventory.StockQueryInspector
//
//     The OSID Java specification for org.osid.inventory.StockQueryInspector.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inventory;


/**
 *  <p>The query inspectors provide a means of accessing the match terms of a 
 *  query. These interfaces are used to examine the actual query terms used in 
 *  a search or that may be used to create a smart catalog. Query inspectors 
 *  may be converted to <code> OsidQuery </code> interfaces for reuse or 
 *  modification in the search sessions. </p>
 */

public interface StockQueryInspector
    extends org.osid.OsidObjectQueryInspector,
            org.osid.OsidFederateableQueryInspector {


    /**
     *  Gets the SKU query terms. 
     *
     *  @return the SKU query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.StringTerm[] getSKUTerms();


    /**
     *  Gets the model <code> Id </code> query terms. 
     *
     *  @return the model <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getModelIdTerms();


    /**
     *  Gets the model query terms. 
     *
     *  @return the model query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.ModelQueryInspector[] getModelTerms();


    /**
     *  Gets the location description query terms. 
     *
     *  @return the location description query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.StringTerm[] getLocationDescriptionTerms();


    /**
     *  Gets the location <code> Id </code> query terms. 
     *
     *  @return the location <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getLocationIdTerms();


    /**
     *  Gets the location query terms. 
     *
     *  @return the location query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.LocationQueryInspector[] getLocationTerms();


    /**
     *  Gets the ancestor stock <code> Id </code> query terms. 
     *
     *  @return the ancestor stock <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getAncestorStockIdTerms();


    /**
     *  Gets the ancestor stock query terms. 
     *
     *  @return the ancestor stock terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.StockQueryInspector[] getAncestorStockTerms();


    /**
     *  Gets the descendant stock <code> Id </code> query terms. 
     *
     *  @return the descendant stock <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getDescendantStockIdTerms();


    /**
     *  Gets the descendant stock query terms. 
     *
     *  @return the descendant stock terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.StockQueryInspector[] getDescendantStockTerms();


    /**
     *  Gets the warehouse <code> Id </code> query terms. 
     *
     *  @return the warehouse <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getWarehouseIdTerms();


    /**
     *  Gets the warehouse query terms. 
     *
     *  @return the warehouse query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.WarehouseQueryInspector[] getWarehouseTerms();


    /**
     *  Gets the stock query inspector record corresponding to the given 
     *  <code> Stock </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  stockRecordType a stock record type 
     *  @return the stock query inspector record 
     *  @throws org.osid.NullArgumentException <code> stockRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(stockRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.records.StockQueryInspectorRecord getStockQueryInspectorRecord(org.osid.type.Type stockRecordType)
        throws org.osid.OperationFailedException;
}
