//
// org.osid.inventory.WarehouseAdminSession
//
//     The OSID Java specification for org.osid.inventory.WarehouseAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inventory;


/**
 *  <p>This session creates, updates, and deletes <code> Warehouses. </code> 
 *  The data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Warehouse, </code> a <code> WarehouseForm </code> is requested using 
 *  <code> getWarehouseFormForCreate() </code> specifying the desired record 
 *  <code> Types </code> or none if no record <code> Types </code> are needed. 
 *  The returned <code> WarehouseForm </code> will indicate that it is to be 
 *  used with a create operation and can be used to examine metdata or 
 *  validate data prior to creation. Once the <code> WarehouseForm </code> is 
 *  submiited to a create operation, it cannot be reused with another create 
 *  operation unless the first operation was unsuccessful. Each <code> 
 *  WarehouseForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> WarehouseForms </code> are requested to the <code> 
 *  Warehouse </code> <code> Id </code> that is to be updated using <code> 
 *  getWarehouseFormForUpdate(). </code> Similarly, the <code> WarehouseForm 
 *  </code> has metadata about the data that can be updated and it can perform 
 *  validation before submitting the update. The <code> WarehouseForm </code> 
 *  can only be used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Warehouses. </code> </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface WarehouseAdminSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can create <code> Warehouses. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> Warehouse. </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not wish to offer create operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Warehouse </code> creation is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateWarehouses();


    /**
     *  Tests if this user can create a single <code> Warehouse </code> using 
     *  the desired record types. While <code> 
     *  InventoryManager.getWarehouseRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> Warehouse. </code> 
     *  Providing an empty array tests if a <code> Warehouse </code> can be 
     *  created with no records. 
     *
     *  @param  warehouseRecordTypes array of warehouse record types 
     *  @return <code> true </code> if <code> Warehouse </code> creation using 
     *          the specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> warehouseRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateWarehouseWithRecordTypes(org.osid.type.Type[] warehouseRecordTypes);


    /**
     *  Gets the warehouse form for creating new warehouses. A new form should 
     *  be requested for each create transaction. 
     *
     *  @param  warehouseRecordTypes array of warehouse record types 
     *  @return the warehouse form 
     *  @throws org.osid.NullArgumentException <code> warehouseRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.WarehouseForm getWarehouseFormForCreate(org.osid.type.Type[] warehouseRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Warehouse. </code> 
     *
     *  @param  warehouseForm the form for this <code> Warehouse </code> 
     *  @return the new <code> Warehouse </code> 
     *  @throws org.osid.IllegalStateException <code> warehouseForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> warehouseForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> warehouseForm </code> did 
     *          not originate from <code> getWarehouseFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.Warehouse createWarehouse(org.osid.inventory.WarehouseForm warehouseForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Warehouses. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> Warehouse </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not wish to offer update operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Warehouse </code> modification 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateWarehouses();


    /**
     *  Gets the warehouse form for updating an existing warehouse. A new 
     *  warehouse form should be requested for each update transaction. 
     *
     *  @param  warehouseId the <code> Id </code> of the <code> Warehouse 
     *          </code> 
     *  @return the warehouse form 
     *  @throws org.osid.NotFoundException <code> warehouseId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> warehouseId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.WarehouseForm getWarehouseFormForUpdate(org.osid.id.Id warehouseId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing warehouse. 
     *
     *  @param  warehouseForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> warehouseForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> warehouseForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> warehouseForm </code> did 
     *          not originate from <code> getWarehouseFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateWarehouse(org.osid.inventory.WarehouseForm warehouseForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> Warehouses. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> Warehouse </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not wish to offer delete operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Warehouse </code> deletion is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteWarehouses();


    /**
     *  Deletes a <code> Warehouse. </code> 
     *
     *  @param  warehouseId the <code> Id </code> of the <code> Warehouse 
     *          </code> to remove 
     *  @throws org.osid.NotFoundException <code> warehouseId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> warehouseId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteWarehouse(org.osid.id.Id warehouseId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Warehouses. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Warehouse </code> aliasing is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageWarehouseAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Warehouse </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Warehouse </code> is determined by the provider. The new 
     *  <code> Id </code> performs as an alias to the primary <code> Id 
     *  </code> . If the alias is a pointer to another warehouse, it is 
     *  reassigned to the given warehouse <code> Id. </code> 
     *
     *  @param  warehouseId the <code> Id </code> of a <code> Warehouse 
     *          </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> aliasId </code> is in use as 
     *          a primary <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> warehouseId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasWarehouse(org.osid.id.Id warehouseId, 
                               org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
