//
// org.osid.inventory.WarehouseQueryInspector
//
//     The OSID Java specification for org.osid.inventory.WarehouseQueryInspector.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inventory;


/**
 *  <p>The query inspectors provide a means of accessing the match terms of a 
 *  query. These interfaces are used to examine the actual query terms used in 
 *  a search or that may be used to create a smart catalog. Query inspectors 
 *  may be converted to <code> OsidQuery </code> interfaces for reuse or 
 *  modification in the search sessions. </p>
 */

public interface WarehouseQueryInspector
    extends org.osid.OsidCatalogQueryInspector {


    /**
     *  Gets the item <code> Id </code> query terms. 
     *
     *  @return the item <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getItemIdTerms();


    /**
     *  Gets the item query terms. 
     *
     *  @return the item query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.ItemQueryInspector[] getItemTerms();


    /**
     *  Gets the stock <code> Id </code> query terms. 
     *
     *  @return the stock <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getStockIdTerms();


    /**
     *  Gets the stock query terms. 
     *
     *  @return the stock query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.StockQueryInspector[] getStockTerms();


    /**
     *  Gets the model <code> Id </code> query terms. 
     *
     *  @return the model <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getModelIdTerms();


    /**
     *  Gets the model query terms. 
     *
     *  @return the model query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.ModelQueryInspector[] getModelTerms();


    /**
     *  Gets the inventory <code> Id </code> query terms. 
     *
     *  @return the inventory <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getInventoryIdTerms();


    /**
     *  Gets the inventory query terms. 
     *
     *  @return the inventory query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.InventoryQueryInspector[] getInventoryTerms();


    /**
     *  Gets the ancestor warehouse <code> Id </code> query terms. 
     *
     *  @return the ancestor warehouse <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getAncestorWarehouseIdTerms();


    /**
     *  Gets the ancestor warehouse query terms. 
     *
     *  @return the ancestor warehouse terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.WarehouseQueryInspector[] getAncestorWarehouseTerms();


    /**
     *  Gets the descendant warehouse <code> Id </code> query terms. 
     *
     *  @return the descendant warehouse <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getDescendantWarehouseIdTerms();


    /**
     *  Gets the descendant warehouse query terms. 
     *
     *  @return the descendant warehouse terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.WarehouseQueryInspector[] getDescendantWarehouseTerms();


    /**
     *  Gets the warehouse query inspector record corresponding to the given 
     *  <code> Warehouse </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  warehouseRecordType a warehouse record type 
     *  @return the warehouse query inspector record 
     *  @throws org.osid.NullArgumentException <code> warehouseRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(warehouseRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.records.WarehouseQueryInspectorRecord getWarehouseQueryInspectorRecord(org.osid.type.Type warehouseRecordType)
        throws org.osid.OperationFailedException;
}
