//
// org.osid.inventory.WarehouseReceiver
//
//     The OSID Java specification for org.osid.inventory.WarehouseReceiver.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inventory;


/**
 *  <p>The warehouse receiver is the consumer supplied interface for receiving 
 *  notifications pertaining to new, updated or deleted Warehouse objects. 
 *  </p>
 */

public interface WarehouseReceiver
    extends org.osid.OsidReceiver {


    /**
     *  The callback for notifications of new warehouses. 
     *
     *  @param  warehouseIds the <code> Ids </code> of the new <code> 
     *          Warehouses </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newWarehouses(org.osid.id.IdList warehouseIds);


    /**
     *  The callback for notifications of new warehouse ancestors. 
     *
     *  @param  warehouseId the <code> Id </code> of the <code> Warehouse 
     *          </code> 
     *  @param  ancestorId the <code> Id </code> of the new <code> Warehouse 
     *          </code> ancestor 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newAncestorWarehouse(org.osid.id.Id warehouseId, 
                                     org.osid.id.Id ancestorId);


    /**
     *  The callback for notifications of new warehouse descendants. 
     *
     *  @param  warehouseId the <code> Id </code> of the <code> Warehouse 
     *          </code> 
     *  @param  descendantId the <code> Id </code> of the new <code> Warehouse 
     *          </code> descendant 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newDescendantWarehouse(org.osid.id.Id warehouseId, 
                                       org.osid.id.Id descendantId);


    /**
     *  The callback for notification of updated warehouses. 
     *
     *  @param  warehouseIds the <code> Ids </code> of the updated <code> 
     *          Warehouses </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void changedWarehouses(org.osid.id.IdList warehouseIds);


    /**
     *  The callback for notification of deleted warehouses. 
     *
     *  @param  warehouseIds the <code> Ids </code> of the deleted <code> 
     *          Warehouses </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedWarehouses(org.osid.id.IdList warehouseIds);


    /**
     *  The callback for notifications of deleted warehouse ancestors. 
     *
     *  @param  warehouseId the <code> Id </code> of the <code> Warehouse 
     *          </code> 
     *  @param  ancestorId the <code> Id </code> of the removed <code> 
     *          Warehouse </code> ancestor 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedAncestorWarehouse(org.osid.id.Id warehouseId, 
                                         org.osid.id.Id ancestorId);


    /**
     *  The callback for notifications of deleted warehouse descendants. 
     *
     *  @param  warehouseId the <code> Id </code> of the <code> Warehouse 
     *          </code> 
     *  @param  descendantId the <code> Id </code> of the removed <code> 
     *          Warehouse </code> descendant 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedDescendantWarehouse(org.osid.id.Id warehouseId, 
                                           org.osid.id.Id descendantId);


    /**
     *  The callback for notifications of changes to a warehouse hierarchy 
     *  where the hierarchy needs to refreshed. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void restructuredWarehouseHierarchy();
}
