//
// org.osid.inventory.batch.InventoryBatchAdminSession
//
//     The OSID Java specification for org.osid.inventory.batch.InventoryBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inventory.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Inventories </code> 
 *  in bulk. The data for create and update is provided by the consumer via 
 *  the form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create an 
 *  <code> Inventory, </code> an <code> InventoryForm </code> is requested 
 *  using <code> getInventoryFormsForCreate() </code> specifying the desired 
 *  record <code> Types </code> or none if no record <code> Types </code> are 
 *  needed. Each of the returned <code> InventoryForms </code> will indicate 
 *  that it is to be used with a create operation and can be used to examine 
 *  metdata or validate data prior to creation. Once an <code> InventoryForm 
 *  </code> is submiited to a create operation, it cannot be reused with 
 *  another create operation unless the first operation was unsuccessful. Each 
 *  <code> InventoryForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> InventoryForms </code> returned from <code> 
 *  getInventoryFormsForCreate() </code> may be linked to the originating 
 *  request through the peer <code> Ids </code> of the <code> InventoryForm. 
 *  </code> In the case where there may be duplicates, any <code> 
 *  InventoryForm </code> of the same peer <code> Ids </code> may be used for 
 *  a create operation. </p> 
 *  
 *  <p> Once a batch of <code> InventoryForms </code> are submitted for 
 *  create, a <code> CreateResponse </code> is returned for each <code> 
 *  InventoryForm, </code> although the ordering is not defined. Only errors 
 *  that pertain to the entire create operation are returned from <code> 
 *  createInventories(), </code> errors specific to an individual <code> 
 *  InventoryForm </code> are indicated in the corresponding <code> 
 *  CreateResponse. </code> <code> CreateResponses </code> may be linked to 
 *  the originating <code> InventoryForm </code> through the <code> 
 *  InventoryForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> InventoryForms </code> are requested to the <code> 
 *  Inventory </code> <code> Id </code> that is to be updated using <code> 
 *  getInventoryFormsForUpdate() </code> where the reference <code> Id </code> 
 *  in the <code> InventoryForm </code> may be used to link the request. 
 *  Similarly, the <code> InventoryForm </code> has metadata about the data 
 *  that can be updated and it can perform validation before submitting the 
 *  update. The <code> InventoryForm </code> can only be used once for a 
 *  successful update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> InventoryForms </code> are submitted for 
 *  update, an <code> UpdateResponse </code> is returned for each <code> 
 *  InventoryForm, </code> although the ordering is not defined. Only errors 
 *  that pertain to the entire update operation are returned from <code> 
 *  updateInventories(), </code> errors specific to an individual <code> 
 *  InventoryForm </code> are indicated in the corresponding <code> 
 *  UpdateResponse. </code> <code> UpdateResponses </code> may be linked to 
 *  the originating <code> InventoryForm </code> through the <code> 
 *  InventoryForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> Inventories </code> in bulk. Bulk 
 *  delete operations return the results in <code> DeleteResponses. </code> 
 *  </p>
 */

public interface InventoryBatchAdminSession
    extends org.osid.inventory.InventoryAdminSession {


    /**
     *  Gets the inventory forms for creating a bunch of new inventories. 
     *
     *  @param  number the number of forms to retrieve 
     *  @param  inventoryRecordTypes array of inventory record types to be 
     *          included in each create operation or an empty list if none 
     *  @return the inventory forms 
     *  @throws org.osid.NullArgumentException <code> inventoryRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.batch.InventoryBatchFormList getInventoryFormsForCreate(long number, 
                                                                                      org.osid.type.Type[] inventoryRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Inventories. </code> This method returns 
     *  an error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  inventoryForms the inventory forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> inventoryForms </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createInventories(org.osid.inventory.batch.InventoryBatchFormList inventoryForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the inventory forms for updating an existing set of inventories. 
     *  A new inventory form should be requested for each update transaction. 
     *
     *  @param  inventoryIds the <code> Ids </code> of the <code> Inventory 
     *          </code> 
     *  @return the inventory form 
     *  @throws org.osid.NotFoundException an <code> inventoryId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> inventoryIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.batch.InventoryBatchFormList getInventoryFormsForUpdate(org.osid.id.IdList inventoryIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing inventories. This method returns an error if the 
     *  entire operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  inventoryForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> inventoryForms </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateInventories(org.osid.inventory.batch.InventoryBatchFormList inventoryForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Inventories. </code> 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllInventories()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes inventories for the given <code> Ids. </code> 
     *
     *  @param  inventoryIds the <code> Ids </code> of the inventories to 
     *          delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> inventoryIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteInventories(org.osid.id.IdList inventoryIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to an <code> Inventory </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Inventory </code> is determined by the provider. The new 
     *  <code> Id </code> is an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another inventory, it is reassigned to the given 
     *  inventory <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasInventories(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
