//
// org.osid.inventory.shipment.EntryQuery
//
//     The OSID Java specification for org.osid.inventory.shipment.EntryQuery.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inventory.shipment;


/**
 *  <p>This is the query for searching entries. Each method match specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface EntryQuery
    extends org.osid.OsidObjectQuery,
            org.osid.OsidSubjugateableQuery {


    /**
     *  Sets the stock <code> Id </code> for this query. 
     *
     *  @param  stockId a stock <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> stockId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchStockId(org.osid.id.Id stockId, boolean match);


    /**
     *  Clears the stock <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStockIdTerms();


    /**
     *  Tests if a <code> StockQuery </code> is available. 
     *
     *  @return <code> true </code> if a stock query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStockQuery();


    /**
     *  Gets the query for a stock. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the stock query 
     *  @throws org.osid.UnimplementedException <code> supportsStockQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStockQuery() </code> is <code> true. </code> 
     */

    public org.osid.inventory.StockQuery getStockQuery();


    /**
     *  Clears the stock terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStockTerms();


    /**
     *  Sets the model <code> Id </code> for this query. 
     *
     *  @param  modelId a model <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> modelId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchModelId(org.osid.id.Id modelId, boolean match);


    /**
     *  Clears the model <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearModelIdTerms();


    /**
     *  Tests if a <code> ModelQuery </code> is available. 
     *
     *  @return <code> true </code> if a model query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsModelQuery();


    /**
     *  Gets the query for a model. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the model query 
     *  @throws org.osid.UnimplementedException <code> supportsModelQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsModelQuery() </code> is <code> true. </code> 
     */

    public org.osid.inventory.ModelQuery getModelQuery();


    /**
     *  Matches entries that have any model set. 
     *
     *  @param  match <code> true </code> to match entries with any model, 
     *          <code> false </code> to match entries with no model 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyModel(boolean match);


    /**
     *  Clears the model terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearModelTerms();


    /**
     *  Sets the item <code> Id </code> for this query. 
     *
     *  @param  itemId an item <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> itemId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchItemId(org.osid.id.Id itemId, boolean match);


    /**
     *  Clears the item <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearItemIdTerms();


    /**
     *  Tests if an <code> ItemQuery </code> is available. 
     *
     *  @return <code> true </code> if an item query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsItemQuery();


    /**
     *  Gets the query for an item. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the item query 
     *  @throws org.osid.UnimplementedException <code> supportsItemQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsItemQuery() </code> is <code> true. </code> 
     */

    public org.osid.inventory.ItemQuery getItemQuery();


    /**
     *  Matches entries that have any item set. 
     *
     *  @param  match <code> true </code> to match entries with any item, 
     *          <code> false </code> to match entries with no item 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyItem(boolean match);


    /**
     *  Clears the item terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearItemTerms();


    /**
     *  Matches entries with a quantity between the given range inclusive. 
     *
     *  @param  low start of range 
     *  @param  high end of range 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> low </code> is 
     *          greater than <code> high </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchQuantity(java.math.BigDecimal low, 
                              java.math.BigDecimal high, boolean match);


    /**
     *  Matches entries that have any quantity set. 
     *
     *  @param  match <code> true </code> to match entries with any quantity, 
     *          <code> false </code> to match entries with no quantity 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyQuantity(boolean match);


    /**
     *  Clears the quantity terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearQuantityTerms();


    /**
     *  Matches the a unit type. 
     *
     *  @param  type a unit tytpe 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> type </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchUnitType(org.osid.type.Type type, boolean match);


    /**
     *  Matches entries that have any unit type set. 
     *
     *  @param  match <code> true </code> to match entries with any unit type, 
     *          <code> false </code> to match entries with no unit type 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyUnitType(boolean match);


    /**
     *  Clears the unit type terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearUnitTypeTerms();


    /**
     *  Sets the warehouse <code> Id </code> for this query to match entries 
     *  assigned to warehouses. 
     *
     *  @param  warehouseId the warehouse <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> warehouseId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchWarehouseId(org.osid.id.Id warehouseId, boolean match);


    /**
     *  Clears the warehouse <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearWarehouseIdTerms();


    /**
     *  Tests if a <code> WarehouseQuery </code> is available. 
     *
     *  @return <code> true </code> if a warehouse query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsWarehouseQuery();


    /**
     *  Gets the query for a warehouse. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the warehouse query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsWarehouseQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsWarehouseQuery() </code> is <code> true. </code> 
     */

    public org.osid.inventory.WarehouseQuery getWarehouseQuery();


    /**
     *  Clears the warehouse terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearWarehouseTerms();


    /**
     *  Gets the entry query record corresponding to the given <code> Entry 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @param  entryRecordType an entry record type 
     *  @return the entry query record 
     *  @throws org.osid.NullArgumentException <code> entryRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(entryRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.shipment.records.EntryQueryRecord getEntryQueryRecord(org.osid.type.Type entryRecordType)
        throws org.osid.OperationFailedException;
}
