//
// org.osid.inventory.shipment.InventoryShipmentProfile
//
//     The OSID Java specification for org.osid.inventory.shipment.InventoryShipmentProfile.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inventory.shipment;


/**
 *  <p>The billing profile describes the interoperability among billing 
 *  management services. </p>
 */

public interface InventoryShipmentProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any warehouse federation is exposed. Federation is exposed 
     *  when a specific warehouse may be identified, selected and used to 
     *  create a lookup or admin session. Federation is not exposed when a set 
     *  of catalogs appears as a single catalog. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if looking up shipments is supported. 
     *
     *  @return <code> true </code> if shipment lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsShipmentLookup();


    /**
     *  Tests if querying shipments is supported. 
     *
     *  @return <code> true </code> if shipment query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsShipmentQuery();


    /**
     *  Tests if searching shipments is supported. 
     *
     *  @return <code> true </code> if shipment search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsShipmentSearch();


    /**
     *  Tests if shipment <code> </code> administrative service is supported. 
     *
     *  @return <code> true </code> if shipment administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsShipmentAdmin();


    /**
     *  Tests if a shipment <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if shipment notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsShipmentNotification();


    /**
     *  Tests if a warehouseing service is supported. 
     *
     *  @return <code> true </code> if warehouseing is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsShipmentWarehouse();


    /**
     *  Tests if a warehouseing service is supported. A warehouseing service 
     *  maps shipments to catalogs. 
     *
     *  @return <code> true </code> if warehouseing is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsShipmentWarehouseAssignment();


    /**
     *  Tests if a shipment smart warehouse session is available. 
     *
     *  @return <code> true </code> if a shipment smart warehouse session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsShipmentSmartWarehouse();


    /**
     *  Tests for the availability of a inventory shipment batch service. 
     *
     *  @return <code> true </code> if an inventory shipment batch service is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInventoryShipmentBatchBatch();


    /**
     *  Gets the supported <code> Shipment </code> record types. 
     *
     *  @return a list containing the supported <code> Shipment </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getShipmentRecordTypes();


    /**
     *  Tests if the given <code> Shipment </code> record type is supported. 
     *
     *  @param  shipmentRecordType a <code> Type </code> indicating a <code> 
     *          Shipment </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> shipmentRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsShipmentRecordType(org.osid.type.Type shipmentRecordType);


    /**
     *  Gets the supported <code> Shipment </code> search record types. 
     *
     *  @return a list containing the supported <code> Shipment </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getShipmentSearchRecordTypes();


    /**
     *  Tests if the given <code> Shipment </code> search record type is 
     *  supported. 
     *
     *  @param  shipmentSearchRecordType a <code> Type </code> indicating a 
     *          <code> Shipment </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> shipmentSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsShipmentSearchRecordType(org.osid.type.Type shipmentSearchRecordType);


    /**
     *  Gets the supported <code> Entry </code> record types. 
     *
     *  @return a list containing the supported <code> Entry </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getEntryRecordTypes();


    /**
     *  Tests if the given <code> Entry </code> record type is supported. 
     *
     *  @param  entryRecordType a <code> Type </code> indicating an <code> 
     *          Entry </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> entryRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEntryRecordType(org.osid.type.Type entryRecordType);


    /**
     *  Gets the supported <code> Entry </code> search record types. 
     *
     *  @return a list containing the supported <code> Entry </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getEntrySearchRecordTypes();


    /**
     *  Tests if the given <code> Entry </code> search record type is 
     *  supported. 
     *
     *  @param  entrySearchRecordType a <code> Type </code> indicating an 
     *          <code> Entry </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> entrySearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEntrySearchRecordType(org.osid.type.Type entrySearchRecordType);
}
