//
// org.osid.inventory.shipment.ShipmentSearchSession
//
//     The OSID Java specification for org.osid.inventory.shipment.ShipmentSearchSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inventory.shipment;


/**
 *  <p>This session provides methods for searching among <code> Shipment 
 *  </code> objects. The search query is constructed using the <code> 
 *  ShipmentQuery. </code> </p> 
 *  
 *  <p> <code> getShipmentsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Shipments. </code> A more advanced search may be 
 *  performed with <code> getShipmentsBySearch(). </code> It accepts a <code> 
 *  ShipmentSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getShipmentsBySearch() </code> returns a <code> 
 *  ShipmentSearchResults </code> that can be used to access the resulting 
 *  <code> ShipmentList </code> or be used to perform a search within the 
 *  result set through <code> ShipmentSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated warehouse view: searches include shipments in 
 *      warehouses of which this warehouse is an ancestor in the warehouse 
 *      hierarchy </li> 
 *      <li> isolated warehouse view: searches are restricted to shipments in 
 *      this warehouse </li> 
 *  </ul>
 *  
 *  
 *  <p> Shipments may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> ShipmentQuery. </code> 
 *  </p>
 */

public interface ShipmentSearchSession
    extends org.osid.inventory.shipment.ShipmentQuerySession {


    /**
     *  Gets a shipment search. 
     *
     *  @return the shipment search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.shipment.ShipmentSearch getShipmentSearch();


    /**
     *  Gets a shipment search order. The <code> ShipmentSearchOrder </code> 
     *  is supplied to a <code> ShipmentSearch </code> to specify the ordering 
     *  of results. 
     *
     *  @return the shipment search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.shipment.ShipmentSearchOrder getShipmentSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  shipmentQuery the shipment query 
     *  @param  shipmentSearch the shipment search 
     *  @return the shipment search results 
     *  @throws org.osid.NullArgumentException <code> shipmentQuery </code> or 
     *          <code> shipmentSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> shipmentQuery </code> or 
     *          <code> shipmentSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.shipment.ShipmentSearchResults getShipmentsBySearch(org.osid.inventory.shipment.ShipmentQuery shipmentQuery, 
                                                                                  org.osid.inventory.shipment.ShipmentSearch shipmentSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a shipment query from an inspector. The inspector is available 
     *  from a <code> ShipmentSearchResults. </code> 
     *
     *  @param  shipmentQueryInspector a shipment query inspector 
     *  @return the shipment query 
     *  @throws org.osid.NullArgumentException <code> shipmentQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> shipmentQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.shipment.ShipmentQuery getShipmentQueryFromInspector(org.osid.inventory.shipment.ShipmentQueryInspector shipmentQueryInspector);
}
