//
// org.osid.inventory.shipment.ShipmentSmartWarehouseSession
//
//     The OSID Java specification for org.osid.inventory.shipment.ShipmentSmartWarehouseSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inventory.shipment;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. A <code> ShipmentQuery </code> can be retrieved from this 
 *  session and mapped to this <code> Warehouse </code> to create a virtual 
 *  collection of <code> Shipments. </code> The shipments may be sequenced 
 *  using the <code> ShipmentSearchOrder </code> from this session. </p> 
 *  
 *  <p> This <code> Warehouse </code> has a default query that matches any 
 *  shipment and a default search order that specifies no sequencing. The 
 *  queries may be examined using a <code> ShipmentQueryInspector. </code> The 
 *  query may be modified by converting the inspector back to a <code> 
 *  ShipmentQuery. </code> </p>
 */

public interface ShipmentSmartWarehouseSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Warehouse </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Warehouse Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getWarehouseId();


    /**
     *  Gets the <code> Warehouse </code> associated with this session. 
     *
     *  @return the warehouse 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.Warehouse getWarehouse()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart warehouses. A return of true does 
     *  not guarantee successful assessment. A return of false indicates that 
     *  it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart warehouse management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartWarehouses();


    /**
     *  Gets a shipment query. 
     *
     *  @return the shipment query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.shipment.ShipmentQuery getShipmentQuery();


    /**
     *  Gets a shipment search order. 
     *
     *  @return the shipment search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.shipment.ShipmentSearchOrder getShipmentSearchOrder();


    /**
     *  Applies a shipment query to this warehouse. 
     *
     *  @param  shipmentQuery the shipment query 
     *  @throws org.osid.NullArgumentException <code> shipmentQuery </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> shipmentQuery </code> not 
     *          of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyShipmentQuery(org.osid.inventory.shipment.ShipmentQuery shipmentQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a shipment query inspector for this warehouse. 
     *
     *  @return the shipment query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.shipment.ShipmentQueryInspector inspectShipmentQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a shipment search order to this warehouse. 
     *
     *  @param  shipmentSearchOrder the shipment search order 
     *  @throws org.osid.NullArgumentException <code> shipmentSearchOrder 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> shipmentSearchOrder 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyShipmentSequencing(org.osid.inventory.shipment.ShipmentSearchOrder shipmentSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a shipment query from an inspector. 
     *
     *  @param  shipmentQueryInspector a query inspector 
     *  @return the shipment query 
     *  @throws org.osid.NullArgumentException <code> shipmentQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> shipmentQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.shipment.ShipmentQuery getShipmentQueryFromInspector(org.osid.inventory.shipment.ShipmentQueryInspector shipmentQueryInspector);
}
