//
// org.osid.inventory.shipment.batch.ShipmentBatchAdminSession
//
//     The OSID Java specification for org.osid.inventory.shipment.batch.ShipmentBatchAdminSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inventory.shipment.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Shipments </code> in 
 *  bulk. The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Shipment, </code> a <code> ShipmentForm </code> is requested using <code> 
 *  getShipmentFormsForCreate() </code> specifying the desired record <code> 
 *  Types </code> or none if no record <code> Types </code> are needed. Each 
 *  of the returned <code> ShipmentForms </code> will indicate that it is to 
 *  be used with a create operation and can be used to examine metdata or 
 *  validate data prior to creation. Once a <code> ShipmentForm </code> is 
 *  submiited to a create operation, it cannot be reused with another create 
 *  operation unless the first operation was unsuccessful. Each <code> 
 *  ShipmentForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> ShipmentForms </code> returned from <code> 
 *  getShipmentFormsForCreate() </code> may be linked to the originating 
 *  request through the peer <code> Ids </code> of the <code> ShipmentForm. 
 *  </code> In the case where there may be duplicates, any <code> ShipmentForm 
 *  </code> of the same peer <code> Ids </code> may be used for a create 
 *  operation. </p> 
 *  
 *  <p> Once a batch of <code> ShipmentForms </code> are submitted for create, 
 *  a <code> CreateResponse </code> is returned for each <code> ShipmentForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire create operation are returned from <code> createShipments(), 
 *  </code> errors specific to an individual <code> ShipmentForm </code> are 
 *  indicated in the corresponding <code> CreateResponse. </code> <code> 
 *  CreateResponses </code> may be linked to the originating <code> 
 *  ShipmentForm </code> through the <code> ShipmentForm </code> <code> Id 
 *  </code> . </p> 
 *  
 *  <p> For updates, <code> ShipmentForms </code> are requested to the <code> 
 *  Shipment </code> <code> Id </code> that is to be updated using <code> 
 *  getShipmentFormsForUpdate() </code> where the reference <code> Id </code> 
 *  in the <code> ShipmentForm </code> may be used to link the request. 
 *  Similarly, the <code> ShipmentForm </code> has metadata about the data 
 *  that can be updated and it can perform validation before submitting the 
 *  update. The <code> ShipmentForm </code> can only be used once for a 
 *  successful update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> ShipmentForms </code> are submitted for update, 
 *  an <code> UpdateResponse </code> is returned for each <code> ShipmentForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire update operation are returned from <code> updateShipments(), 
 *  </code> errors specific to an individual <code> ShipmentForm </code> are 
 *  indicated in the corresponding <code> UpdateResponse. </code> <code> 
 *  UpdateResponses </code> may be linked to the originating <code> 
 *  ShipmentForm </code> through the <code> ShipmentForm </code> <code> Id. 
 *  </code> </p> 
 *  
 *  <p> The delete operations delete <code> Shipments </code> in bulk. To 
 *  unmap a <code> Shipment </code> from the current <code> Warehouse, </code> 
 *  the <code> ShipmentWarehouseAssignmentSession </code> should be used. 
 *  These delete operations attempt to remove the <code> Shipment </code> 
 *  itself thus removing it from all known <code> Warehouse </code> catalogs. 
 *  Bulk delete operations return the results in <code> DeleteResponses. 
 *  </code> </p>
 */

public interface ShipmentBatchAdminSession
    extends org.osid.inventory.shipment.ShipmentAdminSession {


    /**
     *  Gets the shipment forms for creating a bunch of new shipments. 
     *
     *  @param  number the number of forms to retrieve 
     *  @param  shipmentRecordTypes array of shipment record types to be 
     *          included in each create operation or an empty list if none 
     *  @return the shipment forms 
     *  @throws org.osid.NullArgumentException <code> shipmentRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.shipment.batch.ShipmentBatchFormList getShipmentFormsForCreate(long number, 
                                                                                             org.osid.type.Type[] shipmentRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Shipments. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  shipmentForms the shipment forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> shipmentForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createShipments(org.osid.inventory.shipment.batch.ShipmentBatchFormList shipmentForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the shipment forms for updating an existing set of shipments. A 
     *  new shipment form should be requested for each update transaction. 
     *
     *  @param  shipmentIds the <code> Ids </code> of the <code> Shipment 
     *          </code> 
     *  @return the shipment form 
     *  @throws org.osid.NotFoundException a <code> shipmentId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> shipmentIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.shipment.batch.ShipmentBatchFormList getShipmentFormsForUpdate(org.osid.id.IdList shipmentIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing shipments. This method returns an error if the entire 
     *  operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  shipmentForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> shipmentForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateShipments(org.osid.inventory.shipment.batch.ShipmentBatchFormList shipmentForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Shipments </code> in this <code> Warehouse </code> 
     *  . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllShipments()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes shipments for the given <code> Ids. </code> 
     *
     *  @param  shipmentIds the <code> Ids </code> of the shipments to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> shipmentIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteShipments(org.osid.id.IdList shipmentIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Shipment </code> for the purpose 
     *  of creating compatibility. The primary <code> Id </code> of the <code> 
     *  Shipment </code> is determined by the provider. The new <code> Id 
     *  </code> is an alias to the primary <code> Id. </code> If the alias is 
     *  a pointer to another shipment, it is reassigned to the given shipment 
     *  <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasShipments(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the entry forms for creating a bunch of new entries. A form is 
     *  returned for each supplied shipment. 
     *
     *  @param  shipmentIds a list of shipment <code> Ids </code> 
     *  @param  shipmentRecordTypes array of shipment record types to be 
     *          included in each create operation or an empty list if none 
     *  @return the entry forms 
     *  @throws org.osid.NotFoundException a <code> shipmentId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> shipmentIds </code> or 
     *          <code> shipmentRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.shipment.batch.EntryBatchFormList getEntryFormsForCreate(org.osid.id.IdList shipmentIds, 
                                                                                       org.osid.type.Type[] shipmentRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Entries. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  entryForms the entry forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> entryForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createEntries(org.osid.inventory.shipment.batch.EntryBatchFormList entryForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the entry forms for updating an existing set of entries. A new 
     *  entry form should be requested for each update transaction. 
     *
     *  @param  entryIds the <code> Ids </code> of the <code> Entry </code> 
     *  @return the entry form 
     *  @throws org.osid.NotFoundException an <code> entryId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> entryIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.shipment.batch.EntryBatchFormList getEntryFormsForUpdate(org.osid.id.IdList entryIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing entries. This method returns an error if the entire 
     *  operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  entryForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> entryForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateEntries(org.osid.inventory.shipment.batch.EntryBatchFormList entryForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Entries </code> in this <code> Warehouse </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllEntries()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes entries for the given <code> Ids. </code> 
     *
     *  @param  entryIds the <code> Ids </code> of the entries to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> entryIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteEntries(org.osid.id.IdList entryIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes entries for the given shipment. 
     *
     *  @param  shipmentId the <code> Ids </code> of the shipment 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> shipmentId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteEntriesForShipment(org.osid.id.Id shipmentId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to an <code> Entry </code> for the purpose 
     *  of creating compatibility. The primary <code> Id </code> of the <code> 
     *  Entry </code> is determined by the provider. The new <code> Id </code> 
     *  is an alias to the primary <code> Id. </code> If the alias is a 
     *  pointer to another entry, it is reassigned to the given entry <code> 
     *  Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasEntries(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
