//
// org.osid.journaling.BranchLookupSession
//
//     The OSID Java specification for org.osid.journaling.BranchLookupSession.
//
// Copyright (C) 2009, 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.journaling;


/**
 *  <p>This session defines methods for retrieving branches. A <code> Branch 
 *  </code> is an arbitrary entity that may represent a person, place or thing 
 *  used to identify an object used in various services. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated journal view: All branch methods in this session 
 *      operate, retrieve and pertain to branches defined explicitly in the 
 *      current journal. Using an isolated view is useful for managing <code> 
 *      Branches </code> with the <code> BranchAdminSession. </code> </li> 
 *      <li> federated journal view: All branch methods in this session 
 *      operate, retrieve and pertain to all branches defined in this journal 
 *      and any other branches implicitly available in this journal through 
 *      journal inheritence. </li> 
 *      <li> active branch view: Active brcnhes are returned in this session. 
 *      </li> 
 *      <li> any status branch view: Active and inactive branches are returned 
 *      in this session. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedJournalView() </code> and <code> 
 *  useIsolatedJournalView() </code> behave as a radio group and one should be 
 *  selected before invoking any lookup methods. </p> 
 *  
 *  <p> Branches may have an additional records indicated by their respective 
 *  record types. The record may not be accessed through a cast of the <code> 
 *  Branch. </code> </p>
 */

public interface BranchLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Journal </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Journal Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getJournalId();


    /**
     *  Gets the <code> Journal </code> associated with this session. 
     *
     *  @return the <code> Journal </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.Journal getJournal()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Branch </code> lookups. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupBranches();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeBranchView();


    /**
     *  A complete view of the <code> Branch </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryBranchView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include branches in journals which are children of this journal in the 
     *  journal hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedJournalView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this journal only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedJournalView();


    /**
     *  Methods return only branches that are active. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveBranchView();


    /**
     *  Actuve and inactive branches are returned from lookup methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusBranchView();


    /**
     *  Gets the <code> Branch </code> specified by its <code> Id. </code> In 
     *  plenary mode, the exact <code> Id </code> is found or a <code> 
     *  NOT_FOUND </code> results. Otherwise, the returned <code> Branch 
     *  </code> may have a different <code> Id </code> than requested, such as 
     *  the case where a duplicate <code> Id </code> was assigned to a <code> 
     *  Branch </code> and retained for compatibility. 
     *
     *  @param  branchId the <code> Id </code> of the <code> Branch </code> to 
     *          retrieve 
     *  @return the returned <code> Branch </code> 
     *  @throws org.osid.NotFoundException no <code> Branch </code> found with 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> branchId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.Branch getBranch(org.osid.id.Id branchId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BranchList </code> corresponding to the given <code> 
     *  IdList. </code> In plenary mode, the returned list contains all of the 
     *  branches specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Branches </code> may be omitted from the list and 
     *  may present the elements in any order including returning a unique 
     *  set. 
     *
     *  @param  branchIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Branch </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> branchIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.BranchList getBranchesByIds(org.osid.id.IdList branchIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BranchList </code> corresponding to the given branch 
     *  genus <code> Type </code> which does not include branches of types 
     *  derived from the specified <code> Type. </code> In plenary mode, the 
     *  returned list contains all known branches or an error results. 
     *  Otherwise, the returned list may contain only those branches that are 
     *  accessible through this session. 
     *
     *  @param  branchGenusType a branch genus type 
     *  @return the returned <code> Branch </code> list 
     *  @throws org.osid.NullArgumentException <code> branchGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.BranchList getBranchesByGenusType(org.osid.type.Type branchGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BranchList </code> corresponding to the given branch 
     *  genus <code> Type </code> and include any additional branches with 
     *  genus types derived from the specified <code> Type. </code> In plenary 
     *  mode, the returned list contains all known branches or an error 
     *  results. Otherwise, the returned list may contain only those branches 
     *  that are accessible through this session. 
     *
     *  @param  branchGenusType a branch genus type 
     *  @return the returned <code> Branch </code> list 
     *  @throws org.osid.NullArgumentException <code> branchGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.BranchList getBranchesByParentGenusType(org.osid.type.Type branchGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BranchList </code> containing the given branch record 
     *  <code> Type. </code> In plenary mode, the returned list contains all 
     *  known branches or an error results. Otherwise, the returned list may 
     *  contain only those branches that are accessible through this session. 
     *
     *  @param  branchRecordType a branch record type 
     *  @return the returned <code> Branch </code> list 
     *  @throws org.osid.NullArgumentException <code> branchRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.BranchList getBranchesByRecordType(org.osid.type.Type branchRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Branches. </code> In plenary mode, the returned list 
     *  contains all known branches or an error results. Otherwise, the 
     *  returned list may contain only those branches that are accessible 
     *  through this session. 
     *
     *  @return a list of <code> Branches </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.BranchList getBranches()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
