//
// org.osid.journaling.BranchQuery
//
//     The OSID Java specification for org.osid.journaling.BranchQuery.
//
// Copyright (C) 2009, 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.journaling;


/**
 *  <p>This is the query for searching branches Each method specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface BranchQuery
    extends org.osid.OsidObjectQuery,
            org.osid.OsidOperableQuery {


    /**
     *  Sets the origin journal entry <code> Id </code> for this query. 
     *
     *  @param  journalEntryId a journal entry Id <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> journalEntryId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchOriginJournalEntryId(org.osid.id.Id journalEntryId, 
                                          boolean match);


    /**
     *  Clears the origin journal entry <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOriginJournalEntryIdTerms();


    /**
     *  Tests if a <code> JournalEntryQuery </code> is available. 
     *
     *  @return <code> true </code> if a journal entry query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOriginJournalEntryQuery();


    /**
     *  Gets the query for an origin journal entry. Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @return the origin journal entry query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOriginJournalEntryQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOriginJournalEntryQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.journaling.JournalEntryQuery getOriginJournalEntryQuery();


    /**
     *  Clears the origin journal entry terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOriginJournalEntryTerms();


    /**
     *  Sets the latest journal entry <code> Id </code> for this query. 
     *
     *  @param  journalEntryId a journal entry Id <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> journalEntryId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchLatestJournalEntryId(org.osid.id.Id journalEntryId, 
                                          boolean match);


    /**
     *  Clears the latest journal entry <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLatestJournalEntryIdTerms();


    /**
     *  Tests if a <code> JournalEntryQuery </code> is available. 
     *
     *  @return <code> true </code> if a journal entry query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLatestJournalEntryQuery();


    /**
     *  Gets the query for a latest journal entry. Multiple retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @return the latest journal entry query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOriginJournalEntryQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOriginJournalEntryQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.journaling.JournalEntryQuery getLatestJournalEntryQuery();


    /**
     *  Clears the latest journal entry terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLatestJournalEntryTerms();


    /**
     *  Gets the branch query record corresponding to the given <code> Branch 
     *  </code> record <code> Type. </code> Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @param  branchRecordType a branch record type 
     *  @return the branch query record 
     *  @throws org.osid.NullArgumentException <code> branchRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(branchRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.records.BranchQueryRecord getBranchQueryRecord(org.osid.type.Type branchRecordType)
        throws org.osid.OperationFailedException;
}
