//
// org.osid.journaling.BranchSearchSession
//
//     The OSID Java specification for org.osid.journaling.BranchSearchSession.
//
// Copyright (C) 2009, 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.journaling;


/**
 *  <p>This session provides methods for searching among <code> Branch </code> 
 *  objects. The search query is constructed using the <code> BranchQuery. 
 *  </code> </p> 
 *  
 *  <p> <code> getBranchsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Branches. </code> A more advanced search may be 
 *  performed with <code> getBranchesBySearch(). </code> It accepts an <code> 
 *  BranchSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getBranchesBySearch() </code> returns an <code> 
 *  BranchSearchResults </code> that can be used to access the resulting 
 *  <code> BranchList </code> or be used to perform a search within the result 
 *  set through <code> BranchList. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated journal view: searches include branches in journals of 
 *      which this journal is a ancestor in the journal hierarchy </li> 
 *      <li> isolated journal view: searches are restricted to branches in 
 *      this journal </li> 
 *  </ul>
 *  
 *  
 *  <p> Branches may have a query record indicated by their respective recod 
 *  types. The query record is accessed via the <code> BranchQuery. </code> 
 *  </p>
 */

public interface BranchSearchSession
    extends org.osid.journaling.BranchQuerySession {


    /**
     *  Gets a branch search. 
     *
     *  @return the branch search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.BranchSearch getBranchSearch();


    /**
     *  Gets a branch search order. The <code> BranchSearchOrder </code> is 
     *  supplied to a <code> BranchSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the branch search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.BranchSearchOrder getBranchSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  branchQuery the branch query 
     *  @param  branchSearch the branch search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> branchQuery </code> or 
     *          <code> branchSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> branchQuery </code> or 
     *          <code> branchSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.BranchSearchResults getBranchesBySearch(org.osid.journaling.BranchQuery branchQuery, 
                                                                       org.osid.journaling.BranchSearch branchSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a branch query from an inspector. The inspector is available from 
     *  a <code> BranchSearchResults. </code> 
     *
     *  @param  branchQueryInspector a branch query inspector 
     *  @return the branch query 
     *  @throws org.osid.NullArgumentException <code> branchQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> branchQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.BranchQuery getBranchQueryFromInspector(org.osid.journaling.BranchQueryInspector branchQueryInspector);
}
