//
// org.osid.journaling.BranchSmartJournalSession
//
//     The OSID Java specification for org.osid.journaling.BranchSmartJournalSession.
//
// Copyright (C) 2009, 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.journaling;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. A <code> BranchQuery </code> can be retrieved from this session 
 *  and mapped to this <code> Journal </code> to create a virtual collection 
 *  of <code> Branches. </code> The branches may be sequenced using the <code> 
 *  BranchSearchOrder </code> from this session. </p> 
 *  
 *  <p> This <code> Journal </code> has a default query that matches any 
 *  branch and a default search order that specifies no sequencing. The 
 *  queries may be examined using a <code> BranchQueryInspector. </code> The 
 *  query may be modified by converting the inspector back to a <code> 
 *  BranchQuery. </code> </p>
 */

public interface BranchSmartJournalSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Journal </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Journal Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getJournalId();


    /**
     *  Gets the <code> Journal </code> associated with this session. 
     *
     *  @return the <code> Journal </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.Journal getJournal()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart journals. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart journal management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartJournals();


    /**
     *  Gets a branch query. 
     *
     *  @return the branch query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.BranchQuery getBranchQuery();


    /**
     *  Gets a branch search order. 
     *
     *  @return the branch search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.BranchSearchOrder getBranchSearchOrder();


    /**
     *  Applies a branch query to this journal. 
     *
     *  @param  branchQuery the branch query 
     *  @throws org.osid.NullArgumentException <code> branchQuery </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> branchQuery </code> not 
     *          of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyBranchQuery(org.osid.journaling.BranchQuery branchQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a branch query inspector for this journal. 
     *
     *  @return the branch query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.BranchQueryInspector inspectBranchQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a branch search order to this journal. 
     *
     *  @param  branchSearchOrder the branch search order 
     *  @throws org.osid.NullArgumentException <code> branchSearchOrder 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> branchSearchOrder </code> 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyBranchSequencing(org.osid.journaling.BranchSearchOrder branchSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a branch query from an inspector. 
     *
     *  @param  branchQueryInspector a branch query inspector 
     *  @return the branch query 
     *  @throws org.osid.NullArgumentException <code> branchQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> branchQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.BranchQuery getBranchQueryFromInspector(org.osid.journaling.BranchQueryInspector branchQueryInspector);
}
