//
// org.osid.journaling.JournalEntryAdminSession
//
//     The OSID Java specification for org.osid.journaling.JournalEntryAdminSession.
//
// Copyright (C) 2009, 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.journaling;


/**
 *  <p>This session creates, updates, and deletes <code> JournalEntries. 
 *  </code> The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  JournalEntry, </code> a <code> JournalEntryForm </code> is requested using 
 *  <code> getJournalEntryFormForCreate() </code> specifying the desired 
 *  record <code> Types </code> or none if no record <code> Types </code> are 
 *  needed. The returned <code> JournalEntryForm </code> will indicate that it 
 *  is to be used with a create operation and can be used to examine metdata 
 *  or validate data prior to creation. Once the <code> JournalEntryForm 
 *  </code> is submiited to a create operation, it cannot be reused with 
 *  another create operation unless the first operation was unsuccessful. Each 
 *  <code> JournalEntryForm </code> corresponds to an attempted transaction. 
 *  </p> 
 *  
 *  <p> For updates, <code> JournalEntryForms </code> are requested to the 
 *  <code> JournalEntry </code> <code> Id </code> that is to be updated using 
 *  <code> getJournalEntryFormForUpdate(). </code> Similarly, the <code> 
 *  JournalEntryForm </code> has metadata about the data that can be updated 
 *  and it can perform validation before submitting the update. The <code> 
 *  JournalEntryForm </code> can only be used once for a successful update and 
 *  cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> JournalEntries. </code> </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface JournalEntryAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Journal </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Journal Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getJournalId();


    /**
     *  Gets the <code> Journal </code> associated with this session. 
     *
     *  @return the journal 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.Journal getJournal()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create journal entries. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known creating a <code> JournalEntry </code> will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer create operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> JournalEntry </code> creation 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateJournalEntries();


    /**
     *  Tests if this user can create a single <code> JournalEntry </code> 
     *  using the desired record interface types. While <code> 
     *  JournalingManager.getJournalEntryRecordTypes() </code> can be used to 
     *  examine which record interfaces are supported, this method tests which 
     *  record(s) are required for creating a specific <code> JournalEntry. 
     *  </code> Providing an empty array tests if a <code> JournalEntry 
     *  </code> can be created with no records. 
     *
     *  @param  journalEntryRecordTypes array of journal entry record types 
     *  @return <code> true </code> if <code> JournalEntry </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> journalEntryRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateJournalEntryWithRecordTypes(org.osid.type.Type[] journalEntryRecordTypes);


    /**
     *  Gets the journal entry form for creating new entries. A new form 
     *  should be requested for each create transaction. 
     *
     *  @param  branchId the <code> Id </code> for the branch 
     *  @param  sourceId the <code> Id </code> for the journaled object 
     *  @param  journalEntryRecordTypes array of journal entry record types 
     *  @return the journal entry form 
     *  @throws org.osid.NotFoundException <code> branchId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> branchId, sourceId, 
     *          </code> or <code> journalEntryRecordTypes </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.JournalEntryForm getJournalEntryFormForCreate(org.osid.id.Id branchId, 
                                                                             org.osid.id.Id sourceId, 
                                                                             org.osid.type.Type[] journalEntryRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> JournalEntry. </code> 
     *
     *  @param  journalEntryForm the form for this <code> JournalEntry </code> 
     *  @return the new <code> JournalEntry </code> 
     *  @throws org.osid.IllegalStateException <code> journalEntryForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> journalEntryForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> journalEntryForm </code> 
     *          did not originate from <code> getJournalEntryFormForCreate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.JournalEntry createJournalEntry(org.osid.journaling.JournalEntryForm journalEntryForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update journal entries. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known updating a <code> JournalEntry </code> will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer update operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> JournalEntry </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateJournalEntries();


    /**
     *  Gets the journal entry form for updating an existing entry. A new 
     *  journal entry form should be requested for each update transaction. 
     *
     *  @param  journalEntryId the <code> Id </code> of the <code> 
     *          JournalEntry </code> 
     *  @return the entry form 
     *  @throws org.osid.NotFoundException <code> journalEntryId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> journalEntryId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.JournalEntryForm getJournalEntryFormForUpdate(org.osid.id.Id journalEntryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing journal entry. 
     *
     *  @param  journalEntryForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> journalEntryForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> journalEntryForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> journalEntryForm </code> 
     *          did not originate from <code> getJournalEntryFormForUpdate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateJournalEntry(org.osid.journaling.JournalEntryForm journalEntryForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete journal entries. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known deleting a <code> JournalEntry </code> will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer delete operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> JournalEntry </code> deletion 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteJournalEntries();


    /**
     *  Deletes a <code> JournalEntry. </code> 
     *
     *  @param  journalEntryId the <code> Id </code> of the <code> 
     *          JournalEntry </code> to remove 
     *  @throws org.osid.NotFoundException <code> journalEntryId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> journalEntryId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteJournalEntry(org.osid.id.Id journalEntryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for journal 
     *  entries. A return of true does not guarantee successful authorization. 
     *  A return of false indicates that it is known changing an alias will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer alias operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> JournalEntry </code> aliasing 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageJournalEntryAliases();


    /**
     *  Adds an <code> Id </code> to a <code> JournalEntry </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> JournalEntry </code> is determined by the provider. The new 
     *  <code> Id </code> performs as an alias to the primary <code> Id. 
     *  </code> If the alias is a pointer to another journal entry it is 
     *  reassigned to the given journal entry <code> Id. </code> 
     *
     *  @param  journalEntryId the <code> Id </code> of a <code> JournalEntry 
     *          </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> journalEntryId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> journalEntryId </code> 
     *          or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasJournalEntry(org.osid.id.Id journalEntryId, 
                                  org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
