//
// org.osid.journaling.JournalQuery
//
//     The OSID Java specification for org.osid.journaling.JournalQuery.
//
// Copyright (C) 2009, 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.journaling;


/**
 *  <p>This is the query for searching for journals. Each method specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface JournalQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Sets the journal entry <code> Id </code> for this query to match 
     *  entries assigned to journals. 
     *
     *  @param  journalEntryId a journal entry <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> journalEntryId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchJournalEntryId(org.osid.id.Id journalEntryId, 
                                    boolean match);


    /**
     *  Clears the journal entry <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearJournalEntryIdTerms();


    /**
     *  Tests if a journal entry query is available. 
     *
     *  @return <code> true </code> if a journal entry query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJournalEntryQuery();


    /**
     *  Gets the query for a journal. 
     *
     *  @return the journal entry query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJournalEntryQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJournalEntryQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.journaling.JournalEntryQuery getJournalEntryQuery();


    /**
     *  Matches journals with any journal entry. 
     *
     *  @param  match <code> true </code> to match journals with any journal 
     *          entry, <code> false </code> to match journals with no entries 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyJournalEntry(boolean match);


    /**
     *  Clears the journal entry terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearJournalEntryTerms();


    /**
     *  Sets the branch <code> Id </code> for this query to match branches 
     *  assigned to journals. 
     *
     *  @param  branchId a branch <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> branchId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBranchId(org.osid.id.Id branchId, boolean match);


    /**
     *  Clears the branch <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBranchIdTerms();


    /**
     *  Tests if a branch query is available. 
     *
     *  @return <code> true </code> if a branch query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBranchQuery();


    /**
     *  Gets the query for a branch. 
     *
     *  @return the branch query 
     *  @throws org.osid.UnimplementedException <code> supportsBranchQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBranchQuery() </code> is <code> true. </code> 
     */

    public org.osid.journaling.BranchQuery getBranchQuery();


    /**
     *  Matches journals with any branches. 
     *
     *  @param  match <code> true </code> to match journals with any branch, 
     *          <code> false </code> to match journals with no branches 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyBranch(boolean match);


    /**
     *  Clears the branch terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBranchTerms();


    /**
     *  Sets the journal <code> Id </code> for this query to match journals 
     *  that have the specified journal as an ancestor. 
     *
     *  @param  journalId a journal <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> journalId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorJournalId(org.osid.id.Id journalId, boolean match);


    /**
     *  Clears the ancestor journal <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorJournalIdTerms();


    /**
     *  Tests if a <code> JournalQuery </code> is available. 
     *
     *  @return <code> true </code> if a journal query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorJournalQuery();


    /**
     *  Gets the query for a journal. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the journal query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorJournalQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorJournalQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.journaling.JournalQuery getAncestorJournalQuery();


    /**
     *  Matches journals with any ancestor. 
     *
     *  @param  match <code> true </code> to match journals with any ancestor, 
     *          <code> false </code> to match root journals 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorJournal(boolean match);


    /**
     *  Clears the ancestor journal terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorJournalTerms();


    /**
     *  Sets the journal <code> Id </code> for this query to match journals 
     *  that have the specified journal as a descendant. 
     *
     *  @param  journalId a journal <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> journalId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantJournalId(org.osid.id.Id journalId, 
                                         boolean match);


    /**
     *  Clears the descendant journal <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantJournalIdTerms();


    /**
     *  Tests if a <code> JournalQuery </code> is available. 
     *
     *  @return <code> true </code> if a journal query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantJournalQuery();


    /**
     *  Gets the query for a journal. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the journal query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantJournalQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantJournalQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.journaling.JournalQuery getDescendantJournalQuery();


    /**
     *  Matches journals with any descendant. 
     *
     *  @param  match <code> true </code> to match journals with any 
     *          descendant, <code> false </code> to match leaf journals 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantJournal(boolean match);


    /**
     *  Clears the descendant journal terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantJournalTerms();


    /**
     *  Gets the journal query record corresponding to the given <code> 
     *  Journal </code> record <code> Type. </code> Multiple record retrievals 
     *  produce a nested boolean <code> OR </code> term. 
     *
     *  @param  journalRecordType a journal record type 
     *  @return the journal query record 
     *  @throws org.osid.NullArgumentException <code> journalRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(journalRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.records.JournalQueryRecord getJournalQueryRecord(org.osid.type.Type journalRecordType)
        throws org.osid.OperationFailedException;
}
