//
// org.osid.journaling.batch.BranchBatchAdminSession
//
//     The OSID Java specification for org.osid.journaling.batch.BranchBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.journaling.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Branches </code> in 
 *  bulk. The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Branch, </code> a <code> BranchForm </code> is requested using <code> 
 *  getBranchFormsForCreate() </code> specifying the desired work, resource, 
 *  and record <code> Types </code> or none if no record <code> Types </code> 
 *  are needed. Each of the returned <code> BranchForms </code> will indicate 
 *  that it is to be used with a create operation and can be used to examine 
 *  metdata or validate data prior to creation. Once a <code> BranchForm 
 *  </code> is submiited to a create operation, it cannot be reused with 
 *  another create operation unless the first operation was unsuccessful. Each 
 *  <code> BranchForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> BranchForms </code> returned from <code> 
 *  getBranchFormsForCreate() </code> may be linked to the originating request 
 *  through the peer <code> Ids </code> of the <code> BranchForm. </code> In 
 *  the case where there may be duplicates, any <code> BranchForm </code> of 
 *  the same peer <code> Ids </code> may be used for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> BranchForms </code> are submitted for create, a 
 *  <code> CreateResponse </code> is returned for each <code> BranchForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire create operation are returned from <code> createBranches(), 
 *  </code> errors specific to an individual <code> BranchForm </code> are 
 *  indicated in the corresponding <code> CreateResponse. </code> <code> 
 *  CreateResponses </code> may be linked to the originating <code> BranchForm 
 *  </code> through the <code> BranchForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> BranchForms </code> are requested to the <code> 
 *  Branch </code> <code> Id </code> that is to be updated using <code> 
 *  getBranchFormsForUpdate() </code> where the reference <code> Id </code> in 
 *  the <code> BranchForm </code> may be used to link the request. Similarly, 
 *  the <code> BranchForm </code> has metadata about the data that can be 
 *  updated and it can perform validation before submitting the update. The 
 *  <code> BranchForm </code> can only be used once for a successful update 
 *  and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> BranchForms </code> are submitted for update, 
 *  an <code> UpdateResponse </code> is returned for each <code> BranchForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire update operation are returned from <code> updateBranches(), 
 *  </code> errors specific to an individual <code> BranchForm </code> are 
 *  indicated in the corresponding <code> UpdateResponse. </code> <code> 
 *  UpdateResponses </code> may be linked to the originating <code> BranchForm 
 *  </code> through the <code> BranchForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> Branches </code> in bulk. To unmap 
 *  a <code> Branch </code> from the current <code> Journal, </code> the 
 *  <code> BranchJournalAssignmentSession </code> should be used. These delete 
 *  operations attempt to remove the <code> Branch </code> itself thus 
 *  removing it from all known <code> Journal </code> catalogs. Bulk delete 
 *  operations return the results in <code> DeleteResponses. </code> </p>
 */

public interface BranchBatchAdminSession
    extends org.osid.journaling.BranchAdminSession {


    /**
     *  Gets the branch forms for creating a bunch of new branches. A form is 
     *  returned for each supplued journal entry. 
     *
     *  @param  journalEntryIds a list of journal entry <code> Ids </code> 
     *  @param  branchRecordTypes array of branch record types to be included 
     *          in each create operation or an empty list if none 
     *  @return the branch forms 
     *  @throws org.osid.NotFoundException a <code> journalEntryId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> journalEntryIds </code> 
     *          or <code> branchRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.batch.BranchBatchFormList getBranchFormsForCreate(org.osid.id.IdList journalEntryIds, 
                                                                                 org.osid.type.Type[] branchRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Branches. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  branchForms the branch forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> branchForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createBranches(org.osid.journaling.batch.BranchBatchFormList branchForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the branch forms for updating an existing set of branches. A new 
     *  branch form should be requested for each update transaction. 
     *
     *  @param  branchIds the <code> Ids </code> of the <code> Branch </code> 
     *  @return the branch form 
     *  @throws org.osid.NotFoundException a <code> branchId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> branchIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.batch.BranchBatchFormList getBranchFormsForUpdate(org.osid.id.IdList branchIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing branches. This method returns an error if the entire 
     *  operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  branchForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> branchForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateBranches(org.osid.journaling.batch.BranchBatchFormList branchForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Branches </code> in this <code> Journal </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllBranches()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes branches for the given <code> Ids. </code> 
     *
     *  @param  branchIds the <code> Ids </code> of the branches to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> branchIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteBranches(org.osid.id.IdList branchIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes branches expired before the given date. 
     *
     *  @param  date a date 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteIneffectiveBranchesByDate(org.osid.calendaring.DateTime date)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Branch </code> for the purpose 
     *  of creating compatibility. The primary <code> Id </code> of the <code> 
     *  Branch </code> is determined by the provider. The new <code> Id 
     *  </code> is an alias to the primary <code> Id. </code> If the alias is 
     *  a pointer to another branch, it is reassigned to the given branch 
     *  <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasBranches(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
