//
// org.osid.journaling.batch.JournalEntryBatchAdminSession
//
//     The OSID Java specification for org.osid.journaling.batch.JournalEntryBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.journaling.batch;


/**
 *  <p>This session creates, updates, and deletes <code> JournalEntries 
 *  </code> in bulk. The data for create and update is provided by the 
 *  consumer via the form object. <code> OsidForms </code> are requested for 
 *  each create or update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  JournalEntry, </code> a <code> JournalEntryForm </code> is requested using 
 *  <code> getJournalEntryFormsForCreate() </code> specifying the desired 
 *  branch, source, and record <code> Types </code> or none if no record 
 *  <code> Types </code> are needed. Each of the returned <code> 
 *  JournalEntryForms </code> will indicate that it is to be used with a 
 *  create operation and can be used to examine metdata or validate data prior 
 *  to creation. Once a <code> JournalEntryForm </code> is submiited to a 
 *  create operation, it cannot be reused with another create operation unless 
 *  the first operation was unsuccessful. Each <code> JournalEntryForm </code> 
 *  corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> JournalEntryForms </code> returned from <code> 
 *  getJournalEntryFormsForCreate() </code> may be linked to the originating 
 *  request through the peer <code> Ids </code> of the <code> 
 *  JournalEntryForm. </code> In the case where there may be duplicates, any 
 *  <code> JournalEntryForm </code> of the same peer <code> Ids </code> may be 
 *  used for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> JournalEntryForms </code> are submitted for 
 *  create, a <code> CreateResponse </code> is returned for each <code> 
 *  JournalEntryForm, </code> although the ordering is not defined. Only 
 *  errors that pertain to the entire create operation are returned from 
 *  <code> createJournalEntries(), </code> errors specific to an individual 
 *  <code> JournalEntryForm </code> are indicated in the corresponding <code> 
 *  CreateResponse. </code> <code> CreateResponses </code> may be linked to 
 *  the originating <code> JournalEntryForm </code> through the <code> 
 *  JournalEntryForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> JournalEntryForms </code> are requested to the 
 *  <code> JournalEntry </code> <code> Id </code> that is to be updated using 
 *  <code> getJournalEntryFormsForUpdate() </code> where the reference <code> 
 *  Id </code> in the <code> JournalEntryForm </code> may be used to link the 
 *  request. Similarly, the <code> JournalEntryForm </code> has metadata about 
 *  the data that can be updated and it can perform validation before 
 *  submitting the update. The <code> JournalEntryForm </code> can only be 
 *  used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> JournalEntryForms </code> are submitted for 
 *  update, an <code> UpdateResponse </code> is returned for each <code> 
 *  JournalEntryForm, </code> although the ordering is not defined. Only 
 *  errors that pertain to the entire update operation are returned from 
 *  <code> updateJournalEntries(), </code> errors specific to an individual 
 *  <code> JournalEntryForm </code> are indicated in the corresponding <code> 
 *  UpdateResponse. </code> <code> UpdateResponses </code> may be linked to 
 *  the originating <code> JournalEntryForm </code> through the <code> 
 *  JournalEntryForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> JournalEntries </code> in bulk. To 
 *  unmap a <code> JournalEntry </code> from the current <code> Journal, 
 *  </code> the <code> JournalEntryJournalAssignmentSession </code> should be 
 *  used. These delete operations attempt to remove the <code> JournalEntry 
 *  </code> itself thus removing it from all known <code> Journal </code> 
 *  catalogs. Bulk delete operations return the results in <code> 
 *  DeleteResponses. </code> </p>
 */

public interface JournalEntryBatchAdminSession
    extends org.osid.journaling.JournalEntryAdminSession {


    /**
     *  Gets the journal entry forms for creating a bunch of new journal 
     *  entries. A <code> JournalEntryForm </code> is returned for each 
     *  supplied branch and source. 
     *
     *  @param  peers a list of journal entry peers 
     *  @param  journalEntryRecordTypes array of journal entry record types to 
     *          be included in each create operation or an empty list if none 
     *  @return the journal entry forms 
     *  @throws org.osid.NotFoundException a <code> branchId </code> or <code> 
     *          sourceId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> peers </code> or <code> 
     *          journalEntryRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.batch.JournalEntryBatchFormList getJournalEntryFormsForCreate(org.osid.journaling.batch.JournalEntryPeerList peers, 
                                                                                             org.osid.type.Type[] journalEntryRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Journal Entries. </code> This method 
     *  returns an error if the entire operation fails. Otherwise, the status 
     *  of an individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  journalEntryForms the journal entry forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> journalEntryForms 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createJournalEntries(org.osid.journaling.batch.JournalEntryBatchFormList journalEntryForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the journal entry forms for updating an existing set of journal 
     *  entries. A new journal entry form should be requested for each update 
     *  transaction. 
     *
     *  @param  journalEntryIds the <code> Ids </code> of the <code> 
     *          JournalEntry </code> 
     *  @return the journal entry form 
     *  @throws org.osid.NotFoundException a <code> journalEntryId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> journalEntryIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.batch.JournalEntryBatchFormList getJournalEntryFormsForUpdate(org.osid.id.IdList journalEntryIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing journal entries. This method returns an error if the 
     *  entire operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  journalEntryForms the form containing the elements to be 
     *          updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> journalEntryForms 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateJournalEntries(org.osid.journaling.batch.JournalEntryBatchFormList journalEntryForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> JournalEntries </code> in this <code> Journal 
     *  </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllJournalEntries()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes journal entries for the given <code> Ids. </code> 
     *
     *  @param  journalEntryIds the <code> Ids </code> of the journal entries 
     *          to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> journalEntryIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteJournalEntries(org.osid.id.IdList journalEntryIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes journal entries for the given branch. 
     *
     *  @param  branchId the <code> Id </code> of a branch 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> branchId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteJournalEntriesForBranch(org.osid.id.Id branchId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes journal entries for the given source. 
     *
     *  @param  sourceId the <code> Id </code> of a source 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> sourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteJournalEntriesForSource(org.osid.id.Id sourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes journal entries between the given date range inclusive. 
     *
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the delete responses 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteJournalEntriesByDate(org.osid.calendaring.DateTime from, 
                                                                                    org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> JournalEntry </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> JournalEntry </code> is determined by the provider. The new 
     *  <code> Id </code> is an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another journal entry, it is reassigned to the 
     *  given entry <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasJournalEntries(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
