//
// org.osid.journaling.batch.JournalingBatchProxyManager
//
//     The OSID Java specification for org.osid.journaling.batch.JournalingBatchProxyManager.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.journaling.batch;


/**
 *  <p>The journaling batch proxy manager provides access to journaling batch 
 *  sessions and provides interoperability tests for various aspects of this 
 *  service. Methods in this manager support the passing of a <code> Proxy 
 *  </code> object. The sessions included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> JournalEntryBatchAdminSession: </code> a session to 
 *      create, modify and delete journal entries in bulk </li> 
 *      <li> <code> BranchBatchSession: </code> a session to create, modify 
 *      and delete branches in bulk </li> 
 *      <li> <code> JournalBatchAdminSession: </code> a session to create, 
 *      modify and delete journals in bulk </li> 
 *  </ul>
 *  
 */

public interface JournalingBatchProxyManager
    extends org.osid.OsidProxyManager,
            org.osid.journaling.batch.JournalingBatchProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the bulk journal 
     *  entry administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> JournalEntryBatchAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJournalEntryBatchAdmin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJournalEntryBatchAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.journaling.batch.JournalEntryBatchAdminSession getJournalEntryBatchAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the bulk journal 
     *  entry administration service for the given journal. 
     *
     *  @param  journalId the <code> Id </code> of the <code> Journal </code> 
     *  @param  proxy a proxy 
     *  @return a <code> JournalEntryBatchAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Journal </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> journalId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJournalEntryBatchAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJournalEntryBatchAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.journaling.batch.JournalEntryBatchAdminSession getJournalEntryBatchAdminSessionForJournal(org.osid.id.Id journalId, 
                                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the bulk branch 
     *  administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BranchBatchAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBranchBatchAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBranchBatchAdmin() </code> is <code> true. </code> 
     */

    public org.osid.journaling.batch.BranchBatchAdminSession getBranchBatchAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the bulk branch 
     *  administration service for the given journal. 
     *
     *  @param  journalId the <code> Id </code> of the <code> Journal </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BranchBatchAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Journal </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> journalId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBranchBatchAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBranchBatchAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.journaling.batch.BranchBatchAdminSession getBranchBatchAdminSessionForJournal(org.osid.id.Id journalId, 
                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the bulk journal 
     *  administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> JournalBatchAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJournalBatchAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJournalBatchAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.journaling.batch.JournalBatchAdminSession getJournalBatchAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;
}
