//
// org.osid.learning.ActivityForm
//
//     The OSID Java specification for org.osid.learning.ActivityForm.
//
// Copyright (C) 2009 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.learning;


/**
 *  <p>This is the form for creating and updating <code> Activities. </code> 
 *  Like all <code> OsidForm </code> objects, various data elements may be set 
 *  here for use in the create and update methods in the <code> 
 *  ActivityAdminSession. </code> For each data element that may be set, 
 *  metadata may be examined to provide display hints or data constraints. 
 *  </p>
 */

public interface ActivityForm
    extends org.osid.OsidObjectForm,
            org.osid.OsidSubjugateableForm {


    /**
     *  Gets the metadata for the assets. 
     *
     *  @return metadata for the assets 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getAssetsMetadata();


    /**
     *  Sets the assets. 
     *
     *  @param  assetIds the asset <code> Ids </code> 
     *  @throws org.osid.InvalidArgumentException <code> assetIds </code> is 
     *          invalid 
     *  @throws org.osid.NullArgumentException <code> assetIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setAssets(org.osid.id.Id[] assetIds);


    /**
     *  Clears the assets. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAssets();


    /**
     *  Gets the metadata for the courses. 
     *
     *  @return metadata for the courses 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getCoursesMetadata();


    /**
     *  Sets the courses. 
     *
     *  @param  courseIds the course <code> Ids </code> 
     *  @throws org.osid.InvalidArgumentException <code> courseIds </code> is 
     *          invalid 
     *  @throws org.osid.NullArgumentException <code> courseIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setCourses(org.osid.id.Id[] courseIds);


    /**
     *  Clears the courses. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCourses();


    /**
     *  Gets the metadata for the assessments. 
     *
     *  @return metadata for the assessments 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getAssessmentsMetadata();


    /**
     *  Sets the assessments. 
     *
     *  @param  assessmentIds the assessment <code> Ids </code> 
     *  @throws org.osid.InvalidArgumentException <code> assessmentIds </code> 
     *          is invalid 
     *  @throws org.osid.NullArgumentException <code> assessmentIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setAssessments(org.osid.id.Id[] assessmentIds);


    /**
     *  Clears the assessments. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAssessments();


    /**
     *  Gets the <code> ActivityFormRecord </code> corresponding to the given 
     *  activity record <code> Type. </code> 
     *
     *  @param  activityRecordType the activity record type 
     *  @return the activity form record 
     *  @throws org.osid.NullArgumentException <code> activityRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(activityRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.records.ActivityFormRecord getActivityFormRecord(org.osid.type.Type activityRecordType)
        throws org.osid.OperationFailedException;
}
