//
// org.osid.learning.LearningManager
//
//     The OSID Java specification for org.osid.learning.LearningManager.
//
// Copyright (C) 2009 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.learning;


/**
 *  <p>The learning manager provides access to learning sessions and provides 
 *  interoperability tests for various aspects of this service. The sessions 
 *  included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> ObjectiveLookupSession: </code> a session to look up 
 *      objectives </li> 
 *      <li> <code> ObjectiveLookupSession: </code> a session to query 
 *      objectives <code> </code> </li> 
 *      <li> <code> ObjectiveSearchSession: </code> a session to search 
 *      objectives </li> 
 *      <li> <code> ObjectiveAdminSession: </code> a session to create, modify 
 *      and delete objectives <code> </code> </li> 
 *      <li> <code> ObjectiveNotificationSession: a </code> session to receive 
 *      messages pertaining to objective <code> </code> changes </li> 
 *      <li> <code> ObjectiveHierarchySession: </code> a session to traverse 
 *      objective hierarchies </li> 
 *      <li> <code> ObjectiveHierarchyDesignSession: </code> a session to 
 *      design objective hierarchies </li> 
 *      <li> <code> ObjectiveSequencingSession: </code> a session to sequence 
 *      objectives </li> 
 *      <li> <code> ObjectiveObjectiveBankSession: </code> a session for 
 *      retriieving objective and objective bank mappings </li> 
 *      <li> <code> ObjectiveObjectiveBankAssignmentSession: </code> a session 
 *      for managing objective and objective bank mappings </li> 
 *      <li> <code> ObjectiveSmartObjectiveBankSession: </code> a session for 
 *      managing dynamic objective banks </li> 
 *      <li> <code> ObjectiveRequisiteSession: </code> a session to examine 
 *      objective requisites </li> 
 *      <li> <code> ObjectiveRequisiteAssignmentSession: </code> a session to 
 *      manage objective requisites </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> ActivityLookupSession: </code> a session to look up 
 *      activities </li> 
 *      <li> <code> ActivityQuerySession: </code> a session to query 
 *      activities <code> </code> </li> 
 *      <li> <code> ActivitySearchSession: </code> a session to search 
 *      activities </li> 
 *      <li> <code> ActivityAdminSession: </code> a session to create, modify 
 *      and delete activities <code> </code> </li> 
 *      <li> <code> ActivityNotificationSession: a </code> session to receive 
 *      messages pertaining to activity <code> </code> changes </li> 
 *      <li> <code> ActivityObjectiveBankSession: </code> a session for 
 *      retriieving activity and objective bank mappings </li> 
 *      <li> <code> ActivityObjectiveBankAssignmentSession: </code> a session 
 *      for managing activity and objective bank mappings </li> 
 *      <li> <code> ActivitySmartObjectiveBankSession: </code> a session for 
 *      managing dynamic objective banks of activities </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> ProficiencyLookupSession: </code> a session to retrieve 
 *      proficiencies </li> 
 *      <li> <code> ProficiencyQuerySession: </code> a session to query 
 *      proficiencies </li> 
 *      <li> <code> ProficiencySearchSession: </code> a session to search for 
 *      proficiencies </li> 
 *      <li> <code> ProficiencyAdminSession: </code> a session to create, 
 *      update, and delete proficiencies </li> 
 *      <li> <code> ProficiencyNotificationSession: </code> a session to 
 *      receive notifications pertaining to proficiency changes </li> 
 *      <li> <code> ProficiencyObjectiveBankSession: </code> a session to look 
 *      up proficiency to objective bank mappings </li> 
 *      <li> <code> ProficiencyObjectiveBankAssignmentSession: </code> a 
 *      session to manage proficiency to objective bank mappings </li> 
 *      <li> <code> ProficiencySmartObjectiveBankSession: </code> a session to 
 *      manage smart objective banks of proficiencies </li> 
 *      <li> <code> MyLearningPathSession: </code> a session to examine 
 *      learning paths of objectives </li> 
 *      <li> <code> LearningPathSession: </code> a session to examine learning 
 *      paths of objectives </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> ObjectiveBankLookupSession: </code> a session to lookup 
 *      objective banks </li> 
 *      <li> <code> ObjectiveBankQuerySession: </code> a session to query 
 *      objective banks </li> 
 *      <li> <code> ObjectiveBankSearchSession </code> : a session to search 
 *      objective banks </li> 
 *      <li> <code> ObjectiveBankAdminSession </code> : a session to create, 
 *      modify and delete objective banks </li> 
 *      <li> <code> ObjectiveBankNotificationSession </code> : a session to 
 *      receive messages pertaining to objective bank changes </li> 
 *      <li> <code> ObjectiveBankHierarchySession: </code> a session to 
 *      traverse the objective bank hierarchy </li> 
 *      <li> <code> ObjectiveBankHierarchyDesignSession: </code> a session to 
 *      manage the objective bank hierarchy </li> 
 *  </ul>
 *  
 */

public interface LearningManager
    extends org.osid.OsidManager,
            org.osid.learning.LearningProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the objective 
     *  lookup service. 
     *
     *  @return an <code> ObjectiveLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObjectiveLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObjectiveLookup() </code> is <code> true. </code> 
     */

    public org.osid.learning.ObjectiveLookupSession getObjectiveLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the objective 
     *  lookup service for the given objective bank. 
     *
     *  @param  objectiveBankId the <code> Id </code> of the objective bank 
     *  @return <code> an ObjectiveLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> objectiveBankId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> objectiveBankId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObjectiveLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObjectiveLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.learning.ObjectiveLookupSession getObjectiveLookupSessionForObjectiveBank(org.osid.id.Id objectiveBankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the objective 
     *  query service. 
     *
     *  @return an <code> ObjectiveQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObjectiveQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObjectiveQuery() </code> is <code> true. </code> 
     */

    public org.osid.learning.ObjectiveQuerySession getObjectiveQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the objective 
     *  query service for the given objective bank. 
     *
     *  @param  objectiveBankId the <code> Id </code> of the objective bank 
     *  @return <code> an ObjectiveQuerySession </code> 
     *  @throws org.osid.NotFoundException <code> objectiveBankId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> objectiveBankId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObjectiveQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObjectiveQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.learning.ObjectiveQuerySession getObjectiveQuerySessionForObjectiveBank(org.osid.id.Id objectiveBankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the objective 
     *  search service. 
     *
     *  @return an <code> ObjectiveSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObjectiveSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObjectiveSearch() </code> is <code> true. </code> 
     */

    public org.osid.learning.ObjectiveSearchSession getObjectiveSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the objective 
     *  search service for the given objective bank. 
     *
     *  @param  objectiveBankId the <code> Id </code> of the objective bank 
     *  @return <code> an ObjectiveSearchSession </code> 
     *  @throws org.osid.NotFoundException <code> objectiveBankId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> objectiveBankId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObjectiveSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObjectiveSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.learning.ObjectiveSearchSession getObjectiveSearchSessionForObjectiveBank(org.osid.id.Id objectiveBankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the objective 
     *  administration service. 
     *
     *  @return an <code> ObjectiveAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObjectiveAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObjectiveAdmin() </code> is <code> true. </code> 
     */

    public org.osid.learning.ObjectiveAdminSession getObjectiveAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the objective 
     *  admin service for the given objective bank. 
     *
     *  @param  objectiveBankId the <code> Id </code> of the objective bank 
     *  @return <code> an ObjectiveAdminSession </code> 
     *  @throws org.osid.NotFoundException <code> objectiveBankId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> objectiveBankId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObjectiveAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObjectiveAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.learning.ObjectiveAdminSession getObjectiveAdminSessionForObjectiveBank(org.osid.id.Id objectiveBankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to 
     *  objective changes. 
     *
     *  @param  objectiveReceiver the objective receiver 
     *  @return an <code> ObjectiveNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> objectiveReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObjectiveNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObjectiveNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.learning.ObjectiveNotificationSession getObjectiveNotificationSession(org.osid.learning.ObjectiveReceiver objectiveReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the objective 
     *  notification service for the given objective bank. 
     *
     *  @param  objectiveReceiver the objective receiver 
     *  @param  objectiveBankId the <code> Id </code> of the objective bank 
     *  @return <code> an ObjectiveNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> objectiveBankId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> objectiveReceiver 
     *          </code> or <code> objectiveBankId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObjectiveNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObjectiveNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.learning.ObjectiveNotificationSession getObjectiveNotificationSessionForObjectiveBank(org.osid.learning.ObjectiveReceiver objectiveReceiver, 
                                                                                                          org.osid.id.Id objectiveBankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for traversing objective hierarchies. 
     *
     *  @return an <code> ObjectiveHierarchySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObjectiveHierarchy() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObjectiveHierarchy() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.learning.ObjectiveHierarchySession getObjectiveHierarchySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the objective 
     *  hierarchy traversal service for the given objective bank. 
     *
     *  @param  objectiveBankId the <code> Id </code> of the objective bank 
     *  @return an <code> ObjectiveHierarchySession </code> 
     *  @throws org.osid.NotFoundException <code> objectiveBankId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> objectiveBankId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObjectiveHierarchy() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObjectiveHierarchy() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.learning.ObjectiveHierarchySession getObjectiveHierarchySessionForObjectiveBank(org.osid.id.Id objectiveBankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for designing objective hierarchies. 
     *
     *  @return an <code> ObjectiveHierarchyDesignSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObjectiveHierarchyDesign() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObjectiveHierarchyDesign() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.learning.ObjectiveHierarchyDesignSession getObjectiveHierarchyDesignSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the objective 
     *  hierarchy design service for the given objective bank. 
     *
     *  @param  objectiveBankId the <code> Id </code> of the objective bank 
     *  @return an <code> ObjectiveHierarchyDesignSession </code> 
     *  @throws org.osid.NotFoundException <code> objectiveBankId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> objectiveBankId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObjectiveHierarchyDesign() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObjectiveHierarchyDesign() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.learning.ObjectiveHierarchyDesignSession getObjectiveHierarchyDesignSessionForObjectiveBank(org.osid.id.Id objectiveBankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for sequencing objectives. 
     *
     *  @return an <code> ObjectiveSequencingSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObjectiveSequencing() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObjectiveSequencing() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.learning.ObjectiveSequencingSession getObjectiveSequencingSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the objective 
     *  sequencing service for the given objective bank. 
     *
     *  @param  objectiveBankId the <code> Id </code> of the objective bank 
     *  @return an <code> ObjectiveSequencingSession </code> 
     *  @throws org.osid.NotFoundException <code> objectiveBankId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> objectiveBankId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObjectiveSequencing() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObjectiveSequencing() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.learning.ObjectiveSequencingSession getObjectiveSequencingSessionForObjectiveBank(org.osid.id.Id objectiveBankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving objective to objective bank mappings. 
     *
     *  @return an <code> ObjectiveObjectiveBankSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObjectiveObjectiveBank() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObjectiveObjectiveBank() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.learning.ObjectiveObjectiveBankSession getObjectiveObjectiveBankSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning objective to objective bank mappings. 
     *
     *  @return an <code> ObjectiveObjectiveBankAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObjectiveObjectiveBankAssignment() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObjectiveObjectiveBankAssignment() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.learning.ObjectiveObjectiveBankAssignmentSession getObjectiveObjectiveBankAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage dynamic objective banks 
     *  of objectives. 
     *
     *  @param  objectiveBankId the <code> Id </code> of the <code> 
     *          ObjectiveBank </code> 
     *  @return an <code> ObjectiveSmartObjectiveBankSession </code> 
     *  @throws org.osid.NotFoundException no objective bank found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> objectiveBankId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObjectiveSmartObjectiveBank() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObjectiveSmartObjectiveBank() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.learning.ObjectiveSmartObjectiveBankSession getObjectiveSmartObjectiveBankSession(org.osid.id.Id objectiveBankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for examining objective requisites. 
     *
     *  @return an <code> ObjectiveRequisiteSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObjectiveRequisite() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObjectiveRequisite() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.learning.ObjectiveRequisiteSession getObjectiveRequisiteSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the objective 
     *  sequencing service for the given objective bank. 
     *
     *  @param  objectiveBankId the <code> Id </code> of the objective bank 
     *  @return an <code> ObjectiveRequisiteSession </code> 
     *  @throws org.osid.NotFoundException <code> objectiveBankId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> objectiveBankId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObjectiveRequisite() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObjectiveRequisite() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.learning.ObjectiveRequisiteSession getObjectiveRequisiteSessionForObjectiveBank(org.osid.id.Id objectiveBankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for managing objective requisites. 
     *
     *  @return an <code> ObjectiveRequisiteAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObjectiveRequisiteAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObjectiveRequisiteAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.learning.ObjectiveRequisiteAssignmentSession getObjectiveRequisiteAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the objective 
     *  sequencing service for the given objective bank. 
     *
     *  @param  objectiveBankId the <code> Id </code> of the objective bank 
     *  @return an <code> ObjectiveRequisiteAssignmentSession </code> 
     *  @throws org.osid.NotFoundException <code> objectiveBankId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> objectiveBankId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObjectiveRequisiteAssignment() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObjectiveRequisiteAssignment() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.learning.ObjectiveRequisiteAssignmentSession getObjectiveRequisiteAssignmentSessionForObjectiveBank(org.osid.id.Id objectiveBankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the activity 
     *  lookup service. 
     *
     *  @return an <code> ActivityLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActivityLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityLookup() </code> is <code> true. </code> 
     */

    public org.osid.learning.ActivityLookupSession getActivityLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the activity 
     *  lookup service for the given objective bank. 
     *
     *  @param  objectiveBankId the <code> Id </code> of the objective bank 
     *  @return an <code> ActivityLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> objectiveBankId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> objectiveBankId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActivityLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.learning.ActivityLookupSession getActivityLookupSessionForObjectiveBank(org.osid.id.Id objectiveBankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the activity query 
     *  service. 
     *
     *  @return a <code> ActivityQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsActivityQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityQuery() </code> is <code> true. </code> 
     */

    public org.osid.learning.ActivityQuerySession getActivityQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the activity query 
     *  service for the given objective bank. 
     *
     *  @param  objectiveBankId the <code> Id </code> of the objective bank 
     *  @return an <code> ActivityQuerySession </code> 
     *  @throws org.osid.NotFoundException <code> objectiveBankId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> objectiveBankId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsActivityQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.learning.ActivityQuerySession getActivityQuerySessionForObjectiveBank(org.osid.id.Id objectiveBankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the activity 
     *  search service. 
     *
     *  @return a <code> ActivitySearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActivitySearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivitySearch() </code> is <code> true. </code> 
     */

    public org.osid.learning.ActivitySearchSession getActivitySearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the activity 
     *  search service for the given objective bank. 
     *
     *  @param  objectiveBankId the <code> Id </code> of the objective bank 
     *  @return an <code> ActivitySearchSession </code> 
     *  @throws org.osid.NotFoundException <code> objectiveBankId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> objectiveBankId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActivitySearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivitySearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.learning.ActivitySearchSession getActivitySearchSessionForObjectiveBank(org.osid.id.Id objectiveBankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the activity 
     *  administration service. 
     *
     *  @return a <code> ActivityAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsActivityAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityAdmin() </code> is <code> true. </code> 
     */

    public org.osid.learning.ActivityAdminSession getActivityAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the activity admin 
     *  service for the given objective bank. 
     *
     *  @param  objectiveBankId the <code> Id </code> of the objective bank 
     *  @return an <code> ActivityAdminSession </code> 
     *  @throws org.osid.NotFoundException <code> objectiveBankId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> objectiveBankId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsActivityAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.learning.ActivityAdminSession getActivityAdminSessionForObjectiveBank(org.osid.id.Id objectiveBankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to activity 
     *  changes. 
     *
     *  @param  activityReceiver the activity receiver 
     *  @return an <code> ActivityNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> activityReceiver </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActivityNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.learning.ActivityNotificationSession getActivityNotificationSession(org.osid.learning.ActivityReceiver activityReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the activity 
     *  notification service for the given objective bank. 
     *
     *  @param  activityReceiver the activity receiver 
     *  @param  objectiveBankId the <code> Id </code> of the objective bank 
     *  @return <code> an ActivityNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> objectiveBankId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> activityReceiver </code> 
     *          or <code> objectiveBankId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActivityNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.learning.ActivityNotificationSession getActivityNotificationSessionForObjectiveBank(org.osid.learning.ActivityReceiver activityReceiver, 
                                                                                                        org.osid.id.Id objectiveBankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving activity to objective bank mappings. 
     *
     *  @return an <code> ActivityObjectiveBankSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActivityObjectiveBank() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityObjectiveBank() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.learning.ActivityObjectiveBankSession getActivityObjectiveBankSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning activity to objective bank mappings. 
     *
     *  @return an <code> ActivityObjectiveBankAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActivityObjectiveBankAssignment() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityObjectiveBankAssignment() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.learning.ActivityObjectiveBankAssignmentSession getActivityObjectiveBankAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage dynamic objective banks 
     *  of activities. 
     *
     *  @param  objectiveBankId the <code> Id </code> of the <code> 
     *          ObjectiveBank </code> 
     *  @return an <code> ActivitySmartObjectiveBankSession </code> 
     *  @throws org.osid.NotFoundException no objective bank found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> objectiveBankId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActivitySmartObjectiveBank() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivitySmartObjectiveBank() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.learning.ActivitySmartObjectiveBankSession getActivitySmartObjectiveBankSession(org.osid.id.Id objectiveBankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the proficiency 
     *  lookup service. 
     *
     *  @return a <code> ProficiencyLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProficiencyLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProficiencyLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.learning.ProficiencyLookupSession getProficiencyLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the proficiency 
     *  lookup service for the given objective bank. 
     *
     *  @param  objectiveBankId the <code> Id </code> of the obective bank 
     *  @return a <code> ProficiencyLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> ObjectiveBank </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> objectiveBankId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProficiencyLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProficiencyLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.learning.ProficiencyLookupSession getProficiencyLookupSessionForObjectiveBank(org.osid.id.Id objectiveBankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the proficiency 
     *  query service. 
     *
     *  @return a <code> ProficiencyQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProficiencyQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProficiencyQuery() </code> is <code> true. </code> 
     */

    public org.osid.learning.ProficiencyQuerySession getProficiencyQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the proficiency 
     *  query service for the given objective bank. 
     *
     *  @param  objectiveBankId the <code> Id </code> of the obective bank 
     *  @return a <code> ProficiencyQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> ObjectiveBank </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> objectiveBankId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProficiencyQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProficiencyQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.learning.ProficiencyQuerySession getProficiencyQuerySessionForObjectiveBank(org.osid.id.Id objectiveBankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the proficiency 
     *  search service. 
     *
     *  @return a <code> ProficiencySearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProficiencySearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProficiencySearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.learning.ProficiencySearchSession getProficiencySearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the proficiency 
     *  search service for the given objective bank. 
     *
     *  @param  objectiveBankId the <code> Id </code> of the <code> 
     *          ObjectiveBank </code> 
     *  @return a <code> ProficiencySearchSession </code> 
     *  @throws org.osid.NotFoundException no objective bank found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> objectiveBankId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProficiencySearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProficiencySearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.learning.ProficiencySearchSession getProficiencySearchSessionForObjectiveBank(org.osid.id.Id objectiveBankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the proficiency 
     *  administration service. 
     *
     *  @return a <code> ProficiencyAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProficiencyAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProficiencyAdmin() </code> is <code> true. </code> 
     */

    public org.osid.learning.ProficiencyAdminSession getProficiencyAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the proficiency 
     *  administration service for the given objective bank. 
     *
     *  @param  objectiveBankId the <code> Id </code> of the <code> 
     *          ObjectiveBank </code> 
     *  @return a <code> ProficiencyAdminSession </code> 
     *  @throws org.osid.NotFoundException no objective bank found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> objectiveBankId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProficiencyAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProficiencyAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.learning.ProficiencyAdminSession getProficiencyAdminSessionForObjectiveBank(org.osid.id.Id objectiveBankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the proficiency 
     *  notification service. 
     *
     *  @param  proficiencyReceiver the notification callback 
     *  @return a <code> ProficiencyNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> proficiencyReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProficiencyNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProficiencyNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.learning.ProficiencyNotificationSession getProficiencyNotificationSession(org.osid.learning.ProficiencyReceiver proficiencyReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the proficiency 
     *  notification service for the given objective bank. 
     *
     *  @param  proficiencyReceiver the notification callback 
     *  @param  objectiveBankId the <code> Id </code> of the <code> 
     *          ObjectiveBank </code> 
     *  @return a <code> ProficiencyNotificationSession </code> 
     *  @throws org.osid.NotFoundException no objective bank found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> proficiencyReceiver 
     *          </code> or <code> objectiveBankId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProficiencyNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProficiencyNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.learning.ProficiencyNotificationSession getProficiencyNotificationSessionForObjectiveBank(org.osid.learning.ProficiencyReceiver proficiencyReceiver, 
                                                                                                              org.osid.id.Id objectiveBankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup proficiency/objective 
     *  bank mappings. 
     *
     *  @return a <code> ProficiencyObjectiveBankSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProficiencyObjectiveBank() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProficiencyObjectiveBank() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.learning.ProficiencyObjectiveBankSession getProficiencyObjectiveBankSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning 
     *  proficiencys to objective banks. 
     *
     *  @return a <code> ProficiencyObjectiveBankAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProficiencyObjectiveBankAssignment() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProficiencyObjectiveBankAssignment() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.learning.ProficiencyObjectiveBankAssignmentSession getProficiencyObjectiveBankAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage dynamic objective banks 
     *  of objectives. 
     *
     *  @param  objectiveBankId the <code> Id </code> of the <code> 
     *          ObjectiveBank </code> 
     *  @return a <code> ProficiencySmartObjectiveBankSession </code> 
     *  @throws org.osid.NotFoundException no objective bank found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> objectiveBankId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProficiencySmartObjectiveBank() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProficiencySmartObjectiveBank() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.learning.ProficiencySmartObjectiveBankSession getProficiencySmartObjectiveBankSession(org.osid.id.Id objectiveBankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the my learning 
     *  path service. 
     *
     *  @return a <code> MyLearningPathSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsMyLearningPath() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMyLearningPath() </code> is <code> true. </code> 
     */

    public org.osid.learning.MyLearningPathSession getMyLearningPathSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the my learning 
     *  path service for the given objective bank. 
     *
     *  @param  objectiveBankId the <code> Id </code> of the <code> 
     *          ObjectiveBank </code> 
     *  @return a <code> MyLearningPathSession </code> 
     *  @throws org.osid.NotFoundException no objective bank found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> objectiveBankId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsMyLearningPath() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMyLearningPath() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.learning.MyLearningPathSession getMyLearningPathSessionForObjectiveBank(org.osid.id.Id objectiveBankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the learning path 
     *  service. 
     *
     *  @return a <code> LearningPathSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsLearningPath() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLearningPath() </code> is <code> true. </code> 
     */

    public org.osid.learning.LearningPathSession getLearningPathSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the learning path 
     *  service for the given objective bank. 
     *
     *  @param  objectiveBankId the <code> Id </code> of the <code> 
     *          ObjectiveBank </code> 
     *  @return a <code> LearningPathSession </code> 
     *  @throws org.osid.NotFoundException no objective bank found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> objectiveBankId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportyLearningPath() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLearningPath() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.learning.LearningPathSession getLearningPathSessionForObjectiveBank(org.osid.id.Id objectiveBankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the OsidSession associated with the objective bank lookup 
     *  service. 
     *
     *  @return an <code> ObjectiveBankLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObjectiveBankLookup() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObjectiveBankLookup() </code> is true. 
     */

    public org.osid.learning.ObjectiveBankLookupSession getObjectiveBankLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the OsidSession associated with the objective bank query service. 
     *
     *  @return an <code> ObjectiveBankQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObjectiveBankQuery() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObjectiveBankQuery() </code> is true. 
     */

    public org.osid.learning.ObjectiveBankQuerySession getObjectiveBankQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the OsidSession associated with the objective bank search 
     *  service. 
     *
     *  @return an <code> ObjectiveBankSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObjectiveBankSearch() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObjectiveBankSearch() </code> is true. 
     */

    public org.osid.learning.ObjectiveBankSearchSession getObjectiveBankSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the OsidSession associated with the objective bank administration 
     *  service. 
     *
     *  @return an <code> ObjectiveBankAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObjectiveBankAdmin() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObjectiveBankAdmin() </code> is true. 
     */

    public org.osid.learning.ObjectiveBankAdminSession getObjectiveBankAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to 
     *  objective bank service changes. 
     *
     *  @param  objectiveBankReceiver the objective bank receiver 
     *  @return an <code> ObjectiveBankNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> objectiveBankReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObjectiveBankNotification() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObjectiveBankNotification() </code> is true. 
     */

    public org.osid.learning.ObjectiveBankNotificationSession getObjectiveBankNotificationSession(org.osid.learning.ObjectiveBankReceiver objectiveBankReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session traversing objective bank hierarchies. 
     *
     *  @return an <code> ObjectiveBankHierarchySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObjectiveBankHierarchy() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObjectiveBankHierarchy() </code> is true. 
     */

    public org.osid.learning.ObjectiveBankHierarchySession getObjectiveBankHierarchySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session designing objective bank hierarchies. 
     *
     *  @return an <code> ObjectiveBankHierarchyDesignSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObjectiveBankHierarchyDesign() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObjectiveBankHierarchyDesign() </code> is true. 
     */

    public org.osid.learning.ObjectiveBankHierarchyDesignSession getObjectiveBankHierarchyDesignSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a <code> LearningBatchManager. </code> 
     *
     *  @return a <code> LearningBatchManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsLearningBatch() 
     *          is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLearningBatch() </code> is true. 
     */

    public org.osid.learning.batch.LearningBatchManager getLearningBatchManager()
        throws org.osid.OperationFailedException;
}
