//
// org.osid.learning.Objective
//
//     The OSID Java specification for org.osid.learning.Objective.
//
// Copyright (C) 2009 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.learning;


/**
 *  <p>An <code> Objective </code> is a statable learning objective. </p>
 */

public interface Objective
    extends org.osid.OsidObject,
            org.osid.Federateable {


    /**
     *  Tests if an assessment is associated with this objective. 
     *
     *  @return <code> true </code> if an assessment exists, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasAssessment();


    /**
     *  Gets the assessment <code> Id </code> associated with this learning 
     *  objective. 
     *
     *  @return the assessment <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> hasAssessment() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAssessmentId();


    /**
     *  Gets the assessment associated with this learning objective. 
     *
     *  @return the assessment 
     *  @throws org.osid.IllegalStateException <code> hasAssessment() </code> 
     *          is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.Assessment getAssessment()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this objective has a knowledge dimension. 
     *
     *  @return <code> true </code> if a knowledge category exists, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasKnowledgeCategory();


    /**
     *  Gets the grade <code> Id </code> associated with the knowledge 
     *  dimension. 
     *
     *  @return the grade <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> hasKnowledgeCategory() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getKnowledgeCategoryId();


    /**
     *  Gets the grade associated with the knowledge dimension. 
     *
     *  @return the grade 
     *  @throws org.osid.IllegalStateException <code> hasKnowledgeCategory() 
     *          </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.Grade getKnowledgeCategory()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this objective has a cognitive process type. 
     *
     *  @return <code> true </code> if a cognitive process exists, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasCognitiveProcess();


    /**
     *  Gets the grade <code> Id </code> associated with the cognitive 
     *  process. 
     *
     *  @return the grade <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> hasCognitiveProcess() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCognitiveProcessId();


    /**
     *  Gets the grade associated with the cognitive process. 
     *
     *  @return the grade 
     *  @throws org.osid.IllegalStateException <code> hasCognitiveProcess() 
     *          </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.Grade getCognitiveProcess()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the objective bank record corresponding to the given <code> 
     *  Objective </code> record <code> Type. </code> This method is used to 
     *  retrieve an object implementing the requested record. The <code> 
     *  objectiveRecordType </code> may be the <code> Type </code> returned in 
     *  <code> getRecordTypes() </code> or any of its parents in a <code> Type 
     *  </code> hierarchy where <code> hasRecordType(objectiveRecordType) 
     *  </code> is <code> true </code> . 
     *
     *  @param  objectiveRecordType an objective record type 
     *  @return the objective record 
     *  @throws org.osid.NullArgumentException <code> objectiveRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(objectiveRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.records.ObjectiveRecord getObjectiveRecord(org.osid.type.Type objectiveRecordType)
        throws org.osid.OperationFailedException;
}
