//
// org.osid.learning.ObjectiveBankQuery
//
//     The OSID Java specification for org.osid.learning.ObjectiveBankQuery.
//
// Copyright (C) 2009 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.learning;


/**
 *  <p>This is the query for searching objective banks. Each method specifies 
 *  an <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface ObjectiveBankQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Sets the objective <code> Id </code> for this query. 
     *
     *  @param  objectiveId an objective <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> objectiveId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchObjectiveId(org.osid.id.Id objectiveId, boolean match);


    /**
     *  Clears the objective <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearObjectiveIdTerms();


    /**
     *  Tests if an <code> ObjectiveQuery </code> is available. 
     *
     *  @return <code> true </code> if an objective query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObjectiveQuery();


    /**
     *  Gets the query for an objective. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the objective query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObjectiveQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObjectiveQuery() </code> is <code> true. </code> 
     */

    public org.osid.learning.ObjectiveQuery getObjectiveQuery();


    /**
     *  Matches an objective bank that has any objective assigned. 
     *
     *  @param  match <code> true </code> to match objective banks with any 
     *          objective, <code> false </code> to match objective banks with 
     *          no objectives 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyObjective(boolean match);


    /**
     *  Clears the objective terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearObjectiveTerms();


    /**
     *  Sets the activity <code> Id </code> for this query. 
     *
     *  @param  activityId an activity <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> activityId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchActivityId(org.osid.id.Id activityId, boolean match);


    /**
     *  Clears the activity <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearActivityIdTerms();


    /**
     *  Tests if a <code> ActivityQuery </code> is available for querying 
     *  activities. 
     *
     *  @return <code> true </code> if an activity query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityQuery();


    /**
     *  Gets the query for an activity. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the activity query 
     *  @throws org.osid.UnimplementedException <code> supportsActivityQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityQuery() </code> is <code> true. </code> 
     */

    public org.osid.learning.ActivityQuery getActivityQuery();


    /**
     *  Matches an objective bank that has any activity assigned. 
     *
     *  @param  match <code> true </code> to match objective banks with any 
     *          activity, <code> false </code> to match objective banks with 
     *          no activities 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyActivity(boolean match);


    /**
     *  Clears the activity terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearActivityTerms();


    /**
     *  Sets the objective bank <code> Id </code> for this query to match 
     *  objective banks that have the specified objective bank as an ancestor. 
     *
     *  @param  objectiveBankId an objective bank <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> objectiveBankId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorObjectiveBankId(org.osid.id.Id objectiveBankId, 
                                             boolean match);


    /**
     *  Clears the ancestor objective bank <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorObjectiveBankIdTerms();


    /**
     *  Tests if a <code> ObjectiveBankQuery </code> is available for querying 
     *  ancestor objective banks. 
     *
     *  @return <code> true </code> if an objective bank query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorObjectiveBankQuery();


    /**
     *  Gets the query for an objective bank. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the objective bank query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorObjectiveBankQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorCalndarQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.learning.ObjectiveBankQuery getAncestorObjectiveBankQuery();


    /**
     *  Matches an objective bank that has any ancestor. 
     *
     *  @param  match <code> true </code> to match objective banks with any 
     *          ancestor, <code> false </code> to match root objective banks 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorObjectiveBank(boolean match);


    /**
     *  Clears the ancestor objective bank terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorObjectiveBankTerms();


    /**
     *  Sets the objective bank <code> Id </code> for this query to match 
     *  objective banks that have the specified objective bank as a 
     *  descendant. 
     *
     *  @param  objectiveBankId an objective bank <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> objectiveBankId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantObjectiveBankId(org.osid.id.Id objectiveBankId, 
                                               boolean match);


    /**
     *  Clears the descendant objective bank <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantObjectiveBankIdTerms();


    /**
     *  Tests if a <code> ObjectiveBankQuery </code> is available for querying 
     *  descendant objective banks. 
     *
     *  @return <code> true </code> if an objective bank query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantObjectiveBankQuery();


    /**
     *  Gets the query for an objective bank. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the objective bank query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantObjectiveBankQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantCalndarQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.learning.ObjectiveBankQuery getDescendantObjectiveBankQuery();


    /**
     *  Matches an objective bank that has any descendant. 
     *
     *  @param  match <code> true </code> to match objective banks with any 
     *          descendant, <code> false </code> to match leaf objective banks 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantObjectiveBank(boolean match);


    /**
     *  Clears the descendant objective bank terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantObjectiveBankTerms();


    /**
     *  Gets the objective bank query record corresponding to the given <code> 
     *  ObjectiveBank </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  objectiveBankRecordType an objective bank record type 
     *  @return the objective bank query record 
     *  @throws org.osid.NullArgumentException <code> objectiveBankRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(objectiveBankRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.records.ObjectiveBankQueryRecord getObjectiveBankQueryRecord(org.osid.type.Type objectiveBankRecordType)
        throws org.osid.OperationFailedException;
}
