//
// org.osid.learning.ObjectiveForm
//
//     The OSID Java specification for org.osid.learning.ObjectiveForm.
//
// Copyright (C) 2009 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.learning;


/**
 *  <p>This is the form for creating and updating <code> Objectives. </code> 
 *  Like all <code> OsidForm </code> objects, various data elements may be set 
 *  here for use in the create and update methods in the <code> 
 *  ObjectiveAdminSession. </code> For each data element that may be set, 
 *  metadata may be examined to provide display hints or data constraints. 
 *  </p>
 */

public interface ObjectiveForm
    extends org.osid.OsidObjectForm,
            org.osid.OsidFederateableForm {


    /**
     *  Gets the metadata for an assessment. 
     *
     *  @return metadata for the assessment 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getAssessmentMetadata();


    /**
     *  Sets the assessment. 
     *
     *  @param  assessmentId the new assessment 
     *  @throws org.osid.InvalidArgumentException <code> assessmentId </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> assessmentId </code> cannot 
     *          be modified 
     *  @throws org.osid.NullArgumentException <code> assessmentId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setAssessment(org.osid.id.Id assessmentId);


    /**
     *  Clears the assessment. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAssessment();


    /**
     *  Gets the metadata for a knowledge category. 
     *
     *  @return metadata for the knowledge category 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getKnowledgeCategoryMetadata();


    /**
     *  Sets the knowledge category. 
     *
     *  @param  gradeId the new knowledge category 
     *  @throws org.osid.InvalidArgumentException <code> gradeId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> gradeId </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> gradeId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setKnowledgeCategory(org.osid.id.Id gradeId);


    /**
     *  Clears the knowledge category. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearKnowledgeCategory();


    /**
     *  Gets the metadata for a cognitive process. 
     *
     *  @return metadata for the cognitive process 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getCognitiveProcessMetadata();


    /**
     *  Sets the cognitive process. 
     *
     *  @param  gradeId the new cognitive process 
     *  @throws org.osid.InvalidArgumentException <code> gradeId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> gradeId </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> gradeId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setCognitiveProcess(org.osid.id.Id gradeId);


    /**
     *  Clears the cognitive process. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCognitiveProcess();


    /**
     *  Gets the <code> ObjectiveFormRecord </code> corresponding to the given 
     *  objective record <code> Type. </code> 
     *
     *  @param  objectiveRecordType the objective record type 
     *  @return the objective form record 
     *  @throws org.osid.NullArgumentException <code> objectiveRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(objectiveRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.records.ObjectiveFormRecord getObjectiveFormRecord(org.osid.type.Type objectiveRecordType)
        throws org.osid.OperationFailedException;
}
