//
// org.osid.learning.ObjectiveObjectiveBankAssignmentSession
//
//     The OSID Java specification for org.osid.learning.ObjectiveObjectiveBankAssignmentSession.
//
// Copyright (C) 2009 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.learning;


/**
 *  <p>This session provides methods to re-assign <code> Objectives </code> to 
 *  <code> ObjectiveBanks. </code> An <code> Objective </code> may map to 
 *  multiple <code> ObjectiveBanks </code> and removing the last reference to 
 *  an <code> Objective </code> is the equivalent of deleting it. Each <code> 
 *  ObjectiveBank </code> may have its own authorizations governing who is 
 *  allowed to operate on it. </p> 
 *  
 *  <p> Moving or adding a reference of an <code> Objective </code> to another 
 *  <code> ObjectiveBank </code> is not a copy operation (eg: does not change 
 *  its <code> Id </code> ). </p>
 */

public interface ObjectiveObjectiveBankAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter objective/objective bank mappings. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer assignment 
     *  operations to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignObjectives();


    /**
     *  Tests if this user can alter objective/objective bank mappings. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer assignment 
     *  operations to unauthorized users. 
     *
     *  @param  objectiveBankId the <code> Id </code> of the <code> 
     *          ObjectiveBank </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> objectiveBankId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignObjectivesToObjectiveBank(org.osid.id.Id objectiveBankId);


    /**
     *  Gets a list of objective banks including and under the given objective 
     *  bank node in which any objective can be assigned. 
     *
     *  @param  objectiveBankId the <code> Id </code> of the <code> 
     *          ObjectiveBank </code> 
     *  @return list of assignable objective bank <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> objectiveBankId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableObjectiveBankIds(org.osid.id.Id objectiveBankId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of objective banks including and under the given objective 
     *  bank node in which a specific objective can be assigned. 
     *
     *  @param  objectiveBankId the <code> Id </code> of the <code> 
     *          ObjectiveBank </code> 
     *  @param  objectiveId the <code> Id </code> of the <code> Objective 
     *          </code> 
     *  @return list of assignable objective bank <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> objectiveId </code> or 
     *          <code> objectiveBankId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableObjectiveBankIdsForObjective(org.osid.id.Id objectiveBankId, 
                                                                        org.osid.id.Id objectiveId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> Objective </code> to an <code> ObjectiveBank. 
     *  </code> 
     *
     *  @param  objectiveId the <code> Id </code> of the <code> Objective 
     *          </code> 
     *  @param  objectiveBankId the <code> Id </code> of the <code> 
     *          ObjectiveBank </code> 
     *  @throws org.osid.AlreadyExistsException <code> objectiveId </code> 
     *          already mapped to <code> objectiveBankId </code> 
     *  @throws org.osid.NotFoundException <code> objectiveId </code> or 
     *          <code> objectiveBankId </code> not found 
     *  @throws org.osid.NullArgumentException <code> objectiveId </code> or 
     *          <code> objectiveBankId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignObjectiveToObjectiveBank(org.osid.id.Id objectiveId, 
                                               org.osid.id.Id objectiveBankId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes an <code> Objective </code> from an <code> ObjectiveBank. 
     *  </code> 
     *
     *  @param  objectiveId the <code> Id </code> of the <code> Objective 
     *          </code> 
     *  @param  objectiveBankId the <code> Id </code> of the <code> 
     *          ObjectiveBank </code> 
     *  @throws org.osid.NotFoundException <code> objectiveId </code> or 
     *          <code> objectiveBankId </code> not found or <code> objectiveId 
     *          </code> not mapped to <code> objectiveBankId </code> 
     *  @throws org.osid.NullArgumentException <code> objectiveId </code> or 
     *          <code> objectiveBankId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignObjectiveFromObjectiveBank(org.osid.id.Id objectiveId, 
                                                   org.osid.id.Id objectiveBankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Moves an <code> Objective </code> from one <code> ObjectiveBank 
     *  </code> to another. Mappings to other <code> ObjectiveBanks </code> 
     *  are unaffected. 
     *
     *  @param  objectiveId the <code> Id </code> of the <code> Objective 
     *          </code> 
     *  @param  fromObjectiveBankId the <code> Id </code> of the current 
     *          <code> ObjectiveBank </code> 
     *  @param  toObjectiveBankId the <code> Id </code> of the destination 
     *          <code> ObjectiveBank </code> 
     *  @throws org.osid.NotFoundException <code> objectiveId, 
     *          fromObjectiveBankId, </code> or <code> toObjectiveBankId 
     *          </code> not found or <code> objectiveId </code> not mapped to 
     *          <code> fromObjectiveBankId </code> 
     *  @throws org.osid.NullArgumentException <code> objectiveId, 
     *          fromObjectiveBankId, </code> or <code> toObjectiveBankId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void reassignProficiencyToObjectiveBank(org.osid.id.Id objectiveId, 
                                                   org.osid.id.Id fromObjectiveBankId, 
                                                   org.osid.id.Id toObjectiveBankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
