//
// org.osid.learning.ObjectiveQuery
//
//     The OSID Java specification for org.osid.learning.ObjectiveQuery.
//
// Copyright (C) 2009 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.learning;


/**
 *  <p>This is the query for searching objectives. Each method match request 
 *  produces an <code> AND </code> term while multiple invocations of a method 
 *  produces a nested <code> OR. </code> </p>
 */

public interface ObjectiveQuery
    extends org.osid.OsidObjectQuery,
            org.osid.OsidFederateableQuery {


    /**
     *  Sets the assessment <code> Id </code> for this query. 
     *
     *  @param  assessmentId an assessment <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> assessmentId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAssessmentId(org.osid.id.Id assessmentId, boolean match);


    /**
     *  Clears the assessment <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAssessmentIdTerms();


    /**
     *  Tests if an <code> AssessmentQuery </code> is available for querying 
     *  activities. 
     *
     *  @return <code> true </code> if an assessment query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentQuery();


    /**
     *  Gets the query for an assessment. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the assessment query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentQuery() </code> is <code> true. </code> 
     */

    public org.osid.assessment.AssessmentQuery getAssessmentQuery();


    /**
     *  Matches an objective that has any assessment assigned. 
     *
     *  @param  match <code> true </code> to match objectives with any 
     *          assessment, <code> false </code> to match objectives with no 
     *          assessment 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAssessment(boolean match);


    /**
     *  Clears the assessment terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAssessmentTerms();


    /**
     *  Sets the knowledge category <code> Id </code> for this query. 
     *
     *  @param  gradeId a grade <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> gradeId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchKnowledgeCategoryId(org.osid.id.Id gradeId, boolean match);


    /**
     *  Clears the knowledge category <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearKnowledgeCategoryIdTerms();


    /**
     *  Tests if a <code> GradeQuery </code> is available for querying 
     *  knowledge categories. 
     *
     *  @return <code> true </code> if a grade query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsKnowledgeCategoryQuery();


    /**
     *  Gets the query for a knowledge category. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the grade query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsKnowledgeCategoryQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsKnowledgeCategoryQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.grading.GradeQuery getKnowledgeCategoryQuery();


    /**
     *  Matches an objective that has any knowledge category. 
     *
     *  @param  match <code> true </code> to match objectives with any 
     *          knowledge category, <code> false </code> to match objectives 
     *          with no knowledge category 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyKnowledgeCategory(boolean match);


    /**
     *  Clears the knowledge category terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearKnowledgeCategoryTerms();


    /**
     *  Sets the cognitive process <code> Id </code> for this query. 
     *
     *  @param  gradeId a grade <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> gradeId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCognitiveProcessId(org.osid.id.Id gradeId, boolean match);


    /**
     *  Clears the cognitive process <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCognitiveProcessIdTerms();


    /**
     *  Tests if a <code> GradeQuery </code> is available for querying 
     *  cognitive processes. 
     *
     *  @return <code> true </code> if a grade query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCognitiveProcessQuery();


    /**
     *  Gets the query for a cognitive process. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the grade query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCognitiveProcessQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCognitiveProcessQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.grading.GradeQuery getCognitiveProcessQuery();


    /**
     *  Matches an objective that has any cognitive process. 
     *
     *  @param  match <code> true </code> to match objectives with any 
     *          cognitive process, <code> false </code> to match objectives 
     *          with no cognitive process 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCognitiveProcess(boolean match);


    /**
     *  Clears the cognitive process terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCognitiveProcessTerms();


    /**
     *  Sets the activity <code> Id </code> for this query. 
     *
     *  @param  activityId an activity <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> activityId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchActivityId(org.osid.id.Id activityId, boolean match);


    /**
     *  Clears the activity <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearActivityIdTerms();


    /**
     *  Tests if an <code> ActivityQuery </code> is available for querying 
     *  activities. 
     *
     *  @return <code> true </code> if an activity query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityQuery();


    /**
     *  Gets the query for an activity. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the activity query 
     *  @throws org.osid.UnimplementedException <code> supportsActivityQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityQuery() </code> is <code> true. </code> 
     */

    public org.osid.learning.ActivityQuery getActivityQuery();


    /**
     *  Matches an objective that has any related activity. 
     *
     *  @param  match <code> true </code> to match objectives with any 
     *          activity, <code> false </code> to match objectives with no 
     *          activity 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyActivity(boolean match);


    /**
     *  Clears the activity terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearActivityTerms();


    /**
     *  Sets the requisite objective <code> Id </code> for this query. 
     *
     *  @param  requisiteObjectiveId a requisite objective <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> requisiteObjectiveId 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRequisiteObjectiveId(org.osid.id.Id requisiteObjectiveId, 
                                          boolean match);


    /**
     *  Clears the requisite objective <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRequisiteObjectiveIdTerms();


    /**
     *  Tests if an <code> ObjectiveQuery </code> is available for querying 
     *  requisite objectives. 
     *
     *  @return <code> true </code> if an objective query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRequisiteObjectiveQuery();


    /**
     *  Gets the query for a requisite objective. Multiple retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @return the objective query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRequisiteObjectiveQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRequisiteObjectiveQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.learning.ObjectiveQuery getRequisiteObjectiveQuery();


    /**
     *  Matches an objective that has any related requisite. 
     *
     *  @param  match <code> true </code> to match objectives with any 
     *          requisite, <code> false </code> to match objectives with no 
     *          requisite 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRequisiteObjective(boolean match);


    /**
     *  Clears the requisite objective terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRequisiteObjectiveTerms();


    /**
     *  Sets the dependent objective <code> Id </code> to query objectives 
     *  dependent on the given objective. 
     *
     *  @param  dependentObjectiveId a dependent objective <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> dependentObjectiveId 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDependentObjectiveId(org.osid.id.Id dependentObjectiveId, 
                                          boolean match);


    /**
     *  Clears the dependent objective <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDependentObjectiveIdTerms();


    /**
     *  Tests if an <code> ObjectiveQuery </code> is available for querying 
     *  dependent objectives. 
     *
     *  @return <code> true </code> if an objective query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDepndentObjectiveQuery();


    /**
     *  Gets the query for a dependent objective. Multiple retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @return the objective query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDependentObjectiveQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDependentQuery() </code> is <code> true. </code> 
     */

    public org.osid.learning.ObjectiveQuery getDependentObjectiveQuery();


    /**
     *  Matches an objective that has any related dependents. 
     *
     *  @param  match <code> true </code> to match objectives with any 
     *          dependent, <code> false </code> to match objectives with no 
     *          dependents 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDependentObjective(boolean match);


    /**
     *  Clears the dependent objective terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDependentObjectiveTerms();


    /**
     *  Sets the equivalent objective <code> Id </code> to query equivalents. 
     *
     *  @param  equivalentObjectiveId an equivalent objective <code> Id 
     *          </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> equivalentObjectiveId 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchEquivalentObjectiveId(org.osid.id.Id equivalentObjectiveId, 
                                           boolean match);


    /**
     *  Clears the equivalent objective <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEquivalentObjectiveIdTerms();


    /**
     *  Tests if an <code> ObjectiveQuery </code> is available for querying 
     *  equivalent objectives. 
     *
     *  @return <code> true </code> if an objective query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEquivalentObjectiveQuery();


    /**
     *  Gets the query for an equivalent objective. Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @return the objective query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEquivalentObjectiveQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEquivalentQuery() </code> is <code> true. </code> 
     */

    public org.osid.learning.ObjectiveQuery getEquivalentObjectiveQuery();


    /**
     *  Matches an objective that has any related equivalents. 
     *
     *  @param  match <code> true </code> to match objectives with any 
     *          equivalent, <code> false </code> to match objectives with no 
     *          equivalents 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyEquivalentObjective(boolean match);


    /**
     *  Clears the equivalent objective terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEquivalentObjectiveTerms();


    /**
     *  Sets the objective <code> Id </code> for this query to match 
     *  objectives that have the specified objective as an ancestor. 
     *
     *  @param  objectiveId an objective <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> objectiveId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorObjectiveId(org.osid.id.Id objectiveId, 
                                         boolean match);


    /**
     *  Clears the ancestor objective <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorObjectiveIdTerms();


    /**
     *  Tests if an <code> ObjectiveQuery </code> is available. 
     *
     *  @return <code> true </code> if an objective query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorObjectiveQuery();


    /**
     *  Gets the query for an objective. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the objective query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorObjectiveQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorObjectiveQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.learning.ObjectiveQuery getAncestorObjectiveQuery();


    /**
     *  Matches objectives that have any ancestor. 
     *
     *  @param  match <code> true </code> to match objective with any 
     *          ancestor, <code> false </code> to match root objectives 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorObjective(boolean match);


    /**
     *  Clears the ancestor objective query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorObjectiveTerms();


    /**
     *  Sets the objective <code> Id </code> for this query to match 
     *  objectives that have the specified objective as a descendant. 
     *
     *  @param  objectiveId an objective <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> objectiveId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantObjectiveId(org.osid.id.Id objectiveId, 
                                           boolean match);


    /**
     *  Clears the descendant objective <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantObjectiveIdTerms();


    /**
     *  Tests if an <code> ObjectiveQuery </code> is available. 
     *
     *  @return <code> true </code> if an objective query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantObjectiveQuery();


    /**
     *  Gets the query for an objective. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the objective query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantObjectiveQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantObjectiveQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.learning.ObjectiveQuery getDescendantObjectiveQuery();


    /**
     *  Matches objectives that have any ancestor. 
     *
     *  @param  match <code> true </code> to match objectives with any 
     *          ancestor, <code> false </code> to match leaf objectives 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantObjective(boolean match);


    /**
     *  Clears the descendant objective query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantObjectiveTerms();


    /**
     *  Sets the objective bank <code> Id </code> for this query. 
     *
     *  @param  objectiveBankId an objective bank <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> objectiveBankId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchObjectiveBankId(org.osid.id.Id objectiveBankId, 
                                     boolean match);


    /**
     *  Clears the objective bank <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearObjectiveBankIdTerms();


    /**
     *  Tests if a <code> ObjectiveBankQuery </code> is available for querying 
     *  objective banks. 
     *
     *  @return <code> true </code> if an objective bank query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObjectiveBankQuery();


    /**
     *  Gets the query for an objective bank. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the objective bank query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObjectiveBankQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObjectiveBankQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.learning.ObjectiveBankQuery getObjectiveBankQuery();


    /**
     *  Clears the objective bank terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearObjectiveBankTerms();


    /**
     *  Gets the objective query record corresponding to the given <code> 
     *  Objective </code> record <code> Type. </code> Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @param  objectiveRecordType an objective query record type 
     *  @return the objective query record 
     *  @throws org.osid.NullArgumentException <code> objectiveRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(objectiveRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.records.ObjectiveQueryRecord getObjectiveQueryRecord(org.osid.type.Type objectiveRecordType)
        throws org.osid.OperationFailedException;
}
