//
// org.osid.learning.ObjectiveRequisiteAssignmentSession
//
//     The OSID Java specification for org.osid.learning.ObjectiveRequisiteAssignmentSession.
//
// Copyright (C) 2009 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.learning;


/**
 *  <p>This session provides methods to manage requisites. Each <code> 
 *  ObjectiveBank </code> may have its own authorizations governing who is 
 *  allowed to operate on it. </p> 
 *  
 *  <p> Moving or adding a reference of an <code> Objective </code> to another 
 *  <code> ObjectiveBank </code> is not a copy operation (eg: does not change 
 *  its <code> Id </code> ). </p>
 */

public interface ObjectiveRequisiteAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> ObjectiveBank </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> ObjectiveBank Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getObjectiveBankId();


    /**
     *  Gets the <code> ObjectiveBank </code> associated with this session. 
     *
     *  @return the <code> ObjectiveBank </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveBank getObjectiveBank()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage objective requisites. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignRequisites();


    /**
     *  Creates a requirement dependency between two <code> Objectives. 
     *  </code> 
     *
     *  @param  objectiveId the <code> Id </code> of the dependent <code> 
     *          Objective </code> 
     *  @param  requisiteObjectiveId the <code> Id </code> of the required 
     *          <code> Objective </code> 
     *  @throws org.osid.AlreadyExistsException <code> objectiveId </code> 
     *          already mapped to <code> requisiteObjectiveId </code> 
     *  @throws org.osid.NotFoundException <code> objectiveId </code> or 
     *          <code> requisiteObjectiveId </code> not found 
     *  @throws org.osid.NullArgumentException <code> objectiveId </code> or 
     *          <code> requisiteObjectiveId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignObjectiveRequisite(org.osid.id.Id objectiveId, 
                                         org.osid.id.Id requisiteObjectiveId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes an <code> Objective </code> requisite from an <code> 
     *  Objective. </code> 
     *
     *  @param  objectiveId the <code> Id </code> of the <code> Objective 
     *          </code> 
     *  @param  requisiteObjectiveId the <code> Id </code> of the required 
     *          <code> Objective </code> 
     *  @throws org.osid.NotFoundException <code> objectiveId </code> or 
     *          <code> requisiteObjectiveId </code> not found or <code> 
     *          objectiveId </code> not mapped to <code> requisiteObjectiveId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> objectiveId </code> or 
     *          <code> requisiteObjectiveId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignObjectiveRequisite(org.osid.id.Id objectiveId, 
                                           org.osid.id.Id requisiteObjectiveId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Makes an objective equivalent to another objective for the purposes of 
     *  satisfying a requisite. 
     *
     *  @param  objectiveId the <code> Id </code> of the principal <code> 
     *          Objective </code> 
     *  @param  equivalentObjectiveId the <code> Id </code> of the equivalent 
     *          <code> Objective </code> 
     *  @throws org.osid.AlreadyExistsException <code> objectiveId </code> 
     *          already mapped to <code> equiavelntObjectiveId </code> 
     *  @throws org.osid.NotFoundException <code> objectiveId </code> or 
     *          <code> equivalentObjectiveId </code> not found 
     *  @throws org.osid.NullArgumentException <code> objectiveId </code> or 
     *          <code> equivalentObjectiveId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignEquivalentObjective(org.osid.id.Id objectiveId, 
                                          org.osid.id.Id equivalentObjectiveId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes an <code> Objective </code> requisite from an <code> 
     *  Objective. </code> 
     *
     *  @param  objectiveId the <code> Id </code> of the principal <code> 
     *          Objective </code> 
     *  @param  equivalentObjectiveId the <code> Id </code> of the equivalent 
     *          <code> Objective </code> 
     *  @throws org.osid.NotFoundException <code> objectiveId </code> or 
     *          <code> equivalentObjectiveId </code> not found or <code> 
     *          objectiveId </code> is already equivalent to <code> 
     *          equivalentObjectiveId </code> 
     *  @throws org.osid.NullArgumentException <code> objectiveId </code> or 
     *          <code> equivalentObjectiveId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignEquivalentObjective(org.osid.id.Id objectiveId, 
                                            org.osid.id.Id equivalentObjectiveId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
