//
// org.osid.learning.ObjectiveSearchSession
//
//     The OSID Java specification for org.osid.learning.ObjectiveSearchSession.
//
// Copyright (C) 2009 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.learning;


/**
 *  <p>This session provides methods for searching <code> Objective </code> 
 *  objects. The search query is constructed using the <code> ObjectiveQuery. 
 *  </code> The objective record <code> Type </code> also specifies the record 
 *  for the objective query. </p> 
 *  
 *  <p> <code> getObjectivesByQuery() </code> is the basic search method and 
 *  returns a list of <code> Objectives. </code> A more advanced search may be 
 *  performed with <code> getObjectivesBySearch(). </code> It accepts a <code> 
 *  ObjectiveSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getObjectivesBySearch() </code> returns an <code> 
 *  ObjectiveSearchResults </code> that can be used to access the resulting 
 *  <code> ObjectiveList </code> or be used to perform a search within the 
 *  result set through <code> ObjectiveSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated objective bank view: searches include objectives in 
 *      objective banks of which this objective bank is a ancestor in the 
 *      objective bank hierarchy </li> 
 *      <li> isolated objective bank view: searches are restricted to 
 *      objectives in this objective bank </li> 
 *  </ul>
 *  
 *  
 *  <p> Objectives may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> ObjectiveQuery. 
 *  </code> </p>
 */

public interface ObjectiveSearchSession
    extends org.osid.learning.ObjectiveQuerySession {


    /**
     *  Gets an objective search. 
     *
     *  @return the objective search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveSearch getObjectiveSearch();


    /**
     *  Gets a n objective search order. The <code> ObjectiveSearchOrder 
     *  </code> is supplied to an <code> ObjectiveSearch </code> to specify 
     *  the ordering of results. 
     *
     *  @return the objective search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveSearchOrder getObjectiveSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  objectiveQuery the objective search query 
     *  @param  objectiveSearch the objective search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> objectiveQuery </code> 
     *          or <code> objectiveSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> objectiveSearch </code> 
     *          or <code> objectiveQuery </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveSearchResults getObjectivesBySearch(org.osid.learning.ObjectiveQuery objectiveQuery, 
                                                                          org.osid.learning.ObjectiveSearch objectiveSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an objective query from an inspector. The inspector is available 
     *  from an <code> ObjectiveSearchResults. </code> 
     *
     *  @param  objectiveQueryInspector an objective bank query inspector 
     *  @return the objective query 
     *  @throws org.osid.NullArgumentException <code> objectiveQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> objectiveQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveQuery getObjectiveQueryFromInspector(org.osid.learning.ObjectiveQueryInspector objectiveQueryInspector);
}
