//
// org.osid.learning.ObjectiveSequencingSession
//
//     The OSID Java specification for org.osid.learning.ObjectiveSequencingSession.
//
// Copyright (C) 2009 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.learning;


/**
 *  <p>This session provides methods to sequence the objectives in the 
 *  objective hierarchy. </p>
 */

public interface ObjectiveSequencingSession
    extends org.osid.OsidSession {


    /**
     *  Gets the hierarchy <code> Id </code> associated with this session. 
     *
     *  @return the hierarchy <code> Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getObjectiveHierarchyId();


    /**
     *  Gets the hierarchy associated with this session. 
     *
     *  @return the hierarchy associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hierarchy.Hierarchy getObjectiveHierarchy()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can sequence objectives. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known performing any update will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer these operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if sequencing objectives is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceObjectives();


    /**
     *  Moves an objective ahead of a refrence objective under the given 
     *  parent. 
     *
     *  @param  parentObjectiveId the <code> Id </code> of the parent 
     *          objective 
     *  @param  referenceObjectiveId the <code> Id </code> of the objective 
     *  @param  objectiveId the <code> Id </code> of the objective to move 
     *          ahead of <code> referenceObjectiveId </code> 
     *  @throws org.osid.NotFoundException <code> parentObjectiveId, 
     *          referenceObjectiveId, </code> or <code> objectiveId </code> 
     *          not found, or <code> referenceObjectiveId </code> or <code> 
     *          objectiveId </code> is not a child of <code> parentObjectiveId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> parentObjectiveId, 
     *          referenceObjectiveId, </code> or <code> id </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveObjectiveAhead(org.osid.id.Id parentObjectiveId, 
                                   org.osid.id.Id referenceObjectiveId, 
                                   org.osid.id.Id objectiveId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Moves an objective behind a refrence objective under the given parent. 
     *
     *  @param  parentObjectiveId the <code> Id </code> of the parent 
     *          objective 
     *  @param  referenceObjectiveId the <code> Id </code> of the objective 
     *  @param  objectiveId the <code> Id </code> of the objective to move 
     *          behind <code> referenceObjectiveId </code> 
     *  @throws org.osid.NotFoundException <code> parentObjectiveId, 
     *          referenceObjectiveId, </code> or <code> objectiveId </code> 
     *          not found, or <code> referenceObjectiveId </code> or <code> 
     *          objectiveId </code> is not a child of <code> parentObjectiveId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> parentObjectiveId, 
     *          referenceObjectiveId, </code> or <code> id </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveObjectiveBehind(org.osid.id.Id parentObjectiveId, 
                                    org.osid.id.Id referenceObjectiveId, 
                                    org.osid.id.Id objectiveId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Sequences a set of objectives under a parent. 
     *
     *  @param  parentObjectiveId the <code> Id </code> of the parent 
     *          objective 
     *  @param  objectiveIds the <code> Id </code> of the objectives 
     *  @throws org.osid.NotFoundException <code> parentId </code> or an 
     *          <code> objectiveId </code> not found, or an <code> objectiveId 
     *          </code> is not a child of <code> parentObjectiveId </code> 
     *  @throws org.osid.NullArgumentException <code> parenObjectivetId 
     *          </code> or <code> objectiveIds </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void sequenceObjectives(org.osid.id.Id parentObjectiveId, 
                                   org.osid.id.Id[] objectiveIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
