//
// org.osid.learning.ProficiencyAdminSession
//
//     The OSID Java specification for org.osid.learning.ProficiencyAdminSession.
//
// Copyright (C) 2009 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.learning;


/**
 *  <p>This session creates, updates, and deletes <code> Proficiencies. 
 *  </code> The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Proficiency, </code> a <code> ProficiencyForm </code> is requested using 
 *  <code> getProficiencyFormForCreate() </code> specifying the desired 
 *  relationship peers and record <code> Types </code> or none if no record 
 *  <code> Types </code> are needed. The returned <code> ProficiencyForm 
 *  </code> will indicate that it is to be used with a create operation and 
 *  can be used to examine metdata or validate data prior to creation. Once 
 *  the <code> ProficiencyForm </code> is submiited to a create operation, it 
 *  cannot be reused with another create operation unless the first operation 
 *  was unsuccessful. Each <code> ProficiencyForm </code> corresponds to an 
 *  attempted transaction. </p> 
 *  
 *  <p> For updates, <code> ProficiencyForms </code> are requested to the 
 *  <code> Proficiency </code> <code> Id </code> that is to be updated using 
 *  <code> getProficiencyFormForUpdate(). </code> Similarly, the <code> 
 *  ProficiencyForm </code> has metadata about the data that can be updated 
 *  and it can perform validation before submitting the update. The <code> 
 *  ProficiencyForm </code> can only be used once for a successful update and 
 *  cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Proficiencies. </code> To unmap a 
 *  <code> Proficiency </code> from the current <code> ObjectiveBank, </code> 
 *  the <code> ProficiencyObjectiveBankAssignmentSession </code> should be 
 *  used. These delete operations attempt to remove the <code> Proficiency 
 *  </code> itself thus removing it from all known <code> ObjectiveBank 
 *  </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface ProficiencyAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> ObjectiveBank </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> ObjectiveBank Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getObjectiveBankId();


    /**
     *  Gets the <code> ObjectiveBank </code> associated with this session. 
     *
     *  @return the obective bank 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveBank getObjectiveBank()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> Proficiencies. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> Proficiency </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer create operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Proficiency </code> creation is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateProficiencies();


    /**
     *  Tests if this user can create a single <code> Proficiency </code> 
     *  using the desired record types. While <code> 
     *  LearningManager.getProficiencyRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> Proficiency. </code> 
     *  Providing an empty array tests if a <code> Proficiency </code> can be 
     *  created with no records. 
     *
     *  @param  proficiencyRecordTypes array of proficiency record types 
     *  @return <code> true </code> if <code> Proficiency </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> proficiencyRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateProficiencyWithRecordTypes(org.osid.type.Type[] proficiencyRecordTypes);


    /**
     *  Gets the proficiency form for creating new proficiencies. A new form 
     *  should be requested for each create transaction. 
     *
     *  @param  objectiveId the <code> Id </code> of the <code> Objective 
     *          </code> 
     *  @param  resourceId the <code> Id </code> of the <code> Resource 
     *          </code> 
     *  @param  proficiencyRecordTypes array of proficiency record types 
     *  @return the proficiency form 
     *  @throws org.osid.NotFoundException <code> objectiveId </code> or 
     *          <code> resourceId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> objectiveId, resourceId, 
     *          </code> or <code> proficienyRecordTypes </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ProficiencyForm getProficiencyFormForCreate(org.osid.id.Id objectiveId, 
                                                                         org.osid.id.Id resourceId, 
                                                                         org.osid.type.Type[] proficiencyRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Proficiency. </code> A new form should be 
     *  requested for each create transaction. 
     *
     *  @param  proficiencyForm the form for this <code> Proficiency </code> 
     *  @return the new <code> Proficiency </code> 
     *  @throws org.osid.IllegalStateException <code> proficiencyForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> proficiencyForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> proficiencyForm </code> 
     *          did not originate from <code> getProficiencyFormForCreate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.Proficiency createProficiency(org.osid.learning.ProficiencyForm proficiencyForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Proficiencies. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> Proficiency </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer update operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Proficiency </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateProficiencies();


    /**
     *  Gets the proficiency form for updating an existing proficiency. 
     *
     *  @param  proficiencyId the <code> Id </code> of the <code> Proficiency 
     *          </code> 
     *  @return the proficiency form 
     *  @throws org.osid.NotFoundException <code> proficiencyId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> proficiencyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ProficiencyForm getProficiencyFormForUpdate(org.osid.id.Id proficiencyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing proficiency. 
     *
     *  @param  proficiencyForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> proficiencyForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> proficiencyForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> proficiencyForm </code> 
     *          did not originate from <code> getProficiencyFormForUpdate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateProficiency(org.osid.learning.ProficiencyForm proficiencyForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> Proficiencies. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> Proficiency </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer delete operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Proficiency </code> deletion is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteProficiencies();


    /**
     *  Deletes a <code> Proficiency. </code> 
     *
     *  @param  proficiencyId the <code> Id </code> of the <code> Proficiency 
     *          </code> to remove 
     *  @throws org.osid.NotFoundException <code> proficiencyId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> proficiencyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteProficiency(org.osid.id.Id proficiencyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all proficiencies in this <code> ObjectiveBank. </code> 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteProficiencies()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for 
     *  proficiency entries. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Proficiency </code> aliasing is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageProficiencyAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Proficiency </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Proficiency </code> is determined by the provider. The new 
     *  <code> Id </code> performs as an alias to the primary <code> Id. 
     *  </code> If the alias is a pointer to another proficiency, it is 
     *  reassigned to the given proficiency <code> Id. </code> 
     *
     *  @param  proficiencyId the <code> Id </code> of a <code> Proficiency 
     *          </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> proficiencyId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> proficiencyId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasProficiency(org.osid.id.Id proficiencyId, 
                                 org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
