//
// org.osid.learning.ProficiencyNotificationSession
//
//     The OSID Java specification for org.osid.learning.ProficiencyNotificationSession.
//
// Copyright (C) 2009 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.learning;


/**
 *  <p>This session defines methods to receive notifications on adds/changes 
 *  to <code> Proficiency </code> objects in this <code> ObjectiveBank. 
 *  </code> This also includes existing proficiencies that may appear or 
 *  disappear due to changes in the <code> ObjectiveBank </code> hierarchy, 
 *  This session is intended for consumers needing to synchronize their state 
 *  with this service without the use of polling. Notifications are cancelled 
 *  when this session is closed. </p> 
 *  
 *  <p> The two views defined in this session correspond to the views in the 
 *  <code> ProficiencyLookupSession. </code> </p>
 */

public interface ProficiencyNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> ObjectiveBank </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> ObjectiveBank Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getObjectiveBankId();


    /**
     *  Gets the <code> ObjectiveBank </code> associated with this session. 
     *
     *  @return the obective bank 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveBank getObjectiveBank()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can register for <code> Proficiency </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForProficiencyNotifications();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include proficiencies in objective banks which are children of this 
     *  objective bank in the obective bank hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedObjectiveBankView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts notifications to this objective bank only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedObjectiveBankView();


    /**
     *  Reliable notifications are desired. In reliable mode, notifications 
     *  are to be acknowledged using <code> 
     *  acknowledgeProficiencyNotification() </code> . 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void reliableProficiencyNotifications();


    /**
     *  Unreliable notifications are desired. In unreliable mode, 
     *  notifications do not need to be acknowledged. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void unreliableProficiencyNotifications();


    /**
     *  Acknowledge a proficiency notification. 
     *
     *  @param  notificationId the <code> Id </code> of the notification 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void acknowledgeProficiencyNotification(org.osid.id.Id notificationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new proficiencies. <code> 
     *  ProficiencyReceiver.newProficiencies() </code> is invoked when a new 
     *  <code> Proficiency </code> appears in this objective bank. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewProficiencies()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new proficiencies with the given genus 
     *  type. <code> ProficiencyReceiver.newProficiencies() </code> is invoked 
     *  when a new <code> Proficiency </code> appears for the given resource 
     *  in this objective bank. 
     *
     *  @param  proficiencyGenusType the genus type of a proficiency to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> proficiencyGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewProficienciesByGenusType(org.osid.type.Type proficiencyGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new proficiencies. <code> 
     *  ProficiencyReceiver.newProficiencies() </code> is invoked when a new 
     *  <code> Proficiency </code> appears for the given objective in this 
     *  objective bank. 
     *
     *  @param  objectiveId the <code> Id </code> of a resource to monitor 
     *  @throws org.osid.NullArgumentException <code> objectiveId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewProficienciesForObjective(org.osid.id.Id objectiveId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new proficiencies. <code> 
     *  ProficiencyReceiver.newProficiencies() </code> is invoked when a new 
     *  <code> Proficiency </code> appears for the given resource in this 
     *  objective bank. 
     *
     *  @param  resourceId the <code> Id </code> of a resource to monitor 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewProficienciesForResource(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated proficiencies. <code> 
     *  ProficiencyReceiver.changedProficiencies() </code> is invoked when a 
     *  proficiency in this objective bank is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedProficiencies()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated proficiencies of the given genus 
     *  type. <code> ProficiencyReceiver.changedProficiencies() </code> is 
     *  invoked when a proficiency in this objective bank is changed. 
     *
     *  @param  proficiencyGenusType the genus type of the <code> Proficiency 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> proficiencyGenusTYpe 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedProficienciesByGenusType(org.osid.type.Type proficiencyGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated proficiency. <code> 
     *  ProficiencyReceiver.changedProficiencies() </code> is invoked when the 
     *  specified proficiency related to the given objective is changed in 
     *  this objective bank. 
     *
     *  @param  objectiveId the <code> Id </code> of the <code> Objective 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> objectiveId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedProficienciesForObjective(org.osid.id.Id objectiveId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated proficiency. <code> 
     *  ProficiencyReceiver.changedProficiencies() </code> is invoked when the 
     *  specified proficiency related to the given resource is changed in this 
     *  objective bank. 
     *
     *  @param  resourceId the <code> Id </code> of the <code> Resource 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedProficienciesForResource(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated proficiency. <code> 
     *  ProficiencyReceiver.changedProficiencies() </code> is invoked when the 
     *  specified proficiency in this objective bank is changed. 
     *
     *  @param  proficiencyId the <code> Id </code> of the <code> Proficiency 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> proficiencyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedProficiency(org.osid.id.Id proficiencyId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted proficiencies. <code> 
     *  ProficiencyReceiver.deletedProficiencies() </code> is invoked when a 
     *  proficiency is deleted or removed from this objective bank. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedProficiencies()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted proficiencies of the given genus 
     *  type. <code> ProficiencyReceiver.deletedProficiencies() </code> is 
     *  invoked when a proficiency is deleted or removed from this objective 
     *  bank. 
     *
     *  @param  proficiencyGenusType the genus type of the <code> Proficiency 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> proficiencyGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedProficienciesByGenusType(org.osid.type.Type proficiencyGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted proficiency. <code> 
     *  ProficiencyReceiver.deletedProficiencies() </code> is invoked when the 
     *  specified proficiency related to the objective is deleted or removed 
     *  from this objective bank. 
     *
     *  @param  objectiveId the <code> Id </code> of the <code> Objective 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> objectiveId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedProficienciesForObjective(org.osid.id.Id objectiveId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted proficiency. <code> 
     *  ProficiencyReceiver.deletedProficiencies() </code> is invoked when the 
     *  specified proficiency related to the resource is deleted or removed 
     *  from this objective bank. 
     *
     *  @param  resourceId the <code> Id </code> of the <code> Resource 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedProficienciesForResource(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted proficiency. <code> 
     *  ProficiencyReceiver.deletedProficiencies() </code> is invoked when the 
     *  specified proficiency is deleted or removed from this objective bank. 
     *
     *  @param  proficiencyId the <code> Id </code> of the <code> Proficiency 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> proficiencyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedProficiency(org.osid.id.Id proficiencyId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
