//
// org.osid.locale.CalendarFormattingSession
//
//     The OSID Java specification for org.osid.locale.CalendarFormattingSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.locale;


/**
 *  <p>This session defines methods to format and parse date times of the 
 *  calendar and time type defined. </p>
 */

public interface CalendarFormattingSession
    extends org.osid.OsidSession {


    /**
     *  Gets the calendar type for the datetimes used in this session. 
     *
     *  @return the calendar type 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getCalendarType();


    /**
     *  Gets the time type for the times used in this session. 
     *
     *  @return the time type 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getTimeType();


    /**
     *  Gets the date format type used in this session. 
     *
     *  @return the target language 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getDateFormatType();


    /**
     *  Gets the time format type used in this session. 
     *
     *  @return the target script 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getTimeFormatType();


    /**
     *  Tests if this user can format and parse date times. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations. 
     *
     *  @return <code> false </code> if translation methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDisplayPrimitives();


    /**
     *  Gets a string representation of a datetime. 
     *
     *  @param  datetime a datetime value 
     *  @return the display string 
     *  @throws org.osid.InvalidArgumentException <code> 
     *          datetime.getCalendarType() != getCalendarType() </code> or 
     *          <code> datetime.getTimeType() != getTimeType() </code> 
     *  @throws org.osid.NullArgumentException <code> datetime </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public String datetimeToString(org.osid.calendaring.DateTime datetime)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a string representation of a list of datetimes. 
     *
     *  @param  datetimes a datetime value list 
     *  @return the display strings 
     *  @throws org.osid.InvalidArgumentException <code> 
     *          datetime.getCalendarType() != getCalendarType() </code> or 
     *          <code> datetime.getTimeType() != getTimeType() </code> 
     *  @throws org.osid.NullArgumentException <code> datetimes </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public String[] datetimesToStrings(org.osid.calendaring.DateTimeList datetimes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Parses a date time string. 
     *
     *  @param  s a datetime string 
     *  @return the date time value 
     *  @throws org.osid.InvalidArgumentException <code> s </code> is not of 
     *          <code> getDateFormatType() </code> or <code> s </code> is not 
     *          of <code> getTimeFormatType() </code> 
     *  @throws org.osid.NullArgumentException <code> s </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime stringToDateTime(String s)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a string representation of a time. 
     *
     *  @param  time a time value 
     *  @return the display string 
     *  @throws org.osid.InvalidArgumentException <code> time.getTimeType() != 
     *          getTimeType() </code> 
     *  @throws org.osid.NullArgumentException <code> time </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public String timeToString(org.osid.calendaring.Time time)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a string representation of a list of times. 
     *
     *  @param  times a time value list 
     *  @return the display strings 
     *  @throws org.osid.InvalidArgumentException <code> time.getTimeType() 
     *          </code> != <code> getTimeType() </code> 
     *  @throws org.osid.NullArgumentException <code> times </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public String[] timesToStrings(org.osid.calendaring.TimeList times)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Parses a time string. 
     *
     *  @param  s a time string 
     *  @return the time value 
     *  @throws org.osid.InvalidArgumentException <code> s </code> is not of 
     *          <code> getTimeFormatType() </code> 
     *  @throws org.osid.NullArgumentException <code> s </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Time stringToTime(String s)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a string representation of a duration. 
     *
     *  @param  duration a duration value 
     *  @return the display string 
     *  @throws org.osid.InvalidArgumentException <code> 
     *          duration.getCalendarType() != </code> <code> getCalendarType() 
     *          </code> or <code> duration.getTimeType() != getTimeType() 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> duration </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public String durationToString(org.osid.calendaring.Duration duration)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a string representation of a list of durations. 
     *
     *  @param  durations a duration value list 
     *  @return the display strings 
     *  @throws org.osid.InvalidArgumentException <code> 
     *          duration.getCalendarType() != </code> <code> getCalendarType() 
     *          </code> or <code> duration.getTimeType() != getTimeType() 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> durations </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public String[] durationsToStrings(org.osid.calendaring.DurationList durations)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Parses a duration string. 
     *
     *  @param  s a duration string 
     *  @return the duration value 
     *  @throws org.osid.InvalidArgumentException <code> s </code> is not of 
     *          <code> getDateFormatType() </code> or <code> s </code> is not 
     *          of <code> getTimeFormatType() </code> 
     *  @throws org.osid.NullArgumentException <code> s </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Duration stringToDuration(String s)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
