//
// org.osid.locale.CurrencyFormattingSession
//
//     The OSID Java specification for org.osid.locale.CurrencyFormattingSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.locale;


/**
 *  <p>This session defines methods to format and parse currency amounts. </p>
 */

public interface CurrencyFormattingSession
    extends org.osid.OsidSession {


    /**
     *  Gets the currency type for amounts used in this session. 
     *
     *  @return the currency type 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getCurrencyType();


    /**
     *  Gets the numeric format type for the amounts used in this session. 
     *
     *  @return the numeric format type 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getNumericFormatType();


    /**
     *  Tests if this user can format and parse currencies. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations. 
     *
     *  @return <code> false </code> if translation methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canFormatCurrencies();


    /**
     *  Gets a string representation of a currency including the currency 
     *  symbol indicated by the currency type. 
     *
     *  @param  amount a currency value 
     *  @return the display string 
     *  @throws org.osid.InvalidArgumentException <code> 
     *          amount.getCurrencyType() != getCurrencyType() </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public String currencyToString(org.osid.financials.Currency amount)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a string representation of a list of currency amounts including 
     *  the currency symbols indicated by the currency type. 
     *
     *  @param  amounts an array of amounts 
     *  @return the display strings 
     *  @throws org.osid.InvalidArgumentException <code> 
     *          amount.getCurrencyType() != getCurrencyType() </code> 
     *  @throws org.osid.NullArgumentException <code> amounts </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public String[] currenciesToStrings(org.osid.financials.Currency[] amounts)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Parses a currency amount. 
     *
     *  @param  s a currency string 
     *  @return the currency amount 
     *  @throws org.osid.InvalidArgumentException s is not of <code> 
     *          getCurrencyType() </code> or s is not of <code> 
     *          getNumericFormatType() </code> 
     *  @throws org.osid.NullArgumentException <code> s </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.Currency stringToCurrency(String s)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
