//
// org.osid.locale.LocaleProfile
//
//     The OSID Java specification for org.osid.locale.LocaleProfile.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.locale;


/**
 *  <p>The locale profile describes the interoperability of locale services. 
 *  </p>
 */

public interface LocaleProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if visible federation is supported. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if translation is supported. 
     *
     *  @return <code> true </code> if translation is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTranslation();


    /**
     *  Tests if translation administration is supported. 
     *
     *  @return <code> true </code> if translation administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTranslationAdmin();


    /**
     *  Tests if numeric formatting is supported. 
     *
     *  @return <code> true </code> if numeric formatting is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsNumericFormatting();


    /**
     *  Tests if calendar formatting is supported. 
     *
     *  @return <code> true </code> if calendar formatting is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCalendarFormatting();


    /**
     *  Tests if currency formatting is supported. 
     *
     *  @return <code> true </code> if currency formatting is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCurrencyFormatting();


    /**
     *  Tests if coordinate formatting is supported. 
     *
     *  @return <code> true </code> if coordinate formatting is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCoordinateFormatting();


    /**
     *  Tests if unit conversion is supported. 
     *
     *  @return <code> true </code> if unit conversion is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsUnitConversion();


    /**
     *  Tests if currency conversion is supported. 
     *
     *  @return <code> true </code> if currency conversion is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCurrencyConversion();


    /**
     *  Tests if calendar conversion is supported. 
     *
     *  @return <code> true </code> if calendar conversion is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCalendarConversion();


    /**
     *  Tests if coordnate conversion is supported. 
     *
     *  @return <code> true </code> if coordinate conversion is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCoordinateConversion();


    /**
     *  Tests if spatial unit conversion is supported. 
     *
     *  @return <code> true </code> if spatial unit conversion is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSpatialUnitConversion();


    /**
     *  Tests if format conversion is supported. 
     *
     *  @return <code> true </code> if format conversion is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFormatConversion();


    /**
     *  Tests if a calendar informational service is supported. 
     *
     *  @return <code> true </code> if calendar info is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCalendarInfo();


    /**
     *  Tests if a given language translation is supported. 
     *
     *  @param  sourceLanguageType the type of the source language 
     *  @param  sourceScriptType the type of the source script 
     *  @param  targetLanguageType the type of the target language 
     *  @param  targetScriptType the type of the target script 
     *  @return <code> true </code> if the given source and target translation 
     *          is supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> sourceLanguageType, 
     *          sourceScriptType, targetLanguageType </code> or <code> 
     *          targetScriptType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLanguageTypesForTranslation(org.osid.type.Type sourceLanguageType, 
                                                       org.osid.type.Type sourceScriptType, 
                                                       org.osid.type.Type targetLanguageType, 
                                                       org.osid.type.Type targetScriptType);


    /**
     *  Gets the list of target language types for a given source language 
     *  type. 
     *
     *  @param  sourceLanguageType the type of the source language 
     *  @param  sourceScriptType the type of the source script 
     *  @return the list of supported types for the given source language type 
     *  @throws org.osid.NullArgumentException <code> sourceLanguageType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getLanguageTypesForSource(org.osid.type.Type sourceLanguageType, 
                                                            org.osid.type.Type sourceScriptType);


    /**
     *  Gets all the source language types supported. 
     *
     *  @return the list of supported language types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSourceLanguageTypes();


    /**
     *  Gets the list of script types available for a given language type. 
     *
     *  @param  languageType the type of the language 
     *  @return the list of supported script types for the given language type 
     *  @throws org.osid.NullArgumentException <code> languageType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getScriptTypesForLanguageType(org.osid.type.Type languageType);


    /**
     *  Tests if a given numeric format type is supported. 
     *
     *  @param  numericFormatType the type of the numeric format 
     *  @return <code> true </code> if the given numeric format type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> numericFormatType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsNumericFormatTypes(org.osid.type.Type numericFormatType);


    /**
     *  Gets all the numeric format types supported. 
     *
     *  @return the list of supported numeric format types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getNumericFormatTypes();


    /**
     *  Tests if a given calendaring formatting is supported. 
     *
     *  @param  calendarType the type of the calendar 
     *  @param  timeType the type of the time system 
     *  @param  dateFormatType the type of the output date format 
     *  @param  timeFormatType the type of the output time format 
     *  @return <code> true </code> if formatting with the given types is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> calendarType, 
     *          calendarFormatType, timeType, </code> or <code> timeFormatType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCalendarTypesForFormatting(org.osid.type.Type calendarType, 
                                                      org.osid.type.Type timeType, 
                                                      org.osid.type.Type dateFormatType, 
                                                      org.osid.type.Type timeFormatType);


    /**
     *  Gets all the calendar types for which formats are available. 
     *
     *  @return the list of calendar types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCalendarTypesForFormatting();


    /**
     *  Gets the list of date format types for a given calendar type. 
     *
     *  @param  calendarType the type of the calendar 
     *  @return the list of supported date format types 
     *  @throws org.osid.NullArgumentException <code> calendarType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getDateFormatTypesForCalendarType(org.osid.type.Type calendarType);


    /**
     *  Gets all the time types for which formatting is available. 
     *
     *  @return the list of time types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getTimeTypesForFormatting();


    /**
     *  Gets the list of time format types for a given time type. 
     *
     *  @param  timeType the type of the time 
     *  @return the list of supported time format types 
     *  @throws org.osid.NullArgumentException <code> timeType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getTimeFormatTypesForTimeType(org.osid.type.Type timeType);


    /**
     *  Tests if a given currency formatting is supported. 
     *
     *  @param  currencyType the type of the currency 
     *  @param  numericFormatType the type of the output currency format 
     *  @return <code> true </code> if formatting with the given types is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> currencyType </code> or 
     *          <code> numericFormatType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCurrencyTypesForFormatting(org.osid.type.Type currencyType, 
                                                      org.osid.type.Type numericFormatType);


    /**
     *  Gets all the currency types for which formatting is available. 
     *
     *  @return the list of currency types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCurrencyTypesForFormatting();


    /**
     *  Gets the list of currency format types for a given currency type. 
     *
     *  @param  currencyType the type of the currency 
     *  @return the list of supported currency format types 
     *  @throws org.osid.NullArgumentException <code> currencyType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCurrencyFormatTypesForCurrencyType(org.osid.type.Type currencyType);


    /**
     *  Tests if a given coordinate formatting is supported. 
     *
     *  @param  coordinateType the type of the coordinate 
     *  @param  coordinateFormatType the type of the output coordinate format 
     *  @return <code> true </code> if formatting with the given types is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> cooridinateType </code> 
     *          or <code> coodinateFormatType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCoordinateTypesForFormatting(org.osid.type.Type coordinateType, 
                                                        org.osid.type.Type coordinateFormatType);


    /**
     *  Gets all the coordinate types for which formatting is available. 
     *
     *  @return the list of coordinate types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCoordinateTypesForFormatting();


    /**
     *  Gets the list of coordinate format types for a given coordinate type. 
     *
     *  @param  coordinateType the type of the coordinate 
     *  @return the list of supported coordinate format types 
     *  @throws org.osid.NullArgumentException <code> coordinaterType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCoordinateFormatTypesForCoordinateType(org.osid.type.Type coordinateType);


    /**
     *  Tests if a given measure conversion is supported. 
     *
     *  @param  sourceUnitType the type of the source measure 
     *  @param  targetUnitType the type of the target measure 
     *  @return <code> true </code> if the given source and target conversion 
     *          is supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> sourceUnitType </code> 
     *          or <code> targetUnitType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsUnitTypesForConversion(org.osid.type.Type sourceUnitType, 
                                                  org.osid.type.Type targetUnitType);


    /**
     *  Gets the list of target measure types for a given source measure type. 
     *
     *  @param  sourceUnitType the type of the source measure 
     *  @return the list of supported target measure types 
     *  @throws org.osid.NullArgumentException <code> sourceUnitType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getUnitTypesForSource(org.osid.type.Type sourceUnitType);


    /**
     *  Gets all the source unit types supported. 
     *
     *  @return the list of supported source unit types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSourceUnitTypes();


    /**
     *  Tests if a given currency conversion is supported. 
     *
     *  @param  sourceCurrencyType the type of the source currency 
     *  @param  targetCurrencyType the type of the target currency 
     *  @return <code> true </code> if the given source and target conversion 
     *          is supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> sourceCurrencyType 
     *          </code> or <code> targetCurrencyType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCurrencyTypesForConversion(org.osid.type.Type sourceCurrencyType, 
                                                      org.osid.type.Type targetCurrencyType);


    /**
     *  Gets the list of target currency types for a given source currency 
     *  type. 
     *
     *  @param  sourceCurrencyType the type of the source currency 
     *  @return the list of supported currency types 
     *  @throws org.osid.NullArgumentException <code> sourceCurrencyType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCurrencyTypesForSource(org.osid.type.Type sourceCurrencyType);


    /**
     *  Gets the list of source currency types. 
     *
     *  @return the list of supported source currency types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSourceCurrencyTypes();


    /**
     *  Tests if a given calendar conversion is supported. 
     *
     *  @param  sourceCalendarType the type of the source calendar 
     *  @param  targetCalendarType the type of the target calendar 
     *  @return <code> true </code> if the given source and target conversion 
     *          is supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> sourceCalendarType 
     *          </code> or <code> targetCalendarType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCalendarTypesForConversion(org.osid.type.Type sourceCalendarType, 
                                                      org.osid.type.Type targetCalendarType);


    /**
     *  Gets the list of target calendar types for a given source calendar 
     *  type. 
     *
     *  @param  sourceCalendarType the type of the source calendar 
     *  @return the list of supported calendar types 
     *  @throws org.osid.NullArgumentException <code> sourceCalendarType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCalendarTypesForSource(org.osid.type.Type sourceCalendarType);


    /**
     *  Gets the list of source calendar types. 
     *
     *  @return the list of supported source calendar types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSourceCalendarTypes();


    /**
     *  Tests if a given time conversion is supported. 
     *
     *  @param  sourceTimeType the type of the source time 
     *  @param  targetTimeType the type of the target time 
     *  @return <code> true </code> if the given source and target conversion 
     *          is supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> sourceTimeType </code> 
     *          or <code> targetTimeType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTimeTypesForConversion(org.osid.type.Type sourceTimeType, 
                                                  org.osid.type.Type targetTimeType);


    /**
     *  Gets the list of target time types for a given source time type. 
     *
     *  @param  sourceTimeType the type of the source time 
     *  @return the list of supported time types 
     *  @throws org.osid.NullArgumentException <code> sourceTimeType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getTimeTypesForSource(org.osid.type.Type sourceTimeType);


    /**
     *  Gets the list of source time types. 
     *
     *  @return the list of supported source time types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSourceTimeTypes();


    /**
     *  Gets the list of time types supported for a given calendar type where 
     *  they are both used in a <code> DateTime. </code> 
     *
     *  @param  calendarType the type of the calendar 
     *  @return the list of supported time types 
     *  @throws org.osid.NullArgumentException <code> calendarType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getTimeTypesForCalendarType(org.osid.type.Type calendarType);


    /**
     *  Gets the list of calendar types supported for a given time type where 
     *  they are both used in a <code> DateTime. </code> 
     *
     *  @param  timeType the type of the time system 
     *  @return the list of supported calendar types 
     *  @throws org.osid.NullArgumentException <code> timeType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCalendarTypesForTimeType(org.osid.type.Type timeType);


    /**
     *  Tests if a given calendar and time type are used together in a <code> 
     *  DateTime. </code> 
     *
     *  @param  calendarType the type of the calendar 
     *  @param  timeType the type of the time system 
     *  @return <code> true </code> if the given calendar and time types are 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> calendarType </code> or 
     *          <code> timeType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCalendarTimeTypes(org.osid.type.Type calendarType, 
                                             org.osid.type.Type timeType);


    /**
     *  Tests if a given coordinate type for conversion is supported. 
     *
     *  @param  sourceCoordinateType the type of the source coordinate 
     *  @param  targetCoordinateType the type of the target coordinate 
     *  @return <code> true </code> if the given source and target conversion 
     *          is supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> sourceCoordinateType 
     *          </code> or <code> targetCoordinateType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCoordinateTypesForConversion(org.osid.type.Type sourceCoordinateType, 
                                                        org.osid.type.Type targetCoordinateType);


    /**
     *  Gets the list of target coordinate types for a given source coordinate 
     *  type. 
     *
     *  @param  sourceCoordinateType the type of the source coordinate 
     *  @return the list of supported target coordinate types 
     *  @throws org.osid.NullArgumentException <code> sourceCoordinateType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCoordinateTypesForSource(org.osid.type.Type sourceCoordinateType);


    /**
     *  Gets the list of source coordinate types. 
     *
     *  @return the list of supported source coordinate types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSourceCoordinateTypes();


    /**
     *  Tests if a given spatial unit conversion is supported. 
     *
     *  @param  sourceSpatialUnitRecordType the type of the source spatial 
     *          unit record 
     *  @param  targetSpatialUnitRecordType the type of the target spatial 
     *          unit record 
     *  @return <code> true </code> if the given source and target conversion 
     *          is supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          sourceSpatialUnitRecordType </code> or <code> 
     *          targetSpatialUnitRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSpatialUnitRecordTypesForConversion(org.osid.type.Type sourceSpatialUnitRecordType, 
                                                               org.osid.type.Type targetSpatialUnitRecordType);


    /**
     *  Gets the list of target spatial unit types for a given source spatial 
     *  unit type. 
     *
     *  @param  sourceSpatialUnitRecordType the type of the source spatial 
     *          unit record 
     *  @return the list of supported target spatial unit record types 
     *  @throws org.osid.NullArgumentException <code> 
     *          sourceSpatialUnitRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSpatialUnitRecordTypesForSource(org.osid.type.Type sourceSpatialUnitRecordType);


    /**
     *  Gets the list of source spatial unit record types. 
     *
     *  @return the list of supported source spatial unit record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSourceSpatialUnitRecordTypes();


    /**
     *  Tests if a given format conversion is supported. 
     *
     *  @param  sourceFormatType the type of the source format 
     *  @param  targetFormatType the type of the target format 
     *  @return <code> true </code> if the given source and target conversion 
     *          is supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> sourceFormatType </code> 
     *          or <code> targetFormatType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFormatTypesForConversion(org.osid.type.Type sourceFormatType, 
                                                    org.osid.type.Type targetFormatType);


    /**
     *  Gets the list of target format types for a given source spatial unit 
     *  type. 
     *
     *  @param  sourceFormatType the type of the source format 
     *  @return the list of supported target format types 
     *  @throws org.osid.NullArgumentException <code> sourceFormatType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getFormatTypesForSource(org.osid.type.Type sourceFormatType);


    /**
     *  Gets the list of source format types. 
     *
     *  @return the list of supported source format types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSourceFormatTypes();
}
