//
// org.osid.locale.NumericFormattingSession
//
//     The OSID Java specification for org.osid.locale.NumericFormattingSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.locale;


/**
 *  <p>This session defines methods to format and parse numbers. </p>
 */

public interface NumericFormattingSession
    extends org.osid.OsidSession {


    /**
     *  Gets the numeric format type used in this session. The numeric format 
     *  type indicates the format of a number used in a culture, such as the 
     *  use of a period for a decimal place. 
     *
     *  @return the target language 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getNumericFormatType();


    /**
     *  Tests if this user can format and parse numbers. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations. 
     *
     *  @return <code> false </code> if translation methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canFormatNumbers();


    /**
     *  Gets a string representation of a cardinal. 
     *
     *  @param  c a cardinal value 
     *  @return the display string 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public String cardinalToString(long c)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a string representation of an array of cardinals. 
     *
     *  @param  c a cardinal value array 
     *  @return the display strings 
     *  @throws org.osid.NullArgumentException <code> c </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public String[] cardinalsToStrings(long[] c)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Parses a cardinal string. 
     *
     *  @param  str a cardinal string 
     *  @return the cardinal value 
     *  @throws org.osid.InvalidArgumentException <code> str </code> not of 
     *          <code> getNumericFormatType() </code> 
     *  @throws org.osid.NullArgumentException <code> str </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public long stringToCardinal(String str)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a string representation of a decimal. 
     *
     *  @param  d a decimal value 
     *  @return the display string 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public String decimalToString(java.math.BigDecimal d)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a string representation of an array of decimals. 
     *
     *  @param  d a decimals value array 
     *  @return the display strings 
     *  @throws org.osid.NullArgumentException <code> d </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public String[] decimalsToStrings(java.math.BigDecimal[] d)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Parses a decimal string. 
     *
     *  @param  str a decimal string 
     *  @return the decimal value 
     *  @throws org.osid.InvalidArgumentException <code> str </code> not of 
     *          <code> getNumericFormatType() </code> 
     *  @throws org.osid.NullArgumentException <code> str </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal decimalToString(String str)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a string representation of a integer. 
     *
     *  @param  i an integer value 
     *  @return the display string 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public String integerToString(long i)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a string representation of an array of integers. 
     *
     *  @param  i an integer value array 
     *  @return the display strings 
     *  @throws org.osid.NullArgumentException <code> i </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public String[] integersToStrings(long[] i)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Parses an integer string. 
     *
     *  @param  str an integer string 
     *  @return the integer value 
     *  @throws org.osid.InvalidArgumentException <code> str </code> not of 
     *          <code> getNumericFormatType() </code> 
     *  @throws org.osid.NullArgumentException <code> str </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public long integerToString(String str)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
