//
// org.osid.locale.SpatialUnitConversionSession
//
//     The OSID Java specification for org.osid.locale.SpatialUnitConversionSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.locale;


/**
 *  <p>This session defines methods to convert spatial units. </p>
 */

public interface SpatialUnitConversionSession
    extends org.osid.OsidSession {


    /**
     *  Gets the source spatial unit record type used in this session. 
     *
     *  @return the source spatial unit record type 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getSourceSpatialUnitRecordType();


    /**
     *  Gets the target spatial unit record type used in this session. 
     *
     *  @return the target spatial unit record type 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getTargetSpatialUnitRecordType();


    /**
     *  Tests if this user can perform spatial unit conversions. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations. 
     *
     *  @return <code> false </code> if conversion methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canConvertSpatialUnits();


    /**
     *  Converts a spatial unit. 
     *
     *  @param  sourceSpatialUnit the spatial unit to convert 
     *  @return the resulting spatial unit 
     *  @throws org.osid.InvalidArgumentException <code> 
     *          sourceSpatialUnit.hasType(getSourceSpatialUnitRecordType()) 
     *          </code> is <code> false </code> 
     *  @throws org.osid.NullArgumentException <code> sourceSpatialUnit 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.SpatialUnit convertSpatialUnit(org.osid.mapping.SpatialUnit sourceSpatialUnit)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Converts spatial units. 
     *
     *  @param  sourceSpatialUnitList the spatial units to convert 
     *  @return the resulting spatial units 
     *  @throws org.osid.InvalidArgumentException <code> 
     *          sourceSpatialUnit.hasType(getSourceSpatialUnitRecordType()) 
     *          </code> is <code> false </code> 
     *  @throws org.osid.NullArgumentException <code> sourceSpatialUnitList 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.SpatialUnitList convertSpatialUnits(org.osid.mapping.SpatialUnitList sourceSpatialUnitList)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
