//
// org.osid.logging.LogEntryLogAssignmentSession
//
//     The OSID Java specification for org.osid.logging.LogEntryLogAssignmentSession.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.logging;


/**
 *  <p>This session provides methods to re-assign log entries to <code> Logs. 
 *  </code> A <code> LogEntry </code> may map to multiple <code> Log </code> 
 *  objects and removing the last reference to a <code> LogEntry </code> is 
 *  the equivalent of deleting it. Each <code> Log </code> may have its own 
 *  authorizations governing who is allowed to operate on it. </p> 
 *  
 *  <p> Moving or adding a reference of a <code> LogEntry </code> to another 
 *  <code> Log </code> is not a copy operation (eg: does not change its <code> 
 *  Id </code> ). </p>
 */

public interface LogEntryLogAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter log entry/log mappings. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignLogEntries();


    /**
     *  Tests if this user can alter log entry/log mappings. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @param  logId the <code> Id </code> of the <code> Log </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> logId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignLogEntriesToLog(org.osid.id.Id logId);


    /**
     *  Gets a list of log including and under the given log node in which any 
     *  log entry can be assigned. 
     *
     *  @param  logId the <code> Id </code> of the <code> Log </code> 
     *  @return list of assignable log <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> logId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableLogIds(org.osid.id.Id logId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of log including and under the given log node in which a 
     *  specific log entry can be assigned. 
     *
     *  @param  logId the <code> Id </code> of the <code> Log </code> 
     *  @param  logEntryId the <code> Id </code> of the <code> LogEntry 
     *          </code> 
     *  @return list of assignable log <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> logId </code> or <code> 
     *          logEntryId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableLogIdsForLogEntry(org.osid.id.Id logId, 
                                                             org.osid.id.Id logEntryId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> LogEntry </code> to a <code> Log. </code> 
     *
     *  @param  logEntryId the <code> Id </code> of the <code> LogEntry 
     *          </code> 
     *  @param  logId the <code> Id </code> of the <code> Log </code> 
     *  @throws org.osid.AlreadyExistsException <code> logEntryId </code> is 
     *          already assigned to <code> logId </code> 
     *  @throws org.osid.NotFoundException <code> logEntryId </code> or <code> 
     *          logId </code> not found 
     *  @throws org.osid.NullArgumentException <code> logEntryId </code> or 
     *          <code> logId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignLogEntryToLog(org.osid.id.Id logEntryId, 
                                    org.osid.id.Id logId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> LogEntry </code> from a <code> Log. </code> 
     *
     *  @param  logEntryId the <code> Id </code> of the <code> LogEntry 
     *          </code> 
     *  @param  logId the <code> Id </code> of the <code> Log </code> 
     *  @throws org.osid.NotFoundException <code> logEntryId </code> or <code> 
     *          logId </code> not found or <code> logEntryId </code> not 
     *          assigned to <code> logId </code> 
     *  @throws org.osid.NullArgumentException <code> logEntryId </code> or 
     *          <code> logId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignLogEntryFromLog(org.osid.id.Id logEntryId, 
                                        org.osid.id.Id logId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Moves a <code> LogEntry </code> from one <code> Log </code> to 
     *  another. Mappings to other <code> Logs </code> are unaffected. 
     *
     *  @param  logEntryId the <code> Id </code> of the <code> LogEntry 
     *          </code> 
     *  @param  fromLogId the <code> Id </code> of the current <code> Log 
     *          </code> 
     *  @param  toLogId the <code> Id </code> of the destination <code> Log 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> logEntryId, fromLogId, 
     *          </code> or <code> toLogId </code> not found or <code> 
     *          logEntryId </code> not mapped to <code> fromLogId </code> 
     *  @throws org.osid.NullArgumentException <code> logEntryId, fromLogId, 
     *          </code> or <code> toLogId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void reassignLogEntryToLog(org.osid.id.Id logEntryId, 
                                      org.osid.id.Id fromLogId, 
                                      org.osid.id.Id toLogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
