//
// org.osid.logging.LogEntryNotificationSession
//
//     The OSID Java specification for org.osid.logging.LogEntryNotificationSession.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.logging;


/**
 *  <p>This session defines methods to receive notifications on new or deleted 
 *  log entries. This session is intended for consumers needing to synchronize 
 *  their state with this service without the use of polling. Notifications 
 *  are cancelled when this session is closed. </p> 
 *  
 *  <p> Notifications are triggered with changes to assignments of <code> Ids 
 *  </code> to this log. For notifications of changes to the <code> Log 
 *  </code> object use <code> LogNotificationSession. </code> </p>
 */

public interface LogEntryNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Log </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Log Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getLogId();


    /**
     *  Gets the <code> Log </code> associated with this session. 
     *
     *  @return the <code> Log </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.logging.Log getLog()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can register for <code> Log </code> entry 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForLogEntryNotifications();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include entries from parent logs in the log hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedLogView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts notifications for entries to this log only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedLogView();


    /**
     *  Reliable notifications are desired. In reliable mode, notifications 
     *  are to be acknowledged using <code> acknowledgeLogEntryNotification() 
     *  </code> . 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void reliableLogEntryNotifications();


    /**
     *  Unreliable notifications are desired. In unreliable mode, 
     *  notifications do not need to be acknowledged. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void unreliableLogEntryNotifications();


    /**
     *  Acknowledge a log entry notification. 
     *
     *  @param  notificationId the <code> Id </code> of the notification 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void acknowledgeLogEntryNotification(org.osid.id.Id notificationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new log entries. <code> 
     *  LogEntryReceiver.newLogEntries() </code> is invoked when a new <code> 
     *  LogEntry </code> is created. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewLogEntries()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new log entries at or above the given 
     *  priority type. <code> LogEntryReceiver.newLogEntries() </code> is 
     *  invoked when a new <code> LogEntry </code> is created. 
     *
     *  @param  priorityType a priority type 
     *  @throws org.osid.NullArgumentException <code> priorityType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewLogEntriesAtPriority(org.osid.type.Type priorityType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new log entries logged by an agent 
     *  associated with the given resource. <code> 
     *  LogEntryReceiver.newLogEntries() </code> is invoked when a new <code> 
     *  LogEntry </code> is created. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewLogEntriesForResource(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of updated log entries. <code> 
     *  LogEntryReceiver.changedLogEntries() </code> is invoked when a <code> 
     *  LogEntry </code> iin this log is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedLogEntries()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of updated log entries at or above the 
     *  given priority type. <code> LogEntryReceiver.changedLogEntries() 
     *  </code> is invoked when a <code> LogEntry </code> in this log is 
     *  changed. 
     *
     *  @param  priorityType a priority type 
     *  @throws org.osid.NullArgumentException <code> priorityType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedEntriesAtPriority(org.osid.type.Type priorityType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of updated log entries logged by an agent 
     *  associated with the given resource. <code> 
     *  LogEntryReceiver.changedLogEntry() </code> is invoked when a <code> 
     *  LogEntry </code> in this log is changed. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedEntriesForResource(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated log entry. <code> 
     *  LogEntryReceiver.changedLogEntries() </code> is invoked when the 
     *  specified log entry is changed. 
     *
     *  @param  logEntryId the <code> Id </code> of the <code> LogEntry 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> logEntryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedLogEntry(org.osid.id.Id logEntryId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted log entries. <code> 
     *  LogEntryReceiver.deletedLogEntries() </code> is invoked when a log 
     *  entry is deleted or removed from this log. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedLogEntries()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of deleted log entries at or above the 
     *  given priority type. <code> LogEntryReceiver.deletedLogEntries() 
     *  </code> is invoked when a <code> LogEntry </code> is deleted or 
     *  removed from this log. 
     *
     *  @param  priorityType a priority type 
     *  @throws org.osid.NullArgumentException <code> priorityType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedLogEntriesAtPriority(org.osid.type.Type priorityType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of deleted log entries logged by an agent 
     *  associated with the given resource. <code> 
     *  LogEntryReceiver.deletedLogEntries() </code> is invoked when a <code> 
     *  LogEntry </code> is deleted or removed from this log. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedLogEntriesForResource(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted log entry. <code> 
     *  LogEntryReceiver.deleteddLogEntries() </code> is invoked when the 
     *  specified log entry is deleted or removed from this log. 
     *
     *  @param  logEntryId the <code> Id </code> of the <code> LogEntry 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> logEntryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedLogEntry(org.osid.id.Id logEntryId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
