//
// org.osid.logging.LogQuery
//
//     The OSID Java specification for org.osid.logging.LogQuery.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.logging;


/**
 *  <p>This is the query for searching for logs. Each method specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface LogQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Sets a log entry <code> Id. </code> 
     *
     *  @param  logEntryId a log entry <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> logEntryId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchLogEntryId(org.osid.id.Id logEntryId, boolean match);


    /**
     *  Clesrs the log entry <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLogEntryIdTerms();


    /**
     *  Tests if a log entry query is available. 
     *
     *  @return <code> true </code> if a log entry query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLogEntryQuery();


    /**
     *  Gets the query for a log entry. 
     *
     *  @return the log entry query 
     *  @throws org.osid.UnimplementedException <code> supportsLogEntryQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLogEntryQuery() </code> is <code> true. </code> 
     */

    public org.osid.logging.LogEntryQuery getLogEntryQuery();


    /**
     *  Matches logs with any log entry. 
     *
     *  @param  match <code> true </code> to match logs with any entry, <code> 
     *          false </code> to match logs with no log entries 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyLogEntry(boolean match);


    /**
     *  Clesrs the log entry terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLogEntryTerms();


    /**
     *  Sets the log <code> Id </code> for this query to match logs that have 
     *  the specified log as an ancestor. 
     *
     *  @param  logId a log <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> logId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorLogId(org.osid.id.Id logId, boolean match);


    /**
     *  Clesrs the ancestor log <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorLogIdTerms();


    /**
     *  Tests if a <code> LogQuery </code> is available. 
     *
     *  @return <code> true </code> if a log query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorLogQuery();


    /**
     *  Gets the query for a log. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the log query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorLogQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorLogQuery() </code> is <code> true. </code> 
     */

    public org.osid.logging.LogQuery getAncestorLogQuery();


    /**
     *  Matches logs with any ancestor. 
     *
     *  @param  match <code> true </code> to match logs with any ancestor, 
     *          <code> false </code> to match root logs 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorLog(boolean match);


    /**
     *  Clesrs the ancestor log terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorLogTerms();


    /**
     *  Sets the log <code> Id </code> for this query to match logs that have 
     *  the specified log as a descendant. 
     *
     *  @param  logId a log <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> logId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantLogId(org.osid.id.Id logId, boolean match);


    /**
     *  Clesrs the descendant log <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantLogIdTerms();


    /**
     *  Tests if a <code> LogQuery </code> is available. 
     *
     *  @return <code> true </code> if a log query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantLogQuery();


    /**
     *  Gets the query for a log. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the log query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantLogQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantLogQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.logging.LogQuery getDescendantLogQuery();


    /**
     *  Matches logs with any descendant. 
     *
     *  @param  match <code> true </code> to match logs with any descendant, 
     *          <code> false </code> to match leaf logs 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantLog(boolean match);


    /**
     *  Clesrs the descendant log terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantLogTerms();


    /**
     *  Gets the log query record corresponding to the given <code> Log 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested boolean <code> OR </code> term. 
     *
     *  @param  logRecordType a log record type 
     *  @return the log query record 
     *  @throws org.osid.NullArgumentException <code> logRecordType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(logRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.logging.records.LogQueryRecord getLogQueryRecord(org.osid.type.Type logRecordType)
        throws org.osid.OperationFailedException;
}
