//
// org.osid.logging.LoggingProxyManager
//
//     The OSID Java specification for org.osid.logging.LoggingProxyManager.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.logging;


/**
 *  <p>The logging manager provides access to logging sessions and provides 
 *  interoperability tests for various aspects of this service. Methods in 
 *  this manager support the passing of a <code> Proxy </code> for the 
 *  purposes of passing information from server environments. The sessions 
 *  included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> LoggingSession: </code> a session to write to a log </li> 
 *      <li> <code> LogEntryLookupSession: </code> a session to read a log 
 *      </li> 
 *      <li> <code> LogEntryQuerySession: </code> a session to search a log 
 *      </li> 
 *      <li> <code> LogEntrySearchSession: </code> a session to search a log 
 *      </li> 
 *      <li> <code> LogEntryAdminSession: </code> a session to manage log 
 *      entries in a log </li> 
 *      <li> <code> LogEntryNotificationSession: </code> a session to 
 *      subscribe to notifications of new log entries </li> 
 *      <li> <code> LogEntryLogSession: </code> a session to examine log entry 
 *      to log mappings </li> 
 *      <li> <code> LogEntryLogAssignmentSession: </code> a session to manage 
 *      log entry to log mappings </li> 
 *      <li> <code> LogEntrySmartLogSession: </code> a session to manage 
 *      dynamic logs </li> 
 *      <li> <code> LogLookupSession: </code> a session to retrieve log 
 *      objects </li> 
 *      <li> <code> LogQuerySession: </code> a session to search for logs 
 *      </li> 
 *      <li> <code> LogSearchSession: </code> a session to search for logs 
 *      </li> 
 *      <li> <code> LogAdminSession: </code> a session to create, update and 
 *      delete logs </li> 
 *      <li> <code> LogNotificationSession: </code> a session to receive 
 *      notifications for changes in logs </li> 
 *      <li> <code> LogHierarchyTraversalSession: </code> a session to 
 *      traverse hierarchies of logs </li> 
 *      <li> <code> LogHierarchyDesignSession: </code> a session to manage 
 *      hierarchies of logs </li> 
 *  </ul>
 *  
 *  
 *  <p> The logging manager also provides a profile for determing the 
 *  supported search types supported by this service. </p>
 */

public interface LoggingProxyManager
    extends org.osid.OsidProxyManager,
            org.osid.logging.LoggingProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the logging 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> LoggingSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsLogging() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLogging() </code> is <code> true. </code> 
     */

    public org.osid.logging.LoggingSession getLoggingSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the logging 
     *  service for the given log. 
     *
     *  @param  logId the <code> Id </code> of the <code> Log </code> 
     *  @param  proxy a proxy 
     *  @return a <code> LoggingSession </code> 
     *  @throws org.osid.NotFoundException no <code> Log </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> logId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsLogging() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLogging() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.logging.LoggingSession getLoggingSessionForLog(org.osid.id.Id logId, 
                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the logging 
     *  reading service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> LogEntryLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsLogEntryLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLogEntryLookup() </code> is <code> true. </code> 
     */

    public org.osid.logging.LogEntryLookupSession getLogEntryLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the log reading 
     *  service for the given log. 
     *
     *  @param  logId the <code> Id </code> of the <code> Log </code> 
     *  @param  proxy a proxy 
     *  @return a <code> LogEntryLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Log </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> logId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsLogEntryLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLogEntryLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.logging.LogEntryLookupSession getLogEntryLookupSessionForLog(org.osid.id.Id logId, 
                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the logging entry 
     *  query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> LogEntryQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsLogEntryQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLogEntryQuery() </code> is <code> true. </code> 
     */

    public org.osid.logging.LogEntryQuerySession getLogEntryQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the log entry 
     *  query service for the given log. 
     *
     *  @param  logId the <code> Id </code> of the <code> Log </code> 
     *  @param  proxy a proxy 
     *  @return a <code> LogEntryQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Log </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> logId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsLogEntryQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLogEntryQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.logging.LogEntryQuerySession getLogEntryQuerySessionForLog(org.osid.id.Id logId, 
                                                                               org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the logging entry 
     *  search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> LogEntrySearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsLogEntrySearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLogEntrySearch() </code> is <code> true. </code> 
     */

    public org.osid.logging.LogEntrySearchSession getLogEntrySearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the log entry 
     *  search service for the given log. 
     *
     *  @param  logId the <code> Id </code> of the <code> Log </code> 
     *  @param  proxy a proxy 
     *  @return a <code> LogEntrySearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Log </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> logId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsLogEntrySearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLogEntrySearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.logging.LogEntrySearchSession getLogEntrySearchSessionForLog(org.osid.id.Id logId, 
                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the logging entry 
     *  administrative service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> LogEntryAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsLogEntryAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLogEntryAdmin() </code> is <code> true. </code> 
     */

    public org.osid.logging.LogEntryAdminSession getLogEntryAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the log entry 
     *  administrative service for the given log. 
     *
     *  @param  logId the <code> Id </code> of the <code> Log </code> 
     *  @param  proxy a proxy 
     *  @return a <code> LogEntryAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Log </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> logId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsLogEntryAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLogEntryAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.logging.LogEntryAdminSession getLogEntryAdminSessionForLog(org.osid.id.Id logId, 
                                                                               org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the logging entry 
     *  notification service. 
     *
     *  @param  logEntryReceiver the receiver 
     *  @param  proxy a proxy 
     *  @return a <code> LogEntryNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> logEntryReceiver </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsLogEntryNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLogEntryNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.logging.LogEntryNotificationSession getLogEntryNotificationSession(org.osid.logging.LogEntryReceiver logEntryReceiver, 
                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the log entry 
     *  notification service for the given log. 
     *
     *  @param  logEntryReceiver the receiver 
     *  @param  logId the <code> Id </code> of the <code> Log </code> 
     *  @param  proxy a proxy 
     *  @return a <code> LogEntryNotificationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Log </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> logEntryReceiver, logId 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsLogEntryNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLogEntryNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.logging.LogEntryNotificationSession getLogEntryNotificationSessionForLog(org.osid.logging.LogEntryReceiver logEntryReceiver, 
                                                                                             org.osid.id.Id logId, 
                                                                                             org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving log entry to log mappings. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> LogEntryLogSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsLogEntryLog() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLogEntryLog() </code> is <code> true. </code> 
     */

    public org.osid.logging.LogEntryLogSession getLogEntryLogSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning log entry to log mappings. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> LogEntryLogAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsLogEntryLogAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLogEntryLogAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.logging.LogEntryLogAssignmentSession getLogEntryLogAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for managing dynamic log entry logs. 
     *
     *  @param  logId the <code> Id </code> of the log 
     *  @param  proxy a proxy 
     *  @return a <code> LogEntrySmartLogSession </code> 
     *  @throws org.osid.NotFoundException <code> logId </code> not found 
     *  @throws org.osid.NullArgumentException <code> logId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsLogEntrySmartLog() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLogEntrySmartLog() </code> is <code> true. </code> 
     */

    public org.osid.logging.LogEntrySmartLogSession getLogEntrySmartLogSession(org.osid.id.Id logId, 
                                                                               org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the log lookup 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> LogLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsLogLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLogLookup() </code> is <code> true. </code> 
     */

    public org.osid.logging.LogLookupSession getLogLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the log query 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> LogQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsLogQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLogQuery() </code> is <code> true. </code> 
     */

    public org.osid.logging.LogQuerySession getLogQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the log search 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> LogSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsLogSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLogSearch() </code> is <code> true. </code> 
     */

    public org.osid.logging.LogSearchSession getLogSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the log 
     *  administrative service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> LogAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsLogAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLogAdmin() </code> is <code> true. </code> 
     */

    public org.osid.logging.LogAdminSession getLogAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the log 
     *  notification service. 
     *
     *  @param  logReceiver the receiver 
     *  @param  proxy a proxy 
     *  @return a <code> LogNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> logReceiver </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsLogNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLogNotification() </code> is <code> true. </code> 
     */

    public org.osid.logging.LogNotificationSession getLogNotificationSession(org.osid.logging.LogReceiver logReceiver, 
                                                                             org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the log hierarchy 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> LogHierarchySession </code> for logs 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsLogHierarchy() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLogHierarchy() </code> is <code> true. </code> 
     */

    public org.osid.logging.LogHierarchySession getLogHierarchySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the log hierarchy 
     *  design service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> HierarchyDesignSession </code> for logs 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsLogHierarchyDesign() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLogHierarchyDesign() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.logging.LogHierarchyDesignSession getLogHierarchyDesignSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a <code> LoggingBatchProxyManager. </code> 
     *
     *  @return a <code> LoggingBatchProxyManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsLoggingBatch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLoggingBatch() </code> is <code> true. </code> 
     */

    public org.osid.logging.batch.LoggingBatchProxyManager getLoggingBatchProxyManager()
        throws org.osid.OperationFailedException;
}
