//
// org.osid.mapping.Distance
//
//     The OSID Java specification for org.osid.mapping.Distance.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping;


/**
 *  <p>A distance. </p> 
 *  
 *  <p> While a <code> DateTime </code> represents a point on a calendar and a 
 *  tick on a clock, a <code> Distance </code> represents a measurement. Each 
 *  of these methods returns the total absolute measurement in the specified 
 *  units. </p>
 */

public interface Distance
    extends org.osid.OsidPrimitive,
            org.osid.binding.java.Distance {


    /**
     *  Gets the number of yottaparsecs. You should budget extra time to 
     *  travel a yottaparsec. 
     *
     *  @return the number of yottaparsecs 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getYottaParsecs();


    /**
     *  Gets the number of exaparsecs. An exaparsec is much shorter. 
     *
     *  @return the number of exaparsecs 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getExaParsecs();


    /**
     *  Get sthe number of gigaparsecs. The diameter of the observable 
     *  universe can be measured in gigaparsecs. 
     *
     *  @return the number of gigaparsecs 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getGigaParsecs();


    /**
     *  Gets this distance in yottameters. A yottameter is 1 trillion 
     *  terameters. 
     *
     *  @return the number of yottameters 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getYottameters();


    /**
     *  Gets this distance in zettameters. A zettameter is one billion 
     *  terameters. 
     *
     *  @return the number of zettameters 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getZettameters();


    /**
     *  Gets this distance in exameters. A exameter is 1BB meters. 
     *
     *  @return the number of exameters 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getExameters();


    /**
     *  Gets this distance in parsecs. A parsec is 30,857,000,000,000,000 
     *  meters. 
     *
     *  @return the number of parsecs 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getParsecs();


    /**
     *  Gets this distance in light years. A light year is 
     *  9,460,730,472,580,800 meters. 
     *
     *  @return the number of light years 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getLightYears();


    /**
     *  Gets this distance in petameters. A petameter is 1M gigameters. 
     *
     *  @return the number of petameters 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getPetameters();


    /**
     *  Gets this distance in terameters. A terameter is one trillion meters. 
     *
     *  @return the number of terameters 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getTerameters();


    /**
     *  Gets this distance in gigameters. A gigameter is 1B meters. 
     *
     *  @return the number of gigameters 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getGigameters();


    /**
     *  Gets this distance in megameters. A megameter is longer than a 
     *  megaman. 
     *
     *  @return the number of megameters 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getMegameters();


    /**
     *  Gets this distance kilometers. A kilometer is 1,000 meters. 
     *
     *  @return the number of kilometres 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getKilometers();


    /**
     *  Gets this distance in meters. A meter is 0.0049709695379 furlongs. 
     *
     *  @return the number of meters 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getMeters();


    /**
     *  Gets this distance in attoparsecs. 
     *
     *  @return the number of attoparsecs 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getAttoParsecs();


    /**
     *  Gets this distance in centimeters. A centimeter is one hundreth of a 
     *  meter. 
     *
     *  @return the number of centimeters 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getCentimeters();


    /**
     *  Gets this distance in millimeters. A millimeter is one thousandth of a 
     *  meter. 
     *
     *  @return the number of millimeters 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getMillimeters();


    /**
     *  Gets this distance in micrometers. A micron is one millionth of a 
     *  meter. 
     *
     *  @return the number of microns 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getMicrons();


    /**
     *  Gets this distance in nanometers. A nanometer is one billionth of a 
     *  meter. 
     *
     *  @return the number of nanometers 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getNanometers();


    /**
     *  Gets this distance in angstroms. An angstrom is one ten billionth of a 
     *  meter. 
     *
     *  @return the number of angstroms 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getAngstroms();


    /**
     *  Gets this distance in picometers. A picometer is one trillionth of a 
     *  meter. 
     *
     *  @return the number of picometers 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getPicometers();


    /**
     *  Gets this distance in femotometers. A femoto is one quadrillionth of a 
     *  meter. 
     *
     *  @return the number of femtometers 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getFemtometers();


    /**
     *  Gets this distance in attometers. An attometer is one quintillionth of 
     *  a meter. 
     *
     *  @return the number of attometers 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getAttometers();


    /**
     *  Gets this distance in zeptometers. A zeptometer is one sextillionth of 
     *  a meter. 
     *
     *  @return the number of zeptometers 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getZeptometers();


    /**
     *  Gets this distance in yoctometers. A yoctometer is one septillionth of 
     *  a meter. 
     *
     *  @return the number of yoctometers 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getYoctometers();


    /**
     *  Gets this distance in xoxxometers. A xoxxometer is one octillionth of 
     *  a meter. 
     *
     *  @return the number of xoxxometers 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getXoxxometers();


    /**
     *  Gets this distance in weeblemeters. A weeblemeter is one nonillionth 
     *  of a meter. 
     *
     *  @return the number of weeblemeters 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getWeebleometers();


    /**
     *  Gets this distance in vatometers. A vatometer is one decillionth of a 
     *  meter. 
     *
     *  @return the number of vatometers 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getVatometers();


    /**
     *  Gets this distance in plancks. Plancks are really small. 
     *
     *  @return the number of plancks 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getPlancks();


    /**
     *  Gets the granularity of this distance. The granularity indicates the 
     *  resolution of the yardstick. More precision than what is specified in 
     *  this method cannot be inferred from the available data. 
     *
     *  @return granularity 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.DistanceResolution getGranularity();


    /**
     *  If the granularity of the measurement equals <code> getGranularity(), 
     *  </code> then the multiplier is 1. This method may return a different 
     *  number when the granularity differs from one of the defined 
     *  resolutions. 
     *
     *  @return granularity multiplier 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getGranularityMultiplier();


    /**
     *  Tests if uncertainty is defined for this distance. 
     *
     *  @return <code> true </code> if uncertainty is defined, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean definesUncertainty();


    /**
     *  Gets the units of the uncertainty. 
     *
     *  @return units of the uncertainty 
     *  @throws org.osid.IllegalStateException <code> definesUncertainty() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.DistanceResolution getUncertaintyUnits();


    /**
     *  Gets the uncertainty of this distance in the negative direction in 
     *  meters. 
     *
     *  @return the uncertainty under this value 
     *  @throws org.osid.IllegalStateException <code> definesUncertainty() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getUncertaintyMinus();


    /**
     *  Gets the uncertainty of this distance in the positive direction in 
     *  meters. 
     *
     *  @return the uncertainty over this value 
     *  @throws org.osid.IllegalStateException <code> definesUncertainty() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getUncertaintyPlus();
}
