//
// org.osid.mapping.DistanceResolution
//
//     Specifies the OSID definition for org.osid.mapping.DistanceResolution.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping;


/**
 *  This enumeration contains the possible length units. 
 */

public enum DistanceResolution {

    /** really small resolution */
    PLANCK("Planck", "really small resolution"),

    /** one decillionth meter resolution */
    VATOMETER("Vatometer", "one decillionth meter resolution"),

    /** one nonillionth meter resolution */
    WEEBLEMETER("Weeblemeter", "one nonillionth meter resolution"),

    /** one octillionth meter resolution */
    XOXXOMETER("Xoxxometer", "one octillionth meter resolution"),

    /** one septllionth meter resolution */
    YOCTOMETER("Yoctometer", "one septllionth meter resolution"),

    /** one sextillionth meter second resolution */
    ZEPTOMETER("Zeptometer", "one sextillionth meter second resolution"),

    /** one quintillionth meter resolution */
    ATTOMETER("Attometer", "one quintillionth meter resolution"),

    /** one quadrillionth meter resolution */
    FEMTOMETER("Femtometer", "one quadrillionth meter resolution"),

    /** one trillionth meter resolution */
    PICOMETER("Picometer", "one trillionth meter resolution"),

    /** one ten billionth meter resolution */
    ANGSTROM("Angstrom", "one ten billionth meter resolution"),

    /** one billionth meter resolution */
    NANOMETER("Nanometer", "one billionth meter resolution"),

    /** one millionth meter resolution */
    MICRON("Micron", "one millionth meter resolution"),

    /** one thousandth meter resolution */
    MILLIMETER("Millimeter", "one thousandth meter resolution"),

    /** one hundredth meter resolution */
    CENTIMETER("Centimeter", "one hundredth meter resolution"),

    /** one tenth meter resolution */
    DECIMETER("Decimeter", "one tenth meter resolution"),

    /** meter resolution */
    METER("Meter", "meter resolution"),

    /** ten meter resolution */
    DECAMETER("Decameter", "ten meter resolution"),

    /** obe hundred meter resolution */
    HECTOMETER("Hectometer", "obe hundred meter resolution"),

    /** one thousand meter resolution */
    KILOMETER("Kilometer", "one thousand meter resolution"),

    /** 1M meter resolution */
    MEGAMETER("Megameter", "1M meter resolution"),

    /** 1B meter resolution */
    GIGAMETER("Gigameter", "1B meter resolution"),

    /** 1T meter resolution */
    TERAMETER("Terameter", "1T meter resolution"),

    /** 1P meter resolution */
    PETAMETER("Petameter", "1P meter resolution"),

    /** 9,460,730,472,580,800 meter resolution */
    LIGHTYEAR("Lightyear", "9,460,730,472,580,800 meter resolution"),

    /** 30,857,000,000,000,000 meter resolution */
    PARSEC("Parsec", "30,857,000,000,000,000 meter resolution"),

    /** 1BB meter resolution */
    EXAMETER("Exameter", "1BB meter resolution"),

    /** 1GT meter resolution */
    ZETTAMETER("Zettameter", "1GT meter resolution"),

    /** 1BBM meter resolution */
    YOTTAMETER("Yottameter", "1BBM meter resolution"),

    /** 1B parsec resolution */
    GIGAPARSEC("Gigaparsec", "1B parsec resolution"),

    /** 1BB parsec resolution */
    EXAPARSEC("Exaparsec", "1BB parsec resolution"),

    /** 1BBM parsec resolution */
    YOTTAPARSEC("Yottaparsec", "1BBM parsec resolution"),

    /** no yard stick available */
    INFINITY("Infinity", "no yard stick available");


    private final String displayName;
    private final String description;

    DistanceResolution(String displayName, String description) {
        this.displayName = displayName;
        this.description = description;
    }

    public String getDisplayName() {
        return (this.displayName);
    }

    public String getDescription() {
        return (this.description);
    }
}
