//
// org.osid.mapping.LocationSearchSession
//
//     The OSID Java specification for org.osid.mapping.LocationSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping;


/**
 *  <p>This session provides methods for searching among <code> Location 
 *  </code> objects. The search query is constructed using the <code> 
 *  LocationQuery. </code> </p> 
 *  
 *  <p> <code> getLocationsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Locations. </code> A more advanced search may be 
 *  performed with <code> getLocationsBySearch(). </code> It accepts a <code> 
 *  LocationSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getLocationsBySearch() </code> returns a <code> 
 *  LocationSearchResults </code> that can be used to access the resulting 
 *  <code> LocationList </code> or be used to perform a search within the 
 *  result set through <code> LocationSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated map view: searches include locations in maps of which 
 *      this map is an ancestor in the map hierarchy </li> 
 *      <li> isolated map view: searches are restricted to locations in this 
 *      map </li> 
 *  </ul>
 *  
 *  
 *  <p> Locations may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> LocationQuery. </code> 
 *  </p>
 */

public interface LocationSearchSession
    extends org.osid.mapping.LocationQuerySession {


    /**
     *  Gets a location search. 
     *
     *  @return the location search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.LocationSearch getLocationSearch();


    /**
     *  Gets a location search order. The <code> LocationSearchOrder </code> 
     *  is supplied to a <code> LocationSearch </code> to specify the ordering 
     *  of results. 
     *
     *  @return the location search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.LocationSearchOrder getLocationSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  locationQuery the location query 
     *  @param  locationSearch the location search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> locationQuery </code> or 
     *          <code> locationSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> locationQuery </code> or 
     *          <code> locationSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.LocationSearchResults getLocationsBySearch(org.osid.mapping.LocationQuery locationQuery, 
                                                                       org.osid.mapping.LocationSearch locationSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a location query from an inspector. The inspector is available 
     *  from a <code> LocationSearchResults. </code> 
     *
     *  @param  locationQueryInspector a location query inspector 
     *  @return the location query 
     *  @throws org.osid.NullArgumentException <code> locationQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> locationQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.LocationQuery getLocationQueryFromInspector(org.osid.mapping.LocationQueryInspector locationQueryInspector);
}
