//
// org.osid.mapping.path.IntersectionAdminSession
//
//     The OSID Java specification for org.osid.mapping.path.IntersectionAdminSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.path;


/**
 *  <p>This session creates, updates, and deletes <code> Intersections. 
 *  </code> The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create an 
 *  <code> Intersection, </code> an <code> IntersectionForm </code> is 
 *  requested using <code> getIntersectionFormForCreate() </code> specifying 
 *  the desired paths and record <code> Types </code> or none if no record 
 *  <code> Types </code> are needed. The returned <code> IntersectionForm 
 *  </code> will indicate that it is to be used with a create operation and 
 *  can be used to examine metdata or validate data prior to creation. Once 
 *  the <code> IntersectionForm </code> is submiited to a create operation, it 
 *  cannot be reused with another create operation unless the first operation 
 *  was unsuccessful. Each <code> IntersectionForm </code> corresponds to an 
 *  attempted transaction. </p> 
 *  
 *  <p> For updates, <code> IntersectionForms </code> are requested to the 
 *  <code> Intersection </code> <code> Id </code> that is to be updated using 
 *  <code> getIntersectionFormForUpdate(). </code> Similarly, the <code> 
 *  IntersectionForm </code> has metadata about the data that can be updated 
 *  and it can perform validation before submitting the update. The <code> 
 *  IntersectionForm </code> can only be used once for a successful update and 
 *  cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Intersections. </code> To unmap an 
 *  <code> Intersection </code> from the current <code> Map, </code> the 
 *  <code> IntersectionMapAssignmentSession </code> should be used. These 
 *  delete operations attempt to remove the <code> Intersection </code> itself 
 *  thus removing it from all known <code> Map </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface IntersectionAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Map </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Map Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getMapId();


    /**
     *  Gets the <code> Map </code> associated with this session. 
     *
     *  @return the map 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Map getMap()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> Intersections. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating an <code> Intersection </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer create operations 
     *  to unauthorized users. 
     *
     *  @return <code> false </code> if <code> Intersection </code> creation 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateIntersections();


    /**
     *  Tests if this user can create a single <code> Intersection </code> 
     *  using the desired record types. While <code> 
     *  MappingPathManager.getIntersectionRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> Intersection. </code> 
     *  Providing an empty array tests if an <code> Intersection </code> can 
     *  be created with no records. 
     *
     *  @param  intersectionRecordTypes array of intersection record types 
     *  @return <code> true </code> if <code> Intersection </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> intersectionRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateIntersectionWithRecordTypes(org.osid.type.Type[] intersectionRecordTypes);


    /**
     *  Gets the intersection form for creating new intersections. A new form 
     *  should be requested for each create transaction. 
     *
     *  @param  pathIds the <code> Id </code> of the paths 
     *  @param  intersectionRecordTypes array of intersection record types 
     *  @return the intersection form 
     *  @throws org.osid.NotFoundException <code> a pathId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> pathIds </code> or 
     *          <code> intersectionRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get a form with given 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.IntersectionForm getIntersectionFormForCreate(org.osid.id.Id[] pathIds, 
                                                                               org.osid.type.Type[] intersectionRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Intersection. </code> 
     *
     *  @param  intersectionForm an intersection form 
     *  @return the new <code> Intersection </code> 
     *  @throws org.osid.IllegalStateException <code> intersectionForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> pathIds </code> or 
     *          <code> intersectionForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> intersectionForm </code> 
     *          did not originate from <code> getIntersectionFormForCreate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.Intersection createIntersection(org.osid.mapping.path.IntersectionForm intersectionForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Intersections. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating an <code> Intersection </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer update operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Intersection </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateIntersections();


    /**
     *  Tests if this user can update a specified <code> Intersection. </code> 
     *  A return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known updating the <code> Intersection 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer an 
     *  update operation to an unauthorized user for this intersection. 
     *
     *  @param  intersectionId the <code> Id </code> of the <code> 
     *          Intersection </code> 
     *  @return <code> false </code> if intersection modification is not 
     *          authorized, <code> true </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> intersectionId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If the <code> intersectionId </code> is not found, then it is 
     *          acceptable to return false to indicate the lack of an update 
     *          available. 
     */

    public boolean canUpdateIntersection(org.osid.id.Id intersectionId);


    /**
     *  Gets the intersection form for updating an existing intersection. A 
     *  new intersection form should be requested for each update transaction. 
     *
     *  @param  intersectionId the <code> Id </code> of the <code> 
     *          Intersection </code> 
     *  @return the intersection form 
     *  @throws org.osid.NotFoundException <code> intersectionId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> intersectionId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.IntersectionForm getIntersectionFormForUpdate(org.osid.id.Id intersectionId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing intersection. 
     *
     *  @param  intersectionForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> intersectionForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> intersectionForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> intersectionForm </code> 
     *          did not originate from <code> getIntersectionFormForUpdate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateIntersection(org.osid.mapping.path.IntersectionForm intersectionForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds a path to an existing intersection. 
     *
     *  @param  intersectionId the <code> Id </code> of the <code> 
     *          Intersection </code> 
     *  @param  pathId the <code> Id </code> of the a <code> Path </code> 
     *  @throws org.osid.NotFoundException <code> intersectionId </code> or 
     *          <code> pathId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> intersectionId </code> 
     *          or <code> pathId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void addPathToIntersection(org.osid.id.Id intersectionId, 
                                      org.osid.id.Id pathId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> Intersections. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting an <code> Intersection </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer delete operations 
     *  to unauthorized users. 
     *
     *  @return <code> false </code> if <code> Intersection </code> deletion 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteIntersections();


    /**
     *  Deletes an <code> Intersection. </code> 
     *
     *  @param  intersectionId the <code> Id </code> of the <code> 
     *          Intersection </code> to remove 
     *  @throws org.osid.NotFoundException <code> intersectionId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> intersectionId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteIntersection(org.osid.id.Id intersectionId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a path from an existing intersection. 
     *
     *  @param  intersectionId the <code> Id </code> of the <code> 
     *          Intersection </code> 
     *  @param  pathId the <code> Id </code> of the <code> Path </code> to 
     *          remove 
     *  @throws org.osid.NotFoundException <code> intersectionId </code> or 
     *          <code> pathId </code> not found 
     *  @throws org.osid.NullArgumentException <code> intersectionId </code> 
     *          or <code> pathId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removePathFromIntersection(org.osid.id.Id intersectionId, 
                                           org.osid.id.Id pathId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Intersections. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Intersection </code> aliasing 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageIntersectionAliases();


    /**
     *  Adds an <code> Id </code> to an <code> Intersection </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Intersection </code> is determined by the provider. The new 
     *  <code> Id </code> performs as an alias to the primary <code> Id. 
     *  </code> 
     *
     *  @param  intersectionId the <code> Id </code> of an <code> Intersection 
     *          </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> intersectionId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> intersectionId </code> 
     *          or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasIntersection(org.osid.id.Id intersectionId, 
                                  org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
