//
// org.osid.mapping.path.ObstacleAdminSession
//
//     The OSID Java specification for org.osid.mapping.path.ObstacleAdminSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.path;


/**
 *  <p>This session creates, updates, and deletes <code> Obstacles. </code> 
 *  The data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create an 
 *  <code> Obstacle, </code> an <code> ObstacleForm </code> is requested using 
 *  <code> getObstacleFormForCreate() </code> specifying the desired record 
 *  <code> Types </code> or none if no record <code> Types </code> are needed. 
 *  The returned <code> ObstacleForm </code> will indicate that it is to be 
 *  used with a create operation and can be used to examine metdata or 
 *  validate data prior to creation. Once the <code> ObstacleForm </code> is 
 *  submiited to a create operation, it cannot be reused with another create 
 *  operation unless the first operation was unsuccessful. Each <code> 
 *  ObstacleForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> ObstacleForms </code> are requested to the <code> 
 *  Obstacle </code> <code> Id </code> that is to be updated using <code> 
 *  getObstacleFormForUpdate(). </code> Similarly, the <code> ObstacleForm 
 *  </code> has metadata about the data that can be updated and it can perform 
 *  validation before submitting the update. The <code> ObstacleForm </code> 
 *  can only be used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Obstacles. </code> To unmap an 
 *  <code> Obstacle </code> from the current <code> Map, </code> the <code> 
 *  ObstacleMapAssignmentSession </code> should be used. These delete 
 *  operations attempt to remove the <code> Obstacle </code> itself thus 
 *  removing it from all known <code> Map </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface ObstacleAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Map </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Map Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getMapId();


    /**
     *  Gets the <code> Map </code> associated with this session. 
     *
     *  @return the map 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Map getMap()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> Obstacles. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating an <code> Obstacle </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer create operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Obstacle </code> creation is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateObstacles();


    /**
     *  Tests if this user can create a single <code> Obstacle </code> using 
     *  the desired record types. While <code> 
     *  MappingPathManager.getObstacleRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> Obstacle. </code> 
     *  Providing an empty array tests if an <code> Obstacle </code> can be 
     *  created with no records. 
     *
     *  @param  obstacleRecordTypes array of obstacle record types 
     *  @return <code> true </code> if <code> Obstacle </code> creation using 
     *          the specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> obstacleRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateObstacleWithRecordTypes(org.osid.type.Type[] obstacleRecordTypes);


    /**
     *  Gets the obstable form for creating new obstables. A new form should 
     *  be requested for each create transaction. 
     *
     *  @param  pathId the <code> Id </code> of the path 
     *  @param  obstacleRecordTypes array of obstacle record types 
     *  @return the obstable form 
     *  @throws org.osid.NotFoundException <code> pathId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> pathId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form with given 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.ObstacleForm getObstacleFormForCreate(org.osid.id.Id pathId, 
                                                                       org.osid.type.Type[] obstacleRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Obstacle. </code> 
     *
     *  @param  obstacleForm the form for this <code> Obstacle </code> 
     *  @return the new <code> Obstacle </code> 
     *  @throws org.osid.IllegalStateException <code> obstacleForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> pathId </code> or <code> 
     *          obstacleForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> obstacleForm </code> did 
     *          not originate from <code> getObstacleFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.Obstacle createObstacle(org.osid.mapping.path.ObstacleForm obstacleForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Obstacles. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating an <code> Obstacle </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer update operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Obstacle </code> modification 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateObstacles();


    /**
     *  Gets the obstable form for updating an existing obstable. A new 
     *  obstable form should be requested for each update transaction. 
     *
     *  @param  obstacleId the <code> Id </code> of the <code> Obstacle 
     *          </code> 
     *  @return the obstable form 
     *  @throws org.osid.NotFoundException <code> obstacleId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> obstacleId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.ObstacleForm getObstacleFormForUpdate(org.osid.id.Id obstacleId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing obstable. 
     *
     *  @param  obstacleForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> obstacleForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> obstacleId </code> or 
     *          <code> obstableForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> obstacleForm </code> did 
     *          not originate from <code> getObstacleFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateObstacle(org.osid.mapping.path.ObstacleForm obstacleForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> Obstacles. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting an <code> Obstacle </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer delete operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Obstacle </code> deletion is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteObstacles();


    /**
     *  Deletes an <code> Obstacle. </code> 
     *
     *  @param  obstacleId the <code> Id </code> of the <code> Obstacle 
     *          </code> to remove 
     *  @throws org.osid.NotFoundException <code> obstacleId </code> not found 
     *  @throws org.osid.NullArgumentException <code> obstacleId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteObstacle(org.osid.id.Id obstacleId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Obstacles. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Obstacle </code> aliasing is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageObstacleAliases();


    /**
     *  Adds an <code> Id </code> to an <code> Obstacle </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Obstacle </code> is determined by the provider. The new 
     *  <code> Id </code> performs as an alias to the primary <code> Id 
     *  </code> . If the alias is a pointer to another obstabce, it is 
     *  reassigned to the given obstacle <code> Id. </code> 
     *
     *  @param  obstacleId the <code> Id </code> of an <code> Obstacle </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> obstacleId </code> not found 
     *  @throws org.osid.NullArgumentException <code> obstacleId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasObstacle(org.osid.id.Id obstacleId, 
                              org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
