//
// org.osid.mapping.path.ObstacleLookupSession
//
//     The OSID Java specification for org.osid.mapping.path.ObstacleLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.path;


/**
 *  <p>This session defines methods for retrieving obstacle. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated map view: All obstacle methods in this session operate, 
 *      retrieve and pertain to obstacles defined explicitly in the current 
 *      map. Using an isolated view is useful for managing <code> Obstacles 
 *      </code> with the <code> ObstacleAdminSession. </code> </li> 
 *      <li> federated map view: All obstacle lookup methods in this session 
 *      operate, retrieve and pertain to all obstacle defined in this map and 
 *      any other obstacle implicitly available in this map through map 
 *      inheritence. </li> 
 *      <li> active obstacle view: All obstacle lookup methods return active 
 *      obstacles. </li> 
 *      <li> any status obstacle view: Obstacles of any active or inactive 
 *      status are returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedMapView() </code> and <code> 
 *  useIsolatedMapView() </code> behave as a radio group and one should be 
 *  selected before invoking any lookup methods. </p> 
 *  
 *  <p> Obstacles may have an additional records indicated by their respective 
 *  record types. The record may not be accessed through a cast of the <code> 
 *  Obstacles. </code> </p>
 */

public interface ObstacleLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Map </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Map Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getMapId();


    /**
     *  Gets the <code> Map </code> associated with this session. 
     *
     *  @return the map 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Map getMap()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Obstacle </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupObstacles();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeObstacleView();


    /**
     *  A complete view of the <code> Obstacle </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryObstacleView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include obstacle in maps which are children of this map in the map 
     *  hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedMapView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this map only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedMapView();


    /**
     *  Only active obstacles are returned by methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveObstacleView();


    /**
     *  All active and inactive obstacles are returned by methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusObstacleView();


    /**
     *  Gets the <code> Obstacle </code> specified by its <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Obstacle </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to an <code> Obstacle </code> and retained for compatibility. 
     *  
     *  In active mode, obstacles are returned that are currently active. In 
     *  any status mode, active and inactive obstacles are returned. 
     *
     *  @param  obstacleId the <code> Id </code> of the <code> Obstacle 
     *          </code> to retrieve 
     *  @return the returned <code> Obstacle </code> 
     *  @throws org.osid.NotFoundException no <code> Obstacle </code> found 
     *          with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> obstacleId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.Obstacle getObstacle(org.osid.id.Id obstacleId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ObstacleList </code> corresponding to the given <code> 
     *  IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  obstacles specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Obstacles </code> may be omitted from the list and 
     *  may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In active mode, obstacles are returned that are currently active. In 
     *  any status mode, active and inactive obstacles are returned. 
     *
     *  @param  obstacleIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Obstacle </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> obstacleIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.ObstacleList getObstaclesByIds(org.osid.id.IdList obstacleIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ObstacleList </code> corresponding to the given 
     *  obstacle genus <code> Type </code> which does not include obstacles of 
     *  types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  obstacles or an error obstacles Otherwise, the returned list may 
     *  contain only those obstacles that are accessible through this session. 
     *  
     *  In active mode, obstacles are returned that are currently active. In 
     *  any status mode, active and inactive obstacles are returned. 
     *
     *  @param  obstacleGenusType an obstacle genus type 
     *  @return the returned <code> Obstacle </code> list 
     *  @throws org.osid.NullArgumentException <code> obstacleGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.ObstacleList getObstaclesByGenusType(org.osid.type.Type obstacleGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ObstacleList </code> corresponding to the given 
     *  obstacle genus <code> Type </code> and include any additional 
     *  obstacles with genus types derived from the specified <code> Type. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  obstacles or an error results. Otherwise, the returned list may 
     *  contain only those obstacles that are accessible through this session. 
     *  
     *  In active mode, obstacles are returned that are currently active. In 
     *  any status mode, active and inactive obstacles are returned. 
     *
     *  @param  obstacleGenusType an obstacle genus type 
     *  @return the returned <code> Obstacle </code> list 
     *  @throws org.osid.NullArgumentException <code> obstacleGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.ObstacleList getObstaclesByParentGenusType(org.osid.type.Type obstacleGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ObstacleList </code> containing the given obstacle 
     *  record <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  obstacle or an error results. Otherwise, the returned list may contain 
     *  only those obstacles that are accessible through this session. 
     *  
     *  In active mode, obstacles are returned that are currently active. In 
     *  any status mode, active and inactive obstacles are returned. 
     *
     *  @param  obstacleRecordType an obstacle record type 
     *  @return the returned <code> Obstacle </code> list 
     *  @throws org.osid.NullArgumentException <code> obstacleRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.ObstacleList getObstaclesByRecordType(org.osid.type.Type obstacleRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ObstacleList </code> containing the given path. 
     *  
     *  In plenary mode, the returned list contains all known obstacles or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  obstacles that are accessible through this session. 
     *  
     *  In active mode, obstacles are returned that are currently active. In 
     *  any status mode, active and inactive obstacles are returned. 
     *
     *  @param  pathId a path <code> Id </code> 
     *  @return the returned <code> Obstacle </code> list 
     *  @throws org.osid.NullArgumentException <code> pathId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.ObstacleList getObstaclesForPath(org.osid.id.Id pathId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ObstacleList </code> containing the given path between 
     *  the given coordinates inclusive. 
     *  
     *  In plenary mode, the returned list contains all known obstacles or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  obstacles that are accessible through this session. 
     *  
     *  In active mode, obstacles are returned that are currently active. In 
     *  any status mode, active and inactive obstacles are returned. 
     *
     *  @param  pathId a path <code> Id </code> 
     *  @param  coordinate starting coordinate 
     *  @param  distance a distance from coordinate 
     *  @return the returned <code> Obstacle </code> list 
     *  @throws org.osid.NullArgumentException <code> pathId, coordinate 
     *          </code> or <code> distance </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.ObstacleList getObstaclesForPathAtCoordinate(org.osid.id.Id pathId, 
                                                                              org.osid.mapping.Coordinate coordinate, 
                                                                              org.osid.mapping.Distance distance)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Obstacles. </code> 
     *  
     *  In plenary mode, the returned list contains all known obstacles or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  obstacles that are accessible through this session. 
     *  
     *  In active mode, obstacles are returned that are currently active. In 
     *  any status mode, active and inactive obstacles are returned. 
     *
     *  @return a list of <code> Obstacles </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.ObstacleList getObstacles()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
