//
// org.osid.mapping.path.ObstacleSmartMapSession
//
//     The OSID Java specification for org.osid.mapping.path.ObstacleSmartMapSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.path;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. An <code> ObstacleQuery </code> can be retrieved from this 
 *  session and mapped to this <code> Map </code> to create a virtual 
 *  collection of <code> Obstacles. </code> The obstacle may be sequenced 
 *  using the <code> ObstacleSearchOrder </code> from this session. </p> 
 *  
 *  <p> This <code> Map </code> has a default query that matches any obstacle 
 *  and a default search order that specifies no sequencing. The queries may 
 *  be examined using an <code> ObstacleQueryInspector. </code> The query may 
 *  be modified by converting the inspector back to an <code> ObstacleQuery. 
 *  </code> </p>
 */

public interface ObstacleSmartMapSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Map </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Map Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getMapId();


    /**
     *  Gets the <code> Map </code> associated with this session. 
     *
     *  @return the map 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Map getMap()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart maps. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart map management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartMaps();


    /**
     *  Gets an obstacle query. 
     *
     *  @return the obstacle query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.ObstacleQuery getObstacleQuery();


    /**
     *  Gets an obstacle search order. 
     *
     *  @return the obstacle search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.ObstacleSearchOrder getObstacleSearchOrder();


    /**
     *  Applies an obstacle query to this map. 
     *
     *  @param  obstacleQuery the obstacle query 
     *  @throws org.osid.NullArgumentException <code> obstacleQuery </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> obstacleQuery </code> not 
     *          of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyObstacleQuery(org.osid.mapping.path.ObstacleQuery obstacleQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an obstacle query inspector for this map. 
     *
     *  @return the obstacle query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.ObstacleQueryInspector inspecObstacleQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies an obstacle search order to this map. 
     *
     *  @param  obstacleSearchOrder the obstacle search order 
     *  @throws org.osid.NullArgumentException <code> obstacleSearchOrder 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> obstacleSearchOrder 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyObstacleSequencing(org.osid.mapping.path.ObstacleSearchOrder obstacleSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an obstacle query from an inspector. 
     *
     *  @param  obstacleQueryInspector an obstacle query inspector 
     *  @return the obstacle query 
     *  @throws org.osid.NullArgumentException <code> obstacleQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> obstacleQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.ObstacleQuery getObstacleQueryFromInspector(org.osid.mapping.path.ObstacleQueryInspector obstacleQueryInspector);
}
