//
// org.osid.mapping.path.PathQuery
//
//     The OSID Java specification for org.osid.mapping.path.PathQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.path;


/**
 *  <p>This is the query for searching paths. Each method match specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface PathQuery
    extends org.osid.OsidObjectQuery {


    /**
     *  Matches paths overlapping with the specified <code> Coordinate. 
     *  </code> 
     *
     *  @param  coordinate a coordinate 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> coordinate </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCoordinate(org.osid.mapping.Coordinate coordinate, 
                                boolean match);


    /**
     *  Clears the coordinate query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCoordinateTerms();


    /**
     *  Matches paths overlapping with the specified <code> SpatialUnit. 
     *  </code> 
     *
     *  @param  spatialUnit a spatial unit 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> spatialUnit </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchOverlappingSpatialUnit(org.osid.mapping.SpatialUnit spatialUnit, 
                                            boolean match);


    /**
     *  Matches paths that have any overlapping spatial unit. 
     *
     *  @param  match <code> true </code> to match paths with any spatial 
     *          dimension, <code> false </code> to match paths with no spatial 
     *          dimensions 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyOverlappingSpatialUnit(boolean match);


    /**
     *  Clears the spatial unit query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOverlappingSpatialUnitTerms();


    /**
     *  Sets the location <code> Ids </code> for this query to match paths 
     *  including all the given locations. 
     *
     *  @param  locationIds the location <code> Ids </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> locationIds </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAlongLocationIds(org.osid.id.Id[] locationIds, 
                                      boolean match);


    /**
     *  Clears the along location <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAlongLocationIdsTerms();


    /**
     *  Sets the path <code> Id </code> for this query to match paths 
     *  intersecting with another path, 
     *
     *  @param  pathId the path <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> pathId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchIntersectingPathId(org.osid.id.Id pathId, boolean match);


    /**
     *  Clears the intersecting path <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearIntersectingPathIdTerms();


    /**
     *  Tests if a <code> PathQuery </code> is available for intersecting 
     *  paths, 
     *
     *  @return <code> true </code> if a path query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsIntersectingPathQuery();


    /**
     *  Gets the query for an intersecting path, Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the path query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsIntersectingPathQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsIntersectingPathQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.mapping.path.PathQuery getIntersectingPathQuery();


    /**
     *  Matches paths with any intersecting path, 
     *
     *  @param  match <code> true </code> to match paths with any intersecting 
     *          path, <code> false </code> to match paths with no intersecting 
     *          path 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyIntersectingPath(boolean match);


    /**
     *  Clears the intersecting path query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearIntersectingPathTerms();


    /**
     *  Sets the location <code> Id </code> for this query to match paths that 
     *  pass through locations. 
     *
     *  @param  locationId the location <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> locationId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchLocationId(org.osid.id.Id locationId, boolean match);


    /**
     *  Clears the location <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLocationIdTerms();


    /**
     *  Tests if a <code> LocationQuery </code> is available. 
     *
     *  @return <code> true </code> if a location query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLocationQuery();


    /**
     *  Gets the query for a location. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the location query 
     *  @throws org.osid.UnimplementedException <code> supportsLocationQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLocationQuery() </code> is <code> true. </code> 
     */

    public org.osid.mapping.LocationQuery getLocationQuery();


    /**
     *  Matches routes that go through any location. 
     *
     *  @param  match <code> true </code> to match routes with any location, 
     *          <code> false </code> to match routes with no location 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyLocation(boolean match);


    /**
     *  Clears the location query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLocationTerms();


    /**
     *  Sets the route <code> Id </code> for this query to match paths used in 
     *  a route. 
     *
     *  @param  routeId a route <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> routeId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRouteId(org.osid.id.Id routeId, boolean match);


    /**
     *  Clears the route <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRouteIdTerms();


    /**
     *  Tests if a <code> RouteQuery </code> is available. 
     *
     *  @return <code> true </code> if a route query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRouteQuery();


    /**
     *  Gets the query for a route. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the route query 
     *  @throws org.osid.UnimplementedException <code> supportsRouteQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRouteQuery() </code> is <code> true. </code> 
     */

    public org.osid.mapping.route.RouteQuery getRouteQuery();


    /**
     *  Matches paths that are used in any route. 
     *
     *  @param  match <code> true </code> to match paths in any route, <code> 
     *          false </code> to match paths used in no route 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRoute(boolean match);


    /**
     *  Clears the route query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRouteTerms();


    /**
     *  Sets the map <code> Id </code> for this query to match paths assigned 
     *  to maps. 
     *
     *  @param  mapId the map <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> mapId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMapId(org.osid.id.Id mapId, boolean match);


    /**
     *  Clears the map <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMapIdTerms();


    /**
     *  Tests if a <code> MapQuery </code> is available. 
     *
     *  @return <code> true </code> if a map query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMapQuery();


    /**
     *  Gets the query for a map. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the map query 
     *  @throws org.osid.UnimplementedException <code> supportsMapQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMapQuery() </code> is <code> true. </code> 
     */

    public org.osid.mapping.MapQuery getMapQuery();


    /**
     *  Clears the map query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMapTerms();


    /**
     *  Gets the path query record corresponding to the given <code> Path 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @param  pathRecordType a path record type 
     *  @return the path query record 
     *  @throws org.osid.NullArgumentException <code> pathRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(pathRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.records.PathQueryRecord getPathQueryRecord(org.osid.type.Type pathRecordType)
        throws org.osid.OperationFailedException;
}
