//
// org.osid.mapping.path.SignalAdminSession
//
//     The OSID Java specification for org.osid.mapping.path.SignalAdminSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.path;


/**
 *  <p>This session creates, updates, and deletes <code> Signals. </code> The 
 *  data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Signal, </code> a <code> SignalForm </code> is requested using <code> 
 *  getSignalFormForCreate() </code> specifying the desired record <code> 
 *  Types </code> or none if no record <code> Types </code> are needed. The 
 *  returned <code> SignalForm </code> will indicate that it is to be used 
 *  with a create operation and can be used to examine metdata or validate 
 *  data prior to creation. Once the <code> SignalForm </code> is submiited to 
 *  a create operation, it cannot be reused with another create operation 
 *  unless the first operation was unsuccessful. Each <code> SignalForm 
 *  </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> SignalForms </code> are requested to the <code> 
 *  Signal </code> <code> Id </code> that is to be updated using <code> 
 *  getSignalFormForUpdate(). </code> Similarly, the <code> SignalForm </code> 
 *  has metadata about the data that can be updated and it can perform 
 *  validation before submitting the update. The <code> SignalForm </code> can 
 *  only be used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Signals. </code> To unmap a <code> 
 *  Signal </code> from the current <code> Map, </code> the <code> 
 *  SignalMapAssignmentSession </code> should be used. These delete operations 
 *  attempt to remove the <code> Signal </code> itself thus removing it from 
 *  all known <code> Map </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface SignalAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Map </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Map Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getMapId();


    /**
     *  Gets the <code> Map </code> associated with this session. 
     *
     *  @return the map 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Map getMap()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> Signals. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> Signal </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer create operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Signal </code> creation is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateSignals();


    /**
     *  Tests if this user can create a single <code> Signal </code> using the 
     *  desired record types. While <code> 
     *  MappingPathManager.getSignalRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> Signal. </code> Providing 
     *  an empty array tests if a <code> Signal </code> can be created with no 
     *  records. 
     *
     *  @param  signalRecordTypes array of signal record types 
     *  @return <code> true </code> if <code> Signal </code> creation using 
     *          the specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> signalRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateSignalWithRecordTypes(org.osid.type.Type[] signalRecordTypes);


    /**
     *  Gets the signal form for creating new signals. A new form should be 
     *  requested for each create transaction. 
     *
     *  @param  pathId <code> Id </code> of the path 
     *  @param  signalRecordTypes array of signal record types 
     *  @return the signal form 
     *  @throws org.osid.NotFoundException <code> pathId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> pathId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form with given 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.SignalForm getSignalFormForCreate(org.osid.id.Id pathId, 
                                                                   org.osid.type.Type[] signalRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Signal. </code> 
     *
     *  @param  signalForm the form for this <code> Signal </code> 
     *  @return the new <code> Signal </code> 
     *  @throws org.osid.IllegalStateException <code> signalForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> signalForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> signalForm </code> did 
     *          not originate from <code> getSignalFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.Signal createSignal(org.osid.mapping.path.SignalForm signalForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Signals. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> Signal </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer update operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Signal </code> modification is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateSignals();


    /**
     *  Gets the signal form for updating an existing signal. A new signal 
     *  form should be requested for each update transaction. 
     *
     *  @param  signalId the <code> Id </code> of the <code> Signal </code> 
     *  @return the signal form 
     *  @throws org.osid.NotFoundException <code> signalId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> signalId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.SignalForm getSignalFormForUpdate(org.osid.id.Id signalId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing signal. 
     *
     *  @param  signalForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> signalForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> signalId </code> or 
     *          <code> signalForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> signalForm </code> did 
     *          not originate from <code> getSignalFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateSignal(org.osid.mapping.path.SignalForm signalForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> Signals. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> Signal </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer delete operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Signal </code> deletion is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteSignals();


    /**
     *  Deletes a <code> Signal. </code> 
     *
     *  @param  signalId the <code> Id </code> of the <code> Signal </code> to 
     *          remove 
     *  @throws org.osid.NotFoundException <code> signalId </code> not found 
     *  @throws org.osid.NullArgumentException <code> signalId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteSignal(org.osid.id.Id signalId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Signals. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Signal </code> aliasing is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSignalAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Signal </code> for the purpose 
     *  of creating compatibility. The primary <code> Id </code> of the <code> 
     *  Signal </code> is determined by the provider. The new <code> Id 
     *  </code> performs as an alias to the primary <code> Id </code> . If the 
     *  alias is a pointer to another signal, it is reassigned to the given 
     *  signal <code> Id. </code> 
     *
     *  @param  signalId the <code> Id </code> of a <code> Signal </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> signalId </code> not found 
     *  @throws org.osid.NullArgumentException <code> signalId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasSignal(org.osid.id.Id signalId, org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
