//
// org.osid.mapping.path.SignalForm
//
//     The OSID Java specification for org.osid.mapping.path.SignalForm.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.path;


/**
 *  <p>This is the form for creating and updating <code> Signals. </code> Like 
 *  all <code> OsidForm </code> objects, various data elements may be set here 
 *  for use in the create and update methods in the <code> SignalAdminSession. 
 *  </code> For each data element that may be set, metadata may be examined to 
 *  provide display hints or data constraints. </p>
 */

public interface SignalForm
    extends org.osid.OsidRuleForm {


    /**
     *  Gets the metadata for a coordinate. 
     *
     *  @return metadata for the coodinate 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getCoordinateMetadata();


    /**
     *  Sets the coordinate. 
     *
     *  @param  coordinate the new coordinate 
     *  @throws org.osid.InvalidArgumentException <code> coordinate </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> coordinate </code> is 
     *          <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> coordinate </code> type 
     *          is not supported 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setCoordinate(org.osid.mapping.Coordinate coordinate);


    /**
     *  Removes the coordinate. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCoordinate();


    /**
     *  Gets the metadata for the signal states. 
     *
     *  @return metadata for the states 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getStatesMetadata();


    /**
     *  Sets the signal states. 
     *
     *  @param  stateIds the new states 
     *  @throws org.osid.InvalidArgumentException <code> stateIds </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> stateIds </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setStates(org.osid.id.IdList stateIds);


    /**
     *  Removes the signal states. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStates();


    /**
     *  Gets the <code> SignalFormRecord </code> corresponding to the given 
     *  signal record <code> Type. </code> 
     *
     *  @param  signalRecordType a signal record type 
     *  @return the signal form record 
     *  @throws org.osid.NullArgumentException <code> signalRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(signalRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.records.SignalFormRecord getSignalFormRecord(org.osid.type.Type signalRecordType)
        throws org.osid.OperationFailedException;
}
