//
// org.osid.mapping.path.SignalLookupSession
//
//     The OSID Java specification for org.osid.mapping.path.SignalLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.path;


/**
 *  <p>This session defines methods for retrieving signals. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated map view: All signal methods in this session operate, 
 *      retrieve and pertain to signals defined explicitly in the current map. 
 *      Using an isolated view is useful for managing <code> Signals </code> 
 *      with the <code> SignalAdminSession. </code> </li> 
 *      <li> federated map view: All signal lookup methods in this session 
 *      operate, retrieve and pertain to all signals defined in this map and 
 *      any other signals implicitly available in this map through map 
 *      inheritence. </li> 
 *      <li> active signal view: All signal lookup methods return active 
 *      signals. </li> 
 *      <li> any status signal view: Signals of any active or inactive status 
 *      are returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedMapView() </code> and <code> 
 *  useIsolatedMapView() </code> behave as a radio group and one should be 
 *  selected before invoking any lookup methods. </p> 
 *  
 *  <p> Signals may have an additional records indicated by their respective 
 *  record types. The record may not be accessed through a cast of the <code> 
 *  Signals. </code> </p>
 */

public interface SignalLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Map </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Map Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getMapId();


    /**
     *  Gets the <code> Map </code> associated with this session. 
     *
     *  @return the map 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Map getMap()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Signal </code> lookups. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not offer lookup operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupSignals();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeSignalView();


    /**
     *  A complete view of the <code> Signal </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenarySignalView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include signals in maps which are children of this map in the map 
     *  hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedMapView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this map only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedMapView();


    /**
     *  Only active signals are returned by methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveSignalView();


    /**
     *  All active and inactive signals are returned by methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusSignalView();


    /**
     *  Gets the <code> Signal </code> specified by its <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Signal </code> may have a different <code> Id </code> than requested, 
     *  such as the case where a duplicate <code> Id </code> was assigned to a 
     *  <code> Signal </code> and retained for compatibility. 
     *  
     *  In active mode, signals are returned that are currently active. In any 
     *  status mode, active and inactive signals are returned. 
     *
     *  @param  signalId the <code> Id </code> of the <code> Signal </code> to 
     *          retrieve 
     *  @return the returned <code> Signal </code> 
     *  @throws org.osid.NotFoundException no <code> Signal </code> found with 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> signalId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.Signal getSignal(org.osid.id.Id signalId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SignalList </code> corresponding to the given <code> 
     *  IdList. </code> I 
     *  
     *  n plenary mode, the returned list contains all of the signals 
     *  specified in the <code> Id </code> list, in the order of the list, 
     *  including duplicates, or an error results if an <code> Id </code> in 
     *  the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Signals </code> may be omitted from the list and 
     *  may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In active mode, signals are returned that are currently active. In any 
     *  status mode, active and inactive signals are returned. 
     *
     *  @param  signalIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Signal </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> signalIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.SignalList getSignalsByIds(org.osid.id.IdList signalIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SignalList </code> corresponding to the given signal 
     *  genus <code> Type </code> which does not include signals of types 
     *  derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  signals or an error results. Otherwise, the returned list may contain 
     *  only those signals that are accessible through this session. 
     *  
     *  In active mode, signals are returned that are currently active. In any 
     *  status mode, active and inactive signals are returned. 
     *
     *  @param  signalGenusType a signal genus type 
     *  @return the returned <code> Signal </code> list 
     *  @throws org.osid.NullArgumentException <code> signalGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.SignalList getSignalsByGenusType(org.osid.type.Type signalGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SignalList </code> corresponding to the given signal 
     *  genus <code> Type </code> and include any additional signals with 
     *  genus types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  signals or an error results. Otherwise, the returned list may contain 
     *  only those signals that are accessible through this session. 
     *  
     *  In active mode, signals are returned that are currently active. In any 
     *  status mode, active and inactive signals are returned. 
     *
     *  @param  signalGenusType a signal genus type 
     *  @return the returned <code> Signal </code> list 
     *  @throws org.osid.NullArgumentException <code> signalGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.SignalList getSignalsByParentGenusType(org.osid.type.Type signalGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SignalList </code> containing the given signal record 
     *  <code> Type. </code> 
     *  
     *  In plenary mode, the returned list contains all known signals or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  signals that are accessible through this session. 
     *  
     *  In active mode, signals are returned that are currently active. In any 
     *  status mode, active and inactive signals are returned. 
     *
     *  @param  signalRecordType a signal record type 
     *  @return the returned <code> Signal </code> list 
     *  @throws org.osid.NullArgumentException <code> signalRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.SignalList getSignalsByRecordType(org.osid.type.Type signalRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SignalList </code> containing the given path. 
     *  
     *  In plenary mode, the returned list contains all known signals or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  signals that are accessible through this session. 
     *  
     *  In active mode, signals are returned that are currently active. In any 
     *  status mode, active and inactive signals are returned. 
     *
     *  @param  pathId a path <code> Id </code> 
     *  @return the returned <code> Signal </code> list 
     *  @throws org.osid.NullArgumentException <code> pathId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.SignalList getSignalsForPath(org.osid.id.Id pathId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SignalList </code> containing the given path between the 
     *  given coordinates inclusive. 
     *  
     *  In plenary mode, the returned list contains all known signals or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  signals that are accessible through this session. 
     *  
     *  In active mode, signals are returned that are currently active. In any 
     *  status mode, active and inactive signals are returned. 
     *
     *  @param  pathId a path <code> Id </code> 
     *  @param  coordinate starting coordinate 
     *  @param  distance a distance from coordinate 
     *  @return the returned <code> Signal </code> list 
     *  @throws org.osid.NullArgumentException <code> pathId, coordinate 
     *          </code> or <code> distance </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.SignalList getSignalsForPathAtCoordinate(org.osid.id.Id pathId, 
                                                                          org.osid.mapping.Coordinate coordinate, 
                                                                          org.osid.mapping.Distance distance)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Signals. </code> 
     *  
     *  In plenary mode, the returned list contains all known signals or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  signals that are accessible through this session. 
     *  
     *  In active mode, signals are returned that are currently active. In any 
     *  status mode, active and inactive signals are returned. 
     *
     *  @return a list of <code> Signals </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.SignalList getSignals()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
