//
// org.osid.mapping.path.SignalSearchSession
//
//     The OSID Java specification for org.osid.mapping.path.SignalSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.path;


/**
 *  <p>This session provides methods for searching among <code> Signal </code> 
 *  objects. The search query is constructed using the <code> SignalQuery. 
 *  </code> </p> 
 *  
 *  <p> <code> getSignalsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Signals. </code> A more advanced search may be 
 *  performed with <code> getSignalsBySearch(). </code> It accepts a <code> 
 *  SignalSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getSignalsBySearch() </code> returns a <code> 
 *  SignalSearchResults </code> that can be used to access the resulting 
 *  <code> SignalList </code> or be used to perform a search within the result 
 *  set through <code> SignalSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated map view: searches include signals in maps of which 
 *      this map is an ancestor in the map hierarchy </li> 
 *      <li> isolated map view: searches are restricted to signals in this map 
 *      </li> 
 *  </ul>
 *  
 *  
 *  <p> Signals may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> SignalQuery. </code> 
 *  </p>
 */

public interface SignalSearchSession
    extends org.osid.mapping.path.SignalQuerySession {


    /**
     *  Gets a signal search. 
     *
     *  @return the signal search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.SignalSearch getSignalSearch();


    /**
     *  Gets a signal search order. The <code> SignalSearchOrder </code> is 
     *  supplied to a <code> SignalSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the signal search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.SignalSearchOrder getSignalSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  signalQuery the signal query 
     *  @param  signalSearch the signal search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> signalQuery </code> or 
     *          <code> signalSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> signalQuery </code> or 
     *          <code> signalSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.SignalSearchResults getSignalsBySearch(org.osid.mapping.path.SignalQuery signalQuery, 
                                                                        org.osid.mapping.path.SignalSearch signalSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a signal query from an inspector. The inspector is available from 
     *  a <code> SignalSearchResults. </code> 
     *
     *  @param  signalQueryInspector a signal query inspector 
     *  @return the signal query 
     *  @throws org.osid.NullArgumentException <code> signalQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> signalQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.SignalQuery getSignalQueryFromInspector(org.osid.mapping.path.SignalQueryInspector signalQueryInspector);
}
