//
// org.osid.mapping.path.SpeedZoneAdminSession
//
//     The OSID Java specification for org.osid.mapping.path.SpeedZoneAdminSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.path;


/**
 *  <p>This session creates, updates, and deletes <code> SpeedZones. </code> 
 *  The data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  SpeedZoneForm, </code> a <code> SpeedZoneForm </code> is requested using 
 *  <code> getSpeedZoneFormForCreate() </code> specifying the desired record 
 *  <code> Types </code> or none if no record <code> Types </code> are needed. 
 *  The returned <code> SpeedZoneForm </code> will indicate that it is to be 
 *  used with a create operation and can be used to examine metdata or 
 *  validate data prior to creation. Once the <code> SpeedZoneForm </code> is 
 *  submiited to a create operation, it cannot be reused with another create 
 *  operation unless the first operation was unsuccessful. Each <code> 
 *  SpeedZoneForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> SpeedZoneForms </code> are requested to the <code> 
 *  SpeedZone </code> <code> Id </code> that is to be updated using <code> 
 *  getSpeedZoneFormForUpdate(). </code> Similarly, the <code> SpeedZoneForm 
 *  </code> has metadata about the data that can be updated and it can perform 
 *  validation before submitting the update. The <code> SpeedZoneForm </code> 
 *  can only be used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> SpeedZones. </code> To unmap a 
 *  <code> SpeedZone </code> from the current <code> Map, </code> the <code> 
 *  SpeedZoneMapAssignmentSession </code> should be used. These delete 
 *  operations attempt to remove the <code> SpeedZone </code> itself thus 
 *  removing it from all known <code> Map </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface SpeedZoneAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Map </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Map Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getMapId();


    /**
     *  Gets the <code> Map </code> associated with this session. 
     *
     *  @return the map 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Map getMap()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> SpeedZones. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> SpeedZone </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer create operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> SpeedZone </code> creation is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateSpeedZones();


    /**
     *  Tests if this user can create a single <code> SpeedZone </code> using 
     *  the desired record types. While <code> 
     *  MappingPathManager.getSpeedZoneRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> SpeedZone. </code> 
     *  Providing an empty array tests if a <code> SpeedZone </code> can be 
     *  created with no records. 
     *
     *  @param  speedZoneRecordTypes array of speed zone record types 
     *  @return <code> true </code> if <code> SpeedZone </code> creation using 
     *          the specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> speedZoneRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateSpeedZoneWithRecordTypes(org.osid.type.Type[] speedZoneRecordTypes);


    /**
     *  Gets the speed zone form for creating new speed zones. A new form 
     *  should be requested for each create transaction. 
     *
     *  @param  speedZoneRecordTypes array of speed zone record types 
     *  @return the speed zone form 
     *  @throws org.osid.NullArgumentException <code> speedZoneRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form with given 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.SpeedZoneForm getSpeedZoneFormForCreate(org.osid.type.Type[] speedZoneRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> SpeedZone. </code> 
     *
     *  @param  speedZoneForm the form for this <code> SpeedZone </code> 
     *  @return the new <code> SpeedZone </code> 
     *  @throws org.osid.IllegalStateException <code> speedZoneForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> speedZoneForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> speedZoneForm </code> did 
     *          not originate from <code> getSpeedZoneFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.SpeedZone createSpeedZone(org.osid.mapping.path.SpeedZoneForm speedZoneForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> SpeedZones. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> SpeedZone </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer update operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> SpeedZone </code> modification 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateSpeedZones();


    /**
     *  Gets the speed zone form for updating an existing speed zone. A new 
     *  speed zone form should be requested for each update transaction. 
     *
     *  @param  speedZoneId the <code> Id </code> of the <code> SpeedZone 
     *          </code> 
     *  @return the speed zone form 
     *  @throws org.osid.NotFoundException <code> speedZoneId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> speedZoneId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.SpeedZoneForm getSpeedZoneFormForUpdate(org.osid.id.Id speedZoneId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing speed zone. 
     *
     *  @param  speedZoneForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> speedZoneForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> speedZoneId </code> or 
     *          <code> speed zoneForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> speedZoneForm </code> did 
     *          not originate from <code> getSpeedZoneFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateSpeedZone(org.osid.mapping.path.SpeedZoneForm speedZoneForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete a specified <code> SpeedZone. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known deleting the <code> SpeedZone 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer an 
     *  delete operation to an unauthorized user. 
     *
     *  @param  speedZoneId the <code> Id </code> of the <code> SpeedZone 
     *          </code> 
     *  @return <code> false </code> if deletion of this <code> SpeedZone 
     *          </code> is not authorized, <code> true </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> speedZoneId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If the <code> speedZoneId </code> is not found, then it is 
     *          acceptable to return false to indicate the lack of an delete 
     *          available. 
     */

    public boolean canDeleteSpeedZone(org.osid.id.Id speedZoneId);


    /**
     *  Deletes a <code> SpeedZone. </code> 
     *
     *  @param  speedZoneId the <code> Id </code> of the <code> SpeedZone 
     *          </code> to remove 
     *  @throws org.osid.NotFoundException <code> speedZoneId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> speedZoneId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteSpeedZone(org.osid.id.Id speedZoneId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  SpeedZones. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> SpeedZone </code> aliasing is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSpeedZoneAliases();


    /**
     *  Adds an <code> Id </code> to a <code> SpeedZone </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> SpeedZone </code> is determined by the provider. The new 
     *  <code> Id </code> performs as an alias to the primary <code> Id 
     *  </code> . If the alias is a pointer to another speed zone, it is 
     *  reassigned to the given speed zone <code> Id. </code> 
     *
     *  @param  speedZoneId the <code> Id </code> of a <code> SpeedZone 
     *          </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> speedZoneId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> speedZoneId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasSpeedZone(org.osid.id.Id speedZoneId, 
                               org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
