//
// org.osid.mapping.path.SpeedZoneSearchSession
//
//     The OSID Java specification for org.osid.mapping.path.SpeedZoneSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.path;


/**
 *  <p>This session provides methods for searching among <code> SpeedZone 
 *  </code> objects. The search query is constructed using the <code> 
 *  SpeedZoneQuery. </code> </p> 
 *  
 *  <p> <code> getSpeedZonesByQuery() </code> is the basic search method and 
 *  returns a list of <code> SpeedZones. </code> A more advanced search may be 
 *  performed with <code> getSpeedZonesBySearch(). </code> It accepts a <code> 
 *  SpeedZoneSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getSpeedZonesBySearch() </code> returns a <code> 
 *  SpeedZoneSearchResults </code> that can be used to access the resulting 
 *  <code> SpeedZoneList </code> or be used to perform a search within the 
 *  result set through <code> SpeedZoneSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated map view: searches include speed zones in maps of which 
 *      this map is an ancestor in the map hierarchy </li> 
 *      <li> isolated map view: searches are restricted to speed zones in this 
 *      map </li> 
 *  </ul>
 *  
 *  
 *  <p> SpeedZones may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> SpeedZoneQuery. 
 *  </code> </p>
 */

public interface SpeedZoneSearchSession
    extends org.osid.mapping.path.SpeedZoneQuerySession {


    /**
     *  Gets a speed zone search. 
     *
     *  @return the speed zone search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.SpeedZoneSearch getSpeedZoneSearch();


    /**
     *  Gets a speed zone search order. The <code> SpeedZoneSearchOrder 
     *  </code> is supplied to a <code> SpeedZoneSearch </code> to specify the 
     *  ordering of results. 
     *
     *  @return the speed zone search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.SpeedZoneSearchOrder getSpeedZoneSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  speedZoneQuery the speed zone query 
     *  @param  speedZoneSearch the speed zone search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> speedZoneQuery </code> 
     *          or <code> speed zoneSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> speedZoneQuery </code> or 
     *          <code> speed zoneSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.SpeedZoneSearchResults getSpeedZonesBySearch(org.osid.mapping.path.SpeedZoneQuery speedZoneQuery, 
                                                                              org.osid.mapping.path.SpeedZoneSearch speedZoneSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a speed zone query from an inspector. The inspector is available 
     *  from a <code> SpeedZoneSearchResults. </code> 
     *
     *  @param  speedZoneQueryInspector a speed zone query inspector 
     *  @return the speed zone query 
     *  @throws org.osid.NullArgumentException <code> speedZoneQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> speedZoneQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.SpeedZoneQuery getSpeedZoneQueryFromInspector(org.osid.mapping.path.SpeedZoneQueryInspector speedZoneQueryInspector);
}
