//
// org.osid.mapping.path.rules.ObstacleEnablerAdminSession
//
//     The OSID Java specification for org.osid.mapping.path.rules.ObstacleEnablerAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.path.rules;


/**
 *  <p>This session creates and removes obstacle enablers. The data for create 
 *  and update is provided via the <code> ObstacleEnablerForm. </code> </p>
 */

public interface ObstacleEnablerAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Map </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Map Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getMapId();


    /**
     *  Gets the <code> Map </code> associated with this session. 
     *
     *  @return the map 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Map getMap()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create obstacle enablers. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known creating an <code> ObstacleEnabler </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer create operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> ObstacleEnabler </code> 
     *          creation is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateObstacleEnabler();


    /**
     *  Tests if this user can create a single <code> ObstacleEnabler </code> 
     *  using the desired record types. While <code> 
     *  MappingPathRulesManager.getObstacleEnablerRecordTypes() </code> can be 
     *  used to examine which records are supported, this method tests which 
     *  record(s) are required for creating a specific <code> ObstacleEnabler. 
     *  </code> Providing an empty array tests if an <code> ObstacleEnabler 
     *  </code> can be created with no records. 
     *
     *  @param  obstacleEnablerRecordTypes array of obstacle enabler record 
     *          types 
     *  @return <code> true </code> if <code> ObstacleEnabler </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          obstacleEnablerRecordTypes </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateObstacleEnablerWithRecordTypes(org.osid.type.Type[] obstacleEnablerRecordTypes);


    /**
     *  Gets the obstacle enabler form for creating new obstacle enablers. A 
     *  new form should be requested for each create transaction. 
     *
     *  @param  obstacleEnablerRecordTypes array of obstacle enabler record 
     *          types 
     *  @return the obstacle enabler form 
     *  @throws org.osid.NullArgumentException <code> 
     *          obstacleEnablerRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.rules.ObstacleEnablerForm getObstacleEnablerFormForCreate(org.osid.type.Type[] obstacleEnablerRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> ObstacleEnabler. </code> 
     *
     *  @param  obstacleEnablerForm the form for this <code> ObstacleEnabler 
     *          </code> 
     *  @return the new <code> ObstacleEnabler </code> 
     *  @throws org.osid.IllegalStateException <code> obstacleEnablerForm 
     *          </code> already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> obstacleEnablerForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> obstacleEnablerForm 
     *          </code> did not originate from <code> 
     *          getObstacleEnablerFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.rules.ObstacleEnabler createObstacleEnabler(org.osid.mapping.path.rules.ObstacleEnablerForm obstacleEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update obstacle enablers. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known updating an <code> ObstacleEnabler </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer update operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> ObstacleEnabler </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateObstacleEnablers();


    /**
     *  Gets the obstacle enabler form for updating an existing obstacle 
     *  enabler. A new obstacle enabler form should be requested for each 
     *  update transaction. 
     *
     *  @param  obstacleEnablerId the <code> Id </code> of the <code> 
     *          ObstacleEnabler </code> 
     *  @return the obstacle enabler form 
     *  @throws org.osid.NotFoundException <code> obstacleEnablerId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> obstacleEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.rules.ObstacleEnablerForm getObstacleEnablerFormForUpdate(org.osid.id.Id obstacleEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing obstacle enabler. 
     *
     *  @param  obstacleEnablerForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> obstacleEnablerForm 
     *          </code> already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> obstacleEnablerForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> obstacleEnablerForm 
     *          </code> did not originate from <code> 
     *          getObstacleEnablerFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateObstacleEnabler(org.osid.mapping.path.rules.ObstacleEnablerForm obstacleEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete obstacle enablers. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known deleting an <code> ObstacleEnabler </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer delete operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> ObstacleEnabler </code> 
     *          deletion is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteObstacleEnablers();


    /**
     *  Deletes an <code> ObstacleEnabler. </code> 
     *
     *  @param  obstacleEnablerId the <code> Id </code> of the <code> 
     *          ObstacleEnabler </code> to remove 
     *  @throws org.osid.NotFoundException <code> obstacleEnablerId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> obstacleEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteObstacleEnabler(org.osid.id.Id obstacleEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for obstacle 
     *  enablers. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> ObstacleEnabler </code> 
     *          aliasing is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageObstacleEnablerAliases();


    /**
     *  Adds an <code> Id </code> to an <code> ObstacleEnabler </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> ObstacleEnabler </code> is determined by the provider. The 
     *  new <code> Id </code> performs as an alias to the primary <code> Id 
     *  </code> . If the alias is a pointer to another obstacle enabler. it is 
     *  reassigned to the given obstacle enabler <code> Id. </code> 
     *
     *  @param  obstacleEnablerId the <code> Id </code> of an <code> 
     *          ObstacleEnabler </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> obstacleEnablerId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> obstacleEnablerId 
     *          </code> or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasObstacleEnabler(org.osid.id.Id obstacleEnablerId, 
                                     org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
