//
// org.osid.mapping.path.rules.ObstacleEnablerSmartMapSession
//
//     The OSID Java specification for org.osid.mapping.path.rules.ObstacleEnablerSmartMapSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.path.rules;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  maps. An <code> ObstacleEnablerQuery </code> can be retrieved from this 
 *  session and mapped to this <code> Map </code> to create a virtual 
 *  collection of obstacle enablers. The obstacle enabler may be sequenced 
 *  using the <code> ObstacleEnablerSearchOrder </code> from this session. 
 *  </p> 
 *  
 *  <p> This <code> Map </code> has a default query that matches any obstacle 
 *  enabler and a default search order that specifies no sequencing. The 
 *  queries may be examined using an <code> ObstacleEnablerQueryInspector. 
 *  </code> The query may be modified by converting the inspector back to an 
 *  <code> ObstacleEnablerQuery. </code> </p>
 */

public interface ObstacleEnablerSmartMapSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Map </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Map Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getMapId();


    /**
     *  Gets the <code> Map </code> associated with this session. 
     *
     *  @return the map 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Map getMap()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart maps. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart map management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartMaps();


    /**
     *  Gets an obstacle enabler query. 
     *
     *  @return the obstacle enabler query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.rules.ObstacleEnablerQuery getObstacleEnablerQuery();


    /**
     *  Gets an obstacle enabler search order. 
     *
     *  @return the obstacle enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.rules.ObstacleEnablerSearchOrder getObstacleEnablerSearchOrder();


    /**
     *  Applies an obstacle enabler query to this map. 
     *
     *  @param  obstacleEnablerQuery the obstacle enabler query 
     *  @throws org.osid.NullArgumentException <code> obstacleEnablerQuery 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> obstacleEnablerQuery 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyObstacleEnablerQuery(org.osid.mapping.path.rules.ObstacleEnablerQuery obstacleEnablerQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an obstacle enabler query inspector for this map. 
     *
     *  @return the obstacle enabler query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.rules.ObstacleEnablerQueryInspector inspectObstacleEnablerQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies an obstacle enabler search order to this map. 
     *
     *  @param  obstacleEnablerSearchOrder the obstacle enabler search order 
     *  @throws org.osid.NullArgumentException <code> 
     *          obstacleEnablerSearchOrder </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> 
     *          obstacleEnablerSearchOrder </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyObstacleEnablerSequencing(org.osid.mapping.path.rules.ObstacleEnablerSearchOrder obstacleEnablerSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an obstacle enabler query from an inspector. 
     *
     *  @param  obstacleEnablerQueryInspector an obstacle enabler query 
     *          inspector 
     *  @return the obstacle enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          obstacleEnablerQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          obstacleEnablerQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.rules.ObstacleEnablerQuery getObstacleEnablerQueryFromInspector(org.osid.mapping.path.rules.ObstacleEnablerQueryInspector obstacleEnablerQueryInspector);
}
