//
// org.osid.mapping.path.rules.SpeedZoneEnablerNotificationSession
//
//     The OSID Java specification for org.osid.mapping.path.rules.SpeedZoneEnablerNotificationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.path.rules;


/**
 *  <p>This session defines methods to receive notifications on adds/changes 
 *  to <code> SpeedZoneEnabler </code> objects in this <code> Map. </code> 
 *  This also includes existing <code> SpeedZoneEnablers </code> that may 
 *  appear or disappear due to changes in the <code> Map </code> hierarchy, 
 *  This session is intended for consumers needing to synchronize their state 
 *  with this service without the use of polling. Notifications are cancelled 
 *  when this session is closed. </p> 
 *  
 *  <p> The two views defined in this session correspond to the views in the 
 *  <code> SpeedZoneEnablerLookupSession. </code> </p>
 */

public interface SpeedZoneEnablerNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Map </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Map Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getMapId();


    /**
     *  Gets the <code> Map </code> associated with this session. 
     *
     *  @return the map 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Map getMap()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can register for <code> SpeedZoneEnabler </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForSpeedZoneEnablerNotifications();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include enablers in maps which are children of this map in the map 
     *  hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedMapView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts notifications to this map only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedMapView();


    /**
     *  Register for notifications of new speed zone enablers. <code> 
     *  SpeedZoneEnablerReceiver.newSpeedZoneEnablers() </code> is invoked 
     *  when a new <code> SpeedZoneEnabler </code> appears in this map. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewSpeedZoneEnablers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated map enabelrs. <code> 
     *  SpeedZoneEnablerReceiver.changedSpeedZoneEnablers() </code> is invoked 
     *  when a speed zone enabler in this map is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedSpeedZoneEnablers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated speed zone enabler. <code> 
     *  ProvisionableReceiver.changedSpeedZoneEnablers() </code> is invoked 
     *  when the specified speed zone enabler in this map is changed. 
     *
     *  @param  speedZoneEnablerId the <code> Id </code> of the <code> 
     *          SpeedZoneEnabler </code> to monitor 
     *  @throws org.osid.NotFoundException a speed zone enabler was not found 
     *          in this speed zone matchmaker identified by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> speedZoneEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedSpeedZoneEnabler(org.osid.id.Id speedZoneEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted speed zone enablers. <code> 
     *  SpeedZoneEnablerReceiver.deletedSpeedZoneEnablers() </code> is invoked 
     *  when a speed zone enabler is deleted or removed from this map. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedSpeedZoneEnablers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted speed zone enabler. <code> 
     *  SpeedZoneEnablerReceiver.deletedSpeedZoneEnablers() </code> is invoked 
     *  when the specified speed zone enabler is deleted or removed from this 
     *  map. 
     *
     *  @param  speedZoneEnablerId the <code> Id </code> of the <code> 
     *          SpeedZoneEnabler </code> to monitor 
     *  @throws org.osid.NotFoundException a speed zone enabler was not found 
     *          in this speed zone matchmaker identified by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> speedZoneEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedSpeedZoneEnabler(org.osid.id.Id speedZoneEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
