//
// org.osid.mapping.path.rules.SpeedZoneEnablerQuery
//
//     The OSID Java specification for org.osid.mapping.path.rules.SpeedZoneEnablerQuery.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.path.rules;


/**
 *  <p>This is the query for searching speed zone enablers. Each method match 
 *  specifies a <code> AND </code> term while multiple invocations of the same 
 *  method produce a nested <code> OR. </code> </p>
 */

public interface SpeedZoneEnablerQuery
    extends org.osid.OsidEnablerQuery {


    /**
     *  Matches enablers mapped to the speed zone. 
     *
     *  @param  speedZoneId the speed zone <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> speedZoneId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRuledSpeedZoneId(org.osid.id.Id speedZoneId, 
                                      boolean match);


    /**
     *  Clears the speed zone <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRuledSpeedZoneIdTerms();


    /**
     *  Tests if a <code> SpeedZoneQuery </code> is available. 
     *
     *  @return <code> true </code> if a speed zone query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRuledSpeedZoneQuery();


    /**
     *  Gets the query for a speed zone. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the speed zone query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRuledSpeedZoneQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRuledSpeedZoneQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.mapping.path.SpeedZoneQuery getRuledSpeedZoneQuery();


    /**
     *  Matches enablers mapped to any speed zone. 
     *
     *  @param  match <code> true </code> for enablers mapped to any speed 
     *          zone, <code> false </code> to match enablers mapped to no 
     *          speed zones 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRuledSpeedZone(boolean match);


    /**
     *  Clears the speed zone query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRuledSpeedZoneTerms();


    /**
     *  Matches enablers mapped to the map. 
     *
     *  @param  mapId the map <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> mapId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMapId(org.osid.id.Id mapId, boolean match);


    /**
     *  Clears the map <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMapIdTerms();


    /**
     *  Tests if an <code> MapQuery </code> is available. 
     *
     *  @return <code> true </code> if an map query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMapQuery();


    /**
     *  Gets the query for an map. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the map query 
     *  @throws org.osid.UnimplementedException <code> supportsMapQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMapQuery() </code> is <code> true. </code> 
     */

    public org.osid.mapping.MapQuery getMapQuery();


    /**
     *  Clears the map query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMapTerms();


    /**
     *  Gets the speed zone enabler query record corresponding to the given 
     *  <code> SpeedZoneEnabler </code> record <code> Type. </code> Multiple 
     *  record retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  speedZoneEnablerRecordType a speed zone enabler record type 
     *  @return the speed zone enabler query record 
     *  @throws org.osid.NullArgumentException <code> 
     *          speedZoneEnablerRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(speedZoneEnablerRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.rules.records.SpeedZoneEnablerQueryRecord getSpeedZoneEnablerQueryRecord(org.osid.type.Type speedZoneEnablerRecordType)
        throws org.osid.OperationFailedException;
}
