//
// org.osid.mapping.path.rules.SpeedZoneEnablerRuleLookupSession
//
//     The OSID Java specification for org.osid.mapping.path.rules.SpeedZoneEnablerRuleLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.path.rules;


/**
 *  <p>This session provides methods to retrieve <code> SpeedZoneEnabler 
 *  </code> to <code> SpeedZone </code> mappings. a <code> SpeedZone </code> 
 *  with multiple <code> SpeedZoneEnablers </code> means any positive rule 
 *  evaluation across the enablers result in an effective <code> SpeedZone. 
 *  </code> </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated map view: All methods in this session operate, retrieve 
 *      and pertain speed zone enablers defined explicitly in the current map 
 *      </li> 
 *      <li> federated map view: All methods in this session operate, retrieve 
 *      and pertain to all speed zone enablers defined in this map and any 
 *      other speed zone enablers implicitly available in this map through map 
 *      inheritence. </li> 
 *  </ul>
 *  
 */

public interface SpeedZoneEnablerRuleLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Map </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Map Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getMapId();


    /**
     *  Gets the <code> Map </code> associated with this session. 
     *
     *  @return the map 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Map getMap()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform lookups of speed zone enabler/speed 
     *  zone mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known lookup 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if looking up mappings is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupSpeedZoneEnablerRules();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeSpeedZoneEnablerRuleView();


    /**
     *  A complete view of the <code> SpeedZoneEnabler </code> and <code> 
     *  SpeedZone </code> returns is desired. Methods will return what is 
     *  requested or result in an error. This view is used when greater 
     *  precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenarySpeedZoneEnablerRuleView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include speed zone enablers in maps which are children of this map in 
     *  the map hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedMapView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this map only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedMapView();


    /**
     *  Gets the <code> SpeedZoneEnabler Id </code> associated with a <code> 
     *  SpeedZone. </code> 
     *
     *  @param   speedZoneId <code> Id </code> of the <code> SpeedZone </code> 
     *  @return the speed zone enabler <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> speedZoneId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> speedZoneId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getSpeedZoneEnablerIdsForSpeedZone(org.osid.id.Id  speedZoneId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> SpeedZoneEnablers </code> associated with a <code> 
     *  SpeedZone. </code> 
     *
     *  @param  speedZoneId <code> Id </code> of the <code> SpeedZone </code> 
     *  @return the speed zone enablers 
     *  @throws org.osid.NotFoundException <code> speedZoneId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> speedZoneId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.rules.SpeedZoneEnablerList getSpeedZoneEnablersForSpeedZone(org.osid.id.Id speedZoneId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> SpeedZone </code> <code> Ids </code> mapped to a 
     *  <code> SpeedZoneEnabler. </code> 
     *
     *  @param  speedZoneEnablerId <code> Id </code> of a <code> 
     *          SpeedZoneEnabler </code> 
     *  @return list of speed zone <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> speedZoneEnablerId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> speedZoneEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getSpeedZoneIdsForSpeedZoneEnabler(org.osid.id.Id speedZoneEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> SpeedZones </code> mapped to a <code> 
     *  SpeedZoneEnabler. </code> 
     *
     *  @param  speedZoneEnablerId <code> Id </code> of a <code> 
     *          SpeedZoneEnabler </code> 
     *  @return list of speed zones 
     *  @throws org.osid.NotFoundException <code> speedZoneEnablerId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> speedZoneEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.SpeedZoneList getSpeedZonesForSpeedZoneEnabler(org.osid.id.Id speedZoneEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
