//
// org.osid.mapping.route.Route
//
//     The OSID Java specification for org.osid.mapping.route.Route.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.route;


/**
 *  <p>A <code> Route </code> represents one or more paths between two 
 *  locations. A <code> Route </code> is created from a series of <code> 
 *  RouteSegments </code> which, in turn, may relate to a <code> Path. </code> 
 *  A <code> Path </code> is an object representation of a fixed means of 
 *  travel between two locations, such as a road. </p>
 */

public interface Route
    extends org.osid.OsidRelationship,
            org.osid.Aggregateable {


    /**
     *  Gets the <code> Id </code> of the starting location of this route. 
     *
     *  @return the starting location <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getStartingLocationId();


    /**
     *  Gets the starting location of this route. 
     *
     *  @return the starting location 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Location getStartingLocation()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of the ending location of this route. 
     *
     *  @return the ending location <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getEndingLocationId();


    /**
     *  Gets the ending location of this route. 
     *
     *  @return the ending location 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Location getEndingLocation()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the total distance of this route. 
     *
     *  @return the total route distance 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Distance getDistance();


    /**
     *  Gets the estimated travel time across the entire route. 
     *
     *  @return the estimated travel time 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Duration getETA();


    /**
     *  Gets the route segment <code> Ids </code> of this route. 
     *
     *  @return the segment <code> Ids </code> of this route 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getSegmentIds();


    /**
     *  Gets the segments of this route. 
     *
     *  @return the segments of this route 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.route.RouteSegmentList getSegments()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the route record corresponding to the given <code> Route </code> 
     *  record <code> Type. </code> This method is used to retrieve an object 
     *  implementing the requested record. The <code> pathRecordType </code> 
     *  may be the <code> Type </code> returned in <code> getRecordTypes() 
     *  </code> or any of its parents in a <code> Type </code> hierarchy where 
     *  <code> hasRecordType(routeRecordType) </code> is <code> true </code> . 
     *
     *  @param  routeRecordType the type of route record to retrieve 
     *  @return the route record 
     *  @throws org.osid.NullArgumentException <code> routeRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(routeRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.route.records.RouteRecord getRouteRecord(org.osid.type.Type routeRecordType)
        throws org.osid.OperationFailedException;
}
