//
// org.osid.mapping.route.RouteAdminSession
//
//     The OSID Java specification for org.osid.mapping.route.RouteAdminSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.route;


/**
 *  <p>This session creates, updates, and deletes <code> Routes. </code> The 
 *  data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Route, </code> a <code> RouteForm </code> is requested using <code> 
 *  getRouteFormForCreate() </code> specifying the desired record <code> Types 
 *  </code> or none if no record <code> Types </code> are needed. The returned 
 *  <code> RouteForm </code> will indicate that it is to be used with a create 
 *  operation and can be used to examine metdata or validate data prior to 
 *  creation. Once the <code> RouteForm </code> is submiited to a create 
 *  operation, it cannot be reused with another create operation unless the 
 *  first operation was unsuccessful. Each <code> RouteForm </code> 
 *  corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> RouteForms </code> are requested to the <code> 
 *  Route </code> <code> Id </code> that is to be updated using <code> 
 *  getRouteFormForUpdate(). </code> Similarly, the <code> RouteForm </code> 
 *  has metadata about the data that can be updated and it can perform 
 *  validation before submitting the update. The <code> RouteForm </code> can 
 *  only be used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Routes. </code> To unmap a <code> 
 *  Route </code> from the current <code> Map, </code> the <code> 
 *  RouteMapAssignmentSession </code> should be used. These delete operations 
 *  attempt to remove the <code> Route </code> itself thus removing it from 
 *  all known <code> Map </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface RouteAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Map </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Map Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getMapId();


    /**
     *  Gets the <code> Map </code> associated with this session. 
     *
     *  @return the map 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Map getMap()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> Routes. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> Route </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer create operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Route </code> creation is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateRoutes();


    /**
     *  Tests if this user can create a single <code> Route </code> using the 
     *  desired record types. While <code> 
     *  MappingRouteManager.getRouteRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> Route. </code> Providing 
     *  an empty array tests if a <code> Route </code> can be created with no 
     *  records. 
     *
     *  @param  routeRecordTypes array of route record types 
     *  @return <code> true </code> if <code> Route </code> creation using the 
     *          specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> routeRecordTypes </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateRouteWithRecordTypes(org.osid.type.Type[] routeRecordTypes);


    /**
     *  Gets the route form for creating new routes. A new form should be 
     *  requested for each create transaction. 
     *
     *  @param  startingLocationId the <code> Id </code> of the starting 
     *          location. 
     *  @param  endingLocationId the <code> Id </code> of the ending location. 
     *  @param  routeRecordTypes array of route record types 
     *  @return the route form 
     *  @throws org.osid.NotFoundException <code> startingLocationId </code> 
     *          or <code> endingLocationId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> startingLocationId, 
     *          endingLocationId </code> or <code> routeRecordTypes </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable top get form with given 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.route.RouteForm getRouteFormForCreate(org.osid.id.Id startingLocationId, 
                                                                  org.osid.id.Id endingLocationId, 
                                                                  org.osid.type.Type[] routeRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Route. </code> 
     *
     *  @param  routeForm the form for this <code> Route </code> 
     *  @return the new <code> Route </code> 
     *  @throws org.osid.IllegalStateException <code> routeForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> routeForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> routeForm </code> did not 
     *          originate from <code> getRouteFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.route.Route createRoute(org.osid.mapping.route.RouteForm routeForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Routes. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> Route </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer update operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Route </code> modification is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateRoutes();


    /**
     *  Gets the route form for updating an existing route. A new route form 
     *  should be requested for each update transaction. 
     *
     *  @param  routeId the <code> Id </code> of the <code> Route </code> 
     *  @return the route form 
     *  @throws org.osid.NotFoundException <code> routeId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> routeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.route.RouteForm getRouteFormForUpdate(org.osid.id.Id routeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing route. 
     *
     *  @param  routeForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> routeForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> routeForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> routeForm </code> did not 
     *          originate from <code> getRouteFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateRoute(org.osid.mapping.route.RouteForm routeForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> Routes. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> Route </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer delete operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Route </code> deletion is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteRoutes();


    /**
     *  Deletes a <code> Route. </code> 
     *
     *  @param  routeId the <code> Id </code> of the <code> Route </code> to 
     *          remove 
     *  @throws org.osid.NotFoundException <code> routeId </code> not found 
     *  @throws org.osid.NullArgumentException <code> routeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteRoute(org.osid.id.Id routeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Routes. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Route </code> aliasing is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageRouteAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Route </code> for the purpose of 
     *  creating compatibility. The primary <code> Id </code> of the <code> 
     *  Route </code> is determined by the provider. The new <code> Id </code> 
     *  performs as an alias to the primary <code> Id. </code> The new <code> 
     *  Id </code> performs as an alias to the primary <code> Id. </code> If 
     *  the alias is a pointer to another route, it is reassigned to the given 
     *  route <code> Id. </code> 
     *
     *  @param  routeId the <code> Id </code> of a <code> Route </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> routeId </code> not found 
     *  @throws org.osid.NullArgumentException <code> routeId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasRoute(org.osid.id.Id routeId, org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create a single <code> RouteSegment </code> 
     *  using the desired record types. While <code> 
     *  MappingRouteManager.getRouteSegmentRecordTypes() </code> can be used 
     *  to examine which records are supported, this method tests which 
     *  record(s) are required for creating a specific <code> Route. </code> 
     *  Providing an empty array tests if a <code> Route </code> can be 
     *  created with no records. 
     *
     *  @param  routeSegmentRecordTypes array of route segment record types 
     *  @return <code> true </code> if <code> RouteSegment </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> routeSegmentRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateRouteSegmentWithRecordTypes(org.osid.type.Type[] routeSegmentRecordTypes);


    /**
     *  Gets the route segment form for adding route segments. A new form 
     *  should be requested for each create transaction. 
     *
     *  @param  routeId the <code> Id </code> of a <code> Route </code> 
     *  @param  routeSegmentRecordTypes array of route segment record types 
     *  @return the route segment form 
     *  @throws org.osid.NotFoundException <code> routeId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> routeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form with given 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.route.RouteSegmentForm getRouteSegmentFormForCreate(org.osid.id.Id routeId, 
                                                                                org.osid.type.Type[] routeSegmentRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> RouteSegment. </code> 
     *
     *  @param  routeSegmentForm the form for this <code> RouteSegment </code> 
     *  @return the new <code> RouteSegment </code> 
     *  @throws org.osid.IllegalStateException <code> routeSegmentForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> routeForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> routeForm </code> did not 
     *          originate from <code> getRouteSegmentFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.route.RouteSegment createRouteSegment(org.osid.mapping.route.RouteSegmentForm routeSegmentForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the route segment form for adding route segments. A new form 
     *  should be requested for each create transaction. 
     *
     *  @param  routeSegmentId the <code> Id </code> of the <code> 
     *          RouteSegment </code> 
     *  @return the route segment form 
     *  @throws org.osid.NotFoundException <code> routeSegmentId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> routeSegmentId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.route.RouteSegmentForm getRouteSegmentFormForUpdate(org.osid.id.Id routeSegmentId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates a <code> RouteSegment. </code> 
     *
     *  @param  routeSegmentForm the form for this <code> RouteSegment </code> 
     *  @throws org.osid.IllegalStateException <code> routeSegmentForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> routeForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> routeForm </code> did not 
     *          originate from <code> getRouteSegmentFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateRouteSegment(org.osid.mapping.route.RouteSegmentForm routeSegmentForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes a <code> RouteSegment. </code> 
     *
     *  @param  routeSegmentId the <code> Id </code> of the route segment to 
     *          delete 
     *  @throws org.osid.NotFoundException <code> routeSegmentId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> routeSegmentId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteRouteSegment(org.osid.id.Id routeSegmentId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  RouteSegments. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> RouteSegment </code> aliasing 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageRouteSegmentAliases();


    /**
     *  Adds an <code> Id </code> to a <code> RouteSegment </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> RouteSegment </code> is determined by the provider. The new 
     *  <code> Id </code> performs as an alias to the primary <code> Id. 
     *  </code> If the alias is a pointer to another route segment, it is 
     *  reassigned to the given route segment <code> Id. </code> 
     *
     *  @param  routeSegmentId the <code> Id </code> of a <code> RouteSegment 
     *          </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> routeSegmentId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> routeSegmentId </code> 
     *          or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasRouteSegment(org.osid.id.Id routeSegmentId, 
                                  org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
