//
// org.osid.mapping.route.RouteLookupSession
//
//     The OSID Java specification for org.osid.mapping.route.RouteLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.route;


/**
 *  <p>This session provides methods for retrieving premade <code> Routes. 
 *  </code> The <code> Route </code> represents a set of paths <code> . 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated map view: All route methods in this session operate, 
 *      retrieve and pertain to routes defined explicitly in the current map. 
 *      Using an isolated view is useful for managing <code> Routes </code> 
 *      with the <code> RouteAdminSession. </code> </li> 
 *      <li> federated map view: All route methods in this session operate, 
 *      retrieve and pertain to all routes defined in this map and any other 
 *      routes implicitly available in this map through map inheritence. </li> 
 *      <li> effective route view: All route lookup methods return routes 
 *      where the current date falls in between the effective dates inclusive. 
 *      </li> 
 *      <li> any effective route view: Routes of any effective date are 
 *      returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedMapView() </code> and <code> 
 *  useIsolatedMapView() </code> behave as a radio group and one should be 
 *  selected before invoking the methods in this session. </p>
 */

public interface RouteLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Map </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Map Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getMapId();


    /**
     *  Gets the <code> Map </code> associated with this session. 
     *
     *  @return the map 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Map getMap()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Route </code> lookups. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupRoutes();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeRouteView();


    /**
     *  A complete view of the <code> Route </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryRouteView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include routes in maps which are children of this map in the map 
     *  hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedMapView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this map only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedMapView();


    /**
     *  Only routes whose effective dates are current are returned by methods 
     *  in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useEffectiveRouteView();


    /**
     *  All routes of any effective dates are returned by methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyEffectiveRouteView();


    /**
     *  Gets the <code> Route </code> specified by its <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Route </code> may have a different <code> Id </code> than requested, 
     *  such as the case where a duplicate <code> Id </code> was assigned to a 
     *  <code> Route </code> and retained for compatibility. 
     *  
     *  In effective mode, routes are returned that are currently effective. 
     *  In any effective mode, effective routes and those currently expired 
     *  are returned. 
     *
     *  @param  routeId <code> Id </code> of the <code> Route </code> 
     *  @return the route 
     *  @throws org.osid.NotFoundException <code> routeId </code> not found 
     *  @throws org.osid.NullArgumentException <code> routeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.mapping.route.Route getRoute(org.osid.id.Id routeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RouteList </code> corresponding to the given <code> 
     *  IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  routes specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Routes </code> may be omitted from the list and 
     *  may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In effective mode, routes are returned that are currently effective. 
     *  In any effective mode, effective routes and those currently expired 
     *  are returned. 
     *
     *  @param  routeIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Route </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> routeIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.route.RouteList getRoutesByIds(org.osid.id.IdList routeIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RouteList </code> corresponding to the given route genus 
     *  <code> Type </code> which does not include routes of genus types 
     *  derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  routes or an error results. Otherwise, the returned list may contain 
     *  only those routes that are accessible through this session. 
     *  
     *  In effective mode, routes are returned that are currently effective. 
     *  In any effective mode, effective routes and those currently expired 
     *  are returned. 
     *
     *  @param  routeGenusType a route genus type 
     *  @return the returned <code> Route </code> list 
     *  @throws org.osid.NullArgumentException <code> routeGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.route.RouteList getRoutesByGenusType(org.osid.type.Type routeGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RouteList </code> corresponding to the given route genus 
     *  <code> Type </code> and include any additional routes with genus types 
     *  derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  routes or an error results. Otherwise, the returned list may contain 
     *  only those routes that are accessible through this session. 
     *  
     *  In effective mode, routes are returned that are currently effective. 
     *  In any effective mode, effective routes and those currently expired 
     *  are returned. 
     *
     *  @param  routeGenusType a route genus type 
     *  @return the returned <code> Route </code> list 
     *  @throws org.osid.NullArgumentException <code> routeGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.route.RouteList getRoutesByParentGenusType(org.osid.type.Type routeGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RouteList </code> containing the given route record 
     *  <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  routes or an error results. Otherwise, the returned list may contain 
     *  only those routes that are accessible through this session. 
     *  
     *  In effective mode, routes are returned that are currently effective. 
     *  In any effective mode, effective routes and those currently expired 
     *  are returned. 
     *
     *  @param  routeRecordType a route record type 
     *  @return the returned <code> Route </code> list 
     *  @throws org.osid.NullArgumentException <code> routeRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.route.RouteList getRoutesByRecordType(org.osid.type.Type routeRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RouteList </code> effective during the entire given date 
     *  range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known routes or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  routes that are accessible through this session. 
     *  
     *  In effective mode, routes are returned that are currently effective. 
     *  In any effective mode, effective routes and those currently expired 
     *  are returned. 
     *
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Route </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from or to </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.route.RouteList getRoutesOnDate(org.osid.calendaring.DateTime from, 
                                                            org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RouteList </code> for the given starting <code> 
     *  Location. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  routes, or an error results if a route connected to the location is 
     *  not found or inaccessible. Otherwise, inaccessible <code> Routes 
     *  </code> may be omitted from the list. 
     *  
     *  In effective mode, routes are returned that are currently effective. 
     *  In any effective mode, effective routes and those currently expired 
     *  are returned. 
     *
     *  @param  locationId a location <code> Id </code> 
     *  @return the returned <code> Route </code> list 
     *  @throws org.osid.NullArgumentException <code> locationId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.route.RouteList getRoutesForStartingLocation(org.osid.id.Id locationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RouteList </code> for the given starting location 
     *  effective during the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known routes or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  routes that are accessible through this session. 
     *  
     *  In effective mode, routes are returned that are currently effective. 
     *  In any effective mode, effective routes and those currently expired 
     *  are returned. 
     *
     *  @param  locationId a location <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Route </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> locationId, from, or to 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.route.RouteList getRoutesForStartingLocationOnDate(org.osid.id.Id locationId, 
                                                                               org.osid.calendaring.DateTime from, 
                                                                               org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RouteList </code> for the given ending <code> Location. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  routes, or an error results if a route connected to the location is 
     *  not found or inaccessible. Otherwise, inaccessible <code> Routes 
     *  </code> may be omitted from the list. 
     *  
     *  In effective mode, routes are returned that are currently effective. 
     *  In any effective mode, effective routes and those currently expired 
     *  are returned. 
     *
     *  @param  locationId a location <code> Id </code> 
     *  @return the returned <code> Route </code> list 
     *  @throws org.osid.NullArgumentException <code> locationId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.route.RouteList getRoutesForEndingLocation(org.osid.id.Id locationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RouteList </code> for the given ending location 
     *  effective during the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known routes or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  routes that are accessible through this session. 
     *  
     *  In effective mode, routes are returned that are currently effective. 
     *  In any effective mode, effective routes and those currently expired 
     *  are returned. 
     *
     *  @param  locationId a location <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Route </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> locationId, from, or to 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.route.RouteList getRoutesForEndingLocationOnDate(org.osid.id.Id locationId, 
                                                                             org.osid.calendaring.DateTime from, 
                                                                             org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RouteList </code> for the given starting and ending 
     *  <code> Locations. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  routes, or an error results if a route connected to the location is 
     *  not found or inaccessible. Otherwise, inaccessible <code> Routes 
     *  </code> may be omitted from the list. 
     *  
     *  In effective mode, routes are returned that are currently effective. 
     *  In any effective mode, effective routes and those currently expired 
     *  are returned. 
     *
     *  @param  startingLocationId a location <code> Id </code> 
     *  @param  endingLocationId a location <code> Id </code> 
     *  @return the returned <code> Route </code> list 
     *  @throws org.osid.NullArgumentException <code> startingLocationId 
     *          </code> or <code> endingLocationId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.route.RouteList getRoutesForStartingAndEndingLocation(org.osid.id.Id startingLocationId, 
                                                                                  org.osid.id.Id endingLocationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RouteList </code> for the given starting and ending 
     *  location effective during the entire given date range inclusive but 
     *  not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known routes or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  routes that are accessible through this session. 
     *  
     *  In effective mode, routes are returned that are currently effective. 
     *  In any effective mode, effective routes and those currently expired 
     *  are returned. 
     *
     *  @param  startingLocationId a location <code> Id </code> 
     *  @param  endingLocationId a location <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Route </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> startingLocationId, 
     *          endingLocationId, from, or to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.route.RouteList getRoutesForStartingAndEndingLocationOnDate(org.osid.id.Id startingLocationId, 
                                                                                        org.osid.id.Id endingLocationId, 
                                                                                        org.osid.calendaring.DateTime from, 
                                                                                        org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RouteList </code> connected to all the given <code> 
     *  Locations. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  routes along the locations, or an error results if a route connected 
     *  to the location is not found or inaccessible. Otherwise, inaccessible 
     *  <code> Routes </code> may be omitted from the list. 
     *  
     *  In effective mode, routes are returned that are currently effective. 
     *  In any effective mode, effective routes and those currently expired 
     *  are returned. 
     *
     *  @param  locationIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Route </code> list 
     *  @throws org.osid.NullArgumentException <code> locationIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.route.RouteList getRoutesAlongLocations(org.osid.id.IdList locationIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Routes. </code> 
     *  
     *  In plenary mode, the returned list contains all known routes or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  routes that are accessible through this session. 
     *  
     *  In effective mode, routes are returned that are currently effective. 
     *  In any effective mode, effective routes and those currently expired 
     *  are returned. 
     *
     *  @return a list of <code> Routes </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.route.RouteList getRoutes()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
