//
// org.osid.mapping.route.RouteMapAssignmentSession
//
//     The OSID Java specification for org.osid.mapping.route.RouteMapAssignmentSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.route;


/**
 *  <p>This session provides methods to re-assign <code> Routes </code> to 
 *  <code> Map </code> objects. A <code> Route </code> may appear in multiple 
 *  <code> Map </code> objects and removing the last reference to a <code> 
 *  Route </code> is the equivalent of deleting it. Each <code> Map </code> 
 *  may have its own authorizations governing who is allowed to operate on it. 
 *  </p> 
 *  
 *  <p> Adding a reference of a <code> Route </code> to another <code> Map 
 *  </code> is not a copy operation (eg: does not change its <code> Id </code> 
 *  ). </p>
 */

public interface RouteMapAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter route/map mappings. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known location methods in this session will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignRoutes();


    /**
     *  Tests if this user can alter route/map mappings. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known location methods in this session will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @param  mapId the <code> Id </code> of the <code> Map </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> mapId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignRoutesToMap(org.osid.id.Id mapId);


    /**
     *  Gets a list of maps including and under the given map node in which 
     *  any route can be assigned. 
     *
     *  @param  mapId the <code> Id </code> of the <code> Map </code> 
     *  @return list of assignable map <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> mapId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableMapIds(org.osid.id.Id mapId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of maps including and under the given map node in which a 
     *  specific route can be assigned. 
     *
     *  @param  mapId the <code> Id </code> of the <code> Map </code> 
     *  @param  routeId the <code> Id </code> of the <code> Route </code> 
     *  @return list of assignable map <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> mapId </code> or <code> 
     *          routeId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableMapIdsForRoute(org.osid.id.Id mapId, 
                                                          org.osid.id.Id routeId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> Route </code> to a <code> Map. </code> 
     *
     *  @param  routeId the <code> Id </code> of the <code> Route </code> 
     *  @param  mapId the <code> Id </code> of the <code> Map </code> 
     *  @throws org.osid.AlreadyExistsException <code> routeId </code> is 
     *          already assigned to <code> mapId </code> 
     *  @throws org.osid.NotFoundException <code> routeId </code> or <code> 
     *          mapId </code> not found 
     *  @throws org.osid.NullArgumentException <code> routeId </code> or 
     *          <code> mapId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignRouteToMap(org.osid.id.Id routeId, org.osid.id.Id mapId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> Route </code> from a <code> Map. </code> 
     *
     *  @param  routeId the <code> Id </code> of the <code> Route </code> 
     *  @param  mapId the <code> Id </code> of the <code> Map </code> 
     *  @throws org.osid.NotFoundException <code> routeId </code> or <code> 
     *          mapId </code> not found or <code> routeId </code> not assigned 
     *          to <code> mapId </code> 
     *  @throws org.osid.NullArgumentException <code> routeId </code> or 
     *          <code> mapId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignRouteFromMap(org.osid.id.Id routeId, 
                                     org.osid.id.Id mapId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Moves a <code> Route </code> from one <code> Map </code> to another. 
     *  Mappings to other <code> Maps </code> are unaffected. 
     *
     *  @param  routeId the <code> Id </code> of the <code> Route </code> 
     *  @param  fromMapId the <code> Id </code> of the current <code> Map 
     *          </code> 
     *  @param  toMapId the <code> Id </code> of the destination <code> Map 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> routeId fromMapId, </code> 
     *          or <code> toMapId </code> not found or <code> routeId </code> 
     *          not mapped to <code> fromMapId </code> 
     *  @throws org.osid.NullArgumentException <code> routeId, fromMapId, 
     *          </code> or <code> toMapId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void reassignCreditToMap(org.osid.id.Id routeId, 
                                    org.osid.id.Id fromMapId, 
                                    org.osid.id.Id toMapId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
