//
// org.osid.mapping.route.RouteProgress
//
//     The OSID Java specification for org.osid.mapping.route.RouteProgress.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.route;


/**
 *  <p>Route progress defines methods to get information about progress along 
 *  a route. </p>
 */

public interface RouteProgress
    extends org.osid.OsidCompendium {


    /**
     *  Gets the <code> Id </code> of the resource on the route. 
     *
     *  @return the resource <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getResourceId();


    /**
     *  Gets the resource on the route. 
     *
     *  @return the resource 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getResource()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the route <code> Id. </code> 
     *
     *  @return the route <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getRouteId();


    /**
     *  Gets the route. 
     *
     *  @return the route 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.route.Route getRoute()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the starting time on this route. 
     *
     *  @return the starting time 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getTimeStarted();


    /**
     *  Gets the total distance traveled. 
     *
     *  @return the distance 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Distance getTotalDistanceTraveled();


    /**
     *  Gets the total travel time. 
     *
     *  @return total travel time 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Duration getTotalTravelTime();


    /**
     *  Tests if the object is in motion. 
     *
     *  @return <code> true </code> if the object is in motion, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isInMotion();


    /**
     *  Gets the total idle time before completion of the route. 
     *
     *  @return total idle time 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Duration getTotalIdleTime();


    /**
     *  Get sthe time the object last moved. 
     *
     *  @return last moved time 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getTimeLastMoved();


    /**
     *  Tests if the route has been completed. 
     *
     *  @return <code> true </code> if the route has been completed, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isComplete();


    /**
     *  Gets the current route segment <code> Id. </code> 
     *
     *  @return the route segment <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> isComplete() </code> is 
     *          <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getRouteSegmentId();


    /**
     *  Gets the current route segment. 
     *
     *  @return the route segment 
     *  @throws org.osid.IllegalStateException <code> isComplete() </code> is 
     *          <code> true </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.route.RouteSegment getRouteSegment()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the estimated travel time to the next route segment. 
     *
     *  @return the estimated travel time 
     *  @throws org.osid.IllegalStateException <code> isComplete() </code> is 
     *          <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Duration getETAToNextSegment();


    /**
     *  Gets the distance along the current route segment traveled. 
     *
     *  @return distance along the current segment traveled 
     *  @throws org.osid.IllegalStateException <code> isComplete() </code> is 
     *          <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Distance getRouteSegmentTraveled();


    /**
     *  Gets the ending time for this route. 
     *
     *  @return the ending time 
     *  @throws org.osid.IllegalStateException <code> isComplete() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getTimeCompleted();


    /**
     *  Gets the route progress record corresponding to the given <code> 
     *  RouteProgresst </code> record <code> Type. </code> 
     *
     *  @param  routeProgressRecordType a route progress record type 
     *  @return the route progress record 
     *  @throws org.osid.NullArgumentException <code> progressRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasDomainType(progressSegmentRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.route.records.RouteProgressRecord getRouteProgressRecord(org.osid.type.Type routeProgressRecordType)
        throws org.osid.OperationFailedException;
}
