//
// org.osid.mapping.route.RouteSegment
//
//     The OSID Java specification for org.osid.mapping.route.RouteSegment.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.route;


/**
 *  <p>A route segment represents a portion of a route. </p>
 */

public interface RouteSegment
    extends org.osid.OsidObject {


    /**
     *  Gets the starting instructions for this segment. 
     *
     *  @return the starting instructions 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getStartingInstructions();


    /**
     *  Gets the ending instructions for this segment. 
     *
     *  @return the ending instructions 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getEndingInstructions();


    /**
     *  Gets the length of the entire segment. 
     *
     *  @return the distance 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Distance getDistance();


    /**
     *  Gets the estimated travel time across the entire segment. 
     *
     *  @return the estimated travel time 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Duration getETA();


    /**
     *  Tests if this segment has a corresponding path. 
     *
     *  @return <code> true </code> if there is a path, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasPath();


    /**
     *  Gets the corresponding path <code> Id </code> on which this segment 
     *  travels. 
     *
     *  @return the path 
     *  @throws org.osid.IllegalStateException <code> hasPath() </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPathId();


    /**
     *  Gets the corresponding path on which this segment travels. 
     *
     *  @return the path 
     *  @throws org.osid.IllegalStateException <code> hasPath() </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.Path getPath()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the route segment record corresponding to the given <code> 
     *  RouteSegment </code> record <code> Type. </code> 
     *
     *  @param  routeSegmentRecordType a route segment record type 
     *  @return the route segment record 
     *  @throws org.osid.NullArgumentException <code> routeRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasDomainType(routeSegmentRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.route.records.RouteSegmentRecord getRouteSegmentRecord(org.osid.type.Type routeSegmentRecordType)
        throws org.osid.OperationFailedException;
}
