//
// org.osid.mapping.route.RouteSegmentQuery
//
//     The OSID Java specification for org.osid.mapping.route.RouteSegmentQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.route;


/**
 *  <p>This is the query for searching route segments. Each method match 
 *  specifies an <code> AND </code> term while multiple invocations of the 
 *  same method produce a nested <code> OR. </code> </p>
 */

public interface RouteSegmentQuery
    extends org.osid.OsidObjectQuery {


    /**
     *  Matches the starting instructions for the segment. 
     *
     *  @param  startingInstructions the starting instructions 
     *  @param  stringMatchType the string match type 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for negative match 
     *  @throws org.osid.InvalidArgumentException <code> startingInstructions 
     *          </code> is not of <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> startingInstructions 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchStartingInstructions(String startingInstructions, 
                                          org.osid.type.Type stringMatchType, 
                                          boolean match);


    /**
     *  Matches segments that have any starting instructions. 
     *
     *  @param  match <code> true </code> to match segments with any starting 
     *          instructions, <code> false </code> to match segments with no 
     *          starting instriuctions 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyStartingInstructions(boolean match);


    /**
     *  Clears the starting instruction query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStartingInstructionsTerms();


    /**
     *  Matches the ending instructions for the segment. 
     *
     *  @param  endingInstructions the ending instructions 
     *  @param  stringMatchType the string match type 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for negative match 
     *  @throws org.osid.InvalidArgumentException <code> endingInstructions 
     *          </code> is not of <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> endingInstructions 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchEndingInstructions(String endingInstructions, 
                                        org.osid.type.Type stringMatchType, 
                                        boolean match);


    /**
     *  Matches segments that have any ending instructions. 
     *
     *  @param  match <code> true </code> to match segments with any ending 
     *          instructions, <code> false </code> to match segments with no 
     *          ending instriuctions 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyEndingInstructions(boolean match);


    /**
     *  Clears the ending instruction query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEndingInstructionsTerms();


    /**
     *  Matches route segments with distances in the specified range. 
     *
     *  @param  from starting range 
     *  @param  to ending range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> to </code> ie less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDistance(org.osid.mapping.Distance from, 
                              org.osid.mapping.Distance to, boolean match);


    /**
     *  Clears the distance query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDistanceTerms();


    /**
     *  Matches route segments with estimated ravel times in the specified 
     *  range. 
     *
     *  @param  from starting range 
     *  @param  to ending range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> to </code> ie less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchETA(org.osid.calendaring.Duration from, 
                         org.osid.calendaring.Duration to, boolean match);


    /**
     *  Clears the ETA query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearETATerms();


    /**
     *  Sets the path <code> Id </code> for this query to match route segments 
     *  containing paths. 
     *
     *  @param  pathId the path <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> pathId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchPathId(org.osid.id.Id pathId, boolean match);


    /**
     *  Clears the path <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPathIdTerms();


    /**
     *  Tests if a <code> PathQuery </code> is available. 
     *
     *  @return <code> true </code> if a path query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPathQuery();


    /**
     *  Gets the query for a path. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the path query 
     *  @throws org.osid.UnimplementedException <code> supportsPathQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPathQuery() </code> is <code> true. </code> 
     */

    public org.osid.mapping.path.PathQuery getPathQuery();


    /**
     *  Matches route segments that have any path. 
     *
     *  @param  match <code> true </code> to match route segments with any 
     *          path, <code> false </code> to match route segments with no 
     *          path 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyPath(boolean match);


    /**
     *  Clears the path query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPathTerms();


    /**
     *  Sets the path <code> Id </code> for this query to match route segments 
     *  containing paths. 
     *
     *  @param  pathId the path <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> pathId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRouteId(org.osid.id.Id pathId, boolean match);


    /**
     *  Clears the route <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRouteIdTerms();


    /**
     *  Tests if a <code> RouteQuery </code> is available. 
     *
     *  @return <code> true </code> if a route query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRouteQuery();


    /**
     *  Gets the query for a route. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the route query 
     *  @throws org.osid.UnimplementedException <code> supportsRouteQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRouteQuery() </code> is <code> true. </code> 
     */

    public org.osid.mapping.route.RouteQuery getRouteQuery();


    /**
     *  Clears the route query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRouteTerms();


    /**
     *  Gets the route segment query record corresponding to the given <code> 
     *  RouteSegment </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  routeSegmentRecordType a route segment record type 
     *  @return the route segment query record 
     *  @throws org.osid.NullArgumentException <code> routeSegmentRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(routeSegmentRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.route.records.RouteSegmentQueryRecord getRouteSegmentQueryRecord(org.osid.type.Type routeSegmentRecordType)
        throws org.osid.OperationFailedException;
}
