//
// org.osid.mapping.route.RoutingSession
//
//     The OSID Java specification for org.osid.mapping.route.RoutingSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.route;


/**
 *  <p>This session defines methods to traverse through a map. </p>
 */

public interface RoutingSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Map </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Map Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getMapId();


    /**
     *  Gets the <code> Map </code> associated with this session. 
     *
     *  @return the map 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Map getMap()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can query routes. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not offer lookup operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if routing methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupRoutes();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include paths in maps which are children of this map in the map 
     *  hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedMapView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this map only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedMapView();


    /**
     *  Gets the supported routing types. 
     *
     *  @return a list of routing types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getRoutingTypes();


    /**
     *  Tests if the given routing type is supported. 
     *
     *  @param  routingType a routing type 
     *  @return <code> true </code> of the routing type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> routingType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRoutingType(org.osid.type.Type routingType);


    /**
     *  Gets the shortest route between the two given locations. 
     *
     *  @param  locationId the given location <code> Id </code> 
     *  @param  anotherLocationId the given location <code> Id </code> 
     *  @param  routingType a routing type 
     *  @return a list of inbound paths 
     *  @throws org.osid.NotFoundException <code> locationId </code> or <code> 
     *          anotherLocationId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> locationId </code> or 
     *          <code> anotherLocationId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsRoutingType(routingType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.route.Route getShortestRoute(org.osid.id.Id locationId, 
                                                         org.osid.id.Id anotherLocationId, 
                                                         org.osid.type.Type routingType)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the fastest route between the two given locations. 
     *
     *  @param  locationId the given location <code> Id </code> 
     *  @param  anotherLocationId the given location <code> Id </code> 
     *  @param  routingType a routing type 
     *  @return a list of inbound paths 
     *  @throws org.osid.NotFoundException <code> locationId </code> or <code> 
     *          anotherLocationId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> locationId </code> or 
     *          <code> anotherLocationId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsRoutingType(routingType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.route.Route getFastestRoute(org.osid.id.Id locationId, 
                                                        org.osid.id.Id anotherLocationId, 
                                                        org.osid.type.Type routingType)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all routes between the two given locations. 
     *
     *  @param  locationId the given location <code> Id </code> 
     *  @param  anotherLocationId the given location <code> Id </code> 
     *  @return a list of inbound paths 
     *  @throws org.osid.NotFoundException <code> locationId </code> or <code> 
     *          anotherLocationId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> locationId </code> or 
     *          <code> anotherLocationId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.route.Route getRoutes(org.osid.id.Id locationId, 
                                                  org.osid.id.Id anotherLocationId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
