//
// org.osid.messaging.MailboxAdminSession
//
//     The OSID Java specification for org.osid.messaging.MailboxAdminSession.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.messaging;


/**
 *  <p>This session creates, updates, and deletes <code> Mailboxes. </code> 
 *  The data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Mailbox, </code> a <code> MailboxForm </code> is requested using <code> 
 *  getMailboxFormForCreate() </code> specifying the desired record <code> 
 *  Types </code> or none if no record <code> Types </code> are needed. The 
 *  returned <code> MailboxForm </code> will indicate that it is to be used 
 *  with a create operation and can be used to examine metdata or validate 
 *  data prior to creation. Once the <code> MailboxForm </code> is submiited 
 *  to a create operation, it cannot be reused with another create operation 
 *  unless the first operation was unsuccessful. Each <code> MailboxForm 
 *  </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> MailboxForms </code> are requested to the <code> 
 *  Mailbox </code> <code> Id </code> that is to be updated using <code> 
 *  getMailboxFormForUpdate(). </code> Similarly, the <code> MailboxForm 
 *  </code> has metadata about the data that can be updated and it can perform 
 *  validation before submitting the update. The <code> MailboxForm </code> 
 *  can only be used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Mailboxes. </code> </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface MailboxAdminSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can create <code> Mailboxes. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> Mailbox </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not wish to offer create operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Mailbox </code> creation is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateMailboxes();


    /**
     *  Tests if this user can create a single <code> Mailbox </code> using 
     *  the desired record types. While <code> 
     *  MessagingManager.getMailboxRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> Mailbox. </code> Providing 
     *  an empty array tests if a <code> Mailbox </code> can be created with 
     *  no records. 
     *
     *  @param  mailboxRecordTypes array of mailbox record types 
     *  @return <code> true </code> if <code> Mailbox </code> creation using 
     *          the specified <code> Types </code> is supported, <code> false 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> mailboxRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateMailboxWithRecordTypes(org.osid.type.Type[] mailboxRecordTypes);


    /**
     *  Gets the mailbox form for creating new mailboxes. 
     *
     *  @param  mailboxRecordTypes array of mailbox record types 
     *  @return the mailbox form 
     *  @throws org.osid.NullArgumentException <code> mailboxRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.MailboxForm getMailboxFormForCreate(org.osid.type.Type[] mailboxRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Mailbox. </code> 
     *
     *  @param  mailboxForm the form for this <code> Mailbox </code> 
     *  @return the new <code> Mailbox </code> 
     *  @throws org.osid.IllegalStateException <code> mailboxForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> mailboxForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> mailboxForm </code> did 
     *          not originate from <code> getMailboxFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.Mailbox createMailbox(org.osid.messaging.MailboxForm mailboxForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Mailboxes. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> Mailbox </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not wish to offer update operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Mailbox </code> modification is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateMailboxes();


    /**
     *  Gets the mailbox form for updating an existing mailbox. A new mailbox 
     *  form should be requested for each update transaction. 
     *
     *  @param  mailboxId the <code> Id </code> of the <code> Mailbox </code> 
     *  @return the mailbox form 
     *  @throws org.osid.NotFoundException <code> mailboxId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> mailboxId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.MailboxForm getMailboxFormForUpdate(org.osid.id.Id mailboxId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing mailbox. 
     *
     *  @param  mailboxForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> mailboxForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> mailboxForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> mailboxForm </code> did 
     *          not originate from <code> getMailboxFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateMailbox(org.osid.messaging.MailboxForm mailboxForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> Mailboxes. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> Mailbox </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not wish to offer delete operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Mailbox </code> deletion is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteMailboxes();


    /**
     *  Deletes a <code> Mailbox. </code> 
     *
     *  @param  mailboxId the <code> Id </code> of the <code> Mailbox </code> 
     *          to remove 
     *  @throws org.osid.NotFoundException <code> mailboxId </code> not found 
     *  @throws org.osid.NullArgumentException <code> mailboxId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteMailbox(org.osid.id.Id mailboxId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Mailboxes. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Mailbox </code> aliasing is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageMailboxAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Mailbox </code> for the purpose 
     *  of creating compatibility. The primary <code> Id </code> of the <code> 
     *  Mailbox </code> is determined by the provider. The new <code> Id 
     *  </code> performs as an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another mailbox, it is reassigned to the given 
     *  mailbox <code> Id. </code> 
     *
     *  @param  mailboxId the <code> Id </code> of a <code> Mailbox </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> mailboxId </code> not found 
     *  @throws org.osid.NullArgumentException <code> mailboxId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasMailbox(org.osid.id.Id mailboxId, org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
