//
// org.osid.messaging.MailboxNotificationSession
//
//     The OSID Java specification for org.osid.messaging.MailboxNotificationSession.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.messaging;


/**
 *  <p>This session defines methods to receive notifications on adds/changes 
 *  to <code> Mailbox </code> objects. This session is intended for consumers 
 *  needing to synchronize their message with this service without the use of 
 *  polling. Notifications are cancelled when this session is closed. </p>
 */

public interface MailboxNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can register for <code> Mailbox </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForMailboxNotifications();


    /**
     *  Register for notifications of new mailboxes. <code> 
     *  MailboxReceiver.newMailboxes() </code> is invoked when a new <code> 
     *  Mailbox </code> is created. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewMailboxes()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification if an ancestor is added to the specified 
     *  mailbox in the mailbox hierarchy. <code> 
     *  MailboxReceiver.newMailboxAncestor() </code> is invoked when the 
     *  specified mailbox experiences an addition in ancestry. 
     *
     *  @param  mailboxId the <code> Id </code> of the mailbox to monitor 
     *  @throws org.osid.NullArgumentException <code> mailboxId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewMailboxAncestors(org.osid.id.Id mailboxId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification if a descendant is added to the specified 
     *  mailbox in the mailbox hierarchy. <code> 
     *  MailboxReceiver.newMailboxDescendant() </code> is invoked when the 
     *  specified mailbox experiences an addition in descendants. 
     *
     *  @param  mailboxId the <code> Id </code> of the mailbox to monitor 
     *  @throws org.osid.NullArgumentException <code> mailboxId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewMailboxDescendants(org.osid.id.Id mailboxId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated mailboxes. <code> 
     *  MailboxReceiver.changedMailboxes() </code> is invoked when a mailbox 
     *  is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedMailboxes()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated mailbox. <code> 
     *  MailboxReceiver.changedMailboxes() </code> is invoked when the 
     *  specified mailbox is changed. 
     *
     *  @param  mailboxId the <code> Id </code> of the Mailbox to monitor 
     *  @throws org.osid.NullArgumentException <code> mailboxId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedMailbox(org.osid.id.Id mailboxId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted mailboxes. <code> 
     *  MailboxReceiver.deletedMailboxes() </code> is invoked when a mailbox 
     *  is deleted. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedMailboxes()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted mailbox. <code> 
     *  MailboxReceiver.deletedMailboxes() </code> is invoked when the 
     *  specified mailbox is deleted. 
     *
     *  @param  mailboxId the <code> Id </code> of the <code> Mailbox </code> 
     *          to monitor 
     *  @throws org.osid.NullArgumentException <code> mailboxId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedMailbox(org.osid.id.Id mailboxId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification if an ancestor is removed from the 
     *  specified mailbox in the mailbox hierarchy. <code> 
     *  MailboxReceiver.deletedMailboxAncestor() </code> is invoked when the 
     *  specified mailbox experiences a removal of an ancestor. 
     *
     *  @param  mailboxId the <code> Id </code> of the mailbox to monitor 
     *  @throws org.osid.NullArgumentException <code> mailboxId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedMailboxAncestors(org.osid.id.Id mailboxId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification if a descendant is removed from fthe 
     *  specified mailbox in the mailbox hierarchy. <code> 
     *  MailboxReceiver.deletedMailboxDescednant() </code> is invoked when the 
     *  specified mailbox experiences a removal of one of its descdendents. 
     *
     *  @param  mailboxId the <code> Id </code> of the mailbox to monitor 
     *  @throws org.osid.NullArgumentException <code> mailboxId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedMailboxDescendants(org.osid.id.Id mailboxId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
