//
// org.osid.messaging.Message
//
//     The OSID Java specification for org.osid.messaging.Message.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.messaging;


/**
 *  <p>A <code> Message. </code> </p>
 */

public interface Message
    extends org.osid.OsidObject {


    /**
     *  Gets the subject line of this message. 
     *
     *  @return the subject 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getSubjectLine();


    /**
     *  Gets the text of the message. 
     *
     *  @return the text 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getText();


    /**
     *  Tests if this message has been sent. 
     *
     *  @return <code> true </code> if this message has been sent, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isSent();


    /**
     *  Gets the time this message was sent. 
     *
     *  @return the time 
     *  @throws org.osid.IllegalStateException <code> isSent() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getSentTime();


    /**
     *  Gets the sender <code> Id </code> of this message. 
     *
     *  @return the sender agent <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> isSent() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getSenderId();


    /**
     *  Gets the sender of this message. 
     *
     *  @return the sender 
     *  @throws org.osid.IllegalStateException <code> isSent() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getSender()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the sending agent <code> Id </code> of this message. 
     *
     *  @return the sending agent <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> isSent() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getSendingAgentId();


    /**
     *  Gets the sending agent of this message. 
     *
     *  @return the sending agent 
     *  @throws org.osid.IllegalStateException <code> isSent() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.Agent getSendingAgent()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the time this message was received. 
     *
     *  @return the time 
     *  @throws org.osid.IllegalStateException <code> isSent() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getReceivedTime();


    /**
     *  Gets the list of all addressed recipient <code> Ids </code> of this 
     *  message. 
     *
     *  @return the recipient resource <code> Ids </code> 
     *  @throws org.osid.IllegalStateException <code> isSent() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getRecipientIds();


    /**
     *  Gets the list of all addressed recipients of this message. 
     *
     *  @return the recpient resources 
     *  @throws org.osid.IllegalStateException <code> isSent() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceList getRecipients()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if the resource related to the authenticated agent is one of the 
     *  recipients of this message. 
     *
     *  @return <code> true </code> if this agent is a recipient, <code> false 
     *          </code> otherwise 
     *  @throws org.osid.IllegalStateException <code> isSent() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isRecipient();


    /**
     *  Gets the receipt <code> Id </code> for this message. A receipt is 
     *  available for the receiver of this message. 
     *
     *  @return the receipt <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> isRecipient() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getReceiptId();


    /**
     *  Gets the receipt for this message. A receipt is available for the 
     *  receiver of this message. 
     *
     *  @return the receipt 
     *  @throws org.osid.IllegalStateException <code> isRecipient() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.Receipt getReceipt()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the message record corresponding to the given <code> Message 
     *  </code> record <code> Type. </code> This method is used to retrieve an 
     *  object implementing the requested record. The <code> messageRecordType 
     *  </code> may be the <code> Type </code> returned in <code> 
     *  getRecordTypes() </code> or any of its parents in a <code> Type 
     *  </code> hierarchy where <code> hasRecordType(messageRecordType) 
     *  </code> is <code> true </code> . 
     *
     *  @param  messageRecordType the message record type 
     *  @return the message record 
     *  @throws org.osid.NullArgumentException <code> messageRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(messageRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.records.MessageRecord getMessageRecord(org.osid.type.Type messageRecordType)
        throws org.osid.OperationFailedException;
}
