//
// org.osid.messaging.MessageAdminSession
//
//     The OSID Java specification for org.osid.messaging.MessageAdminSession.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.messaging;


/**
 *  <p>This session creates, updates, and deletes <code> Messages. </code> The 
 *  data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Message, </code> a <code> MessageForm </code> is requested using <code> 
 *  getMessageFormForCreate() </code> specifying the desired record <code> 
 *  Types </code> or none if no record <code> Types </code> are needed. The 
 *  returned <code> MessageForm </code> will indicate that it is to be used 
 *  with a create operation and can be used to examine metdata or validate 
 *  data prior to creation. Once the <code> MessageForm </code> is submiited 
 *  to a create operation, it cannot be reused with another create operation 
 *  unless the first operation was unsuccessful. Each <code> MessageForm 
 *  </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> MessageForms </code> are requested to the <code> 
 *  Message </code> <code> Id </code> that is to be updated using <code> 
 *  getMessageFormForUpdate(). </code> Similarly, the <code> MessageForm 
 *  </code> has metadata about the data that can be updated and it can perform 
 *  validation before submitting the update. The <code> MessageForm </code> 
 *  can only be used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Messages. </code> To unmap a 
 *  <code> Message </code> from the current <code> Mailbox, </code> the <code> 
 *  MessageMailboxAssignmentSession </code> should be used. These delete 
 *  operations attempt to remove the <code> Message </code> itself thus 
 *  removing it from all known <code> Mailbox </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface MessageAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Mailbox </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Mailbox Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getMailboxId();


    /**
     *  Gets the <code> Mailbox </code> associated with this session. 
     *
     *  @return the <code> Mailbox </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.Mailbox getMailbox()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> Messages. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> Message </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer create operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Message </code> creation is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateMessages();


    /**
     *  Tests if this user can create a single <code> Message </code> using 
     *  the desired record types. While <code> 
     *  MessagingManager.getMessageRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> Message. </code> Providing 
     *  an empty array tests if a <code> Message </code> can be created with 
     *  no records. 
     *
     *  @param  messageRecordTypes array of message record types 
     *  @return <code> true </code> if <code> Message </code> creation using 
     *          the specified <code> Types </code> is supported, <code> false 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> messageRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateMessageWithRecordTypes(org.osid.type.Type[] messageRecordTypes);


    /**
     *  Gets the message form for creating new messages. A new form should be 
     *  requested for each create transaction. 
     *
     *  @param  messageRecordTypes array of message record types 
     *  @return the message form 
     *  @throws org.osid.NullArgumentException <code> messageRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.MessageForm getMessageFormForCreate(org.osid.type.Type[] messageRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Message. </code> 
     *
     *  @param  messageForm the form for this <code> Message </code> 
     *  @return the new <code> Message </code> 
     *  @throws org.osid.IllegalStateException <code> messageForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> messageForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> messageForm </code> did 
     *          not originate from <code> getMessageFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.Message createMessage(org.osid.messaging.MessageForm messageForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Messages. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> Message </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer update operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Message </code> modification is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateMessages();


    /**
     *  Gets the message form for updating an existing message. A new message 
     *  form should be requested for each update transaction. 
     *
     *  @param  messageId the <code> Id </code> of the <code> Message </code> 
     *  @return the message form 
     *  @throws org.osid.NotFoundException <code> messageId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> messageId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.MessageForm getMessageFormForUpdate(org.osid.id.Id messageId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing message. 
     *
     *  @param  messageForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> messageForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> messageForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> messageForm </code> did 
     *          not originate from <code> getMessageFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateMessage(org.osid.messaging.MessageForm messageForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> Messages. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> Message </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer delete operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Message </code> deletion is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteMessages();


    /**
     *  Deletes a <code> Message. </code> 
     *
     *  @param  messageId the <code> Id </code> of the <code> Message </code> 
     *          to remove 
     *  @throws org.osid.NotFoundException <code> messageId </code> not found 
     *  @throws org.osid.NullArgumentException <code> messageId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteMessage(org.osid.id.Id messageId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Messages. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Message </code> aliasing is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageMessageAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Message </code> for the purpose 
     *  of creating compatibility. The primary <code> Id </code> of the <code> 
     *  Message </code> is determined by the provider. The new <code> Id 
     *  </code> performs as an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another message, it is reassigned to the given 
     *  message <code> Id. </code> 
     *
     *  @param  messageId the <code> Id </code> of a <code> Message </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> messageId </code> not found 
     *  @throws org.osid.NullArgumentException <code> aliasId </code> or 
     *          <code> messageId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasMessage(org.osid.id.Id messageId, org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
