//
// org.osid.messaging.MessageLookupSession
//
//     The OSID Java specification for org.osid.messaging.MessageLookupSession.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.messaging;


/**
 *  <p>This session defines methods for retrieving messages. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated mailbox view: All message methods in this session 
 *      operate, retrieve and pertain to messages defined explicitly in the 
 *      current mailbox. Using an isolated view is useful for managing <code> 
 *      Messages </code> with the <code> MessageAdminSession. </code> </li> 
 *      <li> federated mailbox view: All message methods in this session 
 *      operate, retrieve and pertain to all messages defined in this mailbox 
 *      and any other messages implicitly available in this mailbox through 
 *      mailbox inheritence. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedMailboxView() </code> and <code> 
 *  useIsolatedMailboxView() </code> behave as a radio group and one should be 
 *  selected before invoking any lookup methods. </p> 
 *  
 *  <p> Messages may have an additional records indicated by their respective 
 *  record types. The record may not be accessed through a cast of the <code> 
 *  Message. </code> </p>
 */

public interface MessageLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Mailbox </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Mailbox Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getMailboxId();


    /**
     *  Gets the <code> Mailbox </code> associated with this session. 
     *
     *  @return the <code> Mailbox </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.Mailbox getMailbox()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Message </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer lookup operations. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupMessages();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeMessageView();


    /**
     *  A complete view of the <code> Message </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryMessageView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include messages in mailboxes which are children of this mailbox in 
     *  the mailbox hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedMailboxView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this mailbox only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedMailboxView();


    /**
     *  Gets the <code> Message </code> specified by its <code> Id. </code> In 
     *  plenary mode, the exact <code> Id </code> is found or a <code> 
     *  NOT_FOUND </code> results. Otherwise, the returned <code> Message 
     *  </code> may have a different <code> Id </code> than requested, such as 
     *  the case where a duplicate <code> Id </code> was assigned to a <code> 
     *  Message </code> and retained for compatibility. 
     *
     *  @param  messageId the <code> Id </code> of the <code> Message </code> 
     *          to retrieve 
     *  @return the returned <code> Message </code> 
     *  @throws org.osid.NotFoundException no <code> Message </code> found 
     *          with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> messageId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.Message getMessage(org.osid.id.Id messageId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> MessageList </code> corresponding to the given <code> 
     *  IdList. </code> In plenary mode, the returned list contains all of the 
     *  messages specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Messages </code> may be omitted from the list and 
     *  may present the elements in any order including returning a unique 
     *  set. 
     *
     *  @param  messageIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Message list </code> 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> messageIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.MessageList getMessagesByIds(org.osid.id.IdList messageIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> MessageList </code> corresponding to the given message 
     *  genus <code> Type </code> which does not include messages of types 
     *  derived from the specified <code> Type. </code> In plenary mode, the 
     *  returned list contains all known messages or an error results. 
     *  Otherwise, the returned list may contain only those messages that are 
     *  accessible through this session. 
     *
     *  @param  messageGenusType a message genus type 
     *  @return the returned <code> Message </code> list 
     *  @throws org.osid.NullArgumentException <code> messageGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.MessageList getMessagesByGenusType(org.osid.type.Type messageGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> MessageList </code> corresponding to the given message 
     *  genus <code> Type </code> and include any additional messages with 
     *  genus types derived from the specified <code> Type. </code> In plenary 
     *  mode, the returned list contains all known messages or an error 
     *  results. Otherwise, the returned list may contain only those messages 
     *  that are accessible through this session 
     *
     *  @param  messageGenusType a message genus type 
     *  @return the returned <code> Message </code> list 
     *  @throws org.osid.NullArgumentException <code> messageGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.MessageList getMessagesByParentGenusType(org.osid.type.Type messageGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> MessageList </code> containing the given message record 
     *  <code> Type. </code> In plenary mode, the returned list contains all 
     *  known messages or an error results. Otherwise, the returned list may 
     *  contain only those messages that are accessible through this session. 
     *
     *  @param  messageRecordType a message record type 
     *  @return the returned <code> Message </code> list 
     *  @throws org.osid.NullArgumentException <code> messageRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.MessageList getMessagesByRecordType(org.osid.type.Type messageRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> MessageList </code> sent within the specified range 
     *  inclusive. In plenary mode, the returned list contains all known 
     *  messages or an error results. Otherwise, the returned list may contain 
     *  only those messages that are accessible through this session. 
     *
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> Message </code> list 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.MessageList getMessagesBySentTime(org.osid.calendaring.DateTime from, 
                                                                org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> MessageList </code> of the given genus type and sent 
     *  within the specified range inclusive. In plenary mode, the returned 
     *  list contains all known messages or an error results. Otherwise, the 
     *  returned list may contain only those messages that are accessible 
     *  through this session. 
     *
     *  @param  messageGenusType a message genus type 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> Message </code> list 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> messageGenusType, from 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.MessageList getMessagesBySentTimeAndGenusType(org.osid.type.Type messageGenusType, 
                                                                            org.osid.calendaring.DateTime from, 
                                                                            org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> MessageList </code> sent by the specified sender. In 
     *  plenary mode, the returned list contains all known messages or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  messages that are accessible through this session. 
     *
     *  @param  resourceId a resource Id 
     *  @return the returned <code> Message </code> list 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.MessageList getMessagesFromSender(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> MessageList </code> of the given genus type and sender. 
     *  In plenary mode, the returned list contains all known messages or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  messages that are accessible through this session. 
     *
     *  @param  resourceId a resource Id 
     *  @param  messageGenusType a message genus type 
     *  @return the returned <code> Message </code> list 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> or 
     *          <code> messageGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.MessageList getMessagesByGenusTypeFromSender(org.osid.id.Id resourceId, 
                                                                           org.osid.type.Type messageGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> MessageList </code> sent by the specified sender and 
     *  sent time. In plenary mode, the returned list contains all known 
     *  messages or an error results. Otherwise, the returned list may contain 
     *  only those messages that are accessible through this session 
     *
     *  @param  resourceId a resource Id 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> Message </code> list 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, from </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.MessageList getMessagesBySentTimeFromSender(org.osid.id.Id resourceId, 
                                                                          org.osid.calendaring.DateTime from, 
                                                                          org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> MessageList </code> of the given genus type and sent 
     *  within the specified range inclusive. In plenary mode, the returned 
     *  list contains all known messages or an error results. Otherwise, the 
     *  returned list may contain only those messages that are accessible 
     *  through this session. 
     *
     *  @param  resourceId a resource Id 
     *  @param  messageGenusType a message genus type 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> Message </code> list 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, 
     *          messageGenusType, from </code> or <code> to </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.MessageList getMessagesBySentTimeAndGenusTypeFromSender(org.osid.id.Id resourceId, 
                                                                                      org.osid.type.Type messageGenusType, 
                                                                                      org.osid.calendaring.DateTime from, 
                                                                                      org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> MessageList </code> received by the specified recipient. 
     *  In plenary mode, the returned list contains all known messages or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  messages that are accessible through this session. 
     *
     *  @param  resourceId a resource Id 
     *  @return the returned <code> Message </code> list 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.MessageList getMessagesForRecipient(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> MessageList </code> received by the specified recipient. 
     *  In plenary mode, the returned list contains all known messages or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  messages that are accessible through this session. 
     *
     *  @param  resourceId a resource Id 
     *  @param  messageGenusType a message genus type 
     *  @return the returned <code> Message </code> list 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> or 
     *          <code> messageGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.MessageList getMessagesByGenusTypeForRecipient(org.osid.id.Id resourceId, 
                                                                             org.osid.type.Type messageGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> MessageList </code> received by the specified resource 
     *  and received time. In plenary mode, the returned list contains all 
     *  known messages or an error results. Otherwise, the returned list may 
     *  contain only those messages that are accessible through this session. 
     *
     *  @param  resourceId a resource Id 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> Message </code> list 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, from </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.MessageList getMessagesByReceivedTimeForRecipient(org.osid.id.Id resourceId, 
                                                                                org.osid.calendaring.DateTime from, 
                                                                                org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> MessageList </code> of the given genus type received by 
     *  the specified resource and received time. In plenary mode, the 
     *  returned list contains all known messages or an error results. 
     *  Otherwise, the returned list may contain only those messages that are 
     *  accessible through this session. 
     *
     *  @param  resourceId a resource Id 
     *  @param  messageGenusType a message genus type 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> Message </code> list 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, 
     *          messageGenusType, from </code> or <code> to </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.MessageList getMessagesByReceivedTimeAndGenusTypeForRecipient(org.osid.id.Id resourceId, 
                                                                                            org.osid.type.Type messageGenusType, 
                                                                                            org.osid.calendaring.DateTime from, 
                                                                                            org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> MessageList </code> sent by the specified sender and 
     *  received by the specified recipient. In plenary mode, the returned 
     *  list contains all known messages or an error results. Otherwise, the 
     *  returned list may contain only those messages that are accessible 
     *  through this session. 
     *
     *  @param  senderResourceId a resource Id 
     *  @param  recipientResourceId a resource Id 
     *  @return the returned <code> Message </code> list 
     *  @throws org.osid.NullArgumentException <code> senderResourceId </code> 
     *          or <code> recipientResourceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.MessageList getMessagesFromSenderForRecipient(org.osid.id.Id senderResourceId, 
                                                                            org.osid.id.Id recipientResourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> MessageList </code> of the given genus type sent by the 
     *  specified sender and received by the specified recipient. In plenary 
     *  mode, the returned list contains all known messages or an error 
     *  results. Otherwise, the returned list may contain only those messages 
     *  that are accessible through this session. 
     *
     *  @param  senderResourceId a resource Id 
     *  @param  recipientResourceId a resource Id 
     *  @param  messageGenusType a message genus type 
     *  @return the returned <code> Message </code> list 
     *  @throws org.osid.NullArgumentException <code> senderResourceId, 
     *          recipientResourceId </code> or <code> messageGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.MessageList getMessagesByGenusTypeFromSenderForRecipient(org.osid.id.Id senderResourceId, 
                                                                                       org.osid.id.Id recipientResourceId, 
                                                                                       org.osid.type.Type messageGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> MessageList </code> by the specified sender, recipient, 
     *  and received time. In plenary mode, the returned list contains all 
     *  known messages or an error results. Otherwise, the returned list may 
     *  contain only those messages that are accessible through this session. 
     *
     *  @param  senderResourceId a resource Id 
     *  @param  recipientResourceId a resource Id 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> Message </code> list 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> senderResourceId, 
     *          recipientResourceId, from </code> or <code> to </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.MessageList getMessagesByReceivedTimeFromSenderForRecipient(org.osid.id.Id senderResourceId, 
                                                                                          org.osid.id.Id recipientResourceId, 
                                                                                          org.osid.calendaring.DateTime from, 
                                                                                          org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> MessageList </code> of the given genus type and received 
     *  by the specified resource and received time. In plenary mode, the 
     *  returned list contains all known messages or an error results. 
     *  Otherwise, the returned list may contain only those messages that are 
     *  accessible through this session. 
     *
     *  @param  senderResourceId a resource Id 
     *  @param  recipientResourceId a resource Id 
     *  @param  messageGenusType a message genus type 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> Message </code> list 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> senderResourceId, 
     *          recipientResourceId, messageGenusType, from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.MessageList getMessagesByReceivedTimeAndGenusTypeFromSenderForRecipient(org.osid.id.Id senderResourceId, 
                                                                                                      org.osid.id.Id recipientResourceId, 
                                                                                                      org.osid.type.Type messageGenusType, 
                                                                                                      org.osid.calendaring.DateTime from, 
                                                                                                      org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Messages. </code> In plenary mode, the returned list 
     *  contains all known messages or an error results. Otherwise, the 
     *  returned list may contain only those messages that are accessible 
     *  through this session. 
     *
     *  @return a list of <code> Messages </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.MessageList getMessages()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
