//
// org.osid.messaging.MessageQuery
//
//     The OSID Java specification for org.osid.messaging.MessageQuery.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.messaging;


/**
 *  <p>This is the query for searching messages. Each method specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface MessageQuery
    extends org.osid.OsidObjectQuery {


    /**
     *  Adds a subject line to match. Multiple subject line matches can be 
     *  added to perform a boolean <code> OR </code> among them. 
     *
     *  @param  subject subject to match 
     *  @param  stringMatchType the string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> subject is </code> 
     *          not of <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> subject </code> or 
     *          <code> stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSubjectLine(String subject, 
                                 org.osid.type.Type stringMatchType, 
                                 boolean match);


    /**
     *  Matches messages with any subject line. 
     *
     *  @param  match <code> true </code> to match messages with any subject 
     *          line, <code> false </code> to match messages with no subject 
     *          line 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnySubjectLine(boolean match);


    /**
     *  Clears the subject line terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSubjectLineTerms();


    /**
     *  Adds text to match. Multiple subject line matches can be added to 
     *  perform a boolean <code> OR </code> among them. 
     *
     *  @param  text dtext to match 
     *  @param  stringMatchType the string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> text is </code> not 
     *          of <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> text </code> or <code> 
     *          stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchText(String text, org.osid.type.Type stringMatchType, 
                          boolean match);


    /**
     *  Matches messages with any text. 
     *
     *  @param  match <code> true </code> to match messages with any text, 
     *          <code> false </code> to match messages with no text 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyText(boolean match);


    /**
     *  Clears the text terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTextTerms();


    /**
     *  Matches messages that have been sent. 
     *
     *  @param  match <code> true </code> to match sent messages, <code> false 
     *          </code> to match unsent messages 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSent(boolean match);


    /**
     *  Clears the sent terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSentTerms();


    /**
     *  Matches messages whose sent time is between the supplied range 
     *  inclusive. 
     *
     *  @param  startTime start time 
     *  @param  endTime end time 
     *  @param  match <code> true </code> if for a positive match, <code> 
     *          false </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> startTime </code> is 
     *          greater than <code> endTime </code> 
     *  @throws org.osid.NullArgumentException <code> startTime </code> or 
     *          <code> endTime </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSentTime(org.osid.calendaring.DateTime startTime, 
                              org.osid.calendaring.DateTime endTime, 
                              boolean match);


    /**
     *  Clears the sent time terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSentTimeTerms();


    /**
     *  Matches the sender of the message. 
     *
     *  @param  resourceId <code> Id </code> to match 
     *  @param  match <code> true </code> if for a positive match, <code> 
     *          false </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSenderId(org.osid.id.Id resourceId, boolean match);


    /**
     *  Clears the sender <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSenderIdTerms();


    /**
     *  Tests if a <code> ResourceQuery </code> is available for querying 
     *  senders. 
     *
     *  @return <code> true </code> if a resource query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSenderQuery();


    /**
     *  Gets the query for a resource. 
     *
     *  @return the resource query 
     *  @throws org.osid.UnimplementedException <code> supportsSenderQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSenderQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceQuery getSenderQuery();


    /**
     *  Clears the sender terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSenderTerms();


    /**
     *  Matches the sending agent of the message. 
     *
     *  @param  agentId <code> Id </code> to match 
     *  @param  match <code> true </code> if for a positive match, <code> 
     *          false </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> agentId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSendingAgentId(org.osid.id.Id agentId, boolean match);


    /**
     *  Clears the sending agent <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSendingAgentIdTerms();


    /**
     *  Tests if an <code> AgentQuery </code> is available for querying 
     *  senders. 
     *
     *  @return <code> true </code> if an agent query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSendingAgentQuery();


    /**
     *  Gets the query for an agent. 
     *
     *  @return the agent query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSendingAgentQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSendingAgentQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.authentication.AgentQuery getSendingAgentQuery();


    /**
     *  Clears the sending agent terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSendingAgentTerms();


    /**
     *  Matches messages whose received time is between the supplied range 
     *  inclusive. 
     *
     *  @param  startTime start time 
     *  @param  endTime end time 
     *  @param  match <code> true </code> if for a positive match, <code> 
     *          false </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> startTime </code> is 
     *          greater than <code> endTime </code> 
     *  @throws org.osid.NullArgumentException <code> startTime </code> or 
     *          <code> endTime </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchReceivedTime(org.osid.calendaring.DateTime startTime, 
                                  org.osid.calendaring.DateTime endTime, 
                                  boolean match);


    /**
     *  Clears the received time terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearReceivedTimeTerms();


    /**
     *  Matches messages whose delivery duration is between the supplied range 
     *  inclusive. 
     *
     *  @param  start start time 
     *  @param  end end time 
     *  @param  match <code> true </code> if for a positive match, <code> 
     *          false </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> start </code> is 
     *          greater than <code> end </code> 
     *  @throws org.osid.NullArgumentException <code> start </code> or <code> 
     *          end </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDeliveryTime(org.osid.calendaring.Duration start, 
                                  org.osid.calendaring.Duration end, 
                                  boolean match);


    /**
     *  Clears the delivery time terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDeliveryTimeTerms();


    /**
     *  Matches any recipient of the message. 
     *
     *  @param  resourceId <code> Id </code> to match 
     *  @param  match <code> true </code> if for a positive match, <code> 
     *          false </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRecipientId(org.osid.id.Id resourceId, boolean match);


    /**
     *  Clears the recipient <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRecipientIdTerms();


    /**
     *  Tests if a <code> ResourceQuery </code> is available for querying 
     *  recipients. 
     *
     *  @return <code> true </code> if a resource query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRecipientQuery();


    /**
     *  Gets the query for a recipient resource. 
     *
     *  @return the resource query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRecipientQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecipientQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceQuery getRecipientQuery();


    /**
     *  Clears the recipient terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRecipientTerms();


    /**
     *  Matches the receipt of the message. 
     *
     *  @param  receiptId <code> Id </code> to match 
     *  @param  match <code> true </code> if for a positive match, <code> 
     *          false </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> receiptId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchReceiptId(org.osid.id.Id receiptId, boolean match);


    /**
     *  Clears the receipt <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearReceiptIdTerms();


    /**
     *  Tests if a <code> ReceiptQuery </code> is available for querying 
     *  receipts. 
     *
     *  @return <code> true </code> if a receipt query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsReceiptQuery();


    /**
     *  Gets the query for the receipt. 
     *
     *  @return the receipt query 
     *  @throws org.osid.UnimplementedException <code> supportsReceiptQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsReceiptQuery() </code> is <code> true. </code> 
     */

    public org.osid.messaging.ReceiptQuery getReceiptQuery();


    /**
     *  Matches any received messages. 
     *
     *  @param  match <code> true </code> to match any received messages, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyReceipt(boolean match);


    /**
     *  Clears the receipt terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearReceiptTerms();


    /**
     *  Sets the mailbox <code> Id </code> for this query. 
     *
     *  @param  mailboxId the mailbox <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> mailboxId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMailboxId(org.osid.id.Id mailboxId, boolean match);


    /**
     *  Clears the mailbox <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMailboxIdTerms();


    /**
     *  Tests if a <code> MailboxQuery </code> is available. 
     *
     *  @return <code> true </code> if a mailbox query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMailboxQuery();


    /**
     *  Gets the query for a mailbox. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the mailbox query 
     *  @throws org.osid.UnimplementedException <code> supportsMailboxQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMailboxQuery() </code> is <code> true. </code> 
     */

    public org.osid.messaging.MailboxQuery getMailboxQuery();


    /**
     *  Clears the mailbox terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMailboxTerms();


    /**
     *  Gets the message query record corresponding to the given <code> 
     *  Message </code> record <code> Type. </code> Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @param  messageRecordType a message record type 
     *  @return the message query record 
     *  @throws org.osid.NullArgumentException <code> messageRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(messageRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.records.MessageQueryRecord getMessageQueryRecord(org.osid.type.Type messageRecordType)
        throws org.osid.OperationFailedException;
}
