//
// org.osid.messaging.MessagingManager
//
//     The OSID Java specification for org.osid.messaging.MessagingManager.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.messaging;


/**
 *  <p>The message manager provides access to message lookup and creation 
 *  sessions and provides interoperability tests for various aspects of this 
 *  service. The sessions included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> MessagingSession: </code> a session to send messages </li> 
 *      <li> <code> MessageLookupSession: </code> a session to retrieve 
 *      messages </li> 
 *      <li> <code> MessageQuerySession: </code> a session to query for 
 *      messages </li> 
 *      <li> <code> MessageSearchSession: </code> a session to search for 
 *      messages </li> 
 *      <li> <code> MessageAdminSession: </code> a session to create and 
 *      delete messages </li> 
 *      <li> <code> MessageNotificationSession: </code> a session to receive 
 *      notifications pertaining to message changes </li> 
 *      <li> <code> MessageMailboxSession: </code> a session to look up 
 *      message to mailbox mappings </li> 
 *      <li> <code> MessageMailboxAssignmentSession: </code> a session to 
 *      manage message to mailbox mappings </li> 
 *      <li> <code> MessageSmartMailboxSession: </code> a session to manage 
 *      dynamic mailboxes of messages </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> ReceiptLookupSession: a </code> session to retrieve 
 *      message receipts </li> 
 *      <li> <code> ReceiptAdminSession: </code> a session to update message 
 *      receipts </li> 
 *      <li> <code> ReceiptNotificationSession: </code> a session to receive 
 *      notifications pertaining to changes in message receipts </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> MailboxLookupSession: a </code> session to retrieve 
 *      mailboxes </li> 
 *      <li> <code> MailboxQuerySession: </code> a session to query mailboxes 
 *      </li> 
 *      <li> <code> MailboxSearchSession: </code> a session to search for 
 *      mailboxes </li> 
 *      <li> <code> MailboxAdminSession: </code> a session to create, update 
 *      and delete mailboxes </li> 
 *      <li> <code> MailboxNotificationSession: </code> a session to receive 
 *      notifications pertaining to changes in mailboxes </li> 
 *      <li> <code> MailboxHierarchySession: </code> a session to traverse 
 *      mailbox hierarchies </li> 
 *      <li> <code> MailboxHierarchyDesignSession: </code> a session to manage 
 *      mailbox hierarchies </li> 
 *  </ul>
 *  
 */

public interface MessagingManager
    extends org.osid.OsidManager,
            org.osid.messaging.MessagingProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the message 
     *  sending. 
     *
     *  @return <code> a MessagingSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsMessaging() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMessaging() </code> is <code> true. </code> 
     */

    public org.osid.messaging.MessagingSession getMessagingSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the message lookup 
     *  service. 
     *
     *  @return <code> a MessageLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsMessageLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMessageLookup() </code> is <code> true. </code> 
     */

    public org.osid.messaging.MessageLookupSession getMessageLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the message lookup 
     *  service for the given mailbox. 
     *
     *  @param  mailboxId the <code> Id </code> of the mailbox 
     *  @return <code> a MessageLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> mailboxId </code> not found 
     *  @throws org.osid.NullArgumentException <code> mailboxId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsMessageLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMessageLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.messaging.MessageLookupSession getMessageLookupSessionForMailbox(org.osid.id.Id mailboxId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the message query 
     *  service. 
     *
     *  @return a <code> MessageQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsMessageQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMessageQuery() </code> is <code> true. </code> 
     */

    public org.osid.messaging.MessageQuerySession getMessageQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the message query 
     *  service for the given mailbox. 
     *
     *  @param  mailboxId the <code> Id </code> of the <code> Mailbox </code> 
     *  @return a <code> MessageQuerySession </code> 
     *  @throws org.osid.NotFoundException no mailbox found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> mailboxId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsMessageQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMessageQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.messaging.MessageQuerySession getMessageQuerySessionForMailbox(org.osid.id.Id mailboxId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets a message search session. 
     *
     *  @return <code> a MessageSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsMessageSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMessageSearch() </code> is <code> true. </code> 
     */

    public org.osid.messaging.MessageSearchSession getMessageSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a message search session for the given mailbox. 
     *
     *  @param  mailboxId the <code> Id </code> of the mailbox 
     *  @return <code> a MessageSearchSession </code> 
     *  @throws org.osid.NotFoundException <code> mailboxId </code> not found 
     *  @throws org.osid.NullArgumentException <code> mailboxId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsMessageSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMessageSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.messaging.MessageSearchSession getMessageSearchSessionForMailbox(org.osid.id.Id mailboxId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets a message administration session for creating, updating and 
     *  deleting messages. 
     *
     *  @return <code> a MessageAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsMessageAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMessageAdmin() </code> is <code> true. </code> 
     */

    public org.osid.messaging.MessageAdminSession getMessageAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a message administration session for the given mailbox. 
     *
     *  @param  mailboxId the <code> Id </code> of the mailbox 
     *  @return <code> a MessageAdminSession </code> 
     *  @throws org.osid.NotFoundException <code> mailboxId </code> not found 
     *  @throws org.osid.NullArgumentException <code> mailboxId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsMessageAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMessageAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.messaging.MessageAdminSession getMessageAdminSessionForMailbox(org.osid.id.Id mailboxId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to message 
     *  changes. 
     *
     *  @param  messageReceiver the notification callback 
     *  @return <code> a MessageNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> messageReceiver </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsMessageNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMessageNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.messaging.MessageNotificationSession getMessageNotificationSession(org.osid.messaging.MessageReceiver messageReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the message notification session for the given mailbox. 
     *
     *  @param  messageReceiver the notification callback 
     *  @param  mailboxId the <code> Id </code> of the mailbox 
     *  @return <code> a MessageNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> mailboxId </code> not found 
     *  @throws org.osid.NullArgumentException <code> messageReceiver </code> 
     *          or <code> mailboxId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsMessageNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMessageNotfication() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.messaging.MessageNotificationSession getMessageNotificationSessionForMailbox(org.osid.messaging.MessageReceiver messageReceiver, 
                                                                                                 org.osid.id.Id mailboxId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving message to mailbox mappings. 
     *
     *  @return a <code> MessageMailboxSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsMessageMailbox() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMessageMailbox() </code> is <code> true. </code> 
     */

    public org.osid.messaging.MessageMailboxSession getMessageMailboxSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning message to mailbox mappings. 
     *
     *  @return a <code> MessageMailboxAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsMessageMailboxAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMessageMailboxAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.messaging.MessageMailboxAssignmentSession getMessageMailboxAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage locatin smart mailboxes. 
     *
     *  @param  mailboxId the <code> Id </code> of the mailbox 
     *  @return a <code> MessageSmartMailboxSession </code> 
     *  @throws org.osid.NotFoundException <code> mailboxId </code> not found 
     *  @throws org.osid.NullArgumentException <code> mailboxId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsMessageSmartMailbox() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMessageSmartMailbox() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.messaging.MessageSmartMailboxSession getMessageSmartMailboxSession(org.osid.id.Id mailboxId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the receipt lookup 
     *  service. 
     *
     *  @return <code> a ReceiptLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsReceiptLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsReceiptLookup() </code> is <code> true. </code> 
     */

    public org.osid.messaging.ReceiptLookupSession getReceiptLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the receipt lookup 
     *  service for the given mailbox. 
     *
     *  @param  mailboxId the <code> Id </code> of the mailbox 
     *  @return <code> a ReceiptLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> mailboxId </code> not found 
     *  @throws org.osid.NullArgumentException <code> mailboxId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsReceiptLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsReceiptLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.messaging.ReceiptLookupSession getReceiptLookupSessionForMailbox(org.osid.id.Id mailboxId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the receipt 
     *  administrative service. 
     *
     *  @return <code> a ReceiptAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsReceiptAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsReceiptAdmin() </code> is <code> true. </code> 
     */

    public org.osid.messaging.ReceiptAdminSession getReceiptAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the receipt 
     *  administrative service for the given mailbox. 
     *
     *  @param  mailboxId the <code> Id </code> of the mailbox 
     *  @return <code> a ReceiptAdminSession </code> 
     *  @throws org.osid.NotFoundException <code> mailboxId </code> not found 
     *  @throws org.osid.NullArgumentException <code> mailboxId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsReceiptAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsReceiptAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.messaging.ReceiptAdminSession getReceiptAdminSessionForMailbox(org.osid.id.Id mailboxId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to receipt 
     *  changes. 
     *
     *  @param  receiptReceiver the notification callback 
     *  @return <code> a ReceiptNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> receiptReceiver </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsReceiptNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsreceiptNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.messaging.ReceiptNotificationSession getReceiptNotificationSession(org.osid.messaging.ReceiptReceiver receiptReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the receipt notification session for the given mailbox. 
     *
     *  @param  receiptReceiver the notification callback 
     *  @param  mailboxId the <code> Id </code> of the mailbox 
     *  @return <code> a ReceiptNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> mailboxId </code> not found 
     *  @throws org.osid.NullArgumentException <code> receiptReceiver </code> 
     *          or <code> mailboxId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsReceiptNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsReceiptNotfication() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.messaging.ReceiptNotificationSession getReceiptNotificationSessionForMailbox(org.osid.messaging.ReceiptReceiver receiptReceiver, 
                                                                                                 org.osid.id.Id mailboxId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the mailbox lookup session. 
     *
     *  @return a <code> MailboxLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsMailboxLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMailboxLookup() </code> is <code> true. </code> 
     */

    public org.osid.messaging.MailboxLookupSession getMailboxLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the mailbox query session. 
     *
     *  @return a <code> MailboxQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsMailboxQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMailboxQuery() </code> is <code> true. </code> 
     */

    public org.osid.messaging.MessageQuerySession getMailboxQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the mailbox search session. 
     *
     *  @return a <code> MailboxSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsMailboxSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMailboxSearch() </code> is <code> true. </code> 
     */

    public org.osid.messaging.MailboxSearchSession getMailboxSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the mailbox administrative session for creating, updating and 
     *  deleteing mailboxes. 
     *
     *  @return a <code> MailboxAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsMailboxAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMailboxAdmin() </code> is <code> true. </code> 
     */

    public org.osid.messaging.MailboxAdminSession getMailboxAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the notification session for subscribing to changes to a mailbox. 
     *
     *  @param  mailboxReceiver the notification callback 
     *  @return a <code> MailboxNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> mailboxReceiver </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsMailboxNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMailboxNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.messaging.MailboxNotificationSession getMailboxNotificationSession(org.osid.messaging.MailboxReceiver mailboxReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the mailbox hierarchy traversal session. 
     *
     *  @return <code> a MailboxHierarchySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsMailboxHierarchy() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMailboxHierarchy() </code> is <code> true. </code> 
     */

    public org.osid.messaging.MailboxHierarchySession getMailboxHierarchySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the mailbox hierarchy design session. 
     *
     *  @return a <code> MailboxHierarchyDesignSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsMailboxHierarchyDesign() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMailboxHierarchyDesign() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.messaging.MailboxHierarchyDesignSession getMailboxHierarchyDesignSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a <code> MessagingBatchManager. </code> 
     *
     *  @return a <code> MessagingBatchManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsMessagingBatch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMessagingBatch() </code> is <code> true. </code> 
     */

    public org.osid.messaging.batch.MessagingBatchManager getMessagingBatchManager()
        throws org.osid.OperationFailedException;
}
