//
// org.osid.messaging.ReceiptAdminSession
//
//     The OSID Java specification for org.osid.messaging.ReceiptAdminSession.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.messaging;


/**
 *  <p>This session updates <code> Receipts. </code> A receipt exists for all 
 *  messages where receipts are supported. The data for the update is provided 
 *  by the consumer via the form object. <code> OsidForms </code> are 
 *  requested for each update and may not be reused. </p> 
 *  
 *  <p> <code> ReciptForms </code> are requested to the <code> Receipt </code> 
 *  <code> Id </code> that is to be updated using <code> 
 *  getReciptFormForUpdate(). </code> Similarly, the <code> ReceiptForm 
 *  </code> has metadata about the data that can be updated and it can perform 
 *  validation before submitting the update. The <code> RecieptForm </code> 
 *  can only be used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface ReceiptAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Mailbox </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Mailbox Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getMailboxId();


    /**
     *  Gets the <code> Mailbox </code> associated with this session. 
     *
     *  @return the <code> Mailbox </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.Mailbox getMailbox()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Receipts. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> Receipt </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer update operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Receipt </code> modification is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateReceipts();


    /**
     *  Gets the receipt form for updating an existing receipt. A new receipt 
     *  form should be requested for each update transaction. 
     *
     *  @param  receiptId the <code> Id </code> of the <code> Message </code> 
     *  @return the receipt form 
     *  @throws org.osid.NotFoundException <code> receiptId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> receiptId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.ReceiptForm getReceiptFormForUpdate(org.osid.id.Id receiptId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing receipt. 
     *
     *  @param  receiptForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> receiptForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> receiptForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> receiptForm </code> did 
     *          not originate from <code> getReceiptFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateReceipt(org.osid.messaging.ReceiptForm receiptForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
