//
// org.osid.messaging.ReceiptLookupSession
//
//     The OSID Java specification for org.osid.messaging.ReceiptLookupSession.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.messaging;


/**
 *  <p>This session defines methods for retrieving receipts to messages. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated mailbox view: All receipt methods in this session 
 *      operate, retrieve and pertain to receipts and messages defined 
 *      explicitly in the current mailbox. </li> 
 *      <li> federated mailbox view: All receipt methods in this session 
 *      operate, retrieve and pertain to all receipts and messages defined in 
 *      this mailbox and any other messages implicitly available in this 
 *      mailbox through mailbox inheritence. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedReceiptView() </code> and <code> 
 *  useIsolatedReceiptView() </code> behave as a radio group and one should be 
 *  selected before invoking any lookup methods. </p> 
 *  
 *  <p> Messages may have an additional records indicated by their respective 
 *  record types. The record may not be accessed through a cast of the <code> 
 *  Message. </code> </p>
 */

public interface ReceiptLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Mailbox </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Mailbox Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getMailboxId();


    /**
     *  Gets the <code> Mailbox </code> associated with this session. 
     *
     *  @return the <code> Mailbox </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.Mailbox getMailbox()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Receipt </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer lookup operations. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupReceipts();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeReceiptView();


    /**
     *  A complete view of the <code> Receipt </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryReceiptView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include receipts in mailboxes which are children of this mailbox in 
     *  the mailbox hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedMailboxView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this mailbox only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedMailboxView();


    /**
     *  Gets the <code> Receipt </code> specified by its <code> Id. </code> In 
     *  plenary mode, the exact <code> Id </code> is found or a <code> 
     *  NOT_FOUND </code> results. Otherwise, the returned <code> Receipt 
     *  </code> may have a different <code> Id </code> than requested, such as 
     *  the case where a duplicate <code> Id </code> was assigned to a <code> 
     *  Receipt </code> and retained for compatibility. 
     *
     *  @param  receiptId the <code> Id </code> of the <code> Receipt </code> 
     *          to retrieve 
     *  @return the returned <code> Receipt </code> 
     *  @throws org.osid.NotFoundException no <code> Receipt </code> found 
     *          with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> receiptId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.Receipt getReceipt(org.osid.id.Id receiptId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ReceiptList </code> corresponding to the given <code> 
     *  IdList. </code> In plenary mode, the returned list contains all of the 
     *  receipts specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Receipts </code> may be omitted from the list and 
     *  may present the elements in any order including returning a unique 
     *  set. 
     *
     *  @param  receiptIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Receipt list </code> 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> receiptIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.ReceiptList getReceiptsByIds(org.osid.id.IdList receiptIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ReceiptList </code> corresponding to the given receipt 
     *  genus <code> Type </code> which does not include receipts of types 
     *  derived from the specified <code> Type. </code> In plenary mode, the 
     *  returned list contains all known receipts or an error results. 
     *  Otherwise, the returned list may contain only those receipts that are 
     *  accessible through this session. 
     *
     *  @param  receiptGenusType a receipt genus type 
     *  @return the returned <code> Receipts </code> list 
     *  @throws org.osid.NullArgumentException <code> receiptGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.ReceiptList getReceiptsByGenusType(org.osid.type.Type receiptGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ReceiptList </code> corresponding to the given receipt 
     *  genus <code> Type </code> and include any additional receipts with 
     *  genus types derived from the specified <code> Type. </code> In plenary 
     *  mode, the returned list contains all known receipts or an error 
     *  results. Otherwise, the returned list may contain only those receipts 
     *  that are accessible through this session 
     *
     *  @param  receiptGenusType a receipt genus type 
     *  @return the returned <code> Receipts </code> list 
     *  @throws org.osid.NullArgumentException <code> receiptGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.ReceiptList getReceiptsByParentGenusType(org.osid.type.Type receiptGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ReceiptList </code> containing the given receipt record 
     *  <code> Type. </code> In plenary mode, the returned list contains all 
     *  known receipts or an error results. Otherwise, the returned list may 
     *  contain only those receipts that are accessible through this session. 
     *
     *  @param  receiptRecordType a receipt record type 
     *  @return the returned <code> Receipt </code> list 
     *  @throws org.osid.NullArgumentException <code> receiptRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.ReceiptList getReceiptsByRecordType(org.osid.type.Type receiptRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ReceiptList </code> for the given message. <code> 
     *  </code> In plenary mode, the returned list contains all known receipts 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those receipts that are accessible through this session. 
     *
     *  @param  messageId a message <code> Id </code> 
     *  @return the returned <code> Receipt </code> list 
     *  @throws org.osid.NullArgumentException <code> messageId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.ReceiptList getReceiptsForMessage(org.osid.id.Id messageId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ReceiptList </code> for the given recipient. In plenary 
     *  mode, the returned list contains all known receipts or an error 
     *  results. Otherwise, the returned list may contain only those receipts 
     *  that are accessible through this session. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @return the returned <code> Receipts </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.ReceiptList getReceiptsForRecipient(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of <code> Receipts </code> for the given message and 
     *  recipient. In plenary mode, the returned list contains all known 
     *  receipts or an error results. Otherwise, the returned list may contain 
     *  only those receipts that are accessible through this session. 
     *
     *  @param  messageId a message <code> Id </code> 
     *  @param  resourceId a resource <code> Id </code> 
     *  @return the returned <code> Receipt </code> 
     *  @throws org.osid.NullArgumentException <code> messageId </code> or 
     *          <code> recipientId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.ReceiptList getReceiptsForMessageAndRecipient(org.osid.id.Id messageId, 
                                                                            org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Receipts. </code> In plenary mode, the returned list 
     *  contains all known receipts or an error results. Otherwise, the 
     *  returned list may contain only those receipts that are accessible 
     *  through this session. 
     *
     *  @return the returned <code> Receipt </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.ReceiptList getReceipts()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
