//
// org.osid.messaging.ReceiptNotificationSession
//
//     The OSID Java specification for org.osid.messaging.ReceiptNotificationSession.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.messaging;


/**
 *  <p>This session defines methods to receive notifications on new and 
 *  changed <code> Receipts </code> in this <code> Mailbox. </code> This also 
 *  includes existing receipts that may appear or disappear due to changes in 
 *  the <code> Mailbox </code> hierarchy, This session is intended for 
 *  consumers needing to synchronize their receipts with this service without 
 *  the use of polling. Notifications are cancelled when this session is 
 *  closed. </p> 
 *  
 *  <p> The two views defined in this session correspond to the views in the 
 *  <code> ReceiptLookupSession. </code> </p>
 */

public interface ReceiptNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Mailbox </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Mailbox Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getMailboxId();


    /**
     *  Gets the <code> Mailbox </code> associated with this session. 
     *
     *  @return the <code> Mailbox </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.Mailbox getMailbox()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can register for <code> Receipt </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForReceiptNotifications();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include receipts in mailboxes which are children of this mailbox in 
     *  the mailbox hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedMailboxView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts notifications to this mailbox only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedMailboxView();


    /**
     *  Register for notifications of new receipts. <code> 
     *  ReceiptReceiver.newReceipts() </code> is invoked when a new <code> 
     *  Receipt </code> is appears in this mailbox. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewReceipts()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new receipts for the specified message. 
     *  <code> ReceiptReceiver.newReceipts() </code> is invoked when a new 
     *  <code> Receipt </code> is appears in this mailbox. 
     *
     *  @param  messageId the <code> Id </code> of the <code> Message </code> 
     *          to monitor 
     *  @throws org.osid.NullArgumentException <code> messageId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewReceiptsForMessage(org.osid.id.Id messageId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new receipts for the specified 
     *  recipient. <code> ReceiptReceiver.newReceipst() </code> is invoked 
     *  when a new <code> Receipt </code> is appears in this mailbox. 
     *
     *  @param  recipientId the <code> Id </code> of the <code> Resource 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> recipientId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewReceiptsByRecipient(org.osid.id.Id recipientId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated receipts. <code> 
     *  ReceiptReceiver.changedReceipts() </code> is invoked when a receipt in 
     *  this mailbox is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedReceipts()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of updated receipts for the specified 
     *  message. <code> ReceiptReceiver.changedReceipts() </code> is invoked 
     *  when a <code> Receipt </code> in this mailbox is changed. 
     *
     *  @param  messageId the <code> Id </code> of the <code> Message </code> 
     *          to monitor 
     *  @throws org.osid.NullArgumentException <code> messageId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedReceiptsForMessage(org.osid.id.Id messageId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of updated receipts for the specified 
     *  recipient. <code> ReceiptReceiver.changedReceipts() </code> is invoked 
     *  when a <code> Receipt </code> in this mailbox is changed. 
     *
     *  @param  recipientId the <code> Id </code> of the <code> Resource 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> recipientId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedReceiptsByRecipient(org.osid.id.Id recipientId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated receipt. <code> 
     *  ReceiptReceiver.changedReceipt() </code> is invoked when the specified 
     *  receipt in this mailbox is changed. 
     *
     *  @param  receiptId the <code> Id </code> of the <code> Receipt </code> 
     *          to monitor 
     *  @throws org.osid.NullArgumentException <code> receiptId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedReceipt(org.osid.id.Id receiptId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of receipts whose messages have been 
     *  deleted or removed from this mailbox. <code> 
     *  ReceiptReceiver.deletedReceipts() </code> is invoked when a receipt is 
     *  deleted or removed from this mailbox. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedReceipts()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of deleted receipts for the specified 
     *  message. <code> ReceiptReceiver.deletedReceipts() </code> is invoked 
     *  when a <code> Receipt </code> in this mailbox is removed. 
     *
     *  @param  messageId the <code> Id </code> of the <code> Message </code> 
     *          to monitor 
     *  @throws org.osid.NullArgumentException <code> messageId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedReceiptsForMessage(org.osid.id.Id messageId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of deleted receipts for the specified 
     *  recipient. <code> ReceiptReceiver.deletedReceipts() </code> is invoked 
     *  when a <code> Receipt </code> in this mailbox is removed. 
     *
     *  @param  recipientId the <code> Id </code> of the <code> Resource 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> recipientId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedReceiptsByRecipient(org.osid.id.Id recipientId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted receipt. <code> 
     *  MessageReceiver.deletedReceipts() </code> is invoked when the 
     *  specified receipt is deleted or removed from this mailbox. 
     *
     *  @param  receiptId the <code> Id </code> of the <code> Receipt </code> 
     *          to monitor 
     *  @throws org.osid.NullArgumentException <code> receiptId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedReceipt(org.osid.id.Id receiptId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
