//
// org.osid.messaging.batch.ReceiptBatchAdminSession
//
//     The OSID Java specification for org.osid.messaging.batch.ReceiptBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.messaging.batch;


/**
 *  <p>This session updates <code> Receipts </code> in bulk. The data for 
 *  update is provided by the consumer via the form object. <code> OsidForms 
 *  </code> are requested for each update and may not be reused. </p> 
 *  
 *  <p> For updates, <code> ReceiptForms </code> are requested to the <code> 
 *  Receipt </code> <code> Id </code> that is to be updated using <code> 
 *  getReceiptFormsForUpdate() </code> where the reference <code> Id </code> 
 *  in the <code> ReceiptForm </code> may be used to link the request. 
 *  Similarly, the <code> ReceiptForm </code> has metadata about the data that 
 *  can be updated and it can perform validation before submitting the update. 
 *  The <code> ReceiptForm </code> can only be used once for a successful 
 *  update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> ReceiptForms </code> are submitted for update, 
 *  an <code> UpdateResponse </code> is returned for each <code> ReceiptForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire update operation are returned from <code> updateReceipts(), 
 *  </code> errors specific to an individual <code> ReceiptForm </code> are 
 *  indicated in the corresponding <code> UpdateResponse. </code> <code> 
 *  UpdateResponses </code> may be linked to the originating <code> 
 *  ReceiptForm </code> through the <code> ReceiptForm </code> <code> Id. 
 *  </code> </p>
 */

public interface ReceiptBatchAdminSession
    extends org.osid.messaging.ReceiptAdminSession {


    /**
     *  Gets the receipt forms for updating an existing set of receipts. A new 
     *  receipt form should be requested for each update transaction. 
     *
     *  @param  receiptIds the <code> Ids </code> of the <code> Receipts 
     *          </code> 
     *  @return the receipt form 
     *  @throws org.osid.NotFoundException a <code> receiptId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> receiptIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.batch.ReceiptBatchFormList getReceiptFormsForUpdate(org.osid.id.IdList receiptIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing receipts. This method returns an error if the entire 
     *  operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  receiptForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> receiptForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateReceipts(org.osid.messaging.batch.ReceiptBatchFormList receiptForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
