/**
 * <p>The Open Service Interface Definitions for the org.osid.messaging
 * service.</p>
 * 
 * <p>The Messaging OSID sends and receives messages. </p> 
 * <h4> Messages </h4> 
 * 
 * <p> <code> Messages </code> are structures that include a sender, 
 * recipients, and a timestamp. A <code> Message </code> is created using a 
 * <code> MessageAdminSession. </code> The text of the <code> Message </code> 
 * is displayable as text and may include a specific structure defined using a 
 * <code> MessageRecord. </code> </p> 
 * 
 * <p> Until a <code> Message </code> is sent, it is stored and may be edited 
 * as a draft. Once a <code> Message </code> is sent, the <code> Message 
 * </code> includes the sending <code> Agent </code> as well as the addressed 
 * recipients represented by a list of <code> Resources. </code> A <code> 
 * Message </code> is received by a receiving <code> Agent </code> which 
 * generally is related to one of the recipients. </p> 
 * <h4> Sending Messages </h4> 
 * 
 * <p> Once a Message has been created, it may be sent from the authenticated 
 * <code> Agent to a specified list of recipients </code> using the <code> 
 * MessagingSession. </code> The same <code> Message </code> may be sent to 
 * additional recipients by returning to the <code> MessagingSession </code> 
 * and using the same <code> Message </code> <code> Id. </code> </p> 
 * <h4> Receiving Messages </h4> 
 * 
 * <p> The <code> MessageLookupSession </code> can be used to retrieve 
 * incoming <code> Messages. </code> From the point of view of the receiving 
 * <code> Agent, </code> <code> Messages </code> from the <code> 
 * MessageLookupSession </code> indicate a foreign <code> Agent </code> as the 
 * sender and at least one recipient related to the authenticated <code> Agent 
 * </code> which generally, but may not always, be the receiving <code> Agent. 
 * </code> </p> 
 * 
 * <p> The same interfaces are used to receive <code> Messages </code> as well 
 * as examine created <code> Messages. </code> The <code> Messages </code> 
 * seen in the <code> MessageLookupSession </code> vary depending on the point 
 * of view implied by the <code> Mailbox </code> catalog. </p> 
 * <h4> Message Receipts </h4> 
 * 
 * <p> Once a <code> Message </code> has been received by a receiving <code> 
 * Agent, </code> a <code> Receipt </code> is be generated to include the time 
 * receive and the receiving <code> Agent. </code> A <code> Receipt </code> 
 * can be used to store additional data related to the received <code> 
 * Message. </code> </p> 
 * 
 * <p> <code> Receipts </code> may only be visible to the receiving <code> 
 * Agent </code> or a Messaging OSID Provider may authorize <code> Receipts 
 * </code> to be visible to the sender or other parties. </p> 
 * <h4> Mailbox Catalogs </h4> 
 * 
 * <p> <code> Messages </code> are cataloged using <code> Mailboxes. </code> 
 * Mailboxes be may used to store messages for different users, and may also 
 * be used to provide message folders for each user. Like all <code> 
 * OsidCatalogs, </code> a <code> Mailbox </code> may belong to a federated 
 * hierarchy to provide fedeated and filtering views among multiple mailboxes. 
 * </p> 
 * <h4> On Resource & Agents </h4> 
 * 
 * <p> The <code> Agent </code> is the identity of an authenticated actor 
 * while the <code> Resource </code> represents a real-world entity such as a 
 * person or organization. The mapping between <code> Agents </code> and 
 * <code> Resources </code> is managed by the Resource OSID. In the Messaging 
 * OSID, an <code> Agent </code> sends a <code> Message </code> to a <code> 
 * Resource, </code> However, aspects of the service also examine messages 
 * from the recipient's point of view where the sender appears as an object 
 * instead of an actor. The Messaging OSID references both a sender as a 
 * <code> Resource </code> and asending agent as an <code> Agent. </code> The 
 * Messaging OSID Provider orchestrates the mapping between <code> Agents 
 * </code> and <code> Resources </code> as a messaging application would 
 * access a local address book for looking up full names corresponding to 
 * incoming email addresses. </p> 
 * <h4> Sub Packages </h4> 
 * 
 * <p> The Messaging OSID contains a Messaging Batch OSID for managing <code> 
 * Messages </code> and <code> Mailboxes </code> in bulk. </p>
 * 
 * <br/><hr/><br/>
 * 
 * <p>Copyright &copy; 2002-2004, 2008 Massachusetts Institute of Technology. 
 * </p> 
 * 
 * <p> Copyright &copy; 2011 Ingeenscus. All Rights Reserved. </p>
 * 
 * <p>This Work is being provided by the copyright holder(s) subject to the 
 * following license. By obtaining, using and/or copying this Work, you agree 
 * that you have read, understand, and will comply with the following terms 
 * and conditions. </p> 
 * 
 * <p> Permission to use, copy and distribute unmodified versions of this 
 * Work, for any purpose, without fee or royalty is hereby granted, provided 
 * that you include the above copyright notices and the terms of this license 
 * on ALL copies of the Work or portions thereof. </p> 
 * 
 * <p> You may nodify or create Derivatives of this Work only for your 
 * internal purposes. You shall not distribute or transfer any such Derivative 
 * of this Work to any location or to any third party. For the purposes of 
 * this license, "Derivative" shall mean any derivative of the Work as defined 
 * in the United States Copyright Act of 1976, such as a translation or 
 * modification. </p> 
 * 
 * <p> This Work and the information contained herein is provided on an "AS 
 * IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT 
 * NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR 
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT 
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN 
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN 
 * CONNECTION WITH THE WORK OR THE USE OR OTHER DEALINGS IN THE WORK. </p> 
 * 
 * <p> The export of software employing encryption technology may require a 
 * specific license from the United States Government. It is the 
 * responsibility of any person or organization contemplating export to obtain 
 * such a license before exporting this Work. </p>
 */

package org.osid.messaging;
