//
// OsidInterface.java
//
//     Represents an OSID interface.
//
//
// Tom Coppeto
// OnTapSolutions
// 4 January 2009
//
// Copyright (c) 2009 Ingenescus. All Rights Reserved.
//
//      Permission is hereby granted, free of charge, to any person
//      obtaining a copy of this software and associated documentation
//      files (the "Software"), to deal in the Software without
//      restriction, including without limitation the rights to use,
//      copy, modify, merge, publish, distribute, sublicesne, and/or
//      sell copies of the Software, and to permit the persons to whom
//      the Software is furnished to do so, subject the following
//      conditions:
//
//      The above copyright notice and this permission notice shall be
//      included in all copies or substantial portions of the
//      Software.
//
//      The Software is provided "AS IS", WITHOUT WARRANTY OF ANY
//      KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
//      WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
//      PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
//      COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//      LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
//      OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
//      SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

package org.osid.meta;


/**
 *  Represents an OSID interface. 
 */

public class OsidInterface {    
    private final String name;
    private boolean deprecated;
    private boolean newInterface;
    private String asOf;
    private final java.util.Map<String, OsidMethod> methods = java.util.Collections.synchronizedMap(new java.util.LinkedHashMap<String, OsidMethod>());


    /**
     *  Constructs a new <code>OsidInterface</code>.
     *
     *  @param name the name of the interface
     */

    protected OsidInterface(String name) {
        this.name = name;
        return;
    }

    
    /**
     *  Gets the name of this interface.
     *
     *  @return the interface name
     */

    public String getName() {
        return (this.name);
    }


    /**
     *  Tests if the interface is specified as deprecated.
     *
     *  @return <code>true</code> if the interface is deprecated,
     *          <code>false</code> otherwise
     */

    public boolean isDeprecated() {
        return (this.deprecated);
    }

    
    protected void setDeprecated(String asOf) {
        this.deprecated = true;
        this.asOf = asOf;
        return;
    }


    /**
     *  Tests if the interface is specified as new.
     *
     *  @return <code>true</code> if the interface is new,
     *          <code>false</code> otherwise
     */

    public boolean isNew() {
        return (this.newInterface);
    }

    
    protected void setNew(String asOf) {
        this.newInterface = true;
        this.asOf = asOf;
        return;
    }


    /**
     *  Gets all methods defined in this interface.
     *
     *  @return the methods
     */
    
    public java.util.Collection<OsidMethod> getMethods() {
        java.util.Collection<OsidMethod> methods = new java.util.ArrayList<>();
        for (String key : this.methods.keySet()) {
            methods.add(this.methods.get(key));
        }

        return (methods);
    }


    /**
     *  Gets a method defined in this interface.
     *
     *  @param name the name of the method to retrieve
     *  @return the method or <code>null</code> if not found
     */
    
    public OsidMethod getMethod(String name) {
        return (this.methods.get(name));
    }


    /*
     *  Adds a method to this interface.
     *
     *  @param method
     */

     protected void addMethod(OsidMethod method) {
        this.methods.put(method.getName(), method);
        return;
    }
}
    
