//
// OsidMethod.java
//
//     The structure of an OSID method.
//
//
// Tom Coppeto
// OnTapSolutions
// 4 January 2009
//
// Copyright (c) 2009 Massachusetts Institute of Technology. All Rights
// Reserved.
//
//      Permission is hereby granted, free of charge, to any person
//      obtaining a copy of this software and associated documentation
//      files (the "Software"), to deal in the Software without
//      restriction, including without limitation the rights to use,
//      copy, modify, merge, publish, distribute, sublicesne, and/or
//      sell copies of the Software, and to permit the persons to whom the
//      Software is furnished to do so, subject the following conditions:
//
//      The above copyright notice and this permission notice shall be
//      included in all copies or substantial portions of the Software.
//
//      The Software is provided "AS IS", WITHOUT WARRANTY OF ANY KIND,
//      EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
//      OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
//      NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
//      HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
//      WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
//      OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
//      DEALINGS IN THE SOFTWARE.
//

package org.osid.meta;


/**
 *  Describes the structure of an OSID method.
 */

public class OsidMethod {
    private final String name;
    private final java.util.Collection<OsidParameter> parameters = new java.util.ArrayList<OsidParameter>();
    private final java.util.Collection<String> errors = new java.util.ArrayList<>();
    private OsidReturn returns;
    private boolean mandatory;
    private boolean deprecated;
    private boolean newMethod;
    private String asOf;


    /**
     *  Constructs a new <code>OsidMethod</code>.
     *
     *  @param name method name
     */

    protected OsidMethod(String name) {
        this.name = name;
        return;
    }


    /**
     *  Gets the method name.
     *
     *  @return name of method
     */

    public String getName() {
        return (this.name);
    }


    /**
     *  Gets the method return.
     *
     *  @return the return or <code>null</code> if none
     */

    public OsidReturn getReturn() {
        return (this.returns);
    }

    
    protected void setReturn(OsidReturn ret) {
        this.returns = ret;
        return;
    }


    /**
     *  Gets the method paramerers.
     *
     *  @return the parameters or <code>null</code> if none
     */

    public java.util.Collection<OsidParameter> getParameters() {
        return (java.util.Collections.unmodifiableCollection(this.parameters));
    }


    protected void addParameter(OsidParameter parameter) {
        this.parameters.add(parameter);
        return;
    }


    /**
     *  Gets the method errors.
     *
     *  @return the errors or <code>null</code> if none
     */

    public java.util.Collection<String> getErrors() {
        return (java.util.Collections.unmodifiableCollection(this.errors));
    }


    protected void addError(String error) {
        this.errors.add(error);
        return;
    }


    /**
     *  Tests if the method is specified as mandatory.
     *
     *  @return <code>true</code> if the method is mandatory,
     *          <code>false</code> otherwise
     */

    public boolean isMandatory() {
        return (this.mandatory);
    }

    
    protected void setMandatory(boolean mandatory) {
        this.mandatory = mandatory;
        return;
    }


    /**
     *  Tests if the method is specified as deprecated.
     *
     *  @return <code>true</code> if the method is deprecated,
     *          <code>false</code> otherwise
     */

    public boolean isDeprecated() {
        return (this.deprecated);
    }

    
    protected void setDeprecated(String asOf) {
        this.deprecated = true;
        this.asOf = asOf;
        return;
    }


    /**
     *  Tests if the method is specified as new.
     *
     *  @return <code>true</code> if the method is new,
     *          <code>false</code> otherwise
     */

    public boolean isNew() {
        return (this.newMethod);
    }

    
    protected void setNew(String asOf) {
        this.newMethod = true;
        this.asOf = asOf;
        return;
    }
}


    
    
    
    

    
    