//
// org.osid.metering.MeterUtilityAssignmentSession
//
//     The OSID Java specification for org.osid.metering.MeterUtilityAssignmentSession.
//
// Copyright (C) 2009-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.metering;


/**
 *  <p>This session provides methods to re-assign <code> Meters </code> to 
 *  <code> Utility </code> objects A <code> Meter </code> may appear in 
 *  multiple <code> Utility </code> objects and removing the last reference to 
 *  a <code> Meter </code> is the equivalent of deleting it. Each <code> 
 *  Utility </code> may have its own authorizations governing who is allowed 
 *  to operate on it. </p> 
 *  
 *  <p> Moving or adding a reference of a <code> Meter </code> to another 
 *  <code> Utility </code> is not a copy operation (eg: does not change its 
 *  <code> Id </code> ). </p>
 */

public interface MeterUtilityAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter meter/utility mappings. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignMeters();


    /**
     *  Tests if this user can alter meter/utility mappings. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED </code> . This is intended as a hint to 
     *  an application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @param  utilityId the <code> Id </code> of the <code> Utility </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> utilityId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignMetersToUtility(org.osid.id.Id utilityId);


    /**
     *  Gets a list of utilities including and under the given utility node in 
     *  which any meter can be assigned. 
     *
     *  @param  utilityId the <code> Id </code> of the <code> Utility </code> 
     *  @return list of assignable utility <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> utilityId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableUtilityIds(org.osid.id.Id utilityId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of utilities including and under the given utility node in 
     *  which a specific meter can be assigned. 
     *
     *  @param  utilityId the <code> Id </code> of the <code> Utility </code> 
     *  @param  meterId the <code> Id </code> of the <code> Meter </code> 
     *  @return list of assignable utility <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> utility </code> or 
     *          <code> meterId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableUtilityIdsForMeter(org.osid.id.Id utilityId, 
                                                              org.osid.id.Id meterId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> Meter </code> to a <code> Utility. </code> 
     *
     *  @param  meterId the <code> Id </code> of the <code> Meter </code> 
     *  @param  utilityId the <code> Id </code> of the <code> Utility </code> 
     *  @throws org.osid.AlreadyExistsException <code> meterId </code> is 
     *          already assigned to <code> utilityId </code> 
     *  @throws org.osid.NotFoundException <code> meterId </code> or <code> 
     *          utilityId </code> not found 
     *  @throws org.osid.NullArgumentException <code> meterId </code> or 
     *          <code> utilityId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignMeterToUtility(org.osid.id.Id meterId, 
                                     org.osid.id.Id utilityId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> Meter </code> from a <code> Utility. </code> 
     *
     *  @param  meterId the <code> Id </code> of the <code> Meter </code> 
     *  @param  utilityId the <code> Id </code> of the <code> Utility </code> 
     *  @throws org.osid.NotFoundException <code> meterId </code> or <code> 
     *          utilityId </code> not found or <code> meterId </code> not 
     *          assigned to <code> utilityId </code> 
     *  @throws org.osid.NullArgumentException <code> meterId </code> or 
     *          <code> utilityId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignMeterFromUtility(org.osid.id.Id meterId, 
                                         org.osid.id.Id utilityId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
