//
// org.osid.metering.MeteringProxyManager
//
//     The OSID Java specification for org.osid.metering.MeteringProxyManager.
//
// Copyright (C) 2009-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.metering;


/**
 *  <p>The metering manager provides access to metering sessions and provides 
 *  interoperability tests for various aspects of this service. Methods in 
 *  this manager support the passing of a <code> Proxy </code> for the 
 *  purposes of passing information from a server environment. The sessions 
 *  included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> MeterReadingSession: </code> a session to write to a 
 *      utility </li> 
 *      <li> <code> StatisticLookupSession: </code> a session for retrieving 
 *      some statistics from a meter </li> 
 *      <li> <code> StatisticQuerySession: </code> a session for querying 
 *      statistics </li> 
 *      <li> <code> StatisticSearchSession: </code> a session for searching 
 *      statistics </li> 
 *      <li> <code> StatisticNotificationSession: </code> a session for 
 *      subscribing to statistical notifications </li> 
 *      <li> <code> StatisticSmartUtilitySession: </code> a session for 
 *      managing smart utilities of statistics </li> 
 *      <li> <code> MeterLookupSession: </code> a session to look up meters 
 *      </li> 
 *      <li> <code> MeterQuerySession: </code> a session to query meters </li> 
 *      <li> <code> MeterSearchSession: </code> a session to search meters 
 *      </li> 
 *      <li> <code> MeterAdminSession: </code> a session to manage meters 
 *      </li> 
 *      <li> <code> MeterNotificationSession: </code> a session to subscribe 
 *      to notifications of new or changed meters </li> 
 *      <li> <code> MeterUtilitySession: </code> a session to look up meter to 
 *      utility mappings </li> 
 *      <li> <code> MeterUtilityAssignmentSession: </code> a session to manage 
 *      meter to utility mappings </li> 
 *      <li> <code> MeterSmartUtilitySession: </code> a session tomanage meter 
 *      smart utilities </li> 
 *      <li> <code> UtilityLookupSession: </code> a session to retrieve 
 *      utility objects </li> 
 *      <li> <code> UtilityQuerySession: </code> a session to query utilities 
 *      </li> 
 *      <li> <code> UtilitySearchSession: </code> a session to search for 
 *      utilities </li> 
 *      <li> <code> UtilityAdminSession: </code> a session to create, update 
 *      and delete utilities </li> 
 *      <li> <code> UtilityNotificationSession: </code> a session to receive 
 *      notifications for changes in utilities </li> 
 *      <li> <code> UtilityHierarchyTraversalSession: </code> a session to 
 *      traverse hierarchies of utilities </li> 
 *      <li> <code> UtilityHierarchyDesignSession: </code> a session to manage 
 *      hierarchues of utilities </li> 
 *  </ul>
 *  
 *  
 *  <p> The metering manager also provides a profile for determing the 
 *  supported search types supported by this service. </p>
 */

public interface MeteringProxyManager
    extends org.osid.OsidProxyManager,
            org.osid.metering.MeteringProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the meter reading 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> MeterReadingSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsMeterreading() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMeterReading() </code> is <code> true. </code> 
     */

    public org.osid.metering.MeterReadingSession getMeterReadingSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the meter reading 
     *  service for the given utility. 
     *
     *  @param  utilityId the <code> Id </code> of the <code> Utility </code> 
     *  @param  proxy a proxy 
     *  @return a <code> MeterReadingSession </code> 
     *  @throws org.osid.NotFoundException no <code> Utility </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> utilityId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsMeterReading() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMeterReading() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.metering.MeterReadingSession getMeterReadingSessionForUtility(org.osid.id.Id utilityId, 
                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the statistic 
     *  lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> MeterStatisticsSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStatisticLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStatisticLookup() </code> is <code> true. </code> 
     */

    public org.osid.metering.StatisticLookupSession getStatisticLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the statistic 
     *  lookup service for the given utility. 
     *
     *  @param  utilityId the <code> Id </code> of the <code> Utility </code> 
     *  @param  proxy a proxy 
     *  @return a <code> MeterStatisticsSession </code> 
     *  @throws org.osid.NotFoundException no <code> Utility </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> utilityId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStatisticLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStatisticLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.metering.StatisticLookupSession getStatisticLookupSessionForUtility(org.osid.id.Id utilityId, 
                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the statistic 
     *  query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> StatisticQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStatisticQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStatisticQuery() </code> is <code> true. </code> 
     */

    public org.osid.metering.StatisticQuerySession getStatisticQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the statistic 
     *  query service for the given utility. 
     *
     *  @param  utilityId the <code> Id </code> of the <code> Utility </code> 
     *  @param  proxy a proxy 
     *  @return a <code> StatisticQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Utility </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> utilityId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStatisticQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStatisticQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.metering.StatisticQuerySession getStatisticQuerySessionForUtility(org.osid.id.Id utilityId, 
                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the statistic 
     *  search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> StatisticSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStatisticSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStatisticSearch() </code> is <code> true. </code> 
     */

    public org.osid.metering.StatisticSearchSession getStatisticSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the statistic 
     *  search service for the given utility. 
     *
     *  @param  utilityId the <code> Id </code> of the <code> Utility </code> 
     *  @param  proxy a proxy 
     *  @return a <code> StatisticSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Utility </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> utilityId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStatisticSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStatisticSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.metering.StatisticSearchSession getStatisticSearchSessionForUtility(org.osid.id.Id utilityId, 
                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the statistic 
     *  notification service. 
     *
     *  @param  statisticReceiver the receiver 
     *  @param  proxy a proxy 
     *  @return a <code> StatisticNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> statisticReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStatisticNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStatisticNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.metering.StatisticNotificationSession getStatisticNotificationSession(org.osid.metering.StatisticReceiver statisticReceiver, 
                                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the statistic 
     *  notification service for the given utility. 
     *
     *  @param  statisticReceiver the receiver 
     *  @param  utilityId the <code> Id </code> of the <code> Utility </code> 
     *  @param  proxy a proxy 
     *  @return a <code> StatisticNotificationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Utility </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> statisticReceiver, 
     *          utilityId </code> or <code> proxy </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStatisticNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStatisticNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.metering.StatisticNotificationSession getStatisticNotificationSessionForUtility(org.osid.metering.StatisticReceiver statisticReceiver, 
                                                                                                    org.osid.id.Id utilityId, 
                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the statistic 
     *  smart utility session. 
     *
     *  @param  utilityId the <code> Id </code> of the <code> Utility </code> 
     *  @param  proxy a proxy 
     *  @return a <code> StatisticSmartUtilitySession </code> 
     *  @throws org.osid.NotFoundException no <code> Utility </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> utilityId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStatisticSmartUtility() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStatisticSmartUtility() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.metering.StatisticSmartUtilitySession getStatisticSmartUtilitySession(org.osid.id.Id utilityId, 
                                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the meter lookup 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> MeterLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsMeterLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMeterLookup() </code> is <code> true. </code> 
     */

    public org.osid.metering.MeterLookupSession getMeterLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the utility 
     *  reading service for the given utility. 
     *
     *  @param  utilityId the <code> Id </code> of the <code> Utility </code> 
     *  @param  proxy a proxy 
     *  @return a <code> MeterLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Utility </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> utilityId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsMeterLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMeterLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.metering.MeterLookupSession getMeterLookupSessionForUtility(org.osid.id.Id utilityId, 
                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the meter query 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> MeterQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsMeterQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMeterQuery() </code> is <code> true. </code> 
     */

    public org.osid.metering.MeterQuerySession getMeterQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the utility query 
     *  service for the given utility. 
     *
     *  @param  utilityId the <code> Id </code> of the <code> Utility </code> 
     *  @param  proxy a proxy 
     *  @return a <code> MeterQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Utility </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> utilityId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsMeterQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMeterQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.metering.MeterQuerySession getMeterQuerySessionForUtility(org.osid.id.Id utilityId, 
                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the meter search 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> MeterSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsMeterSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMeterSearch() </code> is <code> true. </code> 
     */

    public org.osid.metering.MeterSearchSession getMeterSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the meter search 
     *  service for the given utility. 
     *
     *  @param  utilityId the <code> Id </code> of the <code> Utility </code> 
     *  @param  proxy a proxy 
     *  @return a <code> MeterSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Utility </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> utilityId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsMeterSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMeterSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.metering.MeterSearchSession getMeterSearchSessionForUtility(org.osid.id.Id utilityId, 
                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the meter 
     *  administrative service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> MeterAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsMeterAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMeterAdmin() </code> is <code> true. </code> 
     */

    public org.osid.metering.MeterAdminSession getMeterAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the meter 
     *  administrative service for the given utility. 
     *
     *  @param  utilityId the <code> Id </code> of the <code> Utility </code> 
     *  @param  proxy a proxy 
     *  @return a <code> MeterAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Utility </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> utilityId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsMeterAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMeterAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.metering.MeterAdminSession getMeterAdminSessionForUtility(org.osid.id.Id utilityId, 
                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the meter 
     *  notification service. 
     *
     *  @param  meterReceiver the receiver 
     *  @param  proxy a proxy 
     *  @return a <code> MeterNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> meterReceiver </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsMeterNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMeterNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.metering.MeterNotificationSession getMeterNotificationSession(org.osid.metering.MeterReceiver meterReceiver, 
                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the meter 
     *  notification service for the given utility. 
     *
     *  @param  meterReceiver the receiver 
     *  @param  utilityId the <code> Id </code> of the <code> Utility </code> 
     *  @param  proxy a proxy 
     *  @return a <code> MeterNotificationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Utility </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> meterReceiver, utilityId 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsMeterNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMeterNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.metering.MeterNotificationSession getMeterNotificationSessionForUtility(org.osid.metering.MeterReceiver meterReceiver, 
                                                                                            org.osid.id.Id utilityId, 
                                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with looking up mapping 
     *  of meters and utilities. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> MeterUtilitySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsMeterUtility() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMeterUtility() </code> is <code> true. </code> 
     */

    public org.osid.metering.MeterUtilitySession getMeterUtilitySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with managing the 
     *  mapping of meters and utilities. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> MeterUtilityAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsMeterUtilityAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMeterUtilityAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.metering.MeterUtilityAssignmentSession getMeterUtilityAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the meter smart 
     *  utility session. 
     *
     *  @param  utilityId the <code> Id </code> of the <code> Utility </code> 
     *  @param  proxy a proxy 
     *  @return a <code> MeterSmartUtilitySession </code> 
     *  @throws org.osid.NotFoundException no <code> Utility </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> utilityId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsMeterSmartUtility() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMeterSmartUtility() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.metering.MeterSmartUtilitySession getMeterSmartUtilitySession(org.osid.id.Id utilityId, 
                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the utility lookup 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> UtilityLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsUtilityLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsUtilityLookup() </code> is <code> true. </code> 
     */

    public org.osid.metering.UtilityLookupSession getUtilityLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the utility query 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> UtilityQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsUtilityQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsUtilityQuery() </code> is <code> true. </code> 
     */

    public org.osid.metering.UtilityQuerySession getUtilityQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the utility search 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> UtilitySearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsUtilitySearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsUtilitySearch() </code> is <code> true. </code> 
     */

    public org.osid.metering.UtilitySearchSession getUtilitySearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the utility 
     *  administrative service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> UtilityAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsUtilityAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsUtilityAdmin() </code> is <code> true. </code> 
     */

    public org.osid.metering.UtilityAdminSession getUtilityAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the utility 
     *  notification service. 
     *
     *  @param  utilityReceiver the receiver 
     *  @param  proxy a proxy 
     *  @return a <code> UtilityNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> utilityReceiver </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsUtilityNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsUtilityNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.metering.UtilityNotificationSession getUtilityNotificationSession(org.osid.metering.UtilityReceiver utilityReceiver, 
                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the utility 
     *  hierarchy service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> UtilityHierarchySession </code> for utilities 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsUtilityHierarchy() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsUtilityHierarchy() </code> is <code> true. </code> 
     */

    public org.osid.metering.UtilityHierarchySession getUtilityHierarchySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the utility 
     *  hierarchy design service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> HierarchyDesignSession </code> for utilities 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsUtilityHierarchyDesign() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsUtilityHierarchyDesign() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.metering.UtilityHierarchyDesignSession getUtilityHierarchyDesignSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a <code> MeteringBatchProxyManager. </code> 
     *
     *  @return a <code> MeteringBatchProxyManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsMeteringBatch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMeteringBatch() </code> is <code> true. </code> 
     */

    public org.osid.metering.batch.MeteringBatchProxyManager getMeteringBatchProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a <code> MeteringThresholdProxyManager. </code> 
     *
     *  @return a <code> MeteringThresholdProxyManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsMeteringThreshold() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMeteringThreshold() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.metering.threshold.MeteringThresholdProxyManager getMeteringThresholdProxyManager()
        throws org.osid.OperationFailedException;
}
