//
// org.osid.metering.Reading
//
//     The OSID Java specification for org.osid.metering.Reading.
//
// Copyright (C) 2009-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.metering;


/**
 *  <p>A <code> Reading </code> represents data from a <code> Meter </code> 
 *  for a referenced metered object at the current point in time. </p>
 */

public interface Reading
    extends org.osid.OsidCapsule {


    /**
     *  Gets the <code> Id </code> of the <code> Meter </code> associated with 
     *  this reading. 
     *
     *  @return gets the <code> Id </code> of the <code> Meter </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getMeterId();


    /**
     *  Gets the <code> Meter </code> associated with this reading. 
     *
     *  @return gets the <code> Meter </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.metering.Meter getMeter()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the metered object associated with this reading. 
     *
     *  @return gets the metered object <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getMeteredObjectId();


    /**
     *  Gets the amount of this reading. 
     *
     *  @return gets the amount of this reading 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getAmount();
}
