//
// org.osid.metering.StatisticLookupSession
//
//     The OSID Java specification for org.osid.metering.StatisticLookupSession.
//
// Copyright (C) 2009-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.metering;


/**
 *  <p>This session is used to retrieve statistics from a meter. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> federated utility view: includes meters in utilities which are 
 *      children of this utility in the utility hierarchy </li> 
 *      <li> isolated utility view: restricts lookups to this utility only 
 *      </li> 
 *      <li> bounded metered view: limits the statistics to the lifetime of 
 *      the metered object </li> 
 *      <li> unbounded metered view: readings factored into statistics outside 
 *      the lifetime of the metered object are zero </li> 
 *  </ul>
 *  
 */

public interface StatisticLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Utility </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Utility Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getUtilityId();


    /**
     *  Gets the <code> Utility </code> associated with this session. 
     *
     *  @return the utility 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.metering.Utility getUtility()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can retrieve meter statistics. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer metering operations. 
     *
     *  @return <code> false </code> if metering methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canGetMeterStatistics();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeMeterView();


    /**
     *  A complete view of the returns is desired. Methods will return what is 
     *  requested or result in an error. This view is used when greater 
     *  precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryMeterView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include meters in utilities which are children of this utility in the 
     *  utility hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedUtilityView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this utility only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedUtilityView();


    /**
     *  If the supplied dates are beyond the lifetime of the metered object, 
     *  bound the statistics to the dates of the lifetime. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useBoundedMeteredView();


    /**
     *  If the supplied dates are beyond the lifetime of the metered object, 
     *  the readings that do not exist are zero. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useUnboundedMeteredView();


    /**
     *  Gets the date range of the available statistics for a metered object. 
     *
     *  @param  meterId the <code> Id </code> of the <code> Meter </code> 
     *  @param  meteredObjectId the <code> Id </code> of the metered object 
     *  @return the date range of the available statistics 
     *  @throws org.osid.NotFoundException no <code> Meter </code> or metered 
     *          object found with the given <code> Id </code> or no data 
     *          available 
     *  @throws org.osid.NullArgumentException <code> meterId </code> or 
     *          <code> meteredObjectId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTimeInterval getAvailableDateRange(org.osid.id.Id meterId, 
                                                                       org.osid.id.Id meteredObjectId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a statistic for the <code> Meter </code> and metered object for 
     *  all available data. 
     *
     *  @param  meterId the <code> Id </code> of the <code> Meter </code> 
     *  @param  meteredObjectId the <code> Id </code> of the metered object 
     *  @return the meter stat 
     *  @throws org.osid.NotFoundException no <code> Meter </code> or metered 
     *          object found with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> meterId </code> or 
     *          <code> meteredObjectId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.metering.Statistic getStatistic(org.osid.id.Id meterId, 
                                                    org.osid.id.Id meteredObjectId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a statistic within a period of time of the <code> Meter </code> 
     *  and metered object specified by its <code> Id. </code> 
     *
     *  @param  meterId the <code> Id </code> of the <code> Meter </code> 
     *  @param  meteredObjectId the <code> Id </code> of the metered object 
     *  @param  from the start time 
     *  @param  to the end time 
     *  @return the meter stat 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NotFoundException no <code> Meter </code> or metered 
     *          object found with the given <code> Id </code> or no data 
     *          available within the given date range 
     *  @throws org.osid.NullArgumentException <code> meterId, 
     *          meteredObjectId, from </code> or <code> to </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.metering.Statistic getStatisticByDate(org.osid.id.Id meterId, 
                                                          org.osid.id.Id meteredObjectId, 
                                                          org.osid.calendaring.DateTime from, 
                                                          org.osid.calendaring.DateTime to)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the statistics for the given metered object <code> IdList </code> 
     *  for all available data. In plenary mode, the returned list contains 
     *  all of the readings specified in the <code> Id </code> list, in the 
     *  order of the list, including duplicates, or an error results if an 
     *  <code> Id </code> in the supplied list is not found or inaccessible. 
     *  Otherwise, inaccessible statistics may be omitted from the list and 
     *  may present the elements in any order including returning a unique 
     *  set. 
     *
     *  @param  meterId the <code> Id </code> of the <code> Meter </code> 
     *  @param  meteredObjectIds the <code> Id </code> of the metered object 
     *  @return the returned <code> Statistic </code> list 
     *  @throws org.osid.NotFoundException <code> meterId </code> or an <code> 
     *          Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> meterId </code> or 
     *          <code> meteredObjects </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.metering.StatisticList getStatistics(org.osid.id.Id meterId, 
                                                         org.osid.id.IdList meteredObjectIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the statistics within a period of time corresponding to the given 
     *  metered object <code> IdList. </code> In plenary mode, the returned 
     *  list contains all of the statistics specified in the <code> Id </code> 
     *  list, in the order of the list, including duplicates, or an error 
     *  results if an <code> Id </code> in the supplied list is not found or 
     *  inaccessible. Otherwise, inaccessible statistics or statistics not 
     *  contained within the given date range may be omitted from the list and 
     *  may present the elements in any order including returning a unique 
     *  set. 
     *
     *  @param  meterId the <code> Id </code> of the <code> Meter </code> 
     *  @param  meteredObjectIds the <code> Id </code> of the metered object 
     *  @param  from the start time 
     *  @param  to the end time 
     *  @return the returned <code> Statistic </code> list 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NotFoundException <code> meterId </code> or an <code> 
     *          Id was </code> not found or no data available within the given 
     *          date range 
     *  @throws org.osid.NullArgumentException <code> meterId, meteredObjects, 
     *          from </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.metering.StatisticList getStatisticsByDate(org.osid.id.Id meterId, 
                                                               org.osid.id.IdList meteredObjectIds, 
                                                               org.osid.calendaring.DateTime from, 
                                                               org.osid.calendaring.DateTime to)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the statistics for a metered object within a period of time at 
     *  consecutive specified intervals. In plenary mode, the returned list 
     *  contains all of the statistics requested or an error results data in 
     *  the supplied date range is not found or inaccessible. Otherwise, 
     *  inaccessible statistics or statistics not contained within the given 
     *  date range may be omitted from the list and may present the elements 
     *  in any order including returning a unique set. 
     *
     *  @param  meterId the <code> Id </code> of the <code> Meter </code> 
     *  @param  meteredObjectId the <code> Id </code> of the metered object 
     *  @param  from the start time 
     *  @param  to the end time 
     *  @param  interval the interval 
     *  @return the returned <code> Statistic </code> list 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NotFoundException <code> meterId </code> or an <code> 
     *          Id was </code> not found or no data available within the given 
     *          date range 
     *  @throws org.osid.NullArgumentException <code> meterId, 
     *          meteredObjectId, from, to </code> or <code> interval </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.metering.StatisticList getStatisticsAtInterval(org.osid.id.Id meterId, 
                                                                   org.osid.id.Id meteredObjectId, 
                                                                   org.osid.calendaring.DateTime from, 
                                                                   org.osid.calendaring.DateTime to, 
                                                                   org.osid.calendaring.DateTimeResolution interval)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
