//
// org.osid.metering.StatisticNotificationSession
//
//     The OSID Java specification for org.osid.metering.StatisticNotificationSession.
//
// Copyright (C) 2009-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.metering;


/**
 *  <p>This session defines methods to receive notifications on statistics. 
 *  This session is intended for consumers needing to synchronize their state 
 *  with this service without the use of polling. Notifications are cancelled 
 *  when this session is closed. </p>
 */

public interface StatisticNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Utility </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Utility Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getUtilityId();


    /**
     *  Gets the <code> Utility </code> associated with this session. 
     *
     *  @return the <code> Utility </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.metering.Utility getUtility()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can register for <code> Statistic </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForStatisticNotifications();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include statistics from parent utilities in the utility hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedUtilityView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts notifications for statistics to this utility only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedUtilityView();


    /**
     *  Register for notifications sums exceeding a threshold. <code> 
     *  StatisticReceiver.exceededSumThreshold() </code> is invoked when the 
     *  sum exceeds the given value. 
     *
     *  @param  meterId the meter <code> Id </code> 
     *  @param  interval the time interval from the present 
     *  @param  units the date time units 
     *  @param  value the threshold value 
     *  @throws org.osid.NullArgumentException <code> meterId </code> or 
     *          <code> units </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForStatisticsExceedingSumThreshold(org.osid.id.Id meterId, 
                                                           long interval, 
                                                           org.osid.calendaring.DateTimeResolution units, 
                                                           java.math.BigDecimal value)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications sums failing a threshold. <code> 
     *  StatisticReceiver.failedSumThreshold() </code> is invoked when the sum 
     *  falls below the given value. 
     *
     *  @param  meterId the meter <code> Id </code> 
     *  @param  interval the time interval from the present 
     *  @param  units the date time units 
     *  @param  value the threshold value 
     *  @throws org.osid.NullArgumentException <code> meterId </code> or 
     *          <code> units </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForStatisticsFailingSumThreshold(org.osid.id.Id meterId, 
                                                         long interval, 
                                                         org.osid.calendaring.DateTimeResolution units, 
                                                         java.math.BigDecimal value)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of means exceeding a threshold. <code> 
     *  StatisticReceiver.exceededMeanThreshold() </code> is invoked when the 
     *  mean exceeds the given value. 
     *
     *  @param  meterId the meter <code> Id </code> 
     *  @param  interval the time interval from the present 
     *  @param  units the date time units 
     *  @param  value the threshold value 
     *  @throws org.osid.NullArgumentException <code> meterId </code> or 
     *          <code> units </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForStatisticsExceedingMeanThreshold(org.osid.id.Id meterId, 
                                                            long interval, 
                                                            org.osid.calendaring.DateTimeResolution units, 
                                                            java.math.BigDecimal value)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications means failing a threshold. <code> 
     *  StatisticReceiver.failedMeanThreshold() </code> is invoked when the 
     *  mean falls below the given value. 
     *
     *  @param  meterId the meter <code> Id </code> 
     *  @param  interval the time interval from the present 
     *  @param  units the date time units 
     *  @param  value the threshold value 
     *  @throws org.osid.NullArgumentException <code> meterId </code> or 
     *          <code> units </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForStatisticsFailingMeanThreshold(org.osid.id.Id meterId, 
                                                          long interval, 
                                                          org.osid.calendaring.DateTimeResolution units, 
                                                          java.math.BigDecimal value)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of medians exceeding a threshold. <code> 
     *  StatisticReceiver.exceededMeanThreshold() </code> is invoked when the 
     *  median exceeds the given value. 
     *
     *  @param  meterId the meter <code> Id </code> 
     *  @param  interval the time interval from the present 
     *  @param  units the date time units 
     *  @param  value the threshold value 
     *  @throws org.osid.NullArgumentException <code> meterId </code> or 
     *          <code> units </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForStatisticsExceedingMedianThreshold(org.osid.id.Id meterId, 
                                                              long interval, 
                                                              org.osid.calendaring.DateTimeResolution units, 
                                                              java.math.BigDecimal value)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of medians failing a threshold. <code> 
     *  StatisticReceiver.failedMeanThreshold() </code> is invoked when the 
     *  median falls below the given value. 
     *
     *  @param  meterId the meter <code> Id </code> 
     *  @param  interval the time interval from the present 
     *  @param  units the date time units 
     *  @param  value the threshold value 
     *  @throws org.osid.NullArgumentException <code> meterId </code> or 
     *          <code> units </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForStatisticsFailingMedianThreshold(org.osid.id.Id meterId, 
                                                            long interval, 
                                                            org.osid.calendaring.DateTimeResolution units, 
                                                            java.math.BigDecimal value)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of the root mean square exceeding a 
     *  threshold. <code> StatisticReceiver.exceededRMSThreshold() </code> is 
     *  invoked when the rms exceeds the given value. 
     *
     *  @param  meterId the meter <code> Id </code> 
     *  @param  interval the time interval from the present 
     *  @param  units the date time units 
     *  @param  value the threshold value 
     *  @throws org.osid.NullArgumentException <code> meterId </code> or 
     *          <code> units </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForStatisticsExceedingRMSThreshold(org.osid.id.Id meterId, 
                                                           long interval, 
                                                           org.osid.calendaring.DateTimeResolution units, 
                                                           java.math.BigDecimal value)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of the root mean square failing a 
     *  threshold. <code> StatisticReceiver.failedRMSThreshold() </code> is 
     *  invoked when the rms falls below the given value. 
     *
     *  @param  meterId the meter <code> Id </code> 
     *  @param  interval the time interval from the present 
     *  @param  units the date time units 
     *  @param  value the threshold value 
     *  @throws org.osid.NullArgumentException <code> meterId or units </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForStatisticsFailingRMSThreshold(org.osid.id.Id meterId, 
                                                         long interval, 
                                                         org.osid.calendaring.DateTimeResolution units, 
                                                         java.math.BigDecimal value)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of the delta exceeding a threshold. <code> 
     *  StatisticReceiver.exceededDeltaThreshold() </code> is invoked when the 
     *  delta exceeds the given value. 
     *
     *  @param  meterId the meter <code> Id </code> 
     *  @param  interval the time interval from the present 
     *  @param  units the date time units 
     *  @param  value the threshold value 
     *  @throws org.osid.NullArgumentException <code> meterId </code> or 
     *          <code> units </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForStatisticsExceedingDeltaThreshold(org.osid.id.Id meterId, 
                                                             long interval, 
                                                             org.osid.calendaring.DateTimeResolution units, 
                                                             java.math.BigDecimal value)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of the delta failing a threshold. <code> 
     *  StatisticReceiver.failedDeltaThreshold() </code> is invoked when the 
     *  delta falls below the given value. 
     *
     *  @param  meterId the meter <code> Id </code> 
     *  @param  interval the time interval from the present 
     *  @param  units the date time units 
     *  @param  value the threshold value 
     *  @throws org.osid.NullArgumentException <code> meterId </code> or 
     *          <code> units </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForStatisticsFailingDeltaThreshold(org.osid.id.Id meterId, 
                                                           long interval, 
                                                           org.osid.calendaring.DateTimeResolution units, 
                                                           java.math.BigDecimal value)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of the percentage change exceeding a 
     *  threshold. <code> StatisticReceiver.exceededPercentChangeThreshold() 
     *  </code> is invoked when the change exceeds the given value. 
     *
     *  @param  meterId the meter <code> Id </code> 
     *  @param  interval the time interval from the present 
     *  @param  units the date time units 
     *  @param  value the threshold value 
     *  @throws org.osid.NullArgumentException <code> meterId </code> or 
     *          <code> units </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForStatisticsExceedingPercentChangeThreshold(org.osid.id.Id meterId, 
                                                                     long interval, 
                                                                     org.osid.calendaring.DateTimeResolution units, 
                                                                     java.math.BigDecimal value)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of the percentage change failing a 
     *  threshold. <code> StatisticReceiver.failedPercentChangeThreshold() 
     *  </code> is invoked when the change falls below the given value. 
     *
     *  @param  meterId the meter <code> Id </code> 
     *  @param  interval the time interval from the present 
     *  @param  units the date time units 
     *  @param  value the threshold value 
     *  @throws org.osid.NullArgumentException <code> meterId or units </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForStatisticsFailingPercentChangeThreshold(org.osid.id.Id meterId, 
                                                                   long interval, 
                                                                   org.osid.calendaring.DateTimeResolution units, 
                                                                   java.math.BigDecimal value)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of the rate exceeding a threshold. <code> 
     *  StatisticReceiver.exceededAverageRateThreshold() </code> is invoked 
     *  when the average rate exceeds the given value. 
     *
     *  @param  meterId the meter <code> Id </code> 
     *  @param  interval the time interval from the present 
     *  @param  units the date time units 
     *  @param  value the threshold value 
     *  @param  rateInterval the time interval of the rate 
     *  @throws org.osid.NullArgumentException <code> meterId, units, </code> 
     *          or <code> rateInterval </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForStatisticsExceedingAverageRateThreshold(org.osid.id.Id meterId, 
                                                                   long interval, 
                                                                   org.osid.calendaring.DateTimeResolution units, 
                                                                   java.math.BigDecimal value, 
                                                                   org.osid.calendaring.DateTimeResolution rateInterval)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of the rate failing a threshold. <code> 
     *  StatisticReceiver.failedAverageRateThreshold() </code> is invoked when 
     *  the average rate falls below the given value. 
     *
     *  @param  meterId the meter <code> Id </code> 
     *  @param  interval the time interval from the present 
     *  @param  units the date time units 
     *  @param  value the threshold value 
     *  @param  rateInterval the time interval of the rate 
     *  @throws org.osid.NullArgumentException <code> meterId, units, </code> 
     *          or <code> rateInterval </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForStatisticsFailingAverageRateThreshold(org.osid.id.Id meterId, 
                                                                 long interval, 
                                                                 org.osid.calendaring.DateTimeResolution units, 
                                                                 java.math.BigDecimal value, 
                                                                 org.osid.calendaring.DateTimeResolution rateInterval)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
