//
// org.osid.metering.StatisticQuery
//
//     The OSID Java specification for org.osid.metering.StatisticQuery.
//
// Copyright (C) 2009-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.metering;


/**
 *  <p>This is the query for searching statistics. Each method specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface StatisticQuery
    extends org.osid.OsidCompendiumQuery {


    /**
     *  Sets a meter <code> Id. </code> 
     *
     *  @param  meterId a meter <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> meterId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMeterId(org.osid.id.Id meterId, boolean match);


    /**
     *  Clears the meter <code> Id </code> query term. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMeterIdTerms();


    /**
     *  Tests if a meter query is available. 
     *
     *  @return <code> true </code> if a meter query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMeterQuery();


    /**
     *  Gets the query for a meter. 
     *
     *  @return the meter query 
     *  @throws org.osid.UnimplementedException <code> supportsMeterQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMeterQuery() </code> is <code> true. </code> 
     */

    public org.osid.metering.MeterQuery getMeterQuery();


    /**
     *  Clears the meter query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMeterTerms();


    /**
     *  Sets an object <code> Id. </code> 
     *
     *  @param  objectId an object <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> objectId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMeteredObjectId(org.osid.id.Id objectId, boolean match);


    /**
     *  Clears the object query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMeteredObjectIdTerms();


    /**
     *  Sets the time for the statistics to generate. 
     *
     *  @param  start the start time 
     *  @param  end the end time 
     *  @throws org.osid.NullArgumentException <code> start </code> or <code> 
     *          end </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setTimeRange(org.osid.calendaring.DateTime start, 
                             org.osid.calendaring.DateTime end);


    /**
     *  Matches statistics with the sum between the given range inclusive. 
     *
     *  @param  low the low end of the range 
     *  @param  high the high end of the range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException the low is greater than the 
     *          high 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSum(java.math.BigDecimal low, java.math.BigDecimal high, 
                         boolean match);


    /**
     *  Clears the sum query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSumTerms();


    /**
     *  Matches statistics with the minimum sum value inclusive. 
     *
     *  @param  value the low end of the range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMinimumSum(java.math.BigDecimal value, boolean match);


    /**
     *  Clears the minimum sum query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMinimumSumTerms();


    /**
     *  Matches statistics with the mean between the given range inclusive. 
     *
     *  @param  low the low end of the range 
     *  @param  high the high end of the range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException the low is greater than the 
     *          high 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMean(java.math.BigDecimal low, java.math.BigDecimal high, 
                          boolean match);


    /**
     *  Clears the mean query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMeanTerms();


    /**
     *  Matches statistics with the minimum mean value inclusive. 
     *
     *  @param  value the low end of the range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMinimumMean(java.math.BigDecimal value, boolean match);


    /**
     *  Clears the minimum mean query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMinimumMeanTerms();


    /**
     *  Matches statistics with the median between the given range inclusive. 
     *
     *  @param  low the low end of the range 
     *  @param  high the high end of the range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException the low is greater than the 
     *          high 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMedian(java.math.BigDecimal low, 
                            java.math.BigDecimal high, boolean match);


    /**
     *  Clears the median query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMedianTerms();


    /**
     *  Matches statistics with the minimum median value inclusive. 
     *
     *  @param  value the low end of the range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMinimumMedian(java.math.BigDecimal value, boolean match);


    /**
     *  Clears the minimum median query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMinimumMedianTerms();


    /**
     *  Matches statistics with the mode between the given range inclusive. 
     *
     *  @param  low the low end of the range 
     *  @param  high the high end of the range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException the low is greater than the 
     *          high 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMode(java.math.BigDecimal low, java.math.BigDecimal high, 
                          boolean match);


    /**
     *  Clears the mode query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearModeTerms();


    /**
     *  Matches statistics with the minimum mode value inclusive. 
     *
     *  @param  value the low end of the range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMinimumMode(java.math.BigDecimal value, boolean match);


    /**
     *  Clears the minimum mode query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMinimumModeTerms();


    /**
     *  Matches statistics with the standard deviation between the given range 
     *  inclusive. 
     *
     *  @param  low the low end of the range 
     *  @param  high the high end of the range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException the low is greater than the 
     *          high 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchStandardDeviation(java.math.BigDecimal low, 
                                       java.math.BigDecimal high, 
                                       boolean match);


    /**
     *  Clears the standard deviation query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStandardDeviationTerms();


    /**
     *  Matches statistics with the minimum standard deviation value 
     *  inclusive. 
     *
     *  @param  value the low end of the range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMinimumStandardDeviation(java.math.BigDecimal value, 
                                              boolean match);


    /**
     *  Clears the minimum standard deviation query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMinimumStandardDeviationTerms();


    /**
     *  Matches statistics with the root mean square between the given range 
     *  inclusive. 
     *
     *  @param  low the low end of the range 
     *  @param  high the high end of the range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException the low is greater than the 
     *          high 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRMS(java.math.BigDecimal low, java.math.BigDecimal high, 
                         boolean match);


    /**
     *  Clears the rms query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRMSTerms();


    /**
     *  Matches statistics with the minimum rms value inclusive. 
     *
     *  @param  value the low end of the range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMinimumRMS(java.math.BigDecimal value, boolean match);


    /**
     *  Clears the minimum rms query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMinimumRMSTerms();


    /**
     *  Matches statistics with the delta between the given range inclusive. 
     *
     *  @param  low the low end of the range 
     *  @param  high the high end of the range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException the low is greater than the 
     *          high 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDelta(java.math.BigDecimal low, java.math.BigDecimal high, 
                           boolean match);


    /**
     *  Clears the delta query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDeltaTerms();


    /**
     *  Matches statistics with the minimum delta value inclusive. 
     *
     *  @param  value the low end of the range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMinimumDelta(java.math.BigDecimal value, boolean match);


    /**
     *  Clears the minimum delta query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMinimumDeltaTerms();


    /**
     *  Matches statistics with the percentage change between the given range 
     *  inclusive. 
     *
     *  @param  low the low end of the range 
     *  @param  high the high end of the range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException the low is greater than the 
     *          high 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchPercentChange(java.math.BigDecimal low, 
                                   java.math.BigDecimal high, boolean match);


    /**
     *  Clears the delta query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPercentChangeTerms();


    /**
     *  Matches statistics with the minimum percentage change value inclusive. 
     *
     *  @param  value the low end of the range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMinimumPercentChange(java.math.BigDecimal value, 
                                          boolean match);


    /**
     *  Clears the minimum percentage change query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMinimumPercentChangeTerms();


    /**
     *  Matches statistics with the average rate between the given range 
     *  inclusive. 
     *
     *  @param  low the low end of the range 
     *  @param  high the high end of the range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException the low is greater than the 
     *          high 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAverageRate(java.math.BigDecimal low, 
                                 java.math.BigDecimal high, boolean match);


    /**
     *  Clears the average rate query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAverageRateTerms();


    /**
     *  Gets the statistic query record corresponding to the given <code> 
     *  Statistic </code> record <code> Type. </code> Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @param  statisticRecordType a statistic record type 
     *  @return the statistic query record 
     *  @throws org.osid.NullArgumentException <code> statisticRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(statisticRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.metering.records.StatisticQueryRecord getStatisticQueryRecord(org.osid.type.Type statisticRecordType)
        throws org.osid.OperationFailedException;
}
