//
// org.osid.metering.StatisticReceiver
//
//     The OSID Java specification for org.osid.metering.StatisticReceiver.
//
// Copyright (C) 2009-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.metering;


/**
 *  <p>The meter receiver is the consumer supplied interface for receiving 
 *  notifications pertaining to new, updated or deleted <code> Statistic 
 *  </code> objects. </p>
 */

public interface StatisticReceiver
    extends org.osid.OsidReceiver {


    /**
     *  The callback for notifications of statistics exceeding a sum 
     *  threshold. 
     *
     *  @param  meterId the <code> Id </code> of the <code> Meter </code> 
     *  @param  objectId the <code> Id </code> of the object 
     *  @param  interval the time interval 
     *  @compliance mandatory This method must be implemented. 
     */

    public void exceededSumThreshold(org.osid.id.Id meterId, 
                                     org.osid.id.Id objectId, 
                                     org.osid.calendaring.DateTimeInterval interval);


    /**
     *  The callback for notifications of statistics falling below a sum 
     *  threshold. 
     *
     *  @param  meterId the <code> Id </code> of the <code> Meter </code> 
     *  @param  objectId the <code> Id </code> of the object 
     *  @param  interval the time interval 
     *  @compliance mandatory This method must be implemented. 
     */

    public void failedSumThreshold(org.osid.id.Id meterId, 
                                   org.osid.id.Id objectId, 
                                   org.osid.calendaring.DateTimeInterval interval);


    /**
     *  The callback for notifications of statistics exceeding a mean 
     *  threshold. 
     *
     *  @param  meterId the <code> Id </code> of the <code> Meter </code> 
     *  @param  objectId the <code> Id </code> of the object 
     *  @param  interval the time interval 
     *  @compliance mandatory This method must be implemented. 
     */

    public void exceededMeanThreshold(org.osid.id.Id meterId, 
                                      org.osid.id.Id objectId, 
                                      org.osid.calendaring.DateTimeInterval interval);


    /**
     *  The callback for notifications of statistics falling below a mean 
     *  threshold. 
     *
     *  @param  meterId the <code> Id </code> of the <code> Meter </code> 
     *  @param  objectId the <code> Id </code> of the object 
     *  @param  interval the time interval 
     *  @compliance mandatory This method must be implemented. 
     */

    public void failedMeanThreshold(org.osid.id.Id meterId, 
                                    org.osid.id.Id objectId, 
                                    org.osid.calendaring.DateTimeInterval interval);


    /**
     *  The callback for notifications of statistics exceeding a median 
     *  threshold. 
     *
     *  @param  meterId the <code> Id </code> of the <code> Meter </code> 
     *  @param  objectId the <code> Id </code> of the object 
     *  @param  interval the time interval 
     *  @compliance mandatory This method must be implemented. 
     */

    public void exceededMedianThreshold(org.osid.id.Id meterId, 
                                        org.osid.id.Id objectId, 
                                        org.osid.calendaring.DateTimeInterval interval);


    /**
     *  The callback for notifications of statistics falling below a median 
     *  threshold. 
     *
     *  @param  meterId the <code> Id </code> of the <code> Meter </code> 
     *  @param  objectId the <code> Id </code> of the object 
     *  @param  interval the time interval 
     *  @compliance mandatory This method must be implemented. 
     */

    public void failedMedianThreshold(org.osid.id.Id meterId, 
                                      org.osid.id.Id objectId, 
                                      org.osid.calendaring.DateTimeInterval interval);


    /**
     *  The callback for notifications of statistics exceeding a root mean 
     *  square threshold. 
     *
     *  @param  meterId the <code> Id </code> of the <code> Meter </code> 
     *  @param  objectId the <code> Id </code> of the object 
     *  @param  interval the time interval 
     *  @compliance mandatory This method must be implemented. 
     */

    public void exceededRMSThreshold(org.osid.id.Id meterId, 
                                     org.osid.id.Id objectId, 
                                     org.osid.calendaring.DateTimeInterval interval);


    /**
     *  The callback for notifications of statistics falling below an rms 
     *  threshold. 
     *
     *  @param  meterId the <code> Id </code> of the <code> Meter </code> 
     *  @param  objectId the <code> Id </code> of the object 
     *  @param  interval the time interval 
     *  @compliance mandatory This method must be implemented. 
     */

    public void failedRMSThreshold(org.osid.id.Id meterId, 
                                   org.osid.id.Id objectId, 
                                   org.osid.calendaring.DateTimeInterval interval);


    /**
     *  The callback for notifications of statistics exceeding a delta 
     *  threshold. 
     *
     *  @param  meterId the <code> Id </code> of the <code> Meter </code> 
     *  @param  objectId the <code> Id </code> of the object 
     *  @param  interval the time interval 
     *  @compliance mandatory This method must be implemented. 
     */

    public void exceededDeltaThreshold(org.osid.id.Id meterId, 
                                       org.osid.id.Id objectId, 
                                       org.osid.calendaring.DateTimeInterval interval);


    /**
     *  The callback for notifications of statistics falling below a delta 
     *  threshold. 
     *
     *  @param  meterId the <code> Id </code> of the <code> Meter </code> 
     *  @param  objectId the <code> Id </code> of the object 
     *  @param  interval the time interval 
     *  @compliance mandatory This method must be implemented. 
     */

    public void failedDeltaThreshold(org.osid.id.Id meterId, 
                                     org.osid.id.Id objectId, 
                                     org.osid.calendaring.DateTimeInterval interval);


    /**
     *  The callback for notifications of statistics exceeding a percentage 
     *  change threshold. 
     *
     *  @param  meterId the <code> Id </code> of the <code> Meter </code> 
     *  @param  objectId the <code> Id </code> of the object 
     *  @param  interval the time interval 
     *  @compliance mandatory This method must be implemented. 
     */

    public void exceededPercentChangeThreshold(org.osid.id.Id meterId, 
                                               org.osid.id.Id objectId, 
                                               org.osid.calendaring.DateTimeInterval interval);


    /**
     *  The callback for notifications of statistics falling below a 
     *  percentage change threshold. 
     *
     *  @param  meterId the <code> Id </code> of the <code> Meter </code> 
     *  @param  objectId the <code> Id </code> of the object 
     *  @param  interval the time interval 
     *  @compliance mandatory This method must be implemented. 
     */

    public void failedPercentChangeThreshold(org.osid.id.Id meterId, 
                                             org.osid.id.Id objectId, 
                                             org.osid.calendaring.DateTimeInterval interval);


    /**
     *  The callback for notifications of statistics exceeding an average rate 
     *  threshold. 
     *
     *  @param  meterId the <code> Id </code> of the <code> Meter </code> 
     *  @param  objectId the <code> Id </code> of the object 
     *  @param  interval the time interval 
     *  @compliance mandatory This method must be implemented. 
     */

    public void exceededAverageRateThreshold(org.osid.id.Id meterId, 
                                             org.osid.id.Id objectId, 
                                             org.osid.calendaring.DateTimeInterval interval);


    /**
     *  The callback for notifications of statistics falling below an average 
     *  rate threshold. 
     *
     *  @param  meterId the <code> Id </code> of the <code> Meter </code> 
     *  @param  objectId the <code> Id </code> of the object 
     *  @param  interval the time interval 
     *  @compliance mandatory This method must be implemented. 
     */

    public void failedAverageRateThreshold(org.osid.id.Id meterId, 
                                           org.osid.id.Id objectId, 
                                           org.osid.calendaring.DateTimeInterval interval);
}
