//
// org.osid.metering.StatisticSearchOrder
//
//     The OSID Java specification for org.osid.metering.StatisticSearchOrder.
//
// Copyright (C) 2009-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.metering;


/**
 *  <p>An interface for specifying the ordering of search results. </p>
 */

public interface StatisticSearchOrder
    extends org.osid.OsidCompendiumSearchOrder {


    /**
     *  Specified a preference for ordering results by the metered object. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByMeter(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a <code> MeterSearchOrder </code> is available. 
     *
     *  @return <code> true </code> if a meter search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMeterSearchOrder();


    /**
     *  Gets the search order for a meter. 
     *
     *  @return the meter search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsMeterSearchOrder() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMeterSearchOrder() </code> is <code> true. </code> 
     */

    public org.osid.metering.MeterSearchOrder getMeterSearchOrder();


    /**
     *  Specified a preference for ordering results by the metered object. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByMeteredObject(org.osid.SearchOrderStyle style);


    /**
     *  Specified a preference for ordering results by the sum. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderBySum(org.osid.SearchOrderStyle style);


    /**
     *  Specified a preference for ordering results by the mean. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByMean(org.osid.SearchOrderStyle style);


    /**
     *  Specified a preference for ordering results by the median. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByMedian(org.osid.SearchOrderStyle style);


    /**
     *  Specified a preference for ordering results by the mode. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByMode(org.osid.SearchOrderStyle style);


    /**
     *  Specified a preference for ordering results by the standard deviation. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByStandardDeviation(org.osid.SearchOrderStyle style);


    /**
     *  Specified a preference for ordering results by the root mean square. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByRMS(org.osid.SearchOrderStyle style);


    /**
     *  Specified a preference for ordering results by the delta. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByDelta(org.osid.SearchOrderStyle style);


    /**
     *  Specified a preference for ordering results by the percent change. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByPercentChange(org.osid.SearchOrderStyle style);


    /**
     *  Specified a preference for ordering results by the average rate. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByAverageRate(org.osid.SearchOrderStyle style);


    /**
     *  Gets the meter search order record corresponding to the given 
     *  statistic record <code> Type. </code> Multiple retrievals return the 
     *  same underlying object. 
     *
     *  @param  statisticRecordType a statistic record type 
     *  @return the statistic search order record 
     *  @throws org.osid.NullArgumentException <code> statisticRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(statisticRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.metering.records.StatisticSearchOrderRecord getStatisticSearchOrderRecord(org.osid.type.Type statisticRecordType)
        throws org.osid.OperationFailedException;
}
