//
// org.osid.metering.StatisticSmartUtilitySession
//
//     The OSID Java specification for org.osid.metering.StatisticSmartUtilitySession.
//
// Copyright (C) 2009-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.metering;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. A <code> StatisticQuery </code> can be retrieved from this 
 *  session and mapped to this <code> Utility </code> to create a virtual 
 *  collection of <code> Statistics. </code> The entries may be sequenced 
 *  using the <code> StatisticSearchOrder </code> from this session. </p> 
 *  
 *  <p> This <code> Utility </code> has a default query that matches any 
 *  statistic and a default search order that specifies no sequencing. The 
 *  queries may be examined using a <code> StatisticQueryInspector. </code> 
 *  The query may be modified by converting the inspector back to a <code> 
 *  StatisticQuery. </code> </p>
 */

public interface StatisticSmartUtilitySession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Utility </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Utility Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getUtilityId();


    /**
     *  Gets the <code> Utility </code> associated with this session. 
     *
     *  @return the <code> Utility </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.metering.Utility getUtility()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart utilities. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer smart operations. 
     *
     *  @return <code> false </code> if smart utility methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartUtilities();


    /**
     *  Gets a statistic query. 
     *
     *  @return the statistic query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.metering.StatisticQuery getStatisticQuery();


    /**
     *  Gets a statistic search order. 
     *
     *  @return the statistic search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.metering.StatisticSearchOrder getStatisticSearchOrder();


    /**
     *  Applies a statistic query to this utility. 
     *
     *  @param  statisticQuery the statistic query 
     *  @throws org.osid.NullArgumentException <code> statisticQuery </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> statisticQuery </code> 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyStatisticQuery(org.osid.metering.StatisticQuery statisticQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a statistic query inspector for this utility. 
     *
     *  @return the statistic query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.metering.StatisticQueryInspector inspectStatisticQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a statistic search order to this utility. 
     *
     *  @param  statisticSearchOrder the statistic search order 
     *  @throws org.osid.NullArgumentException <code> statisticSearchOrder 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> statisticSearchOrder 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyStatisticSequencing(org.osid.metering.StatisticSearchOrder statisticSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a statistic query from an inspector. 
     *
     *  @param  statisticQueryInspector a statistic query inspector 
     *  @return the statistic query 
     *  @throws org.osid.NullArgumentException <code> statisticQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> statisticQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.metering.StatisticQuery getStatisticQueryFromInspector(org.osid.metering.StatisticQueryInspector statisticQueryInspector);
}
