//
// org.osid.metering.UtilityAdminSession
//
//     The OSID Java specification for org.osid.metering.UtilityAdminSession.
//
// Copyright (C) 2009-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.metering;


/**
 *  <p>This session creates, updates, and deletes <code> Utilities. </code> 
 *  The data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  UtilityForm, </code> a <code> UtilityForm </code> is requested using 
 *  <code> getUtilityFormForCreate() </code> specifying the desired record 
 *  <code> Types </code> or none if no record <code> Types </code> are needed. 
 *  The returned <code> UtilityForm </code> will indicate that it is to be 
 *  used with a create operation and can be used to examine metdata or 
 *  validate data prior to creation. Once the <code> UtilityForm </code> is 
 *  submiited to a create operation, it cannot be reused with another create 
 *  operation unless the first operation was unsuccessful. Each <code> 
 *  UtilityForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> UtilityForms </code> are requested to the <code> 
 *  Utility </code> <code> Id </code> that is to be updated using <code> 
 *  getUtilityFormForUpdate(). </code> Similarly, the <code> UtilityForm 
 *  </code> has metadata about the data that can be updated and it can perform 
 *  validation before submitting the update. The <code> UtilityForm </code> 
 *  can only be used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Utilities. </code> </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface UtilityAdminSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can create <code> Utilities. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> Utility </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not wish to offer create operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Utility </code> creation is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateUtilities();


    /**
     *  Tests if this user can create a single <code> Utility </code> using 
     *  the desired record interface types. While <code> 
     *  MeteringManager.getUtilityRecordTypes() </code> can be used to examine 
     *  which record interfaces are supported, this method tests which 
     *  record(s) are required for creating a specific <code> Utility. </code> 
     *  Providing an empty array tests if a <code> Utility </code> can be 
     *  created with no records. 
     *
     *  @param  utilityRecordTypes array of utility record types 
     *  @return <code> true </code> if <code> Utility </code> creation using 
     *          the specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> utilityRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateUtilityWithRecordTypes(org.osid.type.Type[] utilityRecordTypes);


    /**
     *  Gets the utility form for creating new utilities. A new form should be 
     *  requested for each create transaction. 
     *
     *  @param  utilityRecordTypes array of utility record types 
     *  @return the utility form 
     *  @throws org.osid.NullArgumentException <code> utilityRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.metering.UtilityForm getUtilityFormForCreate(org.osid.type.Type[] utilityRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Utility. </code> 
     *
     *  @param  utilityForm the form for this <code> Utility </code> 
     *  @return the new <code> Utility </code> 
     *  @throws org.osid.IllegalStateException <code> utilityForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> utilityForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> utilityForm </code> did 
     *          not originate from <code> getUtilityFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.metering.Utility createUtility(org.osid.metering.UtilityForm utilityForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Utilities. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> Utility </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not wish to offer update operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Utility </code> modification is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateUtilities();


    /**
     *  Gets the utility form for updating an existing utility. A new utility 
     *  form should be requested for each update transaction. 
     *
     *  @param  utilityId the <code> Id </code> of the <code> Utility </code> 
     *  @return the utility form 
     *  @throws org.osid.NotFoundException <code> utilityId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> utilityId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.metering.UtilityForm getUtilityFormForUpdate(org.osid.id.Id utilityId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing utility. 
     *
     *  @param  utilityForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> utilityForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> utilityForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> utilityForm </code> did 
     *          not originate from <code> getUtilityFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateUtility(org.osid.metering.UtilityForm utilityForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> Utilities. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> Utility </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not wish to offer delete operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Utility </code> deletion is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteUtilities();


    /**
     *  Deletes a <code> Utility. </code> 
     *
     *  @param  utilityId the <code> Id </code> of the <code> Utility </code> 
     *          to remove 
     *  @throws org.osid.NotFoundException <code> utilityId </code> not found 
     *  @throws org.osid.NullArgumentException <code> utilityId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteUtility(org.osid.id.Id utilityId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for utilities. 
     *  A return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known changing an alias will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer alias operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Utility </code> aliasing is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageUtilityAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Utility </code> for the purpose 
     *  of creating compatibility. The primary <code> Id </code> of the <code> 
     *  Utility </code> is determined by the provider. The new <code> Id 
     *  </code> performs as an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another event, it is reassigned to the given 
     *  event <code> Id. </code> 
     *
     *  @param  utilityId the <code> Id </code> of a <code> Utility </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> utilityId </code> not found 
     *  @throws org.osid.NullArgumentException <code> utilityId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasUtility(org.osid.id.Id utilityId, org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
