//
// org.osid.metering.UtilitySearchSession
//
//     The OSID Java specification for org.osid.metering.UtilitySearchSession.
//
// Copyright (C) 2009-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.metering;


/**
 *  <p>This session provides methods for searching <code> Utility </code> 
 *  objects. The search query is constructed using the <code> UtilityQuery. 
 *  </code> The utility record <code> Type </code> also specifies the recod 
 *  for the utility query. </p> 
 *  
 *  <p> <code> getUtilitiesByQuery() </code> is the basic search method and 
 *  returns a list of <code> Utility </code> elements. A more advanced search 
 *  may be performed with <code> getUtilitiesBySearch(). </code> It accepts a 
 *  <code> UtilitySearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getUtilitiesBySearch() </code> returns a <code> 
 *  UtilitySearchResults </code> that can be used to access the resulting 
 *  <code> UtilityList </code> or be used to perform a search within the 
 *  result set through <code> UtilitySearch. </code> </p> 
 *  
 *  <p> Utilities may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> UtilityQuery. </code> 
 *  The returns in this session may not be cast directly to these interfaces. 
 *  </p>
 */

public interface UtilitySearchSession
    extends org.osid.metering.UtilityQuerySession {


    /**
     *  Gets a utility search. 
     *
     *  @return the utility search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.metering.UtilitySearch getUtilitySearch();


    /**
     *  Gets a utility search order. The <code> UtilitySearchOrder </code> is 
     *  supplied to a <code> UtilitySearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the utility search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.metering.UtilitySearchOrder getUtilitySearchOrder();


    /**
     *  Gets the search results matching the given search. 
     *
     *  @param  utilityQuery the utility query 
     *  @param  utilitySearch the utility search 
     *  @return the utility search results 
     *  @throws org.osid.NullArgumentException <code> utilityQuery </code> or 
     *          <code> utilitySearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> utilityQuery </code> or 
     *          <code> utilitySearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.metering.UtilitySearchResults getUtilitiesBySearch(org.osid.metering.UtilityQuery utilityQuery, 
                                                                       org.osid.metering.UtilitySearch utilitySearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a utility query from an inspector. The inspector is available 
     *  from a <code> UtilitySearchResults. </code> 
     *
     *  @param  utilityQueryInspector a utility query inspector 
     *  @return the utility query 
     *  @throws org.osid.NullArgumentException <code> utilityQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> utilityQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.metering.UtilityQuery getUtilityQueryFromInspector(org.osid.metering.UtilityQueryInspector utilityQueryInspector);
}
