//
// org.osid.offering.CanonicalUnitAdminSession
//
//     The OSID Java specification for org.osid.offering.CanonicalUnitAdminSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering;


/**
 *  <p>This session creates, updates, and deletes <code> CanonicalUnits. 
 *  </code> The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  CanonicalUnit, </code> a <code> CanonicalUnitForm </code> is requested 
 *  using <code> getCanonicalUnitFormForCreate() </code> specifying the 
 *  desired record <code> Types </code> or none if no record <code> Types 
 *  </code> are needed. The returned <code> CanonicalUnitForm </code> will 
 *  indicate that it is to be used with a create operation and can be used to 
 *  examine metdata or validate data prior to creation. Once the <code> 
 *  CanonicalUnitForm </code> is submiited to a create operation, it cannot be 
 *  reused with another create operation unless the first operation was 
 *  unsuccessful. Each <code> CanonicalUnitForm </code> corresponds to an 
 *  attempted transaction. </p> 
 *  
 *  <p> For updates, <code> CanonicalUnitForms </code> are requested to the 
 *  <code> CanonicalUnit </code> <code> Id </code> that is to be updated using 
 *  <code> getCanonicalUnitFormForUpdate(). </code> Similarly, the <code> 
 *  CanonicalUnitForm </code> has metadata about the data that can be updated 
 *  and it can perform validation before submitting the update. The <code> 
 *  CanonicalUnitForm </code> can only be used once for a successful update 
 *  and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> CanonicalUnits. </code> To unmap a 
 *  <code> CanonicalUnit </code> from the current <code> Catalogue, </code> 
 *  the <code> CanonicalUnitCatalogueAssignmentSession </code> should be used. 
 *  These delete operations attempt to remove the <code> CanonicalUnit </code> 
 *  itself thus removing it from all known <code> Catalogue </code> catalogs. 
 *  </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface CanonicalUnitAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Catalogue </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Catalogue Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCatalogueId();


    /**
     *  Gets the <code> Catalogue </code> associated with this session. 
     *
     *  @return the catalogue 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.Catalogue getCatalogue()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create canonical units. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known creating a <code> CanonicalUnit </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may not wish to offer create operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> CanonicalUnit </code> creation 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateCanonicalUnits();


    /**
     *  Tests if this user can create a single <code> CanonicalUnit </code> 
     *  using the desired record types. While <code> 
     *  OfferingManager.getCanonicalUnitRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> CanonicalUnit. </code> 
     *  Providing an empty array tests if a <code> CanonicalUnit </code> can 
     *  be created with no records. 
     *
     *  @param  canonicalUnitRecordTypes array of canonical unit record types 
     *  @return <code> true </code> if <code> CanonicalUnit </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateCanonicalUnitWithRecordTypes(org.osid.type.Type[] canonicalUnitRecordTypes);


    /**
     *  Gets the canonical unit form for creating new canonical units. A new 
     *  form should be requested for each create transaction. 
     *
     *  @param  canonicalUnitRecordTypes array of canonical unit record types 
     *          to be included in the create operation or an empty list if 
     *          none 
     *  @return the canonical unit form 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException cannot get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.CanonicalUnitForm getCanonicalUnitFormForCreate(org.osid.type.Type[] canonicalUnitRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> CanonicalUnit. </code> 
     *
     *  @param  canonicalUnitForm the form for this <code> CanonicalUnit 
     *          </code> 
     *  @return the new <code> CanonicalUnit </code> 
     *  @throws org.osid.IllegalStateException <code> canonicalUnitForm 
     *          </code> already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> canonicalUnitForm </code> 
     *          did not originate from <code> getCanonicalUnitFormForCreate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.CanonicalUnit createCanonicalUnit(org.osid.offering.CanonicalUnitForm canonicalUnitForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update canonical units. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known updating a <code> CanonicalUnit </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may not wish to offer update operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> CanonicalUnit </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateCanonicalUnits();


    /**
     *  Gets the canonical unit form for updating an existing canonical unit. 
     *  A new canonical unit form should be requested for each update 
     *  transaction. 
     *
     *  @param  canonicalUnitId the <code> Id </code> of the <code> 
     *          CanonicalUnit </code> 
     *  @return the canonical unit form 
     *  @throws org.osid.NotFoundException <code> canonicalUnitId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.CanonicalUnitForm getCanonicalUnitFormForUpdate(org.osid.id.Id canonicalUnitId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing canonical unit. 
     *
     *  @param  canonicalUnitForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> canonicalUnitForm 
     *          </code> already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> canonicalUnitForm </code> 
     *          did not originate from <code> getCanonicalUnitFormForUpdate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateCanonicalUnit(org.osid.offering.CanonicalUnitForm canonicalUnitForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete canonical units. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known deleting an <code> CanonicalUnit </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may not wish to offer delete operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> CanonicalUnit </code> deletion 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteCanonicalUnits();


    /**
     *  Deletes a <code> CanonicalUnit. </code> 
     *
     *  @param  canonicalUnitId the <code> Id </code> of the <code> 
     *          CanonicalUnit </code> to remove 
     *  @throws org.osid.NotFoundException <code> canonicalUnitId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteCanonicalUnit(org.osid.id.Id canonicalUnitId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  CanonicalUnits. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> CanonicalUnit </code> aliasing 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageCanonicalUnitAliases();


    /**
     *  Adds an <code> Id </code> to a <code> CanonicalUnit </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> CanonicalUnit </code> is determined by the provider. The 
     *  new <code> Id </code> is an alias to the primary <code> Id. </code> If 
     *  the alias is a pointer to another canonical unit, it is reassigned to 
     *  the given canonical unit <code> Id. </code> 
     *
     *  @param  canonicalUnitId the <code> Id </code> of a <code> 
     *          CanonicalUnit </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is in 
     *          use as a primary <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> canonicalUnitId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitId </code> 
     *          or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasCanonicalUnit(org.osid.id.Id canonicalUnitId, 
                                   org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
