//
// org.osid.offering.CanonicalUnitLookupSession
//
//     The OSID Java specification for org.osid.offering.CanonicalUnitLookupSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering;


/**
 *  <p>This session defines methods for retrieving canonical units. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated catalogue view: All canonical unit methods in this 
 *      session operate, retrieve and pertain to canonical units defined 
 *      explicitly in the current catalogue. Using an isolated view is useful 
 *      for managing canonical units with the <code> 
 *      CanonicalUnitAdminSession. </code> </li> 
 *      <li> federated catalogue view: All canonical unit lookup methods in 
 *      this session operate, retrieve and pertain to all canonical units 
 *      defined in this catalogue and any other catalogues implicitly 
 *      available in this catalogue through catalogue inheritence. </li> 
 *      <li> active canonical view: All rule lookup methods return active 
 *      canonicals. </li> 
 *      <li> any status canonical view: Canonicals of any active or inactive 
 *      status are returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedCatalogueView() </code> and <code> 
 *  useIsolatedCatalogueView() </code> behave as a radio group and one should 
 *  be selected before invoking any lookup methods. </p>
 */

public interface CanonicalUnitLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Catalogue </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Catalogue Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCatalogueId();


    /**
     *  Gets the <code> Catalogue </code> associated with this session. 
     *
     *  @return the catalogue 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.Catalogue getCatalogue()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can examine this catalogue. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer these operations. 
     *
     *  @return <code> false </code> if catalogue reading methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupCanonicalUnits();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeCanonicalUnitView();


    /**
     *  A complete view of the <code> CanonicalUnit </code> returns is 
     *  desired. Methods will return what is requested or result in an error. 
     *  This view is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryCanonicalUnitView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include canonical units in catalogues which are children of this 
     *  catalogue in the catalogue hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCatalogueView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this catalogue only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCatalogueView();


    /**
     *  Only active canonical units are returned from methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveCanonicalUnitView();


    /**
     *  Active and inactive canonical units are returned from methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusCanonicalUnitView();


    /**
     *  Gets the <code> CanonicalUnit </code> specified by its <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  CanonicalUnit </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> CanonicalUnit </code> and retained for 
     *  compatibility. 
     *  
     *  In active mode, canonicals are returned that are currently active. In 
     *  any status mode, active and inactive canonicals are returned. 
     *
     *  @param  canonicalUnitId the <code> Id </code> of the <code> 
     *          CanonicalUnit </code> to retrieve 
     *  @return the returned <code> CanonicalUnit </code> 
     *  @throws org.osid.NotFoundException no <code> CanonicalUnit </code> 
     *          found with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.CanonicalUnit getCanonicalUnit(org.osid.id.Id canonicalUnitId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CanonicalUnitList </code> corresponding to the given 
     *  <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  canonical units specified in the <code> Id </code> list, in the order 
     *  of the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible canonical units may be omitted from the list and may 
     *  present the elements in any order including returning a unique set. 
     *  
     *  In active mode, canonicals are returned that are currently active. In 
     *  any status mode, active and inactive canonicals are returned. 
     *
     *  @param  canonicalUnitIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> CanonicalUnit list </code> 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.CanonicalUnitList getCanonicalUnitsByIds(org.osid.id.IdList canonicalUnitIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CanonicalUnitList </code> corresponding to the given 
     *  canonical unit genus <code> Type </code> which does not include 
     *  canonical units of types derived from the specified <code> Type. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  canonical units or an error results. Otherwise, the returned list may 
     *  contain only those canonical units that are accessible through this 
     *  session. 
     *  
     *  In active mode, canonicals are returned that are currently active. In 
     *  any status mode, active and inactive canonicals are returned. 
     *
     *  @param  canonicalUnitGenusType a canonical units genus type 
     *  @return the returned <code> CanonicalUnit list </code> 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.CanonicalUnitList getCanonicalUnitsByGenusType(org.osid.type.Type canonicalUnitGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CanonicalUnitList </code> corresponding to the given 
     *  canonical unit genus <code> Type </code> and include any additional 
     *  canonical units with genus types derived from the specified <code> 
     *  Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  canonical units or an error results. Otherwise, the returned list may 
     *  contain only those canonical units that are accessible through this 
     *  session. 
     *  
     *  In active mode, canonicals are returned that are currently active. In 
     *  any status mode, active and inactive canonicals are returned. 
     *
     *  @param  canonicalUnitGenusType a canonical unit genus type 
     *  @return the returned <code> CanonicalUnit list </code> 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.CanonicalUnitList getCanonicalUnitsByParentGenusType(org.osid.type.Type canonicalUnitGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CanonicalUnitList </code> containing the given canonical 
     *  unit record <code> Type. </code> 
     *  
     *  In plenary mode, the returned list contains all known canonical units 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those canonical units that are accessible through this session. 
     *  
     *  In active mode, canonicals are returned that are currently active. In 
     *  any status mode, active and inactive canonicals are returned. 
     *
     *  @param  canonicalUnitRecordType a canonical unit record type 
     *  @return the returned <code> CanonicalUnitList </code> 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.CanonicalUnitList getCanonicalUnitsByRecordType(org.osid.type.Type canonicalUnitRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets canonical units by code. 
     *  
     *  In plenary mode, the returned list contains all known canonical units 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those canonical units that are accessible through this session. 
     *  
     *  In active mode, canonicals are returned that are currently active. In 
     *  any status mode, active and inactive canonicals are returned. 
     *
     *  @param  code a code 
     *  @return a list of canonical units 
     *  @throws org.osid.NullArgumentException <code> code </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.CanonicalUnitList getCanonicalUnitsByCode(String code)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all canonical units. 
     *  
     *  In plenary mode, the returned list contains all known canonical units 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those canonical units that are accessible through this session. 
     *  
     *  In active mode, canonicals are returned that are currently active. In 
     *  any status mode, active and inactive canonicals are returned. 
     *
     *  @return a list of canonical units 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.CanonicalUnitList getCanonicalUnits()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
