//
// org.osid.offering.CanonicalUnitQuery
//
//     The OSID Java specification for org.osid.offering.CanonicalUnitQuery.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering;


/**
 *  <p>This is the query for searching canonical units. Each method specifies 
 *  an <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface CanonicalUnitQuery
    extends org.osid.OsidObjectQuery,
            org.osid.OsidOperableQuery {


    /**
     *  Matches a title. 
     *
     *  @param  title a title 
     *  @param  stringMatchType a string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> title </code> is not 
     *          of <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> title </code> or <code> 
     *          stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchTitle(String title, org.osid.type.Type stringMatchType, 
                           boolean match);


    /**
     *  Matches canonical units with any title. 
     *
     *  @param  match <code> true </code> to match canonical units with any 
     *          title, <code> false </code> to match canonical units with no 
     *          title 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyTitle(boolean match);


    /**
     *  Clears all title terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTitleTerms();


    /**
     *  Matches a code. 
     *
     *  @param  code a code 
     *  @param  stringMatchType a string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> code </code> is not 
     *          of <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> code </code> or <code> 
     *          stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCode(String code, org.osid.type.Type stringMatchType, 
                          boolean match);


    /**
     *  Matches canonical units with any code. 
     *
     *  @param  match <code> true </code> to match canonical units with any 
     *          code, <code> false </code> to match canonical units with no 
     *          code 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCode(boolean match);


    /**
     *  Clears all code terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCodeTerms();


    /**
     *  Sets the cyclic time period <code> Id </code> for this query. 
     *
     *  @param  cyclicTimePeriodId a cyclic time period <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> cyclicTimePeriodId 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchOfferedCyclicTimePeriodId(org.osid.id.Id cyclicTimePeriodId, 
                                               boolean match);


    /**
     *  Clears all offered cyclic time period <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOfferedCyclicTimePeriodIdTerms();


    /**
     *  Tests if a <code> CyclicTimePeriodQuery </code> is available. 
     *
     *  @return <code> true </code> if a cyclic time period query is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfferedCyclicTimePeriodQuery();


    /**
     *  Gets the query for a cyclic period query. Multiple retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @return the cyclic time period query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfferedCyclicTimePeriodQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferedCyclicTimePeriodQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.cycle.CyclicTimePeriodQuery getOfferedCyclicTimePeriodQuery();


    /**
     *  Matches canonicals that have any cyclic time period. 
     *
     *  @param  match <code> true </code> to match canonicals with any cyclic 
     *          time period, <code> false </code> to match canonicals with no 
     *          cyclic time periods 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyOfferedCyclicTimePeriod(boolean match);


    /**
     *  Clears all cyclic time period terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOfferedCyclicTimePeriodTerms();


    /**
     *  Sets the grade system <code> Id </code> for this query. 
     *
     *  @param  gradeSystemId a grade system <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> gradeSystemId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchResultOptionId(org.osid.id.Id gradeSystemId, 
                                    boolean match);


    /**
     *  Clears the grade system <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearResultOptionIdTerms();


    /**
     *  Tests if a <code> GradeSystemQuery </code> is available. 
     *
     *  @return <code> true </code> if a grade system query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResultOptionQuery();


    /**
     *  Gets the query for a grading option. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return a grade system query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResultOptionQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradingOptionQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.grading.GradeSystemQuery getResultOptionQuery();


    /**
     *  Matches canonicals that have any grading option. 
     *
     *  @param  match <code> true </code> to match canonicals with any grading 
     *          option, <code> false </code> to match canonicals with no 
     *          grading options 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyResultOption(boolean match);


    /**
     *  Clears the grading option terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearResultOptionTerms();


    /**
     *  Sets the resource <code> Id </code> for this query to match canonicals 
     *  that have a sponsor. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSponsorId(org.osid.id.Id resourceId, boolean match);


    /**
     *  Clears the sponsor <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSponsorIdTerms();


    /**
     *  Tests if a <code> ResourceQuery </code> is available. 
     *
     *  @return <code> true </code> if a resource query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSponsorQuery();


    /**
     *  Gets the query for a sponsor. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return a resource query 
     *  @throws org.osid.UnimplementedException <code> supportsSponsorQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSponsorQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceQuery getSponsorQuery();


    /**
     *  Matches canonicals that have any sponsor. 
     *
     *  @param  match <code> true </code> to match canonicals with any 
     *          sponsor, <code> false </code> to match canonicals with no 
     *          sponsors 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnySponsor(boolean match);


    /**
     *  Clears the sponsor terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSponsorTerms();


    /**
     *  Sets the catalogue <code> Id </code> for this query to match canonical 
     *  units assigned to catalogues. 
     *
     *  @param  catalogueId a catalogue <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCatalogueId(org.osid.id.Id catalogueId, boolean match);


    /**
     *  Clears all catalogue <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCatalogueIdTerms();


    /**
     *  Tests if a <code> CatalogueQuery </code> is available. 
     *
     *  @return <code> true </code> if a catalogue query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCatalogueQuery();


    /**
     *  Gets the query for a catalogue query. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the catalogue query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCatalogueQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCatalogueQuery() </code> is <code> true. </code> 
     */

    public org.osid.offering.CatalogueQuery getCatalogueQuery();


    /**
     *  Clears all catalogue terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCatalogueTerms();


    /**
     *  Gets the canonical unit query record corresponding to the given <code> 
     *  CanonicalUnit </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  canonicalUnitRecordType a canonical unit record type 
     *  @return the canonical unit query record 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(canonicalUnitRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.records.CanonicalUnitQueryRecord getCanonicalUnitQueryRecord(org.osid.type.Type canonicalUnitRecordType)
        throws org.osid.OperationFailedException;
}
