//
// org.osid.offering.CanonicalUnitSmartCatalogueSession
//
//     The OSID Java specification for org.osid.offering.CanonicalUnitSmartCatalogueSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. A <code> CanonicalUnitQuery </code> can be retrieved from this 
 *  session and mapped to this <code> Catalogue </code> to create a virtual 
 *  collection of <code> CanonicalUnits. </code> The canonical units may be 
 *  sequenced using the <code> CanonicalUnitSearchOrder </code> from this 
 *  session. </p> 
 *  
 *  <p> This <code> Catalogue </code> has a default query that matches any 
 *  canonical unit and a default search order that specifies no sequencing. 
 *  The queries may be examined using a <code> CanonicalUnitQueryInspector. 
 *  </code> The query may be modified by converting the inspector back to a 
 *  <code> CanonicalUnitQuery. </code> </p>
 */

public interface CanonicalUnitSmartCatalogueSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Catalogue </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Catalogue Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCatalogueId();


    /**
     *  Gets the <code> Catalogue </code> associated with this session. 
     *
     *  @return the <code> Catalogue </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.Catalogue getCatalogue()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart catalogues. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart catalogue management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartCatalogues();


    /**
     *  Gets a canonical unit query. 
     *
     *  @return the canonical unit query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.CanonicalUnitQuery getCanonicalUnitQuery();


    /**
     *  Gets a canonical unit search order. 
     *
     *  @return the canonical unit search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.CanonicalUnitSearchOrder getCanonicalUnitSearchOrder();


    /**
     *  Applies a canonical unit query to this catalogue. 
     *
     *  @param  canonicalUnitQuery the canonical unit query 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitQuery 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> canonical unitQuery 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyCanonicalUnitQuery(org.osid.offering.CanonicalUnitQuery canonicalUnitQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a canonical unit query inspector for this catalogue. 
     *
     *  @return the canonical unit query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.CanonicalUnitQueryInspector inspectCanonicalUnitQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a canonical unit search order to this catalogue. 
     *
     *  @param  canonicalUnitSearchOrder the canonical unit search order 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitSearchOrder 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> canonicalUnitSearchOrder 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyCanonicalUnitSequencing(org.osid.offering.CanonicalUnitSearchOrder canonicalUnitSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a canonical unit query from an inspector. 
     *
     *  @param  canonicalUnitQueryInspector a query inspector 
     *  @return the canonical unit query 
     *  @throws org.osid.NullArgumentException <code> 
     *          canonicalUnitQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          canonicalUnitQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.CanonicalUnitQuery getCanonicalUnitQueryFromInspector(org.osid.offering.CanonicalUnitQueryInspector canonicalUnitQueryInspector);
}
