//
// org.osid.offering.CatalogueNotificationSession
//
//     The OSID Java specification for org.osid.offering.CatalogueNotificationSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering;


/**
 *  <p>This session defines methods to receive notifications on adds/changes 
 *  to <code> Catalogue </code> objects. This session is intended for 
 *  consumers needing to synchronize their state with this service without the 
 *  use of polling. Notifications are cancelled when this session is closed. 
 *  </p> 
 *  
 *  <p> Notifications are triggered with changes to the <code> Catalogue 
 *  </code> object itself. Adding and removing canonical units result in 
 *  notifications available from the notification session for canonical units. 
 *  </p>
 */

public interface CatalogueNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can register for <code> Catalogue </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForCatalogueNotifications();


    /**
     *  Register for notifications of new catalogues. <code> 
     *  CatalogueReceiver.newCatalogues() </code> is invoked when a new <code> 
     *  Catalogue </code> is created. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewCatalogues()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated hierarchy structure that 
     *  introduces a new ancestor of the specified catalogue. <code> 
     *  CatalogueReceiver.newAncestorCatalogue() </code> is invoked when the 
     *  specified catalogue node gets a new ancestor. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> node to monitor 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewCatalogueAncestors(org.osid.id.Id catalogueId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated hierarchy structure that 
     *  introduces a new descendant of the specified catalogue. <code> 
     *  CatalogueReceiver.newDescendantCatalogue() </code> is invoked when the 
     *  specified catalogue node gets a new descendant. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> node to monitor 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewCatalogueDescendants(org.osid.id.Id catalogueId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated catalogues. <code> 
     *  CatalogueReceiver.changedCatalogues() </code> is invoked when a 
     *  catalogue is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedCatalogues()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated catalogue. <code> 
     *  CatalogueReceiver.changedCatalogues() </code> is invoked when the 
     *  specified catalogue is changed. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted catalogues. <code> 
     *  CatalogueReceiver.deletedCatalogues() </code> is invoked when a 
     *  catalogue is deleted. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedCatalogues()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted catalogue. <code> 
     *  CatalogueReceiver.deletedCatalogues() </code> is invoked when the 
     *  specified catalogue is deleted. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated hierarchy structure that 
     *  removes an ancestor of the specified catalogue <code> 
     *  CatalogueReceiver.deletedAncestor() </code> is invoked when the 
     *  specified catalogue node loses an ancestor. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedCatalogueAncestors(org.osid.id.Id catalogueId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated hierarchy structure that 
     *  removes a descendant of the specified catalogue. <code> 
     *  CatalogueReceiver.deletedDescendant() </code> is invoked when the 
     *  specified catalogue node loses a descendant. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedCatalogueDescendants(org.osid.id.Id catalogueId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
