//
// org.osid.offering.CatalogueQuery
//
//     The OSID Java specification for org.osid.offering.CatalogueQuery.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering;


/**
 *  <p>This is the query for searching for catalogues. Each method specifies 
 *  an <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface CatalogueQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Sets the canonical unit <code> Id </code> for this query to match 
     *  canonical units assigned to catalogues. 
     *
     *  @param  canonicalUnitId a canonical unit <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCanonicalUnitId(org.osid.id.Id canonicalUnitId, 
                                     boolean match);


    /**
     *  Clears all canonical unit <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCanonicalUnitIdTerms();


    /**
     *  Tests if a canonical unit query is available. 
     *
     *  @return <code> true </code> if a canonical unit query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCanonicalUnitQuery();


    /**
     *  Gets the query for a catalogue. 
     *
     *  @return the canonical unit query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.offering.CanonicalUnitQuery getCanonicalUnitQuery();


    /**
     *  Matches catalogues with any canonical unit. 
     *
     *  @param  match <code> true </code> to match catalogues with any 
     *          canonical unit, <code> false </code> to match catalogues with 
     *          no canonical units 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCanonicalUnit(boolean match);


    /**
     *  Clears all canonical unit terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCanonicalUnitTerms();


    /**
     *  Sets the offering <code> Id </code> for this query to match offerings 
     *  assigned to catalogues. 
     *
     *  @param  offeringId an offering <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> offeringId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchOfferingId(org.osid.id.Id offeringId, boolean match);


    /**
     *  Clears all offering <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOfferingIdTerms();


    /**
     *  Tests if an offering query is available. 
     *
     *  @return <code> true </code> if an offering query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfferingQuery();


    /**
     *  Gets the query for an offering. 
     *
     *  @return the offering query 
     *  @throws org.osid.UnimplementedException <code> supportsOfferingQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingQuery() </code> is <code> true. </code> 
     */

    public org.osid.offering.OfferingQuery getOfferingQuery();


    /**
     *  Matches catalogues with any offering. 
     *
     *  @param  match <code> true </code> to match catalogues with any 
     *          offering, <code> false </code> to match catalogues with no 
     *          offerings 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyOffering(boolean match);


    /**
     *  Clears all offering terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOfferingTerms();


    /**
     *  Sets the participant <code> Id </code> for this query to match 
     *  participants assigned to catalogues. 
     *
     *  @param  participantId a participant <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> participantId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchParticipantId(org.osid.id.Id participantId, boolean match);


    /**
     *  Clears all participant <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearParticipantIdTerms();


    /**
     *  Tests if a participant query is available. 
     *
     *  @return <code> true </code> if a participant query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsParticipantQuery();


    /**
     *  Gets the query for a participant. 
     *
     *  @return the participant query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParticipantQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParticipantQuery() </code> is <code> true. </code> 
     */

    public org.osid.offering.ParticipantQuery getParticipantQuery();


    /**
     *  Matches catalogues with any participant. 
     *
     *  @param  match <code> true </code> to match catalogues with any 
     *          participant, <code> false </code> to match catalogues with no 
     *          participants 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyParticipant(boolean match);


    /**
     *  Clears all participant terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearParticipantTerms();


    /**
     *  Sets the result <code> Id </code> for this query to match results. 
     *
     *  @param  resultId an result <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> resultId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchResultId(org.osid.id.Id resultId, boolean match);


    /**
     *  Clears all result <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearResultIdTerms();


    /**
     *  Tests if an result query is available. 
     *
     *  @return <code> true </code> if an result query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResultQuery();


    /**
     *  Gets the query for an result. 
     *
     *  @return the result query 
     *  @throws org.osid.UnimplementedException <code> supportsResultQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResultQuery() </code> is <code> true. </code> 
     */

    public org.osid.offering.ResultQuery getResultQuery();


    /**
     *  Matches catalogues with any result. 
     *
     *  @param  match <code> true </code> to match catalogues with any result, 
     *          <code> false </code> to match catalogues with no results 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyResult(boolean match);


    /**
     *  Clears all result terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearResultTerms();


    /**
     *  Sets the catalogue <code> Id </code> for this query to match 
     *  catalogues that have the specified catalogue as an ancestor. 
     *
     *  @param  catalogueId a catalogue <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorCatalogueId(org.osid.id.Id catalogueId, 
                                         boolean match);


    /**
     *  Clears all ancestor catalogue <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorCatalogueIdTerms();


    /**
     *  Tests if a <code> CatalogueQuery </code> is available. 
     *
     *  @return <code> true </code> if a catalogue query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorCatalogueQuery();


    /**
     *  Gets the query for a catalogue. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the catalogue query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorCatalogueQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorCatalogueQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.offering.CatalogueQuery getAncestorCatalogueQuery();


    /**
     *  Matches catalogues with any ancestor. 
     *
     *  @param  match <code> true </code> to match catalogues with any 
     *          ancestor, <code> false </code> to match root catalogues 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorCatalogue(boolean match);


    /**
     *  Clears all ancestor catalogue terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorCatalogueTerms();


    /**
     *  Sets the catalogue <code> Id </code> for this query to match 
     *  catalogues that have the specified catalogue as a descendant. 
     *
     *  @param  catalogueId a catalogue <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantCatalogueId(org.osid.id.Id catalogueId, 
                                           boolean match);


    /**
     *  Clears all descendant catalogue <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantCatalogueIdTerms();


    /**
     *  Tests if a <code> CatalogueQuery </code> is available. 
     *
     *  @return <code> true </code> if a catalogue query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantCatalogueQuery();


    /**
     *  Gets the query for a catalogue. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the catalogue query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantCatalogueQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantCatalogueQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.offering.CatalogueQuery getDescendantCatalogueQuery();


    /**
     *  Matches catalogues with any descendant. 
     *
     *  @param  match <code> true </code> to match catalogues with any 
     *          descendant, <code> false </code> to match leaf catalogues 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantCatalogue(boolean match);


    /**
     *  Clears all descendant catalogue terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantCatalogueTerms();


    /**
     *  Gets the record query corresponding to the given <code> Catalogue 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested boolean <code> OR </code> term. 
     *
     *  @param  catalogueRecordType a catalogue record type 
     *  @return the catalogue query record 
     *  @throws org.osid.NullArgumentException <code> catalogueRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(catalogueRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.records.CatalogueQueryRecord getCatalogueQueryRecord(org.osid.type.Type catalogueRecordType)
        throws org.osid.OperationFailedException;
}
