//
// org.osid.offering.CatalogueReceiver
//
//     The OSID Java specification for org.osid.offering.CatalogueReceiver.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering;


/**
 *  <p>The catalogue receiver is the consumer supplied interface for receiving 
 *  notifications pertaining to new, updated or deleted <code> Catalogue 
 *  </code> objects. </p>
 */

public interface CatalogueReceiver
    extends org.osid.OsidReceiver {


    /**
     *  The callback for notifications of new catalogues. 
     *
     *  @param  catalogueIds the <code> Ids </code> of the new <code> 
     *          Catalogues </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newCatalogues(org.osid.id.IdList catalogueIds);


    /**
     *  The callback for notifications of new ancestors of a catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the registered <code> 
     *          Catalogue </code> 
     *  @param  ancestorId the Id of the new ancestor catalogue 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newAncestorCatalogue(org.osid.id.Id catalogueId, 
                                     org.osid.id.Id ancestorId);


    /**
     *  The callback for notifications of new descendant of a catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the registered <code> 
     *          Catalogue </code> 
     *  @param  descendantId the Id of the new descendant catalogue 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newDescendantCatalogue(org.osid.id.Id catalogueId, 
                                       org.osid.id.Id descendantId);


    /**
     *  The callback for notification of updated catalogues. 
     *
     *  @param  catalogueIds the <code> Ids </code> of the updated <code> 
     *          Catalogues </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void changedCatalogues(org.osid.id.IdList catalogueIds);


    /**
     *  the callback for notification of deleted catalogues. 
     *
     *  @param  catalogueIds the <code> Ids </code> of the registered <code> 
     *          Catalogues </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedCatalogues(org.osid.id.IdList catalogueIds);


    /**
     *  The callback for notifications of deleted ancestors of a catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the registered <code> 
     *          Catalogue </code> 
     *  @param  ancestorId the Id of the removed ancestor catalogue 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedAncestorCatalogue(org.osid.id.Id catalogueId, 
                                         org.osid.id.Id ancestorId);


    /**
     *  The callback for notifications of deleted descendants of a catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the registered <code> 
     *          Catalogue </code> 
     *  @param  descendantId the Id of the deleted descendant catalogue 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedDescendantCatalogue(org.osid.id.Id catalogueId, 
                                           org.osid.id.Id descendantId);


    /**
     *  The callback for notifications of changes to a catalogue hierarchy 
     *  where the hierarchy needs to refreshed. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void restructuredCatalogueHierarchy();
}
