//
// org.osid.offering.OfferingLookupSession
//
//     The OSID Java specification for org.osid.offering.OfferingLookupSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering;


/**
 *  <p>This session defines methods for retrieving offerings. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated catalogue view: All offering methods in this session 
 *      operate, retrieve and pertain to offerings defined explicitly in the 
 *      current catalogue. Using an isolated view is useful for managing 
 *      offerings with the <code> OfferingAdminSession. </code> </li> 
 *      <li> federated catalogue view: All offering lookup methods in this 
 *      session operate, retrieve and pertain to all offerings defined in this 
 *      catalogue and any other catalogues implicitly available in this 
 *      catalogue through catalogue inheritence. </li> 
 *      <li> effective offering view: All offering lookup methods return 
 *      offerings where the current date falls in between the effective dates 
 *      inclusive. </li> 
 *      <li> any status offering view: Offerings of any effective date are 
 *      returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedCatalogueView() </code> and <code> 
 *  useIsolatedCatalogueView() </code> behave as a radio group and one should 
 *  be selected before invoking any lookup methods. </p>
 */

public interface OfferingLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Catalogue </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Catalogue Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCatalogueId();


    /**
     *  Gets the <code> Catalogue </code> associated with this session. 
     *
     *  @return the catalogue 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.Catalogue getCatalogue()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can examine this catalogue. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer these operations. 
     *
     *  @return <code> false </code> if catalogue reading methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupOfferings();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeOfferingView();


    /**
     *  A complete view of the <code> Offering </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryOfferingView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include offerings in catalogues which are children of this catalogue 
     *  in the catalogue hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCatalogueView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this catalogue only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCatalogueView();


    /**
     *  Only offerings whose effective dates are current are returned by 
     *  methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useEffectiveOfferingView();


    /**
     *  All offerings of any effective dates are returned by methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyEffectiveOfferingView();


    /**
     *  Gets the <code> Offering </code> specified by its <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Offering </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to an <code> Offering </code> and retained for compatibility. 
     *  
     *  In effective mode, offerings are returned that are currently 
     *  effective. In any effective mode, effective offerings and those 
     *  currently expired are returned. 
     *
     *  @param  offeringId the <code> Id </code> of the <code> Offering 
     *          </code> to retrieve 
     *  @return the returned <code> Offering </code> 
     *  @throws org.osid.NotFoundException no <code> Offering </code> found 
     *          with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> offeringId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.Offering getOffering(org.osid.id.Id offeringId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> OfferingList </code> corresponding to the given <code> 
     *  IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  offerings specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible offerings may be omitted from the list and may present 
     *  the elements in any order including returning a unique set. 
     *  
     *  In effective mode, offerings are returned that are currently 
     *  effective. In any effective mode, effective offerings and those 
     *  currently expired are returned. 
     *
     *  @param  offeringIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Offering list </code> 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> offeringIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.OfferingList getOfferingsByIds(org.osid.id.IdList offeringIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> OfferingList </code> corresponding to the given 
     *  offering genus <code> Type </code> which does not include offerings of 
     *  types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  offerings or an error results. Otherwise, the returned list may 
     *  contain only those offerings that are accessible through this session. 
     *  
     *  In effective mode, offerings are returned that are currently 
     *  effective. In any effective mode, effective offerings and those 
     *  currently expired are returned. 
     *
     *  @param  offeringGenusType an offerings genus type 
     *  @return the returned <code> Offering list </code> 
     *  @throws org.osid.NullArgumentException <code> offeringGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.OfferingList getOfferingsByGenusType(org.osid.type.Type offeringGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> OfferingList </code> corresponding to the given 
     *  offering genus <code> Type </code> and include any additional 
     *  offerings with genus types derived from the specified <code> Type. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  offerings or an error results. Otherwise, the returned list may 
     *  contain only those offerings that are accessible through this session. 
     *  
     *  In effective mode, offerings are returned that are currently 
     *  effective. In any effective mode, effective offerings and those 
     *  currently expired are returned. 
     *
     *  @param  offeringGenusType an offering genus type 
     *  @return the returned <code> Offering list </code> 
     *  @throws org.osid.NullArgumentException <code> offeringGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.OfferingList getOfferingsByParentGenusType(org.osid.type.Type offeringGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> OfferingList </code> containing the given offering 
     *  record <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  offerings or an error results. Otherwise, the returned list may 
     *  contain only those offerings that are accessible through this session. 
     *  
     *  In effective mode, offerings are returned that are currently 
     *  effective. In any effective mode, effective offerings and those 
     *  currently expired are returned. 
     *
     *  @param  offeringRecordType an offering record type 
     *  @return the returned <code> OfferingList </code> 
     *  @throws org.osid.NullArgumentException <code> offeringRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.OfferingList getOfferingsByRecordType(org.osid.type.Type offeringRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> OfferingList </code> effective during the entire given 
     *  date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known offerings or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  offerings that are accessible through this session. 
     *  
     *  In effective mode, offerings are returned that are currently 
     *  effective. In any effective mode, effective offerings and those 
     *  currently expired are returned. 
     *
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> OfferingList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.OfferingList getOfferingsOnDate(org.osid.calendaring.DateTime from, 
                                                             org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> OfferingList </code> by genus type and effective during 
     *  the entire given date range inclusive but not confined to the date 
     *  range. 
     *  
     *  In plenary mode, the returned list contains all known offerings or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  offerings that are accessible through this session. 
     *  
     *  In effective mode, offerings are returned that are currently 
     *  effective. In any effective mode, effective offerings and those 
     *  currently expired are returned. 
     *
     *  @param  offeringGenusType an offering genus type 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> OfferingList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> offeringGenusType, from, 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.OfferingList getOfferingsByGenusTypeOnDate(org.osid.type.Type offeringGenusType, 
                                                                        org.osid.calendaring.DateTime from, 
                                                                        org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> OfferingList </code> for the given canonical unit. 
     *  <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  offerings or an error results. Otherwise, the returned list may 
     *  contain only those offerings that are accessible through this session. 
     *  
     *  In effective mode, offerings are returned that are currently 
     *  effective. In any effective mode, effective offerings and those 
     *  currently expired are returned. 
     *
     *  @param  canonicalUnitId a canonical unit <code> Id </code> 
     *  @return the returned <code> OfferingList </code> 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.OfferingList getOfferingsForCanonicalUnit(org.osid.id.Id canonicalUnitId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> OfferingList </code> by genus type for the given 
     *  canonical unit. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  offerings or an error results. Otherwise, the returned list may 
     *  contain only those offerings that are accessible through this session. 
     *  
     *  In effective mode, offerings are returned that are currently 
     *  effective. In any effective mode, effective offerings and those 
     *  currently expired are returned. 
     *
     *  @param  canonicalUnitId a canonical unit <code> Id </code> 
     *  @param  offeringGenusType an offering genus type 
     *  @return the returned <code> OfferingList </code> 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitId </code> 
     *          or <code> offeringGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.OfferingList getOfferingsByGenusTypeForCanonicalUnit(org.osid.id.Id canonicalUnitId, 
                                                                                  org.osid.type.Type offeringGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> OfferingList </code> for the given canonical unit and 
     *  effective during the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known offerings or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  offerings that are accessible through this session. 
     *  
     *  In effective mode, offerings are returned that are currently 
     *  effective. In any effective mode, effective offerings and those 
     *  currently expired are returned. 
     *
     *  @param  canonicalUnitId a canonical unit <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> OfferingList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitId, from, 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.OfferingList getOfferingsForCanonicalUnitOnDate(org.osid.id.Id canonicalUnitId, 
                                                                             org.osid.calendaring.DateTime from, 
                                                                             org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> OfferingList </code> by genus type for the given 
     *  canonical unit and effective during the entire given date range 
     *  inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known offerings or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  offerings that are accessible through this session. 
     *  
     *  In effective mode, offerings are returned that are currently 
     *  effective. In any effective mode, effective offerings and those 
     *  currently expired are returned. 
     *
     *  @param  canonicalUnitId a canonical unit <code> Id </code> 
     *  @param  offeringGenusType an offering genus type 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> OfferingList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitId, 
     *          offeringGenusType, from, </code> or <code> to </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.OfferingList getOfferingsByGenusTypeForCanonicalUnitOnDate(org.osid.id.Id canonicalUnitId, 
                                                                                        org.osid.type.Type offeringGenusType, 
                                                                                        org.osid.calendaring.DateTime from, 
                                                                                        org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> OfferingList </code> for the given time period. <code> 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  offerings or an error results. Otherwise, the returned list may 
     *  contain only those offerings that are accessible through this session. 
     *  
     *  In effective mode, offerings are returned that are currently 
     *  effective. In any effective mode, effective offerings and those 
     *  currently expired are returned. 
     *
     *  @param  timePeriodId a time period <code> Id </code> 
     *  @return the returned <code> OfferingList </code> 
     *  @throws org.osid.NullArgumentException <code> timePeriodId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.OfferingList getOfferingsForTimePeriod(org.osid.id.Id timePeriodId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> OfferingList </code> by genus type for the given time 
     *  period. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  offerings or an error results. Otherwise, the returned list may 
     *  contain only those offerings that are accessible through this session. 
     *  
     *  In effective mode, offerings are returned that are currently 
     *  effective. In any effective mode, effective offerings and those 
     *  currently expired are returned. 
     *
     *  @param  timePeriodId a time period <code> Id </code> 
     *  @param  offeringGenusType an offering genus type 
     *  @return the returned <code> OfferingList </code> 
     *  @throws org.osid.NullArgumentException <code> timePeriodId </code> or 
     *          <code> offeringGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.OfferingList getOfferingsByGenusTypeForTimePeriod(org.osid.id.Id timePeriodId, 
                                                                               org.osid.type.Type offeringGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> OfferingList </code> for the given time period and 
     *  effective during the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known offerings or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  offerings that are accessible through this session. 
     *  
     *  In effective mode, offerings are returned that are currently 
     *  effective. In any effective mode, effective offerings and those 
     *  currently expired are returned. 
     *
     *  @param  timePeriodId a time period <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> OfferingList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> timePeriodId, from, 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.OfferingList getOfferingsForTimePeriodOnDate(org.osid.id.Id timePeriodId, 
                                                                          org.osid.calendaring.DateTime from, 
                                                                          org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> OfferingList </code> by genus type for the given time 
     *  period and effective during the entire given date range inclusive but 
     *  not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known offerings or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  offerings that are accessible through this session. 
     *  
     *  In effective mode, offerings are returned that are currently 
     *  effective. In any effective mode, effective offerings and those 
     *  currently expired are returned. 
     *
     *  @param  timePeriodId a time period <code> Id </code> 
     *  @param  offeringGenusType an offering genus type 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> OfferingList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> timePeriodId, 
     *          offeringGenusType, from, </code> or <code> to </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.OfferingList getOfferingsByGenusTypeForTimePeriodOnDate(org.osid.id.Id timePeriodId, 
                                                                                     org.osid.type.Type offeringGenusType, 
                                                                                     org.osid.calendaring.DateTime from, 
                                                                                     org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> OfferingList </code> for the given canonical unit and 
     *  time period. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  offerings or an error results. Otherwise, the returned list may 
     *  contain only those offerings that are accessible through this session. 
     *  
     *  In effective mode, offerings are returned that are currently 
     *  effective. In any effective mode, effective offerings and those 
     *  currently expired are returned. 
     *
     *  @param  canonicalUnitId a canonical unit <code> Id </code> 
     *  @param  timePeriodId a time period <code> Id </code> 
     *  @return the returned <code> OfferingList </code> 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitId </code> 
     *          or <code> timePeriodId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.OfferingList getOfferingsForCanonicalUnitAndTimePeriod(org.osid.id.Id canonicalUnitId, 
                                                                                    org.osid.id.Id timePeriodId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> OfferingList </code> by genus type for the given 
     *  canonical unit and time period. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  offerings or an error results. Otherwise, the returned list may 
     *  contain only those offerings that are accessible through this session. 
     *  
     *  In effective mode, offerings are returned that are currently 
     *  effective. In any effective mode, effective offerings and those 
     *  currently expired are returned. 
     *
     *  @param  canonicalUnitId a canonical unit <code> Id </code> 
     *  @param  timePeriodId a time period <code> Id </code> 
     *  @param  offeringGenusType an offering genus type 
     *  @return the returned <code> OfferingList </code> 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitId, </code> 
     *          <code> timePeriodId, </code> or <code> offeringGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.OfferingList getOfferingsByGenusTypeForCanonicalUnitAndTimePeriod(org.osid.id.Id canonicalUnitId, 
                                                                                               org.osid.id.Id timePeriodId, 
                                                                                               org.osid.type.Type offeringGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> OfferingList </code> for the given canonical unit, time 
     *  period, and effective during the entire given date range inclusive but 
     *  not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known offerings or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  offerings that are accessible through this session. 
     *  
     *  In effective mode, offerings are returned that are currently 
     *  effective. In any effective mode, effective offerings and those 
     *  currently expired are returned. 
     *
     *  @param  canonicalUnitId a canonical unit <code> Id </code> 
     *  @param  timePeriodId a time period <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> OfferingList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitId, 
     *          timePeriodId, from, </code> or <code> to </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.OfferingList getOfferingsForCanonicalUnitAndTimePeriodOnDate(org.osid.id.Id canonicalUnitId, 
                                                                                          org.osid.id.Id timePeriodId, 
                                                                                          org.osid.calendaring.DateTime from, 
                                                                                          org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> OfferingList </code> by genus type for the given 
     *  canonical, time period, and effective during the entire given date 
     *  range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known offerings or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  offerings that are accessible through this session. 
     *  
     *  In effective mode, offerings are returned that are currently 
     *  effective. In any effective mode, effective offerings and those 
     *  currently expired are returned. 
     *
     *  @param  canonicalUnitId a canonical unit <code> Id </code> 
     *  @param  timePeriodId a time period <code> Id </code> 
     *  @param  offeringGenusType an offering genus type 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> OfferingList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitId, 
     *          timePeriodId, offeringGenusType, from, </code> or <code> to 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.OfferingList getOfferingsByGenusTypeForCanonicalUnitAndTimePeriodOnDate(org.osid.id.Id canonicalUnitId, 
                                                                                                     org.osid.id.Id timePeriodId, 
                                                                                                     org.osid.type.Type offeringGenusType, 
                                                                                                     org.osid.calendaring.DateTime from, 
                                                                                                     org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> OfferingList </code> by code and time period. 
     *  
     *  In plenary mode, the returned list contains all known offerings or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  offerings that are accessible through this session. 
     *  
     *  In effective mode, offerings are returned that are currently 
     *  effective. In any effective mode, effective offerings and those 
     *  currently expired are returned. 
     *
     *  @param  code a canonical unit <code> Id </code> 
     *  @param  timePeriodId a time period <code> Id </code> 
     *  @return the returned <code> OfferingList </code> 
     *  @throws org.osid.NullArgumentException <code> code </code> or <code> 
     *          timePeriodId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.OfferingList getOfferingsByCodeAndTimePeriod(String code, 
                                                                          org.osid.id.Id timePeriodId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all offerings. 
     *  
     *  In plenary mode, the returned list contains all known offerings or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  offerings that are accessible through this session. 
     *  
     *  In effective mode, offerings are returned that are currently 
     *  effective. In any effective mode, effective offerings and those 
     *  currently expired are returned. 
     *
     *  @return a list of offerings 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.OfferingList getOfferings()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
