//
// org.osid.offering.OfferingProfile
//
//     The OSID Java specification for org.osid.offering.OfferingProfile.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering;


/**
 *  <p>The offering profile describes the interoperability among offering 
 *  services. </p>
 */

public interface OfferingProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any catalogue federation is exposed. Federation is exposed 
     *  when a specific catalogue may be identified, selected and used to 
     *  create a lookup or admin session. Federation is not exposed when a set 
     *  of catalogues appears as a single catalogue. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests for the availability of a canonical unit lookup service. 
     *
     *  @return <code> true </code> if canonical unit lookup is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCanonicalUnitLookup();


    /**
     *  Tests for the availability of a canonical unit query service. 
     *
     *  @return <code> true </code> if canonical unit query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCanonicalUnitQuery();


    /**
     *  Tests if searching for canonical units is available. 
     *
     *  @return <code> true </code> if canonical unit search is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCanonicalUnitSearch();


    /**
     *  Tests if managing for canonical units is available. 
     *
     *  @return <code> true </code> if a canonical unit adminstrative service 
     *          is available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCanonicalUnitAdmin();


    /**
     *  Tests if canonical unit notification is available. 
     *
     *  @return <code> true </code> if canonical unit notification is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCanonicalUnitNotification();


    /**
     *  Tests if a canonical unit to catalogue lookup session is available. 
     *
     *  @return <code> true </code> if canonical unit catalogue lookup session 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCanonicalUnitCatalogue();


    /**
     *  Tests if a canonical unit to catalogue assignment session is 
     *  available. 
     *
     *  @return <code> true </code> if canonical unit catalogue assignment is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCanonicalUnitCatalogueAssignment();


    /**
     *  Tests if a canonical unit smart catalogue session is available. 
     *
     *  @return <code> true </code> if canonical unit smart catalogue is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCanonicalUnitSmartCatalogue();


    /**
     *  Tests for the availability of an offering lookup service. 
     *
     *  @return <code> true </code> if offering lookup is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfferingLookup();


    /**
     *  Tests for the availability of an offering query service. 
     *
     *  @return <code> true </code> if offering query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfferingQuery();


    /**
     *  Tests if searching for offerings is available. 
     *
     *  @return <code> true </code> if offering search is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfferingSearch();


    /**
     *  Tests if managing for offerings is available. 
     *
     *  @return <code> true </code> if an offering adminstrative service is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfferingAdmin();


    /**
     *  Tests if offering notification is available. 
     *
     *  @return <code> true </code> if offering notification is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfferingNotification();


    /**
     *  Tests if an offering to catalogue lookup session is available. 
     *
     *  @return <code> true </code> if offering catalogue lookup session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfferingCatalogue();


    /**
     *  Tests if an offering to catalogue assignment session is available. 
     *
     *  @return <code> true </code> if offering catalogue assignment is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfferingCatalogueAssignment();


    /**
     *  Tests if an offering smart catalogue session is available. 
     *
     *  @return <code> true </code> if offering smart catalogue is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfferingSmartCatalogue();


    /**
     *  Tests for the availability of a participant lookup service. 
     *
     *  @return <code> true </code> if participant lookup is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsParticipantLookup();


    /**
     *  Tests for the availability of a participant query service. 
     *
     *  @return <code> true </code> if participant query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsParticipantQuery();


    /**
     *  Tests if searching for participants is available. 
     *
     *  @return <code> true </code> if participant search is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsParticipantSearch();


    /**
     *  Tests if managing for participants is available. 
     *
     *  @return <code> true </code> if a participant adminstrative service is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsParticipantAdmin();


    /**
     *  Tests if participant notification is available. 
     *
     *  @return <code> true </code> if participant notification is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsParticipantNotification();


    /**
     *  Tests if a participant to catalogue lookup session is available. 
     *
     *  @return <code> true </code> if participant catalogue lookup session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsParticipantCatalogue();


    /**
     *  Tests if a participant to catalogue assignment session is available. 
     *
     *  @return <code> true </code> if participant catalogue assignment is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsParticipantCatalogueAssignment();


    /**
     *  Tests if a participant smart catalogue session is available. 
     *
     *  @return <code> true </code> if participant smart catalogue is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsParticipantSmartCatalogue();


    /**
     *  Tests for the availability of an result lookup service. 
     *
     *  @return <code> true </code> if result lookup is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResultLookup();


    /**
     *  Tests for the availability of an result query service. 
     *
     *  @return <code> true </code> if result query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResultQuery();


    /**
     *  Tests if searching for results is available. 
     *
     *  @return <code> true </code> if result search is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResultSearch();


    /**
     *  Tests if managing for results is available. 
     *
     *  @return <code> true </code> if an result adminstrative service is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResultAdmin();


    /**
     *  Tests if result notification is available. 
     *
     *  @return <code> true </code> if result notification is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResultNotification();


    /**
     *  Tests if an result to catalogue lookup session is available. 
     *
     *  @return <code> true </code> if result catalogue lookup session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResultCatalogue();


    /**
     *  Tests if an result to catalogue assignment session is available. 
     *
     *  @return <code> true </code> if result catalogue assignment is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResultCatalogueAssignment();


    /**
     *  Tests if an result smart catalogue session is available. 
     *
     *  @return <code> true </code> if result smart catalogue is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResultSmartCatalogue();


    /**
     *  Tests for the availability of an catalogue lookup service. 
     *
     *  @return <code> true </code> if catalogue lookup is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCatalogueLookup();


    /**
     *  Tests if querying catalogues is available. 
     *
     *  @return <code> true </code> if catalogue query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCatalogueQuery();


    /**
     *  Tests if searching for catalogues is available. 
     *
     *  @return <code> true </code> if catalogue search is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCatalogueSearch();


    /**
     *  Tests for the availability of a catalogue administrative service for 
     *  creating and deleting catalogues. 
     *
     *  @return <code> true </code> if catalogue administration is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCatalogueAdmin();


    /**
     *  Tests for the availability of a catalogue notification service. 
     *
     *  @return <code> true </code> if catalogue notification is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsCatalogueNotification();


    /**
     *  Tests for the availability of a catalogue hierarchy traversal service. 
     *
     *  @return <code> true </code> if catalogue hierarchy traversal is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCatalogueHierarchy();


    /**
     *  Tests for the availability of a catalogue hierarchy design service. 
     *
     *  @return <code> true </code> if catalogue hierarchy design is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsCatalogueHierarchyDesign();


    /**
     *  Tests for the availability of a offering batch service. 
     *
     *  @return <code> true </code> if a offering batch service is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsOfferingBatch();


    /**
     *  Tests for the availability of a offering rules service. 
     *
     *  @return <code> true </code> if a offering rules service is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsOfferingRules();


    /**
     *  Gets the supported <code> CanonicalUnit </code> record types. 
     *
     *  @return a list containing the supported canonical unit record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCanonicalUnitRecordTypes();


    /**
     *  Tests if the given <code> CanonicalUnit </code> record type is 
     *  supported. 
     *
     *  @param  canonicalUnitRecordType a <code> Type </code> indicating a 
     *          <code> CanonicalUnit </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCanonicalUnitRecordType(org.osid.type.Type canonicalUnitRecordType);


    /**
     *  Gets the supported canonical unit search record types. 
     *
     *  @return a list containing the supported canonical unit search record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCanonicalUnitSearchRecordTypes();


    /**
     *  Tests if the given canonical unit search record type is supported. 
     *
     *  @param  canonicalUnitSearchRecordType a <code> Type </code> indicating 
     *          a canonical unit record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          canonicalUnitSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCanonicalUnitSearchRecordType(org.osid.type.Type canonicalUnitSearchRecordType);


    /**
     *  Gets the supported <code> Offering </code> record types. 
     *
     *  @return a list containing the supported offering record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getOfferingRecordTypes();


    /**
     *  Tests if the given <code> Offering </code> record type is supported. 
     *
     *  @param  offeringRecordType a <code> Type </code> indicating an <code> 
     *          Offering </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> offeringRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfferingRecordType(org.osid.type.Type offeringRecordType);


    /**
     *  Gets the supported offering search record types. 
     *
     *  @return a list containing the supported offering search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getOfferingSearchRecordTypes();


    /**
     *  Tests if the given offering search record type is supported. 
     *
     *  @param  offeringSearchRecordType a <code> Type </code> indicating an 
     *          offering record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> offeringSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfferingSearchRecordType(org.osid.type.Type offeringSearchRecordType);


    /**
     *  Gets the supported <code> Participant </code> record types. 
     *
     *  @return a list containing the supported participant record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getParticipantRecordTypes();


    /**
     *  Tests if the given <code> Participant </code> record type is 
     *  supported. 
     *
     *  @param  participantRecordType a <code> Type </code> indicating a 
     *          <code> Participant </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> participantRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsParticipantRecordType(org.osid.type.Type participantRecordType);


    /**
     *  Gets the supported participant search record types. 
     *
     *  @return a list containing the supported participant search record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getParticipantSearchRecordTypes();


    /**
     *  Tests if the given participant search record type is supported. 
     *
     *  @param  participantSearchRecordType a <code> Type </code> indicating a 
     *          participant record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          participantSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsParticipantSearchRecordType(org.osid.type.Type participantSearchRecordType);


    /**
     *  Gets the supported <code> Result </code> record types. 
     *
     *  @return a list containing the supported result record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getResultRecordTypes();


    /**
     *  Tests if the given <code> Result </code> record type is supported. 
     *
     *  @param  resultRecordType a <code> Type </code> indicating an <code> 
     *          Result </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> resultRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResultRecordType(org.osid.type.Type resultRecordType);


    /**
     *  Gets the supported result search record types. 
     *
     *  @return a list containing the supported result search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getResultSearchRecordTypes();


    /**
     *  Tests if the given result search record type is supported. 
     *
     *  @param  resultSearchRecordType a <code> Type </code> indicating an 
     *          result record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> resultSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResultSearchRecordType(org.osid.type.Type resultSearchRecordType);


    /**
     *  Gets the supported <code> Catalogue </code> record types. 
     *
     *  @return a list containing the supported catalogue record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCatalogueRecordTypes();


    /**
     *  Tests if the given <code> Catalogue </code> record type is supported. 
     *
     *  @param  catalogueRecordType a <code> Type </code> indicating a <code> 
     *          Catalogue </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> catalogueRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCatalogueRecordType(org.osid.type.Type catalogueRecordType);


    /**
     *  Gets the supported catalogue search record types. 
     *
     *  @return a list containing the supported catalogue search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCatalogueSearchRecordTypes();


    /**
     *  Tests if the given catalogue search record type is supported. 
     *
     *  @param  catalogueSearchRecordType a <code> Type </code> indicating a 
     *          catalogue record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          catalogueSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCatalogueSearchRecordType(org.osid.type.Type catalogueSearchRecordType);
}
