//
// org.osid.offering.OfferingSearchSession
//
//     The OSID Java specification for org.osid.offering.OfferingSearchSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering;


/**
 *  <p>This session provides methods for searching <code> Offering </code> 
 *  objects. The search query is constructed using the <code> OfferingQuery. 
 *  </code> The offering record <code> Type </code> also specifies the record 
 *  for the offering query. </p> 
 *  
 *  <p> <code> getOfferingsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Offering </code> elements. A more advanced search 
 *  may be performed with <code> getOfferingsBySearch(). </code> It accepts an 
 *  <code> OfferingSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getOfferingsBySearch() </code> returns an <code> 
 *  OfferingSearchResults </code> that can be used to access the resulting 
 *  <code> OfferingList </code> or be used to perform a search within the 
 *  result set through <code> OfferingSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated catalogue view: searches include offerings in 
 *      catalogues of which this catalogue is a ancestor in the catalogue 
 *      hierarchy </li> 
 *      <li> isolated catalogue view: searches are restricted to offerings in 
 *      this catalogue </li> 
 *  </ul>
 *  
 *  
 *  <p> Offerings may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> OfferingQuery. </code> 
 *  The returns in this session may not be cast directly to these interfaces. 
 *  </p>
 */

public interface OfferingSearchSession
    extends org.osid.offering.OfferingQuerySession {


    /**
     *  Gets an offering search. 
     *
     *  @return the offering search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.OfferingSearch getOfferingSearch();


    /**
     *  Gets an offering search order. The <code> OfferingSearchOrder </code> 
     *  is supplied to an <code> OfferingSearch </code> to specify the 
     *  ordering of results. 
     *
     *  @return the offering search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.OfferingSearchOrder getOfferingSearchOrder();


    /**
     *  Gets the search results matching the given search. 
     *
     *  @param  offeringQuery the offering query 
     *  @param  offeringSearch the offering search 
     *  @return the search results 
     *  @throws org.osid.NullArgumentException <code> offeringQuery </code> or 
     *          <code> offeringSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> offeringQuery </code> or 
     *          <code> offeringSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.OfferingSearchResults getOfferingsBySearch(org.osid.offering.OfferingQuery offeringQuery, 
                                                                        org.osid.offering.OfferingSearch offeringSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an offering query from an inspector. The inspector is available 
     *  from an <code> OfferingSearchResults. </code> 
     *
     *  @param  offeringQueryInspector an offering query inspector 
     *  @return the offering query 
     *  @throws org.osid.NullArgumentException <code> offeringQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> offeringQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.OfferingQuery getOfferingQueryFromInspector(org.osid.offering.OfferingQueryInspector offeringQueryInspector);
}
