//
// org.osid.offering.Participant
//
//     The OSID Java specification for org.osid.offering.Participant.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering;


/**
 *  <p>A <code> Participant </code> in an <code> OsidRelationship </code> 
 *  between an <code> Offering </code> and a <code> Resource. </code> </p>
 */

public interface Participant
    extends org.osid.OsidRelationship {


    /**
     *  Gets the <code> Id </code> of the offering to which this participant 
     *  is assigned. 
     *
     *  @return the <code> Offering </code> <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getOfferingId();


    /**
     *  Gets the offering for this participant. 
     *
     *  @return the <code> Offering </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.Offering getOffering()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of the resource. 
     *
     *  @return the <code> Resource </code> <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getResourceId();


    /**
     *  Gets the resource for this participant. 
     *
     *  @return the <code> Resource </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getResource()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of the time period. 
     *
     *  @return the <code> TimePeriod </code> <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getTimePeriodId();


    /**
     *  Gets the time period for this participant. 
     *
     *  @return the <code> TimePeriod </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.TimePeriod getTimePeriod()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if there are result options that inform or constrain the 
     *  results. 
     *
     *  @return <code> true </code> if there are results, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasResults();


    /**
     *  Gets the various result option <code> Ids </code> applied to this 
     *  participation. 
     *
     *  @return the returned list of grading option <code> Ids </code> 
     *  @throws org.osid.IllegalStateException <code> hasResults() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getResultOptionIds();


    /**
     *  Gets the various result option <code> Ids </code> applied to this 
     *  participation. 
     *
     *  @return the returned list of grading options 
     *  @throws org.osid.IllegalStateException <code> hasResults() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeSystemList getResultOptions()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the record corresponding to the given <code> Participant </code> 
     *  record <code> Type. </code> This method is used to retrieve an object 
     *  implementing the requested record. The <code> participantRecordType 
     *  </code> may be the <code> Type </code> returned in <code> 
     *  getRecordTypes() </code> or any of its parents in a <code> Type 
     *  </code> hierarchy where <code> hasRecordType(participantRecordType) 
     *  </code> is <code> true </code> . 
     *
     *  @param  participantRecordType the type of participant record to 
     *          retrieve 
     *  @return the participant record 
     *  @throws org.osid.NullArgumentException <code> participantRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(participantRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.records.ParticipantRecord getParticipantRecord(org.osid.type.Type participantRecordType)
        throws org.osid.OperationFailedException;
}
