//
// org.osid.offering.ParticipantAdminSession
//
//     The OSID Java specification for org.osid.offering.ParticipantAdminSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering;


/**
 *  <p>This session creates, updates, and deletes <code> Partiicpants. </code> 
 *  The data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Participant, </code> a <code> ParticipantForm </code> is requested using 
 *  <code> getParticipantFormForCreate() </code> specifying the offering, 
 *  resource, and desired record <code> Types </code> or none if no record 
 *  <code> Types </code> are needed. The returned <code> ParticipantForm 
 *  </code> will indicate that it is to be used with a create operation and 
 *  can be used to examine metdata or validate data prior to creation. Once 
 *  the <code> ParticipantForm </code> is submiited to a create operation, it 
 *  cannot be reused with another create operation unless the first operation 
 *  was unsuccessful. Each <code> ParticipantForm </code> corresponds to an 
 *  attempted transaction. </p> 
 *  
 *  <p> For updates, <code> ParticipantForms </code> are requested to the 
 *  <code> Participant </code> <code> Id </code> that is to be updated using 
 *  <code> getParticipantFormForUpdate(). </code> Similarly, the <code> 
 *  ParticipantForm </code> has metadata about the data that can be updated 
 *  and it can perform validation before submitting the update. The <code> 
 *  ParticipantForm </code> can only be used once for a successful update and 
 *  cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Participants. </code> To unmap a 
 *  <code> Participant </code> from the current <code> Catalogue, </code> the 
 *  <code> ParticipantCatalogueAssignmentSession </code> should be used. These 
 *  delete operations attempt to remove the <code> Participant </code> itself 
 *  thus removing it from all known <code> Catalogue </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface ParticipantAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Catalogue </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Catalogue Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCatalogueId();


    /**
     *  Gets the <code> Catalogue </code> associated with this session. 
     *
     *  @return the catalogue 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.Catalogue getCatalogue()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create participants. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known creating a <code> Participant </code> will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer create operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Participant </code> creation is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateParticipants();


    /**
     *  Tests if this user can create a single <code> Participant </code> 
     *  using the desired record types. While <code> 
     *  OfferingManager.getParticipantRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> Participant. </code> 
     *  Providing an empty array tests if a <code> Participant </code> can be 
     *  created with no records. 
     *
     *  @param  participantRecordTypes array of participant record types 
     *  @return <code> true </code> if <code> Participant </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> participantRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateParticipantWithRecordTypes(org.osid.type.Type[] participantRecordTypes);


    /**
     *  Gets the participant form for creating new participants. A new form 
     *  should be requested for each create transaction. 
     *
     *  @param  offeringId the offering <code> Id </code> to which this 
     *          participant belongs 
     *  @param  resourceId the resource <code> Id </code> for this participant 
     *  @param  participantRecordTypes array of participant record types to be 
     *          included in the create operation or an empty list if none 
     *  @return the participant form 
     *  @throws org.osid.NotFoundException <code> offeringId </code> or <code> 
     *          resourceId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> offeringId, resourceId, 
     *          </code> or <code> participantRecordTypes </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException cannot get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.ParticipantForm getParticipantFormForCreate(org.osid.id.Id offeringId, 
                                                                         org.osid.id.Id resourceId, 
                                                                         org.osid.type.Type[] participantRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Participant. </code> 
     *
     *  @param  participantForm the form for this <code> Participant </code> 
     *  @return the new <code> Participant </code> 
     *  @throws org.osid.IllegalStateException <code> participantForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> participantForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> participantForm </code> 
     *          did not originate from <code> getParticipantFormForCreate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.Participant createParticipant(org.osid.offering.ParticipantForm participantForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update participants. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known updating a <code> Participant </code> will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer update operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Participant </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateParticipants();


    /**
     *  Gets the participant form for updating an existing participant. A new 
     *  participant form should be requested for each update transaction. 
     *
     *  @param  participantId the <code> Id </code> of the <code> Participant 
     *          </code> 
     *  @return the participant form 
     *  @throws org.osid.NotFoundException <code> participantId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> participantId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.ParticipantForm getParticipantFormForUpdate(org.osid.id.Id participantId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing participant. 
     *
     *  @param  participantForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> participantForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> participantForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> participantForm </code> 
     *          did not originate from <code> getParticipantFormForUpdate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateParticipant(org.osid.offering.ParticipantForm participantForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete participants. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known deleting an <code> Participant </code> will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer delete operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Participant </code> deletion is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteParticipants();


    /**
     *  Deletes a <code> Participant. </code> 
     *
     *  @param  participantId the <code> Id </code> of the <code> Participant 
     *          </code> to remove 
     *  @throws org.osid.NotFoundException <code> participantId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> participantId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteParticipant(org.osid.id.Id participantId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Participants. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Participant </code> aliasing is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageParticipantAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Participant </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Participant </code> is determined by the provider. The new 
     *  <code> Id </code> is an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another participant, it is reassigned to the 
     *  given participant <code> Id. </code> 
     *
     *  @param  participantId the <code> Id </code> of a <code> Participant 
     *          </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is in 
     *          use as a primary <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> participantId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> participantId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasParticipant(org.osid.id.Id participantId, 
                                 org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
