//
// org.osid.offering.ParticipantLookupSession
//
//     The OSID Java specification for org.osid.offering.ParticipantLookupSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering;


/**
 *  <p>This session defines methods for retrieving participants. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated catalogue view: All participant methods in this session 
 *      operate, retrieve and pertain to participants defined explicitly in 
 *      the current catalogue. Using an isolated view is useful for managing 
 *      participants with the <code> ParticipantAdminSession. </code> </li> 
 *      <li> federated catalogue view: All participant lookup methods in this 
 *      session operate, retrieve and pertain to all participants defined in 
 *      this catalogue and any other catalogues implicitly available in this 
 *      catalogue through catalogue inheritence. </li> 
 *      <li> effective participant view: All participant lookup methods return 
 *      participants where the current date falls in between the effective 
 *      dates inclusive. </li> 
 *      <li> any effective participant view: Participants of any effective 
 *      date are returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedCatalogueView() </code> and <code> 
 *  useIsolatedCatalogueView() </code> behave as a radio group and one should 
 *  be selected before invoking any lookup methods. </p>
 */

public interface ParticipantLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Catalogue </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Catalogue Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCatalogueId();


    /**
     *  Gets the <code> Catalogue </code> associated with this session. 
     *
     *  @return the catalogue 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.Catalogue getCatalogue()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can examine this catalogue. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer these operations. 
     *
     *  @return <code> false </code> if catalogue reading methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupParticipants();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeParticipantView();


    /**
     *  A complete view of the <code> Participant </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryParticipantView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include participants in catalogues which are children of this 
     *  catalogue in the catalogue hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCatalogueView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this catalogue only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCatalogueView();


    /**
     *  Only participants whose effective dates are current are returned by 
     *  methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useEffectiveParticipantView();


    /**
     *  All participants of any effective dates are returned by methods in 
     *  this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyEffectiveParticipantView();


    /**
     *  Gets the <code> Participant </code> specified by its <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Participant </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> Participant </code> and retained for 
     *  compatibility. 
     *  
     *  In effective mode, participants are returned that are currently 
     *  effective. In any effective mode, effective participants and those 
     *  currently expired are returned. 
     *
     *  @param  participantId the <code> Id </code> of the <code> Participant 
     *          </code> to retrieve 
     *  @return the returned <code> Participant </code> 
     *  @throws org.osid.NotFoundException no <code> Participant </code> found 
     *          with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> participantId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.Participant getParticipant(org.osid.id.Id participantId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ParticipantList </code> corresponding to the given 
     *  <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  participants specified in the <code> Id </code> list, in the order of 
     *  the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible participants may be omitted from the list and may present 
     *  the elements in any order including returning a unique set. 
     *  
     *  In effective mode, participants are returned that are currently 
     *  effective. In any effective mode, effective participants and those 
     *  currently expired are returned. 
     *
     *  @param  participantIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Participant list </code> 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> participantIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.ParticipantList getParticipantsByIds(org.osid.id.IdList participantIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ParticipantList </code> corresponding to the given 
     *  participant genus <code> Type </code> which does not include 
     *  participants of types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  participants or an error results. Otherwise, the returned list may 
     *  contain only those participants that are accessible through this 
     *  session. 
     *  
     *  In effective mode, participants are returned that are currently 
     *  effective. In any effective mode, effective participants and those 
     *  currently expired are returned. 
     *
     *  @param  participantGenusType a participant genus type 
     *  @return the returned <code> Participant list </code> 
     *  @throws org.osid.NullArgumentException <code> participantGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.ParticipantList getParticipantsByGenusType(org.osid.type.Type participantGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ParticipantList </code> corresponding to the given 
     *  participant genus <code> Type </code> and include any additional 
     *  participants with genus types derived from the specified <code> Type. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  participants or an error results. Otherwise, the returned list may 
     *  contain only those participants that are accessible through this 
     *  session. 
     *  
     *  In active mode, participants are returned that are currently active. 
     *  In any status mode, active and inactive participants are returned. 
     *
     *  @param  participantGenusType a participant genus type 
     *  @return the returned <code> Participant list </code> 
     *  @throws org.osid.NullArgumentException <code> participantGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.ParticipantList getParticipantsByParentGenusType(org.osid.type.Type participantGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ParticipantList </code> containing the given participant 
     *  record <code> Type. </code> 
     *  
     *  In plenary mode, the returned list contains all known participants or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  participants that are accessible through this session. 
     *  
     *  In effective mode, participants are returned that are currently 
     *  effective. In any effective mode, effective participants and those 
     *  currently expired are returned. 
     *
     *  @param  participantRecordType a participant record type 
     *  @return the returned <code> ParticipantList </code> 
     *  @throws org.osid.NullArgumentException <code> participantRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.ParticipantList getParticipantsByRecordType(org.osid.type.Type participantRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ParticipantList </code> effective during the entire 
     *  given date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known participants or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  participants that are accessible through this session. 
     *  
     *  In effective mode, participants are returned that are currently 
     *  effective. In any effective mode, effective participants and those 
     *  currently expired are returned. 
     *
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> ParticipantList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.ParticipantList getParticipantsOnDate(org.osid.calendaring.DateTime from, 
                                                                   org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ParticipantList </code> by genus type and effective 
     *  during the entire given date range inclusive but not confined to the 
     *  date range. 
     *  
     *  In plenary mode, the returned list contains all known participants or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  participants that are accessible through this session. 
     *  
     *  In effective mode, participants are returned that are currently 
     *  effective. In any effective mode, effective participants and those 
     *  currently expired are returned. 
     *
     *  @param  participantGenusType a participant genus type 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> ParticipantList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> participantGenusType, 
     *          from, </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.ParticipantList getParticipantsByGenusTypeOnDate(org.osid.type.Type participantGenusType, 
                                                                              org.osid.calendaring.DateTime from, 
                                                                              org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ParticipantList </code> for the given offering <code> . 
     *  </code> 
     *  
     *  In plenary mode, the returned list contains all known participants or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  participants that are accessible through this session. 
     *  
     *  In effective mode, participants are returned that are currently 
     *  effective. In any effective mode, effective participants and those 
     *  currently expired are returned. 
     *
     *  @param  offeringId an offering <code> Id </code> 
     *  @return the returned <code> ParticipantList </code> 
     *  @throws org.osid.NullArgumentException <code> offeringId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.ParticipantList getParticipantsForOffering(org.osid.id.Id offeringId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ParticipantList </code> by genus type for the given 
     *  offering <code> . </code> 
     *  
     *  In plenary mode, the returned list contains all known participants or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  participants that are accessible through this session. 
     *  
     *  In effective mode, participants are returned that are currently 
     *  effective. In any effective mode, effective participants and those 
     *  currently expired are returned. 
     *
     *  @param  offeringId an offering <code> Id </code> 
     *  @param  participantGenusType a participant genus type 
     *  @return the returned <code> ParticipantList </code> 
     *  @throws org.osid.NullArgumentException <code> participantGenusType 
     *          </code> or <code> offeringId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.ParticipantList getParticipantsByGenusTypeForOffering(org.osid.id.Id offeringId, 
                                                                                   org.osid.type.Type participantGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ParticipantList </code> for an offering and effective 
     *  during the entire given date range inclusive but not confined to the 
     *  date range. 
     *  
     *  In plenary mode, the returned list contains all known participants or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  participants that are accessible through this session. 
     *  
     *  In effective mode, participants are returned that are currently 
     *  effective. In any effective mode, effective participants and those 
     *  currently expired are returned. 
     *
     *  @param  offeringId an offering <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return a list of participants 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> offeringId, from, 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.ParticipantList getParticipantsForOfferingOnDate(org.osid.id.Id offeringId, 
                                                                              org.osid.calendaring.DateTime from, 
                                                                              org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ParticipantList </code> by genus type for an offering 
     *  and effective during the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known participants or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  participants that are accessible through this session. 
     *  
     *  In effective mode, participants are returned that are currently 
     *  effective. In any effective mode, effective participants and those 
     *  currently expired are returned. 
     *
     *  @param  offeringId an offering <code> Id </code> 
     *  @param  participantGenusType a participant genus type 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return a list of participants 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> offeringId, 
     *          participantGenusType, from, </code> or <code> to </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.ParticipantList getParticipantsByGenusTypeForOfferingOnDate(org.osid.id.Id offeringId, 
                                                                                         org.osid.type.Type participantGenusType, 
                                                                                         org.osid.calendaring.DateTime from, 
                                                                                         org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ParticipantList </code> for the given offering in a time 
     *  period <code> . </code> 
     *  
     *  In plenary mode, the returned list contains all known participants or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  participants that are accessible through this session. 
     *  
     *  In effective mode, participants are returned that are currently 
     *  effective. In any effective mode, effective participants and those 
     *  currently expired are returned. 
     *
     *  @param  offeringId an offering <code> Id </code> 
     *  @param  timePeriodId a time period <code> Id </code> 
     *  @return the returned <code> ParticipantList </code> 
     *  @throws org.osid.NullArgumentException <code> offeringId </code> or 
     *          <code> timePeriodId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.ParticipantList getParticipantsByTimePeriodForOffering(org.osid.id.Id offeringId, 
                                                                                    org.osid.id.Id timePeriodId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ParticipantList </code> by genus type for the given 
     *  offering in a time period <code> . </code> 
     *  
     *  In plenary mode, the returned list contains all known participants or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  participants that are accessible through this session. 
     *  
     *  In effective mode, participants are returned that are currently 
     *  effective. In any effective mode, effective participants and those 
     *  currently expired are returned. 
     *
     *  @param  offeringId an offering <code> Id </code> 
     *  @param  timePeriodId a time period <code> Id </code> 
     *  @param  participantGenusType a participant genus type 
     *  @return the returned <code> ParticipantList </code> 
     *  @throws org.osid.NullArgumentException <code> offeringId, 
     *          timePeriodId, </code> or <code> participantGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.ParticipantList getParticipantsByTimePeriodAndGenusTypeForOffering(org.osid.id.Id offeringId, 
                                                                                                org.osid.id.Id timePeriodId, 
                                                                                                org.osid.type.Type participantGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ParticipantList </code> for an offering in a time period 
     *  and effective during the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known participants or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  participants that are accessible through this session. 
     *  
     *  In effective mode, participants are returned that are currently 
     *  effective. In any effective mode, effective participants and those 
     *  currently expired are returned. 
     *
     *  @param  offeringId an offering <code> Id </code> 
     *  @param  timePeriodId a time period <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return a list of participants 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> offeringId, 
     *          timePeriodId, from, </code> or <code> to </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.ParticipantList getParticipantsByTimePeriodForOfferingOnDate(org.osid.id.Id offeringId, 
                                                                                          org.osid.id.Id timePeriodId, 
                                                                                          org.osid.calendaring.DateTime from, 
                                                                                          org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ParticipantList </code> by genus type for an offering in 
     *  a time period and effective during the entire given date range 
     *  inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known participants or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  participants that are accessible through this session. 
     *  
     *  In effective mode, participants are returned that are currently 
     *  effective. In any effective mode, effective participants and those 
     *  currently expired are returned. 
     *
     *  @param  offeringId an offering <code> Id </code> 
     *  @param  timePeriodId a time period <code> Id </code> 
     *  @param  participantGenusType a participant genus type 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return a list of participants 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> offeringId, 
     *          timePeriodId, participantGenusType, from, </code> or <code> to 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.ParticipantList getParticipantsByTimePeriodAndGenusTypeForOfferingOnDate(org.osid.id.Id offeringId, 
                                                                                                      org.osid.id.Id timePeriodId, 
                                                                                                      org.osid.type.Type participantGenusType, 
                                                                                                      org.osid.calendaring.DateTime from, 
                                                                                                      org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ParticipantList </code> for the given resource. 
     *  
     *  In plenary mode, the returned list contains all known participants or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  participants that are accessible through this session. 
     *  
     *  In effective mode, participants are returned that are currently 
     *  effective. In any effective mode, effective participants and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @return the returned <code> ParticipantList </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.ParticipantList getParticipantsForResource(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ParticipantList </code> by genus type for the given 
     *  resource. 
     *  
     *  In plenary mode, the returned list contains all known participants or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  participants that are accessible through this session. 
     *  
     *  In effective mode, participants are returned that are currently 
     *  effective. In any effective mode, effective participants and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  participantGenusType a participant genus type 
     *  @return the returned <code> ParticipantList </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> or 
     *          <code> participantGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.ParticipantList getParticipantsByGenusTypeForResource(org.osid.id.Id resourceId, 
                                                                                   org.osid.type.Type participantGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ParticipantList </code> for a resource and effective 
     *  during the entire given date range inclusive but not confined to the 
     *  date range. 
     *  
     *  In plenary mode, the returned list contains all known participants or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  participants that are accessible through this session. 
     *  
     *  In effective mode, participants are returned that are currently 
     *  effective. In any effective mode, effective participants and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return a list of participants 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, from, 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.ParticipantList getParticipantsForResourceOnDate(org.osid.id.Id resourceId, 
                                                                              org.osid.calendaring.DateTime from, 
                                                                              org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ParticipantList </code> by genus type for a resource and 
     *  effective during the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known participants or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  participants that are accessible through this session. 
     *  
     *  In effective mode, participants are returned that are currently 
     *  effective. In any effective mode, effective participants and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  participantGenusType a participant genus type 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return a list of participants 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, 
     *          participantGenusType, from, </code> or <code> to </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.ParticipantList getParticipantsByGenusTypeForResourceOnDate(org.osid.id.Id resourceId, 
                                                                                         org.osid.type.Type participantGenusType, 
                                                                                         org.osid.calendaring.DateTime from, 
                                                                                         org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ParticipantList </code> for the given resource in a time 
     *  period <code> . </code> 
     *  
     *  In plenary mode, the returned list contains all known participants or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  participants that are accessible through this session. 
     *  
     *  In effective mode, participants are returned that are currently 
     *  effective. In any effective mode, effective participants and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  timePeriodId a time period <code> Id </code> 
     *  @return the returned <code> ParticipantList </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> or 
     *          <code> timePeriodId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.ParticipantList getParticipantsByTimePeriodForResource(org.osid.id.Id resourceId, 
                                                                                    org.osid.id.Id timePeriodId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ParticipantList </code> by genus type for the given 
     *  resource in a time period <code> . </code> 
     *  
     *  In plenary mode, the returned list contains all known participants or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  participants that are accessible through this session. 
     *  
     *  In effective mode, participants are returned that are currently 
     *  effective. In any effective mode, effective participants and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  timePeriodId a time period <code> Id </code> 
     *  @param  participantGenusType a participant genus type 
     *  @return the returned <code> ParticipantList </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, 
     *          timePeriodId, </code> or <code> participantGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.ParticipantList getParticipantsByTimePeriodAndGenusTypeForResource(org.osid.id.Id resourceId, 
                                                                                                org.osid.id.Id timePeriodId, 
                                                                                                org.osid.type.Type participantGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ParticipantList </code> for a resource in a time period 
     *  and effective during the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known participants or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  participants that are accessible through this session. 
     *  
     *  In effective mode, participants are returned that are currently 
     *  effective. In any effective mode, effective participants and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  timePeriodId a time period <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return a list of participants 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, 
     *          timePeriodId, from, </code> or <code> to </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.ParticipantList getParticipantsByTimePeriodForResourceOnDate(org.osid.id.Id resourceId, 
                                                                                          org.osid.id.Id timePeriodId, 
                                                                                          org.osid.calendaring.DateTime from, 
                                                                                          org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ParticipantList </code> by genus type for a resource in 
     *  a time period and effective during the entire given date range 
     *  inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known participants or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  participants that are accessible through this session. 
     *  
     *  In effective mode, participants are returned that are currently 
     *  effective. In any effective mode, effective participants and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  timePeriodId a time period <code> Id </code> 
     *  @param  participantGenusType a participant genus type 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return a list of participants 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, 
     *          timePeriodId, participantGenusType, from, </code> or <code> to 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.ParticipantList getParticipantsByTimePeriodAndGenusTypeForResourceOnDate(org.osid.id.Id resourceId, 
                                                                                                      org.osid.id.Id timePeriodId, 
                                                                                                      org.osid.type.Type participantGenusType, 
                                                                                                      org.osid.calendaring.DateTime from, 
                                                                                                      org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ParticipantList </code> for the given offering and 
     *  resource <code> . </code> 
     *  
     *  In plenary mode, the returned list contains all known participants or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  participants that are accessible through this session. 
     *  
     *  In effective mode, participants are returned that are currently 
     *  effective. In any effective mode, effective participants and those 
     *  currently expired are returned. 
     *
     *  @param  offeringId an offering <code> Id </code> 
     *  @param  resourceId a resource <code> Id </code> 
     *  @return the returned <code> ParticipantList </code> 
     *  @throws org.osid.NullArgumentException <code> offeringId </code> or 
     *          <code> resourceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.ParticipantList getParticipantsForOfferingAndResource(org.osid.id.Id offeringId, 
                                                                                   org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ParticipantList </code> by genus type for the given 
     *  offering and resource <code> . </code> 
     *  
     *  In plenary mode, the returned list contains all known participants or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  participants that are accessible through this session. 
     *  
     *  In effective mode, participants are returned that are currently 
     *  effective. In any effective mode, effective participants and those 
     *  currently expired are returned. 
     *
     *  @param  offeringId an offering <code> Id </code> 
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  participantGenusType a participant genus type 
     *  @return the returned <code> ParticipantList </code> 
     *  @throws org.osid.NullArgumentException <code> offeringId, resourceId 
     *          </code> or <code> participantGenusType </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.ParticipantList getParticipantsByGenusTypeForOfferingAndResource(org.osid.id.Id offeringId, 
                                                                                              org.osid.id.Id resourceId, 
                                                                                              org.osid.type.Type participantGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ParticipantList </code> for an offering, resource, and 
     *  effective during the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known participants or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  participants that are accessible through this session. 
     *  
     *  In effective mode, participants are returned that are currently 
     *  effective. In any effective mode, effective participants and those 
     *  currently expired are returned. 
     *
     *  @param  offeringId an offering <code> Id </code> 
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return a list of participants 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, from, 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.ParticipantList getParticipantsForOfferingAndResourceOnDate(org.osid.id.Id offeringId, 
                                                                                         org.osid.id.Id resourceId, 
                                                                                         org.osid.calendaring.DateTime from, 
                                                                                         org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ParticipantList </code> by genus type for an offering, 
     *  resource, and effective during the entire given date range inclusive 
     *  but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known participants or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  participants that are accessible through this session. 
     *  
     *  In effective mode, participants are returned that are currently 
     *  effective. In any effective mode, effective participants and those 
     *  currently expired are returned. 
     *
     *  @param  offeringId an offering <code> Id </code> 
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  participantGenusType a participant genus type 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return a list of participants 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, 
     *          participantGenusType, from, </code> or <code> to </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.ParticipantList getParticipantsByGenusTypeForOfferingAndResourceOnDate(org.osid.id.Id offeringId, 
                                                                                                    org.osid.id.Id resourceId, 
                                                                                                    org.osid.type.Type participantGenusType, 
                                                                                                    org.osid.calendaring.DateTime from, 
                                                                                                    org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ParticipantList </code> for the given offering and 
     *  resource in a time period <code> . </code> 
     *  
     *  In plenary mode, the returned list contains all known participants or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  participants that are accessible through this session. 
     *  
     *  In effective mode, participants are returned that are currently 
     *  effective. In any effective mode, effective participants and those 
     *  currently expired are returned. 
     *
     *  @param  offeringId an offering <code> Id </code> 
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  timePeriodId a time period <code> Id </code> 
     *  @return the returned <code> ParticipantList </code> 
     *  @throws org.osid.NullArgumentException <code> offeringId, resourceId, 
     *          </code> or <code> timePeriodId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.ParticipantList getParticipantsByTimePeriodForOfferingAndResource(org.osid.id.Id offeringId, 
                                                                                               org.osid.id.Id resourceId, 
                                                                                               org.osid.id.Id timePeriodId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ParticipantList </code> by genus type for the given 
     *  offering and resource in a time period <code> . </code> 
     *  
     *  In plenary mode, the returned list contains all known participants or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  participants that are accessible through this session. 
     *  
     *  In effective mode, participants are returned that are currently 
     *  effective. In any effective mode, effective participants and those 
     *  currently expired are returned. 
     *
     *  @param  offeringId an offering <code> Id </code> 
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  timePeriodId a time period <code> Id </code> 
     *  @param  participantGenusType a participant genus type 
     *  @return the returned <code> ParticipantList </code> 
     *  @throws org.osid.NullArgumentException <code> offeringId, resourceId, 
     *          </code> <code> timePeriodId </code> or <code> 
     *          participantGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.ParticipantList getParticipantsByTimePeriodAndGenusTypeForOfferingAndResource(org.osid.id.Id offeringId, 
                                                                                                           org.osid.id.Id resourceId, 
                                                                                                           org.osid.id.Id timePeriodId, 
                                                                                                           org.osid.type.Type participantGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ParticipantList </code> for an offering and resource in 
     *  a time period and effective during the entire given date range 
     *  inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known participants or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  participants that are accessible through this session. 
     *  
     *  In effective mode, participants are returned that are currently 
     *  effective. In any effective mode, effective participants and those 
     *  currently expired are returned. 
     *
     *  @param  offeringId an offering <code> Id </code> 
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  timePeriodId a time period <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return a list of participants 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> offeringId, resourceId, 
     *          timePeriodId, from, </code> or <code> to </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.ParticipantList getParticipantsByTimePeriodForOfferingAndResourceOnDate(org.osid.id.Id offeringId, 
                                                                                                     org.osid.id.Id resourceId, 
                                                                                                     org.osid.id.Id timePeriodId, 
                                                                                                     org.osid.calendaring.DateTime from, 
                                                                                                     org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ParticipantList </code> by genus type for an offering 
     *  and resource in a time period and effective during the entire given 
     *  date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known participants or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  participants that are accessible through this session. 
     *  
     *  In effective mode, participants are returned that are currently 
     *  effective. In any effective mode, effective participants and those 
     *  currently expired are returned. 
     *
     *  @param  offeringId an offering <code> Id </code> 
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  timePeriodId a time period <code> Id </code> 
     *  @param  participantGenusType a participant genus type 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return a list of participants 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> offeringId, resourceId, 
     *          timePeriodId,participantGenusType, from, </code> or <code> to 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.ParticipantList getParticipantsByTimePeriodAndGenusTypeForOfferingAndResourceOnDate(org.osid.id.Id offeringId, 
                                                                                                                 org.osid.id.Id resourceId, 
                                                                                                                 org.osid.id.Id timePeriodId, 
                                                                                                                 org.osid.type.Type participantGenusType, 
                                                                                                                 org.osid.calendaring.DateTime from, 
                                                                                                                 org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all participants. 
     *  
     *  In plenary mode, the returned list contains all known participants or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  participants that are accessible through this session. 
     *  
     *  In effective mode, participants are returned that are currently 
     *  effective. In any effective mode, effective participants and those 
     *  currently expired are returned. 
     *
     *  @return a list of participants 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.ParticipantList getParticipants()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
