//
// org.osid.offering.ParticipantSearchSession
//
//     The OSID Java specification for org.osid.offering.ParticipantSearchSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering;


/**
 *  <p>This session provides methods for searching <code> Participant </code> 
 *  objects. The search query is constructed using the <code> 
 *  ParticipantQuery. </code> The participant record <code> Type </code> also 
 *  specifies the record for the participant query. </p> 
 *  
 *  <p> <code> getParticipantsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Participant </code> elements. A more advanced 
 *  search may be performed with <code> getParticipantsBySearch(). </code> It 
 *  accepts a <code> ParticipantSearch </code> in addition to the query for 
 *  the purpose of specifying additional options affecting the entire search, 
 *  such as ordering. <code> getParticipantsBySearch() </code> returns a 
 *  <code> ParticipantSearchResults </code> that can be used to access the 
 *  resulting <code> ParticipantList </code> or be used to perform a search 
 *  within the result set through <code> ParticipantSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated catalogue view: searches include participants in 
 *      catalogues of which this catalogue is a ancestor in the catalogue 
 *      hierarchy </li> 
 *      <li> isolated catalogue view: searches are restricted to participants 
 *      in this catalogue </li> 
 *  </ul>
 *  
 *  
 *  <p> Participants may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> 
 *  ParticipantQuery. </code> The returns in this session may not be cast 
 *  directly to these interfaces. </p>
 */

public interface ParticipantSearchSession
    extends org.osid.offering.ParticipantQuerySession {


    /**
     *  Gets a participant search. 
     *
     *  @return the participant search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.ParticipantSearch getParticipantSearch();


    /**
     *  Gets a participant search order. The <code> ParticipantSearchOrder 
     *  </code> is supplied to a <code> ParticipantSearch </code> to specify 
     *  the ordering of results. 
     *
     *  @return the participant search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.ParticipantSearchOrder getParticipantSearchOrder();


    /**
     *  Gets the search results matching the given search. 
     *
     *  @param  participantQuery the participant query 
     *  @param  participantSearch the participant search 
     *  @return the search results 
     *  @throws org.osid.NullArgumentException <code> participantQuery </code> 
     *          or <code> participantSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> participantQuery </code> 
     *          or <code> participantSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.ParticipantSearchResults getParticipantsBySearch(org.osid.offering.ParticipantQuery participantQuery, 
                                                                              org.osid.offering.ParticipantSearch participantSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the participant query inspector. 
     *
     *  @param  participantQueryInspector a participant query inspector 
     *  @return the participant query 
     *  @throws org.osid.NullArgumentException <code> 
     *          participantQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> participantQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.ParticipantQuery getParticipantQueryFromInspector(org.osid.offering.ParticipantQueryInspector participantQueryInspector);
}
