//
// org.osid.offering.ParticipantSmartCatalogueSession
//
//     The OSID Java specification for org.osid.offering.ParticipantSmartCatalogueSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. A <code> ParticipantQuery </code> can be retrieved from this 
 *  session and mapped to this <code> Catalogue </code> to create a virtual 
 *  collection of <code> Participants. </code> The participants may be 
 *  sequenced using the <code> ParticipantSearchOrder </code> from this 
 *  session. </p> 
 *  
 *  <p> This <code> Catalogue </code> has a default query that matches any 
 *  participant and a default search order that specifies no sequencing. The 
 *  queries may be examined using a <code> ParticipantQueryInspector. </code> 
 *  The query may be modified by converting the inspector back to a <code> 
 *  ParticipantQuery. </code> </p>
 */

public interface ParticipantSmartCatalogueSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Catalogue </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Catalogue Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCatalogueId();


    /**
     *  Gets the <code> Catalogue </code> associated with this session. 
     *
     *  @return the <code> Catalogue </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.Catalogue getCatalogue()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart catalogues. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart catalogue management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartCatalogues();


    /**
     *  Gets a participant query. 
     *
     *  @return the participant query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.ParticipantQuery getParticipantQuery();


    /**
     *  Gets a participant search order. 
     *
     *  @return the participant search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.ParticipantSearchOrder getParticipantSearchOrder();


    /**
     *  Applies a participant query to this catalogue. 
     *
     *  @param  participantQuery the participant query 
     *  @throws org.osid.NullArgumentException <code> participantQuery </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> participantQuery </code> 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyParticipantQuery(org.osid.offering.ParticipantQuery participantQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a participant query inspector for this catalogue. 
     *
     *  @return the participant query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.ParticipantQueryInspector inspectParticipantQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a participant search order to this catalogue. 
     *
     *  @param  participantSearchOrder the participant search order 
     *  @throws org.osid.NullArgumentException <code> participantSearchOrder 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> participantSearchOrder 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyParticipantSequencing(org.osid.offering.ParticipantSearchOrder participantSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a participant query from an inspector. 
     *
     *  @param  participantQueryInspector a query inspector 
     *  @return the participant query 
     *  @throws org.osid.NullArgumentException <code> 
     *          participantQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> participantQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.ParticipantQuery getParticipantQueryFromInspector(org.osid.offering.ParticipantQueryInspector participantQueryInspector);
}
