//
// org.osid.offering.batch.CatalogueBatchAdminSession
//
//     The OSID Java specification for org.osid.offering.batch.CatalogueBatchAdminSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Catalogues </code> in 
 *  bulk. The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Catalogue, </code> a <code> CatalogueForm </code> is requested using 
 *  <code> getCatalogueFormsForCreate() </code> specifying the desired record 
 *  <code> Types </code> or none if no record <code> Types </code> are needed. 
 *  Each of the returned <code> CatalogueForms </code> will indicate that it 
 *  is to be used with a create operation and can be used to examine metdata 
 *  or validate data prior to creation. Once a <code> CatalogueForm </code> is 
 *  submiited to a create operation, it cannot be reused with another create 
 *  operation unless the first operation was unsuccessful. Each <code> 
 *  CatalogueForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> CatalogueForms </code> returned from <code> 
 *  getCatalogueFormsForCreate() </code> may be linked to the originating 
 *  request through the peer <code> Ids </code> of the <code> CatalogueForm. 
 *  </code> In the case where there may be duplicates, any <code> 
 *  CatalogueForm </code> of the same peer <code> Ids </code> may be used for 
 *  a create operation. </p> 
 *  
 *  <p> Once a batch of <code> CatalogueForms </code> are submitted for 
 *  create, a <code> CreateResponse </code> is returned for each <code> 
 *  CatalogueForm, </code> although the ordering is not defined. Only errors 
 *  that pertain to the entire create operation are returned from <code> 
 *  createCatalogues(), </code> errors specific to an individual <code> 
 *  CatalogueForm </code> are indicated in the corresponding <code> 
 *  CreateResponse. </code> <code> CreateResponses </code> may be linked to 
 *  the originating <code> CatalogueForm </code> through the <code> 
 *  CatalogueForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> CatalogueForms </code> are requested to the <code> 
 *  Catalogue </code> <code> Id </code> that is to be updated using <code> 
 *  getCatalogueFormsForUpdate() </code> where the reference <code> Id </code> 
 *  in the <code> CatalogueForm </code> may be used to link the request. 
 *  Similarly, the <code> CatalogueForm </code> has metadata about the data 
 *  that can be updated and it can perform validation before submitting the 
 *  update. The <code> CatalogueForm </code> can only be used once for a 
 *  successful update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> CatalogueForms </code> are submitted for 
 *  update, an <code> UpdateResponse </code> is returned for each <code> 
 *  CatalogueForm, </code> although the ordering is not defined. Only errors 
 *  that pertain to the entire update operation are returned from <code> 
 *  updateCatalogues(), </code> errors specific to an individual <code> 
 *  CatalogueForm </code> are indicated in the corresponding <code> 
 *  UpdateResponse. </code> <code> UpdateResponses </code> may be linked to 
 *  the originating <code> CatalogueForm </code> through the <code> 
 *  CatalogueForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> Catalogues </code> in bulk. To 
 *  unmap a <code> Catalogue </code> from the current <code> Calendar, </code> 
 *  the <code> CatalogueCalendarAssignmentSession </code> should be used. 
 *  These delete operations attempt to remove the <code> Catalogue </code> 
 *  itself thus removing it from all known <code> Calendar </code> catalogs. 
 *  Bulk delete operations return the results in <code> DeleteResponses. 
 *  </code> </p>
 */

public interface CatalogueBatchAdminSession
    extends org.osid.offering.CatalogueAdminSession {


    /**
     *  Gets the catalogue forms for creating a bunch of new catalogues. 
     *
     *  @param  number the number of forms to retrieve 
     *  @param  catalogueRecordTypes array of catalogue record types to be 
     *          included in each create operation or an empty list if none 
     *  @return the catalogue forms 
     *  @throws org.osid.NullArgumentException <code> catalogueRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.batch.CatalogueBatchFormList getCatalogueFormsForCreate(long number, 
                                                                                     org.osid.type.Type[] catalogueRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Catalogues. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  catalogueForms the catalogue forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> catalogueForms </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createCatalogues(org.osid.offering.batch.CatalogueBatchFormList catalogueForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the catalogue forms for updating an existing set of catalogues. A 
     *  new catalogue form should be requested for each update transaction. 
     *
     *  @param  catalogueIds the <code> Ids </code> of the <code> Catalogue 
     *          </code> 
     *  @return the catalogue form 
     *  @throws org.osid.NotFoundException a <code> catalogueId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> catalogueIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.batch.CatalogueBatchFormList getCatalogueFormsForUpdate(org.osid.id.IdList catalogueIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing catalogues. This method returns an error if the 
     *  entire operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  catalogueForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> catalogueForms </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateCatalogues(org.osid.offering.batch.CatalogueBatchFormList catalogueForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Catalogues </code> in this <code> Calendar </code> 
     *  . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllCatalogues()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes catalogues for the given <code> Ids. </code> 
     *
     *  @param  catalogueIds the <code> Ids </code> of the catalogues to 
     *          delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> catalogueIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteCatalogues(org.osid.id.IdList catalogueIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Catalogue </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Catalogue </code> is determined by the provider. The new 
     *  <code> Id </code> is an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another catalogue, it is reassigned to the given 
     *  catalogue <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasCatalogues(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
