//
// org.osid.offering.batch.OfferingBatchAdminSession
//
//     The OSID Java specification for org.osid.offering.batch.OfferingBatchAdminSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Offerings </code> in 
 *  bulk. The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create an 
 *  <code> Offering, </code> an <code> OfferingForm </code> is requested using 
 *  <code> getOfferingFormsForCreate() </code> specifying the desired 
 *  canonical unit, time period, and record <code> Types </code> or none if no 
 *  record <code> Types </code> are needed. Each of the returned <code> 
 *  OfferingForms </code> will indicate that it is to be used with a create 
 *  operation and can be used to examine metdata or validate data prior to 
 *  creation. Once an <code> OfferingForm </code> is submiited to a create 
 *  operation, it cannot be reused with another create operation unless the 
 *  first operation was unsuccessful. Each <code> OfferingForm </code> 
 *  corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> OfferingForms </code> returned from <code> 
 *  getOfferingFormsForCreate() </code> may be linked to the originating 
 *  request through the peer <code> Ids </code> of the <code> OfferingForm. 
 *  </code> In the case where there may be duplicates, any <code> OfferingForm 
 *  </code> of the same peer <code> Ids </code> may be used for a create 
 *  operation. </p> 
 *  
 *  <p> Once a batch of <code> OfferingForms </code> are submitted for create, 
 *  a <code> CreateResponse </code> is returned for each <code> OfferingForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire create operation are returned from <code> createOfferings(), 
 *  </code> errors specific to an individual <code> OfferingForm </code> are 
 *  indicated in the corresponding <code> CreateResponse. </code> <code> 
 *  CreateResponses </code> may be linked to the originating <code> 
 *  OfferingForm </code> through the <code> OfferingForm </code> <code> Id 
 *  </code> . </p> 
 *  
 *  <p> For updates, <code> OfferingForms </code> are requested to the <code> 
 *  Offering </code> <code> Id </code> that is to be updated using <code> 
 *  getOfferingFormsForUpdate() </code> where the reference <code> Id </code> 
 *  in the <code> OfferingForm </code> may be used to link the request. 
 *  Similarly, the <code> OfferingForm </code> has metadata about the data 
 *  that can be updated and it can perform validation before submitting the 
 *  update. The <code> OfferingForm </code> can only be used once for a 
 *  successful update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> OfferingForms </code> are submitted for update, 
 *  an <code> UpdateResponse </code> is returned for each <code> OfferingForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire update operation are returned from <code> updateOfferings(), 
 *  </code> errors specific to an individual <code> OfferingForm </code> are 
 *  indicated in the corresponding <code> UpdateResponse. </code> <code> 
 *  UpdateResponses </code> may be linked to the originating <code> 
 *  OfferingForm </code> through the <code> OfferingForm </code> <code> Id. 
 *  </code> </p> 
 *  
 *  <p> The delete operations delete <code> Offerings </code> in bulk. To 
 *  unmap an <code> Offering </code> from the current <code> Catalogue, 
 *  </code> the <code> OfferingCatalogueAssignmentSession </code> should be 
 *  used. These delete operations attempt to remove the <code> Offering 
 *  </code> itself thus removing it from all known <code> Catalogue </code> 
 *  catalogs. Bulk delete operations return the results in <code> 
 *  DeleteResponses. </code> </p>
 */

public interface OfferingBatchAdminSession
    extends org.osid.offering.OfferingAdminSession {


    /**
     *  Gets the offeringforms for creating a bunch of new offerings. A new 
     *  result form is returned for each supplied canonical unit and time 
     *  period. 
     *
     *  @param  peers a list of canonical unit peers 
     *  @param  offeringRecordTypes array of offering record types to be 
     *          included in each create operation or an empty list if none 
     *  @return the offeringforms 
     *  @throws org.osid.NotFoundException a <code> canonicalUnitId </code> or 
     *          <code> timePeriodId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> peers </code> or <code> 
     *          offeringRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.batch.OfferingBatchFormList getOfferingFormsForCreate(org.osid.offering.batch.OfferingPeerList peers, 
                                                                                   org.osid.type.Type[] offeringRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Offerings. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  offeringForms the offering forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> offeringForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createOfferings(org.osid.offering.batch.OfferingBatchFormList offeringForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the offering forms for updating an existing set of offerings. A 
     *  new offeringform should be requested for each update transaction. 
     *
     *  @param  offeringIds the <code> Ids </code> of the <code> Offering 
     *          </code> 
     *  @return the offering form 
     *  @throws org.osid.NotFoundException an <code> offeringId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> offeringIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.batch.OfferingBatchFormList getOfferingFormsForUpdate(org.osid.id.IdList offeringIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing offerings. This method returns an error if the entire 
     *  operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  offeringForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> offeringForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateOfferings(org.osid.offering.batch.OfferingBatchFormList offeringForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Offerings </code> in this <code> Catalogue </code> 
     *  . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllOfferings()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes offerings for the given <code> Ids. </code> 
     *
     *  @param  offeringIds the <code> Ids </code> of the offerings to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> offeringIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteOfferings(org.osid.id.IdList offeringIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all offerings mapped to the given canonical unit. 
     *
     *  @param  canonicalUnitId an <code> Id </code> of a canonical unit 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteOfferingsForCanonicalUnit(org.osid.id.Id canonicalUnitId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all offerings mapped to the given time period. 
     *
     *  @param  timePeriodId an <code> Id </code> of a time period 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> timePeriodId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteOfferingsForTimePeriod(org.osid.id.Id timePeriodId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to an <code> Offering </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Offering </code> is determined by the provider. The new 
     *  <code> Id </code> is an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another offering, it is reassigned to the given 
     *  offering <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasOfferings(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
