/**
 * <p>The Open Service Interface Definitions for the org.osid.offering
 * service.</p>
 * 
 * <p>The Offering OSID defines a means for managing offerings of things, 
 * participants in offerings, and their results. This is an OSID expression of 
 * the Kuali Student core model. </p> 
 * <h4> Offering </h4> 
 * 
 * <p> An <code> Offering </code> is any deliverable. <code> Offerings </code> 
 * define the logistics of the deliverable such as the <code> Schedule </code> 
 * . <code> Offerings </code> are offered in a <code> TimePeriod. </code> </p> 
 * <h4> CanonincalUnit </h4> 
 * 
 * <p> A <code> CanonicalUnit </code> is the approved item to be offered. All 
 * <code> Offerings </code> are offered from a <code> CanonicalUnit. </code> 
 * The <code> CanonicalUnit </code> describes what is offered and the <code> 
 * Offering </code> captures the logistics. </p> 
 * <h4> Participant </h4> 
 * 
 * <p> A <code> Participant </code> is an <code> OsidRelationship </code> used 
 * to associated a <code> Resource </code> to an <code> Offering. </code> </p> 
 * <h4> Result </h4> 
 * 
 * <p> The <code> Result </code> is any outcome as a result of a <code> 
 * Participation </code> in an <code> Offering. </code> Each <code> 
 * Participant </code> may have multiple <code> Results </code> of different 
 * types of within sub- <code> TimePeriods </code> . <code> Results </code> 
 * references <code> Grades </code> which are constrained by their <code> 
 * GradingSystems. </code> <code> GradeSystems </code> may be defined for 
 * various purposes, including constrained numeric results and enumerated 
 * certifications. </p> 
 * <h4> Example </h4> 
 * 
 * <p> The Offering OSID may be used as an abstract layer for the Course OSID 
 * where the <code> CanonicalUnits </code> are <code> Courses, </code> <code> 
 * Offerings </code> are <code> CourseOfferings, </code> <code> Participants 
 * </code> are instructors and <code> CourseRegistrations, </code> and <code> 
 * Results </code> are <code> Grades. </code> </p> 
 * 
 * <p> The Offering OSID may be used to describe other offerings. For example, 
 * an airline route is a <code> CanonicalUnit, </code> a flight at a 
 * particular time is an <code> Offering, </code> a reservation is a <code> 
 * Participant, </code> and the frequent flyer miles awarded is a <code> 
 * Result </code> . </p> 
 * <h4> Catalogue Cataloging </h4> 
 * 
 * <p> <code> CanonicalUnits, Offerings, Participants </code> , and <code> 
 * Results </code> are mapped to <code> Catalogues </code> for offering. 
 * <code> Catalogues </code> can be managed hierarchically to federate 
 * multiple collections of <code> CanonicalUnits </code> . </p> 
 * 
 * <p> Every <code> Catalogue </code> has one offering hierarchy. By selecting 
 * the <code> Catalogue is, </code> in effect, selecting the offeringal 
 * hierarchy. Each hierarchy may expose multiple offeringal roots that do not 
 * have to be related. Looking up and searching <code> Offerings </code> 
 * exposes all of their offeringal units. It may be helpful to retrieve the 
 * offeringal roots for a <code> Catalogue </code> and navigating from there. 
 * </p> 
 * <h4> Sub Packages </h4> 
 * 
 * <p> The Offering OSID contains an Offering Rules OSID for managing the 
 * offering rules of <code> CanonicalUnits </code> and an Offering Batch OSID 
 * for creating, updating, and deleting <code> CanonicalUnits, </code> <code> 
 * Offerings, </code> <code> Participants, </code> and <code> Results </code> 
 * in bulk. </p>
 * 
 * <br/><hr/><br/>
 * 
 * <p>Copyright &copy; 2013 Ingenescus. All Rights Reserved. </p>
 * 
 * <p>This Work is being provided by the copyright holder(s) subject to the 
 * following license. By obtaining, using and/or copying this Work, you agree 
 * that you have read, understand, and will comply with the following terms 
 * and conditions. </p> 
 * 
 * <p> Permission to use, copy and distribute unmodified versions of this 
 * Work, for any purpose, without fee or royalty is hereby granted, provided 
 * that you include the above copyright notices and the terms of this license 
 * on ALL copies of the Work or portions thereof. </p> 
 * 
 * <p> You may modify or create Derivatives of this Work only for your 
 * internal purposes. You shall not distribute or transfer any such Derivative 
 * of this Work to any location or to any third party. For the purposes of 
 * this license, "Derivative" shall mean any derivative of the Work as defined 
 * in the United States Copyright Act of 1976, such as a translation or 
 * modification. </p> 
 * 
 * <p> This Work and the information contained herein is provided on an "AS 
 * IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT 
 * NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR 
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT 
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN 
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN 
 * CONNECTION WITH THE WORK OR THE USE OR OTHER DEALINGS IN THE WORK. </p> 
 * 
 * <p> The export of software employing encryption technology may require a 
 * specific license from the United States Government. It is the 
 * responsibility of any person or organization contemplating export to obtain 
 * such a license before exporting this Work. </p>
 */

package org.osid.offering;
