//
// org.osid.offering.rules.CanonicalUnitEnablerSearchSession
//
//     The OSID Java specification for org.osid.offering.rules.CanonicalUnitEnablerSearchSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering.rules;


/**
 *  <p>This session provides methods for searching among <code> 
 *  CanonicalUnitEnabler </code> objects. The search query is constructed 
 *  using the <code> CanonicalUnitEnableryQuery. </code> </p> 
 *  
 *  <p> <code> getCanonicalUnitEnablersByQuery() </code> is the basic search 
 *  method and returns a list of <code> CanonicalUnitEnablers. </code> A more 
 *  advanced search may be performed with <code> 
 *  getCanonicalUnitEnablersBySearch(). </code> It accepts a <code> 
 *  CanonicalUnitEnablerSearch </code> in addition to the query for the 
 *  purpose of specifying additional options affecting the entire search, such 
 *  as offering. <code> getCanonicalUnitEnablersBySearch() </code> returns a 
 *  <code> CanonicalUnitEnablerSearchResults </code> that can be used to 
 *  access the resulting <code> CanonicalUnitEnablerList </code> or be used to 
 *  perform a search within the result set through <code> 
 *  CanonicalUnitEnablerSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated catalogue view: searches include canonical unit 
 *      enablers in catalogues of which this catalogue is an ancestor in the 
 *      catalogue hierarchy </li> 
 *      <li> isolated catalogue view: searches are restricted to canonical 
 *      unit enablers in this catalogue </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> CanonicalUnitEnablers </code> may have a query record indicated 
 *  by their respective record types. The query record is accessed via the 
 *  <code> CanonicalUnitEnablerQuery. </code> </p>
 */

public interface CanonicalUnitEnablerSearchSession
    extends org.osid.offering.rules.CanonicalUnitEnablerQuerySession {


    /**
     *  Gets a canonical unit enabler search. 
     *
     *  @return the canonical unit enabler search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.CanonicalUnitEnablerSearch getCanonicalUnitEnablerSearch();


    /**
     *  Gets a canonical unit enabler search order. The <code> 
     *  CanonicalUnitEnablerSearchOrder </code> is supplied to a <code> 
     *  CanonicalUnitEnablerSearch </code> to specify the ordering of results. 
     *
     *  @return the canonical unit enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.CanonicalUnitEnablerSearchOrder getCanonicalUnitEnablerSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  canonicalUnitEnablerQuery the canonical unit enabler query 
     *  @param  canonicalUnitEnablerSearch the canonical unit enabler search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> 
     *          canonicalUnitEnablerQuery </code> or <code> 
     *          canonicalUnitEnablerSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> canonicalUnitEnablerQuery 
     *          </code> or <code> canonicalUnitEnablerSearch </code> is not of 
     *          this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.CanonicalUnitEnablerSearchResults getCanonicalUnitEnablersBySearch(org.osid.offering.rules.CanonicalUnitEnablerQuery canonicalUnitEnablerQuery, 
                                                                                                      org.osid.offering.rules.CanonicalUnitEnablerSearch canonicalUnitEnablerSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a canonical unit enabler query from an inspector. The inspector 
     *  is available from a <code> CanonicalUnitEnablerSearchResults. </code> 
     *
     *  @param  canonicalUnitEnablerQueryInspector a canonical unit enabler 
     *          query inspector 
     *  @return the canonical unit enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          canonicalUnitEnablerQueryInspector </code> is <code> null 
     *          </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          canonicalUnitEnablerQueryInspector </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.CanonicalUnitEnablerQuery getCanonicalUnitEnablerQueryFromInspector(org.osid.offering.rules.CanonicalUnitEnablerQueryInspector canonicalUnitEnablerQueryInspector);
}
