//
// org.osid.offering.rules.CanonicalUnitProcessorEnablerAdminSession
//
//     The OSID Java specification for org.osid.offering.rules.CanonicalUnitProcessorEnablerAdminSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering.rules;


/**
 *  <p>This session creates and removes canonical unit processor enablers. The 
 *  data for create and update is provided via the <code> 
 *  CanonicalUnitProcessorEnablerForm. </code> </p>
 */

public interface CanonicalUnitProcessorEnablerAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Catalogue </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Catalogue Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCatalogueId();


    /**
     *  Gets the <code> Catalogue </code> associated with this session. 
     *
     *  @return the catalogue 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.Catalogue getCatalogue()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create canonical unit processor enablers. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known creating a <code> 
     *  CanonicalUnitProcessorEnabler </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer create operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> CanonicalUnitProcessorEnabler 
     *          </code> creation is not authorized, <code> true </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateCanonicalUnitProcessorEnabler();


    /**
     *  Tests if this user can create a single <code> 
     *  CanonicalUnitProcessorEnabler </code> using the desired record types. 
     *  While <code> 
     *  OfferingRulesManager.getCanonicalUnitProcessorEnablerRecordTypes() 
     *  </code> can be used to examine which records are supported, this 
     *  method tests which record(s) are required for creating a specific 
     *  <code> CanonicalUnitProcessorEnabler. </code> Providing an empty array 
     *  tests if a <code> CanonicalUnitProcessorEnabler </code> can be created 
     *  with no records. 
     *
     *  @param  canonicalUnitProcessorEnablerRecordTypes array of canonical 
     *          unit processor enabler record types 
     *  @return <code> true </code> if <code> CanonicalUnitProcessorEnabler 
     *          </code> creation using the specified record <code> Types 
     *          </code> is supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          canonicalUnitProcessorEnablerRecordTypes </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateCanonicalUnitProcessorEnablerWithRecordTypes(org.osid.type.Type[] canonicalUnitProcessorEnablerRecordTypes);


    /**
     *  Gets the canonical unit processor enabler form for creating new 
     *  canonical unit processor enablers. A new form should be requested for 
     *  each create transaction. 
     *
     *  @param  canonicalUnitProcessorEnablerRecordTypes array of canonical 
     *          unit processor enabler record types 
     *  @return the canonical unit processor enabler form 
     *  @throws org.osid.NullArgumentException <code> 
     *          canonicalUnitProcessorEnablerRecordTypes </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorEnablerForm getCanonicalUnitProcessorEnablerFormForCreate(org.osid.type.Type[] canonicalUnitProcessorEnablerRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> CanonicalUnitProcessorEnabler. </code> 
     *
     *  @param  canonicalUnitProcessorEnablerForm the form for this <code> 
     *          CanonicalUnitProcessorEnabler </code> 
     *  @return the new <code> CanonicalUnitProcessorEnabler </code> 
     *  @throws org.osid.IllegalStateException <code> 
     *          canonicalUnitProcessorEnablerForm </code> already used in a 
     *          create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> 
     *          canonicalUnitProcessorEnablerForm </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> 
     *          canonicalUnitProcessorEnablerForm did not originate from 
     *          getCanonicalUnitProcessorEnablerFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorEnabler createCanonicalUnitProcessorEnabler(org.osid.offering.rules.CanonicalUnitProcessorEnablerForm canonicalUnitProcessorEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update canonical unit processor enablers. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known updating a <code> 
     *  CanonicalUnitProcessorEnabler </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer update operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> CanonicalUnitProcessorEnabler 
     *          </code> modification is not authorized, <code> true </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateCanonicalUnitProcessorEnablers();


    /**
     *  Gets the canonical unit processor enabler form for updating an 
     *  existing canonical unit processor enabler. A new canonical unit 
     *  processor enabler form should be requested for each update 
     *  transaction. 
     *
     *  @param  canonicalUnitProcessorEnablerId the <code> Id </code> of the 
     *          <code> CanonicalUnitProcessorEnabler </code> 
     *  @return the canonical unit processor enabler form 
     *  @throws org.osid.NotFoundException <code> 
     *          canonicalUnitProcessorEnablerId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          canonicalUnitProcessorEnablerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorEnablerForm getCanonicalUnitProcessorEnablerFormForUpdate(org.osid.id.Id canonicalUnitProcessorEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing canonical unit processor enabler. 
     *
     *  @param  canonicalUnitProcessorEnablerForm the form containing the 
     *          elements to be updated 
     *  @throws org.osid.IllegalStateException <code> 
     *          canonicalUnitProcessorEnablerForm </code> already used in an 
     *          update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> 
     *          canonicalUnitProcessorEnablerForm </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> 
     *          canonicalUnitProcessorEnablerForm did not originate from 
     *          getCanonicalUnitProcessorEnablerFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateCanonicalUnitProcessorEnabler(org.osid.offering.rules.CanonicalUnitProcessorEnablerForm canonicalUnitProcessorEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete canonical unit processor enablers. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known deleting a <code> 
     *  CanonicalUnitProcessorEnabler </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer delete operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> CanonicalUnitProcessorEnabler 
     *          </code> deletion is not authorized, <code> true </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteCanonicalUnitProcessorEnablers();


    /**
     *  Deletes a <code> CanonicalUnitProcessorEnabler. </code> 
     *
     *  @param  canonicalUnitProcessorEnablerId the <code> Id </code> of the 
     *          <code> CanonicalUnitProcessorEnabler </code> to remove 
     *  @throws org.osid.NotFoundException <code> 
     *          canonicalUnitProcessorEnablerId </code> not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          canonicalUnitProcessorEnablerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteCanonicalUnitProcessorEnabler(org.osid.id.Id canonicalUnitProcessorEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for canonical 
     *  unit processor enablers. A return of true does not guarantee 
     *  successful authorization. A return of false indicates that it is known 
     *  changing an alias will result in a <code> PERMISSION_DENIED. </code> 
     *  This is intended as a hint to an application that may opt not to offer 
     *  alias operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> CanonicalUnitProcessorEnabler 
     *          </code> aliasing is not authorized, <code> true </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageCanonicalUnitProcessorEnablerAliases();


    /**
     *  Adds an <code> Id </code> to a <code> CanonicalUnitProcessorEnabler 
     *  </code> for the purpose of creating compatibility. The primary <code> 
     *  Id </code> of the <code> CanonicalUnitProcessorEnabler </code> is 
     *  determined by the provider. The new <code> Id </code> performs as an 
     *  alias to the primary <code> Id </code> . If the alias is a pointer to 
     *  another canonical unit processor enabler. it is reassigned to the 
     *  given canonical unit processor enabler <code> Id. </code> 
     *
     *  @param  canonicalUnitProcessorEnablerId the <code> Id </code> of a 
     *          <code> CanonicalUnitProcessorEnabler </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> 
     *          canonicalUnitProcessorEnablerId </code> not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          canonicalUnitProcessorEnablerId </code> or <code> aliasId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasCanonicalUnitProcessorEnabler(org.osid.id.Id canonicalUnitProcessorEnablerId, 
                                                   org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
