//
// org.osid.offering.rules.CanonicalUnitProcessorEnablerQuery
//
//     The OSID Java specification for org.osid.offering.rules.CanonicalUnitProcessorEnablerQuery.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering.rules;


/**
 *  <p>This is the query for searching canonical unit processor enablers. Each 
 *  method match specifies an <code> AND </code> term while multiple 
 *  invocations of the same method produce a nested <code> OR. </code> </p>
 */

public interface CanonicalUnitProcessorEnablerQuery
    extends org.osid.OsidEnablerQuery {


    /**
     *  Matches enablers mapped to the canonical unit processor. 
     *
     *  @param  canonicalUnitProcessorId the canonical unit <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitProcessorId 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRuledCanonicalUnitProcessorId(org.osid.id.Id canonicalUnitProcessorId, 
                                                   boolean match);


    /**
     *  Clears the canonical unit processor <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRuledCanonicalUnitProcessorIdTerms();


    /**
     *  Tests if a <code> CanonicalUnitProcessorQuery </code> is available. 
     *
     *  @return <code> true </code> if a canonical unit processor query is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRuledCanonicalUnitProcessorQuery();


    /**
     *  Gets the query for a canonical unit processor. Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @return the canonical unit processor query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRuledCanonicalUnitProcessorQuery() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRuledCanonicalUnitProcessorQuery() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorQuery getRuledCanonicalUnitProcessorQuery();


    /**
     *  Matches enablers mapped to any canonical unit processor. 
     *
     *  @param  match <code> true </code> for enablers mapped to any canonical 
     *          unit processor, <code> false </code> to match enablers mapped 
     *          to no canonical unit processors 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRuledCanonicalUnitProcessor(boolean match);


    /**
     *  Clears the canonical unit processor query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRuledCanonicalUnitProcessorTerms();


    /**
     *  Matches enablers mapped to the catalogue. 
     *
     *  @param  catalogueId the catalogue <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCatalogueId(org.osid.id.Id catalogueId, boolean match);


    /**
     *  Clears the catalogue <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCatalogueIdTerms();


    /**
     *  Tests if a <code> CatalogueQuery </code> is available. 
     *
     *  @return <code> true </code> if a catalogue query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCatalogueQuery();


    /**
     *  Gets the query for a catalogue. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the catalogue query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCatalogueQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCatalogueQuery() </code> is <code> true. </code> 
     */

    public org.osid.offering.CatalogueQuery getCatalogueQuery();


    /**
     *  Clears the catalogue query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCatalogueTerms();


    /**
     *  Gets the canonical unit processor enabler query record corresponding 
     *  to the given <code> CanonicalUnitProcessorEnabler </code> record 
     *  <code> Type. </code> Multiple record retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @param  canonicalUnitProcessorEnablerRecordType a canonical unit 
     *          processor enabler record type 
     *  @return the canonical unit processor enabler query record 
     *  @throws org.osid.NullArgumentException <code> 
     *          canonicalUnitProcessorEnablerRecordType </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(canonicalUnitProcessorEnablerRecordType) </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.records.CanonicalUnitProcessorEnablerQueryRecord getCanonicalUnitProcessorEnablerQueryRecord(org.osid.type.Type canonicalUnitProcessorEnablerRecordType)
        throws org.osid.OperationFailedException;
}
