//
// org.osid.offering.rules.CanonicalUnitProcessorEnablerRuleApplicationSession
//
//     The OSID Java specification for org.osid.offering.rules.CanonicalUnitProcessorEnablerRuleApplicationSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering.rules;


/**
 *  <p>This session provides methods to apply <code> 
 *  CanonicalUnitProcessorEnablers </code> to <code> CanonicalUnitProcessors. 
 *  </code> A <code> CanonicalUnitProcessor </code> with multiple <code> 
 *  CanonicalUnitProcessorEnablers </code> means any positive rule evaluation 
 *  across the enablers result in an effective <code> CanonicalUnitProcessor. 
 *  </code> </p>
 */

public interface CanonicalUnitProcessorEnablerRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Catalogue </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Catalogue Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCatalogueId();


    /**
     *  Gets the <code> Catalogue </code> associated with this session. 
     *
     *  @return the catalogue 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.Catalogue getCatalogue()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter canonical unit processor 
     *  enabler/canonical unit processor mappings. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known mapping methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignCanonicalUnitProcessorEnablers();


    /**
     *  Adds an existing <code> CanonicalUnitProcessorEnabler </code> to a 
     *  <code> CanonicalUnitProcessor. </code> 
     *
     *  @param  canonicalUnitProcessorEnablerId the <code> Id </code> of the 
     *          <code> CanonicalUnitProcessorEnabler </code> 
     *  @param  canonicalUnitProcessorId the <code> Id </code> of the <code> 
     *          CanonicalUnitProcessor </code> 
     *  @throws org.osid.AlreadyExistsException <code> 
     *          canonicalUnitProcessorEnablerId </code> already applied to 
     *          <code> canonicalUnitProcessorId </code> 
     *  @throws org.osid.NotFoundException <code> 
     *          canonicalUnitProcessorEnablerId </code> or <code> 
     *          canonicalUnitProcessorId </code> not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          canonicalUnitProcessorEnablerId </code> or <code> 
     *          canonicalUnitProcessorId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignCanonicalUnitProcessorEnablerToCanonicalUnitProcessor(org.osid.id.Id canonicalUnitProcessorEnablerId, 
                                                                            org.osid.id.Id canonicalUnitProcessorId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> CanonicalUnitProcessorEnabler </code> from a <code> 
     *  CanonicalUnitProcessor. </code> 
     *
     *  @param  canonicalUnitProcessorEnablerId the <code> Id </code> of the 
     *          <code> CanonicalUnitProcessorEnabler </code> 
     *  @param  canonicalUnitProcessorId the <code> Id </code> of the <code> 
     *          CanonicalUnitProcessor </code> 
     *  @throws org.osid.NotFoundException <code> 
     *          canonicalUnitProcessorEnablerId </code> or <code> 
     *          canonicalUnitProcessorId </code> not found or not mapped 
     *  @throws org.osid.NullArgumentException <code> 
     *          canonicalUnitProcessorEnablerId </code> or <code> 
     *          canonicalUnitProcessorId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignCanonicalUnitProcessorEnablerFromCanonicalUnitProcessor(org.osid.id.Id canonicalUnitProcessorEnablerId, 
                                                                                org.osid.id.Id canonicalUnitProcessorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> CanonicalUnitProcessors. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known sequencing operations will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> CanonicalUnitProcessorEnabler 
     *          </code> ordering is not authorized, <code> true </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceCanonicalUnitProcessorEnablers();


    /**
     *  Reorders canonical unit processor enablers for a canonical unit 
     *  processor by moving the specified canonical unit processor enabler in 
     *  front of a reference canonical unit processor enabler. 
     *
     *  @param  canonicalUnitProcessorEnablerId the <code> Id </code> of a 
     *          <code> CanonicalUnitProcessorEnabler </code> 
     *  @param  canonicalUnitProcessorId the <code> Id </code> of a <code> 
     *          CanonicalUnitProcessor </code> 
     *  @param  referenceId the reference canonical unit processor <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> 
     *          canonicalUnitProcessorEnablerId, canonicalUnitProcesorId, 
     *          </code> or <code> referenceId </code> not found or, <code> 
     *          canonicalUnitProcessorEnablerId </code> or <code> referenceId 
     *          </code> not related to <code> canonicalUnitProcessorId </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          canonicalUnitProcessorEnablerId, canonicalUnitProcessorId, 
     *          </code> or <code> referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveCanonicalUnitProcessorEnablerAhead(org.osid.id.Id canonicalUnitProcessorEnablerId, 
                                                       org.osid.id.Id canonicalUnitProcessorId, 
                                                       org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders canonical unit processor enablers for a canonical unit 
     *  processor by moving the specified canonical unit processor enabler 
     *  behind a reference canonical unit processor enabler. 
     *
     *  @param  canonicalUnitProcessorEnablerId the <code> Id </code> of a 
     *          <code> CanonicalUnitProcessorEnabler </code> 
     *  @param  canonicalUnitProcessorId the <code> Id </code> of a <code> 
     *          CanonicalUnitProcessor </code> 
     *  @param  referenceId the reference canonical unit processor <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> 
     *          canonicalUnitProcessorEnablerId, canonicalUnitProcesorId, 
     *          </code> or <code> referenceId </code> not found or, <code> 
     *          canonicalUnitProcessorEnablerId </code> or <code> referenceId 
     *          </code> not related to <code> canonicalUnitProcessorId </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          canonicalUnitProcessorEnablerId, canonicalUnitProcessorId, 
     *          </code> or <code> referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveCanonicalUnitProcessorEnablerBehind(org.osid.id.Id canonicalUnitProcessorEnablerId, 
                                                        org.osid.id.Id canonicalUnitProcessorId, 
                                                        org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of canonical unit processor enablers for a canonical 
     *  unit processor. 
     *
     *  @param  canonicalUnitProcessorEnablerIds the <code> Ids </code> for a 
     *          set of <code> CanonicalUnitProcessorEnablers </code> 
     *  @param  canonicalUnitProcessorId the <code> Id </code> of a <code> 
     *          CanonicalUnitProcessor </code> 
     *  @throws org.osid.NotFoundException <code> canonicalUnitProcessorId 
     *          </code> not found or, a <code> canonicalUnitProcessorEnablerId 
     *          </code> not related to <code> canonicalUnitProcessorId </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          canonicalUnitProcessorEnablerIds </code> or <code> 
     *          canonicalUnitProcessorId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderCanonicalUnitProcessorEnablers(org.osid.id.Id[] canonicalUnitProcessorEnablerIds, 
                                                    org.osid.id.Id canonicalUnitProcessorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
