//
// org.osid.offering.rules.CanonicalUnitProcessorEnablerSearch
//
//     The OSID Java specification for org.osid.offering.rules.CanonicalUnitProcessorEnablerSearch.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering.rules;


/**
 *  <p>The search interface for governing canonical unit processor enabler 
 *  searches. </p>
 */

public interface CanonicalUnitProcessorEnablerSearch
    extends org.osid.OsidSearch {


    /**
     *  Execute this search among the given list of canonical unit processor 
     *  enablers. 
     *
     *  @param  canonicalUnitProcessorEnablerIds list of canonical unit 
     *          processor enablers 
     *  @throws org.osid.NullArgumentException <code> 
     *          canonicalUnitProcessorEnablerIds </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void searchAmongCanonicalUnitProcessorEnablers(org.osid.id.IdList canonicalUnitProcessorEnablerIds);


    /**
     *  Specify an ordering to the search results. 
     *
     *  @param  canonicalUnitProcessorEnablerSearchOrder canonical unit 
     *          processor enabler search order 
     *  @throws org.osid.NullArgumentException <code> 
     *          canonicalUnitProcessorEnablerSearchOrder </code> is <code> 
     *          null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          canonicalUnitProcessorEnablerSearchOrder </code> is not of 
     *          this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderCanonicalUnitProcessorEnablerResults(org.osid.offering.rules.CanonicalUnitProcessorEnablerSearchOrder canonicalUnitProcessorEnablerSearchOrder);


    /**
     *  Gets the canonical unit processor enabler search record corresponding 
     *  to the given canonical unit processor enabler search record <code> 
     *  Type. </code> This method is used to retrieve an object implementing 
     *  the requested record. 
     *
     *  @param  canonicalUnitProcessorEnablerSearchRecordType a canonical unit 
     *          processor enabler search record type 
     *  @return the canonical unit processor enabler search record 
     *  @throws org.osid.NullArgumentException <code> 
     *          canonicalUnitProcessorEnablerSearchRecordType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(canonicalUnitProcessorEnablerSearchRecordType) 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.records.CanonicalUnitProcessorEnablerSearchRecord getCanonicalUnitProcessorEnablerSearchRecord(org.osid.type.Type canonicalUnitProcessorEnablerSearchRecordType)
        throws org.osid.OperationFailedException;
}
