//
// org.osid.offering.rules.CanonicalUnitProcessorEnablerSearchSession
//
//     The OSID Java specification for org.osid.offering.rules.CanonicalUnitProcessorEnablerSearchSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering.rules;


/**
 *  <p>This session provides methods for searching among <code> 
 *  CanonicalUnitProcessorEnabler </code> objects. The search query is 
 *  constructed using the <code> CanonicalUnitProcessorEnableryQuery. </code> 
 *  </p> 
 *  
 *  <p> <code> getCanonicalUnitProcessorEnablersByQuery() </code> is the basic 
 *  search method and returns a list of <code> CanonicalUnitProcessorEnablers. 
 *  </code> A more advanced search may be performed with <code> 
 *  getCanonicalUnitProcessorEnablersBySearch(). </code> It accepts a <code> 
 *  CanonicalUnitProcessorEnablerSearch </code> in addition to the query for 
 *  the purpose of specifying additional options affecting the entire search, 
 *  such as offering. <code> getCanonicalUnitProcessorEnablersBySearch() 
 *  </code> returns a <code> CanonicalUnitProcessorEnablerSearchResults 
 *  </code> that can be used to access the resulting <code> 
 *  CanonicalUnitProcessorEnablerList </code> or be used to perform a search 
 *  within the result set through <code> CanonicalUnitProcessorEnablerSearch. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated catalogue view: searches include canonical unit 
 *      processor enablers in catalogues of which this catalogue is an 
 *      ancestor in the catalogue hierarchy </li> 
 *      <li> isolated catalogue view: searches are restricted to canonical 
 *      unit processor enablers in this catalogue </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> CanonicalUnitProcessorEnablers </code> may have a query record 
 *  indicated by their respective record types. The query record is accessed 
 *  via the <code> CanonicalUnitProcessorEnablerQuery. </code> </p>
 */

public interface CanonicalUnitProcessorEnablerSearchSession
    extends org.osid.offering.rules.CanonicalUnitProcessorEnablerQuerySession {


    /**
     *  Gets a canonical unit processor enabler search. 
     *
     *  @return the canonical unit processor enabler search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorEnablerSearch getCanonicalUnitProcessorEnablerSearch();


    /**
     *  Gets a canonical unit processor enabler search order. The <code> 
     *  CanonicalUnitProcessorEnablerSearchOrder </code> is supplied to a 
     *  <code> CanonicalUnitProcessorEnablerSearch </code> to specify the 
     *  ordering of results. 
     *
     *  @return the canonical unit processor enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorEnablerSearchOrder getCanonicalUnitProcessorEnablerSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  canonicalUnitProcessorEnablerQuery the canonical unit 
     *          processor enabler query 
     *  @param  canonicalUnitProcessorEnablerSearch the canonical unit 
     *          processor enabler search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> 
     *          canonicalUnitProcessorEnablerQuery </code> or <code> 
     *          canonicalUnitProcessorEnablerSearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> 
     *          canonicalUnitProcessorEnablerQuery </code> or <code> 
     *          canonicalUnitProcessorEnablerSearch </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorEnablerSearchResults getCanonicalUnitProcessorEnablersBySearch(org.osid.offering.rules.CanonicalUnitProcessorEnablerQuery canonicalUnitProcessorEnablerQuery, 
                                                                                                                        org.osid.offering.rules.CanonicalUnitProcessorEnablerSearch canonicalUnitProcessorEnablerSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a canonical unit processor enabler query from an inspector. The 
     *  inspector is available from a <code> 
     *  CanonicalUnitProcessorEnablerSearchResults. </code> 
     *
     *  @param  canonicalUnitProcessorEnablerQueryInspector a canonical unit 
     *          processor enabler query inspector 
     *  @return the canonical unit processor enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          canonicalUnitProcessorEnablerQueryInspector </code> is <code> 
     *          null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          canonicalUnitProcessorEnablerQueryInspector </code> is not of 
     *          this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorEnablerQuery getCanonicalUnitProcessorEnablerQueryFromInspector(org.osid.offering.rules.CanonicalUnitProcessorEnablerQueryInspector canonicalUnitProcessorEnablerQueryInspector);
}
