//
// org.osid.offering.rules.CanonicalUnitProcessorLookupSession
//
//     The OSID Java specification for org.osid.offering.rules.CanonicalUnitProcessorLookupSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering.rules;


/**
 *  <p>This session provides methods for retrieving <code> 
 *  CanonicalUnitProcessors. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated catalogue view: All canonical unit processor methods in 
 *      this session operate, retrieve and pertain to canonical unit processor 
 *      defined explicitly in the current catalogue. Using an isolated view is 
 *      useful for managing <code> CanonicalUnitProcessors </code> with the 
 *      <code> CanonicalUnitProcessorAdminSession. </code> </li> 
 *      <li> federated catalogue view: All canonical unit processor methods in 
 *      this session operate, retrieve and pertain to all canonical unit 
 *      processor defined in this catalogue and any other canonical unit 
 *      processor implicitly available in this catalogue through catalogue 
 *      inheritence. </li> 
 *      <li> active canonical unit processor view: All canonical unit 
 *      processor lookup methods return active canonical unit processors. 
 *      </li> 
 *      <li> any status canonical unit processor view: CanonicalUnit 
 *      processors of any active or inactive status are returned from methods. 
 *      </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedDistributorView() </code> and <code> 
 *  useIsolatedDistributorView() </code> behave as a radio group and one 
 *  should be selected before invoking the methods in this session. </p>
 */

public interface CanonicalUnitProcessorLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Catalogue </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Catalogue Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCatalogueId();


    /**
     *  Gets the <code> Catalogue </code> associated with this session. 
     *
     *  @return the catalogue 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.Catalogue getCatalogue()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> CanonicalUnitProcessors </code> 
     *  lookups. A return of true does not guarantee successful authorization. 
     *  A return of false indicates that it is known all methods in this 
     *  session will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer lookup 
     *  operations to unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupCanonicalUnitProcessors();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeCanonicalUnitProcessorView();


    /**
     *  A complete view of the <code> CanonicalUnitProcessor </code> returns 
     *  is desired. Methods will return what is requested or result in an 
     *  error. This view is used when greater precision is desired at the 
     *  expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryCanonicalUnitProcessorView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include canonical unit processor in catalogues which are children of 
     *  this catalogue in the catalogue hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCatalogueView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this catalogue only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCatalogueView();


    /**
     *  Only active canonical unit processors are returned by methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveCanonicalUnitProcessorView();


    /**
     *  All active and inactive canonical unit processors are returned by 
     *  methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusCanonicalUnitProcessorView();


    /**
     *  Gets the <code> CanonicalUnitProcessor </code> specified by its <code> 
     *  Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  CanonicalUnitProcessor </code> may have a different <code> Id </code> 
     *  than requested, such as the case where a duplicate <code> Id </code> 
     *  was assigned to a <code> CanonicalUnitProcessor </code> and retained 
     *  for compatibility. 
     *  
     *  In active mode, canonical unit processors are returned that are 
     *  currently active. In any status mode, active and inactive canonical 
     *  unit processors are returned. 
     *
     *  @param  canonicalUnitProcessorId <code> Id </code> of the <code> 
     *          CanonicalUnitProcessor </code> 
     *  @return the canonical unit processor 
     *  @throws org.osid.NotFoundException <code> canonicalUnitProcessorId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitProcessorId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.offering.rules.CanonicalUnitProcessor getCanonicalUnitProcessor(org.osid.id.Id canonicalUnitProcessorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CanonicalUnitProcessorList </code> corresponding to the 
     *  given <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  canonical unit processor specified in the <code> Id </code> list, in 
     *  the order of the list, including duplicates, or an error results if an 
     *  <code> Id </code> in the supplied list is not found or inaccessible. 
     *  Otherwise, inaccessible <code> CanonicalUnitProcessors </code> may be 
     *  omitted from the list and may present the elements in any order 
     *  including returning a unique set. 
     *  
     *  In active mode, canonical unit processors are returned that are 
     *  currently active. In any status mode, active and inactive canonical 
     *  unit processors are returned. 
     *
     *  @param  canonicalUnitProcessorIds the list of <code> Ids </code> to 
     *          retrieve 
     *  @return the returned <code> CanonicalUnitProcessor </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          canonicalUnitProcessorIds </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorList getCanonicalUnitProcessorsByIds(org.osid.id.IdList canonicalUnitProcessorIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CanonicalUnitProcessorList </code> corresponding to the 
     *  given canonical unit processor genus <code> Type </code> which does 
     *  not include canonical unit processor of genus types derived from the 
     *  specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  canonical unit processor or an error results. Otherwise, the returned 
     *  list may contain only those canonical unit processor that are 
     *  accessible through this session. 
     *  
     *  In active mode, canonical unit processors are returned that are 
     *  currently active. In any status mode, active and inactive canonical 
     *  unit processors are returned. 
     *
     *  @param  canonicalUnitProcessorGenusType a canonical unit processor 
     *          genus type 
     *  @return the returned <code> CanonicalUnitProcessor </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          canonicalUnitProcessorGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorList getCanonicalUnitProcessorsByGenusType(org.osid.type.Type canonicalUnitProcessorGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CanonicalUnitProcessorList </code> corresponding to the 
     *  given canonical unit processor genus <code> Type </code> and include 
     *  any additional canonical unit processor with genus types derived from 
     *  the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  canonical unit processor or an error results. Otherwise, the returned 
     *  list may contain only those canonical unit processor that are 
     *  accessible through this session. 
     *  
     *  In active mode, canonical unit processors are returned that are 
     *  currently active. In any status mode, active and inactive canonical 
     *  unit processors are returned. 
     *
     *  @param  canonicalUnitProcessorGenusType a canonical unit processor 
     *          genus type 
     *  @return the returned <code> CanonicalUnitProcessor </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          canonicalUnitProcessorGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorList getCanonicalUnitProcessorsByParentGenusType(org.osid.type.Type canonicalUnitProcessorGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CanonicalUnitProcessorList </code> containing the given 
     *  canonical unit processor record <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  canonical unit processor or an error results. Otherwise, the returned 
     *  list may contain only those canonical unit processor that are 
     *  accessible through this session. 
     *  
     *  In active mode, canonical unit processors are returned that are 
     *  currently active. In any status mode, active and inactive canonical 
     *  unit processors are returned. 
     *
     *  @param  canonicalUnitProcessorRecordType a canonical unit processor 
     *          record type 
     *  @return the returned <code> CanonicalUnitProcessor </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          canonicalUnitProcessorRecordType </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorList getCanonicalUnitProcessorsByRecordType(org.osid.type.Type canonicalUnitProcessorRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> CanonicalUnitProcessors. </code> 
     *  
     *  In plenary mode, the returned list contains all known canonical unit 
     *  processor or an error results. Otherwise, the returned list may 
     *  contain only those canonical unit processor that are accessible 
     *  through this session. 
     *  
     *  In active mode, canonical unit processors are returned that are 
     *  currently active. In any status mode, active and inactive canonical 
     *  unit processors are returned. 
     *
     *  @return the returned <code> CanonicalUnitProcessor </code> list 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorList getCanonicalUnitProcessors()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
