//
// org.osid.offering.rules.CanonicalUnitProcessorRuleLookupSession
//
//     The OSID Java specification for org.osid.offering.rules.CanonicalUnitProcessorRuleLookupSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering.rules;


/**
 *  <p>This session provides methods to retrieve <code> CanonicalUnitProcessor 
 *  </code> to <code> CanonicalUnit </code> mappings. <code> </code> </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated catalogue view: All methods in this session operate, 
 *      retrieve and pertain canonical unit processor defined explicitly in 
 *      the current catalogue </li> 
 *      <li> federated catalogue view: All methods in this session operate, 
 *      retrieve and pertain to all canonical unit processor defined in this 
 *      catalogue and any other canonical unit processor implicitly available 
 *      in this catalogue through catalogue inheritence. </li> 
 *  </ul>
 *  
 */

public interface CanonicalUnitProcessorRuleLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Catalogue </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Catalogue Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCatalogueId();


    /**
     *  Gets the <code> Catalogue </code> associated with this session. 
     *
     *  @return the catalogue 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.Catalogue getCatalogue()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform lookups of canonical unit 
     *  processor/canonical unit mappings. A return of true does not guarantee 
     *  successful authorization. A return of false indicates that it is known 
     *  lookup methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if looking up mappings is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupCanonicalUnitProcessorRules();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeCanonicalUnitProcessorRuleView();


    /**
     *  A complete view of the <code> CanonicalUnitProcessor </code> and 
     *  <code> CanonicalUnit </code> returns is desired. Methods will return 
     *  what is requested or result in an error. This view is used when 
     *  greater precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryCanonicalUnitProcessorRuleView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include canonical unit processor in catalogues which are children of 
     *  this catalogue in the catalogue hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCatalogueView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this catalogue only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCatalogueView();


    /**
     *  Gets the <code> CanonicalUnitProcessor Id </code> associated with a 
     *  <code> CanonicalUnit. </code> 
     *
     *  @param   canonicalUnitId <code> Id </code> of the <code> CanonicalUnit 
     *          </code> 
     *  @return the canonical unit processor <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> canonicalUnitId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getCanonicalUnitProcessorIdsForCanonicalUnit(org.osid.id.Id  canonicalUnitId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> CanonicalUnitProcessor </code> associated with a 
     *  <code> CanonicalUnit. </code> 
     *
     *  @param  canonicalUnitId <code> Id </code> of the <code> CanonicalUnit 
     *          </code> 
     *  @return the canonical unit processors 
     *  @throws org.osid.NotFoundException <code> canonicalUnitId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorList getCanonicalUnitProcessorsForCanonicalUnit(org.osid.id.Id canonicalUnitId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> CanonicalUnit </code> <code> Ids </code> mapped to a 
     *  <code> CanonicalUnitProcessor. </code> 
     *
     *  @param  canonicalUnitProcessorId <code> Id </code> of a <code> 
     *          CanonicalUnitProcessor </code> 
     *  @return list of canonical unit <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> canonicalUnitProcessorId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitProcessorId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getCanonicalUnitIdsForCanonicalUnitProcessor(org.osid.id.Id canonicalUnitProcessorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> CanonicalUnits </code> mapped to a <code> 
     *  CanonicalUnitProcessor. </code> 
     *
     *  @param  canonicalUnitProcessorId <code> Id </code> of a <code> 
     *          CanonicalUnitProcessor </code> 
     *  @return list of canonicalUnits 
     *  @throws org.osid.NotFoundException <code> canonicalUnitProcessorId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitProcessorId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.CanonicalUnitList getCanonicalUnitsForCanonicalUnitProcessor(org.osid.id.Id canonicalUnitProcessorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
