//
// org.osid.offering.rules.CanonicalUnitProcessorSearchSession
//
//     The OSID Java specification for org.osid.offering.rules.CanonicalUnitProcessorSearchSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering.rules;


/**
 *  <p>This session provides methods for searching among <code> 
 *  CanonicalUnitProcessor </code> objects. The search query is constructed 
 *  using the <code> CanonicalUnitProcessoryQuery. </code> </p> 
 *  
 *  <p> <code> getCanonicalUnitProcessorsByQuery() </code> is the basic search 
 *  method and returns a list of <code> CanonicalUnitProcessors. </code> A 
 *  more advanced search may be performed with <code> 
 *  getCanonicalUnitProcessorsBySearch(). </code> It accepts a <code> 
 *  CanonicalUnitProcessorSearch </code> in addition to the query for the 
 *  purpose of specifying additional options affecting the entire search, such 
 *  as offering. <code> getCanonicalUnitProcessorsBySearch() </code> returns a 
 *  <code> CanonicalUnitProcessorSearchResults </code> that can be used to 
 *  access the resulting <code> CanonicalUnitProcessorList </code> or be used 
 *  to perform a search within the result set through <code> 
 *  CanonicalUnitProcessorSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated catalogue view: searches include canonical unit 
 *      processor in catalogues of which this catalogue is an ancestor in the 
 *      catalogue hierarchy </li> 
 *      <li> isolated catalogue view: searches are restricted to canonical 
 *      unit processor in this catalogue </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> CanonicalUnitProcessors </code> may have a query record 
 *  indicated by their respective record types. The query record is accessed 
 *  via the <code> CanonicalUnitProcessorQuery. </code> </p>
 */

public interface CanonicalUnitProcessorSearchSession
    extends org.osid.offering.rules.CanonicalUnitProcessorQuerySession {


    /**
     *  Gets a canonical unit processor search. 
     *
     *  @return the canonical unit processor search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorSearch getCanonicalUnitProcessorSearch();


    /**
     *  Gets a canonical unit processor search order. The <code> 
     *  CanonicalUnitProcessorSearchOrder </code> is supplied to a <code> 
     *  CanonicalUnitProcessorSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the canonical unit processor search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorSearchOrder getCanonicalUnitProcessorSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  canonicalUnitProcessorQuery the canonical unit processor query 
     *  @param  canonicalUnitProcessorSearch the canonical unit processor 
     *          search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> 
     *          canonicalUnitProcessorQuery </code> or <code> 
     *          canonicalUnitProcessorSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> 
     *          canonicalUnitProcessorQuery </code> or <code> 
     *          canonicalUnitProcessorSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorSearchResults getCanonicalUnitProcessorsBySearch(org.osid.offering.rules.CanonicalUnitProcessorQuery canonicalUnitProcessorQuery, 
                                                                                                          org.osid.offering.rules.CanonicalUnitProcessorSearch canonicalUnitProcessorSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a canonical unit processor query from an inspector. The inspector 
     *  is available from a <code> CanonicalUnitProcessorSearchResults. 
     *  </code> 
     *
     *  @param  canonicalUnitProcessorQueryInspector a canonical unit 
     *          processor query inspector 
     *  @return the canonical unit processor query 
     *  @throws org.osid.NullArgumentException <code> 
     *          canonicalUnitProcessorQueryInspector </code> is <code> null 
     *          </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          canonicalUnitProcessorQueryInspector </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorQuery getCanonicalUnitProcessorQueryFromInspector(org.osid.offering.rules.CanonicalUnitProcessorQueryInspector canonicalUnitProcessorQueryInspector);
}
