//
// org.osid.offering.rules.OfferingConstrainerEnablerQuerySession
//
//     The OSID Java specification for org.osid.offering.rules.OfferingConstrainerEnablerQuerySession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering.rules;


/**
 *  <p>This session provides methods for searching among <code> 
 *  OfferingConstrainerEnabler </code> objects. The search query is 
 *  constructed using the <code> OfferingConstrainerEnablerQuery. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated catalogue view: searches include offering constrainer 
 *      enablers in catalogues of which this catalogue is an ancestor in the 
 *      catalogue hierarchy </li> 
 *      <li> isolated catalogue view: searches are restricted to offering 
 *      constrainer enablers in this catalogue </li> 
 *  </ul>
 *  
 *  
 *  <p> CanonicalUnit constrainer enablers may have a query record indicated 
 *  by their respective record types. The query record is accessed via the 
 *  <code> OfferingConstrainerEnablerQuery. </code> </p>
 */

public interface OfferingConstrainerEnablerQuerySession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Catalogue </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Catalogue Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCatalogueId();


    /**
     *  Gets the <code> Catalogue </code> associated with this session. 
     *
     *  @return the catalogue 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.Catalogue getCatalogue()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> OfferingConstrainerEnabler 
     *  </code> lookups. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may not 
     *  offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if search methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSearchOfferingConstrainerEnablers();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include offering constrainer enablers in catalogues which are children 
     *  of this broker in the catalogue hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCatalogueView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this catalogue only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCatalogueView();


    /**
     *  Gets an offering constrainer enabler query. 
     *
     *  @return the offering constrainer enabler query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.OfferingConstrainerEnablerQuery getOfferingConstrainerEnablerQuery();


    /**
     *  Gets a list of <code> OfferingConstrainerEnablers </code> matching the 
     *  given search. 
     *
     *  @param  offeringConstrainerEnablerQuery the canonical unit constraienr 
     *          enabler query 
     *  @return the returned <code> OfferingConstrainerEnablerList </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          offeringConstrainerEnablerQuery </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> 
     *          offeringConstrainerEnablerQuery </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.OfferingConstrainerEnablerList getOfferingConstrainerEnablersByQuery(org.osid.offering.rules.OfferingConstrainerEnablerQuery offeringConstrainerEnablerQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
