//
// org.osid.offering.rules.OfferingConstrainerEnablerRuleApplicationSession
//
//     The OSID Java specification for org.osid.offering.rules.OfferingConstrainerEnablerRuleApplicationSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering.rules;


/**
 *  <p>This session provides methods to apply <code> 
 *  OfferingConstrainerEnablers </code> to <code> OfferingConstrainers. 
 *  </code> An <code> OfferingConstrainer </code> with multiple <code> 
 *  OfferingConstrainerEnablers </code> means any positive rule evaluation 
 *  across the enablers result in an effective <code> OfferingConstrainer. 
 *  </code> </p>
 */

public interface OfferingConstrainerEnablerRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Catalogue </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Catalogue Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCatalogueId();


    /**
     *  Gets the <code> Catalogue </code> associated with this session. 
     *
     *  @return the catalogue 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.Catalogue getCatalogue()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter offering constrainer enabler/offering 
     *  constrainer mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known mapping 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignOfferingConstrainerEnablers();


    /**
     *  Adds an existing <code> OfferingConstrainerEnabler </code> to an 
     *  <code> OfferingConstrainer. </code> 
     *
     *  @param  offeringConstrainerEnablerId the <code> Id </code> of the 
     *          <code> OfferingConstrainerEnabler </code> 
     *  @param  offeringConstrainerId the <code> Id </code> of the <code> 
     *          OfferingConstrainer </code> 
     *  @throws org.osid.AlreadyExistsException <code> 
     *          offeringConstrainerEnablerId </code> already applied to <code> 
     *          offeringConstrainerId </code> 
     *  @throws org.osid.NotFoundException <code> offeringConstrainerEnablerId 
     *          </code> or <code> offeringConstrainerId </code> not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          offeringConstrainerEnablerId </code> or <code> 
     *          offeringConstrainerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignOfferingConstrainerEnablerToOfferingConstrainer(org.osid.id.Id offeringConstrainerEnablerId, 
                                                                      org.osid.id.Id offeringConstrainerId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes an <code> OfferingConstrainerEnabler </code> from an <code> 
     *  OfferingConstrainer. </code> 
     *
     *  @param  offeringConstrainerEnablerId the <code> Id </code> of the 
     *          <code> OfferingConstrainerEnabler </code> 
     *  @param  offeringConstrainerId the <code> Id </code> of the <code> 
     *          OfferingConstrainer </code> 
     *  @throws org.osid.NotFoundException <code> offeringConstrainerEnablerId 
     *          </code> or <code> offeringConstrainerId </code> not found or 
     *          <code> offeringConstrainerEnablerId </code> not applied to 
     *          <code> offeringConstrainerId </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          offeringConstrainerEnablerId </code> or <code> 
     *          offeringConstrainerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignOfferingConstrainerEnablerFromOfferingConstrainer(org.osid.id.Id offeringConstrainerEnablerId, 
                                                                          org.osid.id.Id offeringConstrainerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> OfferingConstrainerEnablers. 
     *  </code> A return of true does not guarantee successful authorization. 
     *  A return of false indicates that it is known sequencing operations 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer sequencing 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> OfferingConstrainerEnabler 
     *          </code> ordering is not authorized, <code> true </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceOfferingConstrainerEnablers();


    /**
     *  Reorders offering constrainer enablers for an offering constrainer by 
     *  moving the specified offering constrainer enabler in front of a 
     *  reference offering constrainer enabler. 
     *
     *  @param  offeringConstrainerEnablerId the <code> Id </code> of an 
     *          <code> OfferingConstrainerEnabler </code> 
     *  @param  offeringConstrainerId the <code> Id </code> of an <code> 
     *          OfferingConstrainer </code> 
     *  @param  referenceId the reference offering constrainer enabler <code> 
     *          Id </code> 
     *  @throws org.osid.NotFoundException <code> 
     *          offeringConstrainerEnablerId, offeringConstrainerId, </code> 
     *          or <code> referenceId </code> not found or, <code> 
     *          offeringConstrainerEnablerId </code> or <code> referenceId 
     *          </code> not related to <code> offeringConstrainerId </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          offeringConstrainerEnablerId, offeringConstrainerId, </code> 
     *          or <code> referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveOfferingConstrainerEnablerAhead(org.osid.id.Id offeringConstrainerEnablerId, 
                                                    org.osid.id.Id offeringConstrainerId, 
                                                    org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders offering constrainer enablers for a canonical unit by moving 
     *  the specified offering constrainer enabler behind a reference offering 
     *  constrainer enabler. 
     *
     *  @param  offeringConstrainerEnablerId the <code> Id </code> of an 
     *          <code> OfferingConstrainerEnabler </code> 
     *  @param  offeringConstrainerId the <code> Id </code> of an <code> 
     *          OfferingConstrainer </code> 
     *  @param  referenceId the reference offering constrainer enabler <code> 
     *          Id </code> 
     *  @throws org.osid.NotFoundException <code> 
     *          offeringConstrainerEnablerId, offeringConstrainerId, </code> 
     *          or <code> referenceId </code> not found or, <code> 
     *          offeringConstrainerEnablerId </code> or <code> referenceId 
     *          </code> not related to <code> offeringConstrainerId </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          offeringConstrainerEnablerId, offeringConstrainerId, </code> 
     *          or <code> referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveOfferingConstrainerEnablerBehind(org.osid.id.Id offeringConstrainerEnablerId, 
                                                     org.osid.id.Id offeringConstrainerId, 
                                                     org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of offering constrainer enablers for an offering 
     *  constrainer. 
     *
     *  @param  offeringConstrainerEnablerIds the <code> Ids </code> for a set 
     *          of <code> OfferingConstrainerEnablers </code> 
     *  @param  offeringConstrainerId the <code> Id </code> of an <code> 
     *          OfferingConstrainer </code> 
     *  @throws org.osid.NotFoundException <code> canonicalUnitConstraienrId 
     *          </code> not found or, an <code> offeringConstrainerEnablerId 
     *          </code> not related to <code> offeringConstrainerId </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          offeringConstrainerEnablerIds </code> or <code> 
     *          offeringConstrainerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderOfferingConstrainerEnablers(org.osid.id.Id[] offeringConstrainerEnablerIds, 
                                                 org.osid.id.Id offeringConstrainerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
