//
// org.osid.offering.rules.OfferingConstrainerEnablerSearchSession
//
//     The OSID Java specification for org.osid.offering.rules.OfferingConstrainerEnablerSearchSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering.rules;


/**
 *  <p>This session provides methods for searching among <code> 
 *  OfferingConstrainerEnabler </code> objects. The search query is 
 *  constructed using the <code> OfferingConstrainerEnableryQuery. </code> 
 *  </p> 
 *  
 *  <p> <code> getOfferingConstrainerEnablersByQuery() </code> is the basic 
 *  search method and returns a list of <code> OfferingConstrainerEnablers. 
 *  </code> A more advanced search may be performed with <code> 
 *  getOfferingConstrainerEnablersBySearch(). </code> It accepts an <code> 
 *  OfferingConstrainerEnablerSearch </code> in addition to the query for the 
 *  purpose of specifying additional options affecting the entire search, such 
 *  as offering. <code> getOfferingConstrainerEnablersBySearch() </code> 
 *  returns an <code> OfferingConstrainerEnablerSearchResults </code> that can 
 *  be used to access the resulting <code> OfferingConstrainerEnablerList 
 *  </code> or be used to perform a search within the result set through 
 *  <code> OfferingConstrainerEnablerSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated catalogue view: searches include offering constrainer 
 *      enablers in catalogues of which this catalogue is an ancestor in the 
 *      catalogue hierarchy </li> 
 *      <li> isolated catalogue view: searches are restricted to offering 
 *      constrainer enablers in this catalogue </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> OfferingConstrainerEnablers </code> may have a query record 
 *  indicated by their respective record types. The query record is accessed 
 *  via the <code> OfferingConstrainerEnablerQuery. </code> </p>
 */

public interface OfferingConstrainerEnablerSearchSession
    extends org.osid.offering.rules.OfferingConstrainerEnablerQuerySession {


    /**
     *  Gets an offering constrainer enabler search. 
     *
     *  @return the offering constrainer enabler search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.OfferingConstrainerEnablerSearch getOfferingConstrainerEnablerSearch();


    /**
     *  Gets an offering constrainer enabler search order. The <code> 
     *  OfferingConstrainerEnablerSearchOrder </code> is supplied to an <code> 
     *  OfferingConstrainerEnablerSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the offering constrainer enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.OfferingConstrainerEnablerSearchOrder getOfferingConstrainerEnablerSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  offeringConstrainerEnablerQuery the offering constrainer 
     *          enabler query 
     *  @param  offeringConstrainerEnablerSearch the offering constrainer 
     *          enabler search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> 
     *          offeringConstrainerEnablerQuery </code> or <code> 
     *          offeringConstrainerEnablerSearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> 
     *          offeringConstrainerEnablerQuery </code> or <code> 
     *          offeringConstrainerEnablerSearch </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.OfferingConstrainerEnablerSearchResults getOfferingConstrainerEnablersBySearch(org.osid.offering.rules.OfferingConstrainerEnablerQuery offeringConstrainerEnablerQuery, 
                                                                                                                  org.osid.offering.rules.OfferingConstrainerEnablerSearch offeringConstrainerEnablerSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an offering constrainer enabler query from an inspector. The 
     *  inspector is available from an <code> 
     *  OfferingConstrainerEnablerSearchResults. </code> 
     *
     *  @param  offeringConstrainerEnablerQueryInspector an offering 
     *          constrainer enabler query inspector 
     *  @return the offering constrainer enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          offeringConstrainerEnablerQueryInspector </code> is <code> 
     *          null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          offeringConstrainerEnablerQueryInspector </code> is not of 
     *          this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.OfferingConstrainerEnablerQuery getOfferingConstrainerEnablerQueryFromInspector(org.osid.offering.rules.OfferingConstrainerEnablerQueryInspector offeringConstrainerEnablerQueryInspector);
}
