//
// org.osid.offering.rules.OfferingConstrainerSmartCatalogueSession
//
//     The OSID Java specification for org.osid.offering.rules.OfferingConstrainerSmartCatalogueSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering.rules;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogues. An <code> OfferingConstrainerQuery </code> can be retrieved 
 *  from this session and mapped to this <code> Catalogue </code> to create a 
 *  virtual collection of offering constrainers. The offering constrainer may 
 *  be sequenced using the <code> OfferingConstrainerSearchOrder </code> from 
 *  this session. </p> 
 *  
 *  <p> This <code> Catalogue </code> has a default query that matches any 
 *  offering constrainer and a default search order that specifies no 
 *  sequencing. The queries may be examined using an <code> 
 *  OfferingConstrainerQueryInspector. </code> The query may be modified by 
 *  converting the inspector back to an <code> OfferingConstrainerQuery. 
 *  </code> </p>
 */

public interface OfferingConstrainerSmartCatalogueSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Catalogue </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Catalogue Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCatalogueId();


    /**
     *  Gets the <code> Catalogue </code> associated with this session. 
     *
     *  @return the catalogue 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.Catalogue getCatalogue()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart catalogues. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart catalogue management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartCatalogues();


    /**
     *  Gets an offering constrainer query. 
     *
     *  @return the offering constrainer query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.OfferingConstrainerQuery getOfferingConstrainerQuery();


    /**
     *  Gets an offering constrainer search order. 
     *
     *  @return the offering constrainer search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.OfferingConstrainerSearchOrder getOfferingConstrainerSearchOrder();


    /**
     *  Applies an offering constrainer query to this catalogue. 
     *
     *  @param  offeringConstrainerQuery the offering constrainer query 
     *  @throws org.osid.NullArgumentException <code> offeringConstrainerQuery 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> offeringConstrainerQuery 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyOfferingConstrainerQuery(org.osid.offering.rules.OfferingConstrainerQuery offeringConstrainerQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an offering constrainer query inspector for this catalogue. 
     *
     *  @return the offering constrainer query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.OfferingConstrainerQueryInspector inspectOfferingConstrainerQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies an offering constrainer search order to this catalogue. 
     *
     *  @param  offeringConstrainerSearchOrder the offering constrainer search 
     *          order 
     *  @throws org.osid.NullArgumentException <code> 
     *          offeringConstrainerSearchOrder </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> 
     *          offeringConstrainerSearchOrder </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyOfferingConstrainerSequencing(org.osid.offering.rules.OfferingConstrainerSearchOrder offeringConstrainerSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an offering constrainer query from an inspector. 
     *
     *  @param  offeringConstrainerQueryInspector an offering constrainer 
     *          query inspector 
     *  @return the offering constrainer query 
     *  @throws org.osid.NullArgumentException <code> 
     *          offeringConstrainerQueryInspector </code> is <code> null 
     *          </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          offeringConstrainerQueryInspector </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.OfferingConstrainerQuery getOfferingConstrainerQueryFromInspector(org.osid.offering.rules.OfferingConstrainerQueryInspector offeringConstrainerQueryInspector);
}
