//
// org.osid.offering.rules.OfferingRulesManager
//
//     The OSID Java specification for org.osid.offering.rules.OfferingRulesManager.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering.rules;


/**
 *  <p>The offering rules manager provides access to offering rules sessions 
 *  and provides interoperability tests for various aspects of this service. 
 *  The sessions included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> CanonicalUnitEnablerLookupSession: </code> a session to 
 *      retrieve canonical unit enablers </li> 
 *      <li> <code> CanonicalUnitEnablerQuerySession: </code> a session to 
 *      query for canonical unit enablers </li> 
 *      <li> <code> CanonicalUnitEnablerSearchSession: </code> a session to 
 *      search for canonical unit enablers </li> 
 *      <li> <code> CanonicalUnitEnablerAdminSession: </code> a session to 
 *      create and delete canonical unit enablers </li> 
 *      <li> <code> CanonicalUnitEnablerNotificationSession: </code> a session 
 *      to receive notifications pertaining to canonical unit enabler changes 
 *      </li> 
 *      <li> <code> CanonicalUnitEnablerCatalogueSession: </code> a session to 
 *      look up canonical unit enabler catalogue mappings </li> 
 *      <li> <code> CanonicalUnitEnablerCatalogueAssignmentSession: </code> a 
 *      session to manage canonical unit enabler to catalogue mappings </li> 
 *      <li> <code> CanonicalUnitEnablerSmartCatalogueSession: </code> a 
 *      session to manage dynamic catalogues of canonical unit enablers </li> 
 *      <li> <code> CanonicalUnitEnableRuleLookupSession: </code> a session to 
 *      look up canonical unit enabler mappings </li> 
 *      <li> <code> CanonicalUnitEnablerRuleApplicationSession: </code> a 
 *      session to apply canonical unit enablers </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> CanonicalUnitProcessorLookupSession: </code> a session to 
 *      retrieve canonical unit processor </li> 
 *      <li> <code> CanonicalUnitProcessorQuerySession: </code> a session to 
 *      query for canonical unit processor </li> 
 *      <li> <code> CanonicalUnitProcessorSearchSession: </code> a session to 
 *      search for canonical unit processor </li> 
 *      <li> <code> CanonicalUnitProcessorAdminSession: </code> a session to 
 *      create and delete canonical unit processor </li> 
 *      <li> <code> CanonicalUnitProcessorNotificationSession: </code> a 
 *      session to receive notifications pertaining to canonical unit 
 *      processor changes </li> 
 *      <li> <code> CanonicalUnitProcessorCatalogueSession: </code> a session 
 *      to look up canonical unit processor catalogue mappings </li> 
 *      <li> <code> CanonicalUnitProcessorCatalogueAssignmentSession: </code> 
 *      a session to manage canonical unit processor to catalogue mappings 
 *      </li> 
 *      <li> <code> CanonicalUnitProcessorSmartCatalogueSession: </code> a 
 *      session to manage dynamic catalogues of canonical unit processor </li> 
 *      <li> <code> CanonicalUnitProcessorRuleLookupSession: </code> a session 
 *      to look up canonical unit processor to canonical unit mappings </li> 
 *      <li> <code> CanonicalUnitProcessorRuleApplicationSession: </code> a 
 *      session to apply canonical unit processor to canonicalUnits </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> CanonicalUnitProcessorEnablerLookupSession: </code> a 
 *      session to retrieve canonical unit processor enablers </li> 
 *      <li> <code> CanonicalUnitProcessorEnablerQuerySession: </code> a 
 *      session to query for canonical unit processor enablers </li> 
 *      <li> <code> CanonicalUnitProcessorEnablerSearchSession: </code> a 
 *      session to search for canonical unit processor enablers </li> 
 *      <li> <code> CanonicalUnitProcessorEnablerAdminSession: </code> a 
 *      session to create and delete canonical unit processor enablers </li> 
 *      <li> <code> CanonicalUnitProcessorEnablerNotificationSession: </code> 
 *      a session to receive notifications pertaining to canonical unit 
 *      processor enabler changes </li> 
 *      <li> <code> CanonicalUnitProcessorEnablerCatalogueSession: </code> a 
 *      session to look up canonical unit processor enabler catalogue mappings 
 *      </li> 
 *      <li> <code> CanonicalUnitProcessorEnablerCatalogueAssignmentSession: 
 *      </code> a session to manage canonical unit processor enabler to 
 *      catalogue mappings </li> 
 *      <li> <code> CanonicalUnitProcessorEnablerSmartCatalogueSession: 
 *      </code> a session to manage dynamic catalogues of canonical unit 
 *      processor enablers </li> 
 *      <li> <code> CanonicalUnitProcessorEnablerRuleLookupSession: </code> a 
 *      session to look up canonical unit processor enabler mappings </li> 
 *      <li> <code> CanonicalUnitProcessorEnablerRuleApplicationSession: 
 *      </code> a session to apply canonical unit processor enablers </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> OfferingConstrainerLookupSession: </code> a session to 
 *      retrieve offering constrainer </li> 
 *      <li> <code> OfferingConstrainerQuerySession: </code> a session to 
 *      query for offering constrainer </li> 
 *      <li> <code> OfferingConstrainerSearchSession: </code> a session to 
 *      search for offering constrainer </li> 
 *      <li> <code> OfferingConstrainerAdminSession: </code> a session to 
 *      create and delete offering constrainer </li> 
 *      <li> <code> OfferingConstrainerNotificationSession: </code> a session 
 *      to receive notifications pertaining to offering constrainer changes 
 *      </li> 
 *      <li> <code> OfferingConstrainerCatalogueSession: </code> a session to 
 *      look up offering constrainer catalogue mappings </li> 
 *      <li> <code> OfferingConstrainerCatalogueAssignmentSession: </code> a 
 *      session to manage offering constrainer to catalogue mappings </li> 
 *      <li> <code> OfferingConstrainerSmartCatalogueSession: </code> a 
 *      session to manage dynamic catalogues of offering constrainer </li> 
 *      <li> <code> OfferingConstrainerRuleLookupSession: </code> a session to 
 *      look up offering constrainer to canonical unit mappings </li> 
 *      <li> <code> OfferingConstrainerRuleApplicationSession: </code> a 
 *      session to apply offering constrainer to canonicalUnits </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> OfferingConstrainerEnablerLookupSession: </code> a session 
 *      to retrieve offering constrainer enablers </li> 
 *      <li> <code> OfferingConstrainerEnablerQuerySession: </code> a session 
 *      to query for offering constrainer enablers </li> 
 *      <li> <code> OfferingConstrainerEnablerSearchSession: </code> a session 
 *      to search for offering constrainer enablers </li> 
 *      <li> <code> OfferingConstrainerEnablerAdminSession: </code> a session 
 *      to create and delete offering constrainer enablers </li> 
 *      <li> <code> OfferingConstrainerEnablerNotificationSession: </code> a 
 *      session to receive notifications pertaining to offering constrainer 
 *      enabler changes </li> 
 *      <li> <code> OfferingConstrainerEnablerCatalogueSession: </code> a 
 *      session to look up offering constrainer enabler catalogue mappings 
 *      </li> 
 *      <li> <code> OfferingConstrainerEnablerCatalogueAssignmentSession: 
 *      </code> a session to manage offering constrainer enabler to catalogue 
 *      mappings </li> 
 *      <li> <code> OfferingConstrainerEnablerSmartCatalogueSession: </code> a 
 *      session to manage dynamic catalogues of offering constrainer enablers 
 *      </li> 
 *      <li> <code> OfferingConstrainerEnableRuleLookupSession: </code> a 
 *      session to look up offering constrainer enabler mappings </li> 
 *      <li> <code> OfferingConstrainerEnablerRuleApplicationSession: </code> 
 *      a session to apply offering constrainer enablers </li> 
 *  </ul>
 *  
 */

public interface OfferingRulesManager
    extends org.osid.OsidManager,
            org.osid.offering.rules.OfferingRulesProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  enabler lookup service. 
     *
     *  @return a <code> CanonicalUnitEnablerLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitEnablerLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitEnablerLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.offering.rules.CanonicalUnitEnablerLookupSession getCanonicalUnitEnablerLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  enabler lookup service for the given catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return a <code> CanonicalUnitEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitEnablerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitEnablerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.offering.rules.CanonicalUnitEnablerLookupSession getCanonicalUnitEnablerLookupSessionForCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  enabler query service. 
     *
     *  @return a <code> CanonicalUnitEnablerQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitEnablerQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitEnablerQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.offering.rules.CanonicalUnitEnablerQuerySession getCanonicalUnitEnablerQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  enabler query service for the given catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return a <code> CanonicalUnitEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitEnablerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.offering.rules.CanonicalUnitEnablerQuerySession getCanonicalUnitEnablerQuerySessionForCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  enabler search service. 
     *
     *  @return a <code> CanonicalUnitEnablerSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitEnablerSearch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitEnablerSearch() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.offering.rules.CanonicalUnitEnablerSearchSession getCanonicalUnitEnablerSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  enablers earch service for the given catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return a <code> CanonicalUnitEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitEnablerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitEnablerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.offering.rules.CanonicalUnitEnablerSearchSession getCanonicalUnitEnablerSearchSessionForCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  enabler administration service. 
     *
     *  @return a <code> CanonicalUnitEnablerAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitEnablerAdmin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitEnablerAdmin() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.offering.rules.CanonicalUnitEnablerAdminSession getCanonicalUnitEnablerAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  enabler administration service for the given catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return a <code> CanonicalUnitEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitEnablerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.offering.rules.CanonicalUnitEnablerAdminSession getCanonicalUnitEnablerAdminSessionForCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  enabler notification service. 
     *
     *  @param  canonicalUnitEnablerReceiver the notification callback 
     *  @return a <code> CanonicalUnitEnablerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          canonicalUnitEnablerReceiver </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitEnablerNotification() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitEnablerNotification() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.offering.rules.CanonicalUnitEnablerNotificationSession getCanonicalUnitEnablerNotificationSession(org.osid.offering.rules.CanonicalUnitEnablerReceiver canonicalUnitEnablerReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  enabler notification service for the given catalogue. 
     *
     *  @param  canonicalUnitEnablerReceiver the notification callback 
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return a <code> CanonicalUnitEnablerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no catalogue found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          canonicalUnitEnablerReceiver </code> or <code> catalogueId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitEnablerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitEnablerNotification() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.offering.rules.CanonicalUnitEnablerNotificationSession getCanonicalUnitEnablerNotificationSessionForCatalogue(org.osid.offering.rules.CanonicalUnitEnablerReceiver canonicalUnitEnablerReceiver, 
                                                                                                                                  org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup canonical unit 
     *  enabler/catalogue mappings for canonical unit enablers. 
     *
     *  @return a <code> CanonicalUnitEnablerCatalogueSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitEnablerCatalogue() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitEnablerCatalogue() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.offering.rules.CanonicalUnitEnablerCatalogueSession getCanonicalUnitEnablerCatalogueSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning 
     *  canonical unit enablers to catalogues. 
     *
     *  @return a <code> CanonicalUnitEnablerCatalogueAssignmentSession 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitEnablerCatalogueAssignment() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitEnablerCatalogueAssignment() </code> 
     *              is <code> true. </code> 
     */

    public org.osid.offering.rules.CanonicalUnitEnablerCatalogueAssignmentSession getCanonicalUnitEnablerCatalogueAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage canonical unit enabler 
     *  smart catalogues. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return a <code> CanonicalUnitEnablerSmartCatalogueSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitEnablerSmartCatalogue() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitEnablerSmartCatalogue() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.offering.rules.CanonicalUnitEnablerSmartCatalogueSession getCanonicalUnitEnablerSmartCatalogueSession(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  enabler mapping lookup service. 
     *
     *  @return a <code> CanonicalUnitEnablerRuleLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitEnablerRuleLookup() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitEnablerRuleLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.offering.rules.CanonicalUnitEnablerRuleLookupSession getCanonicalUnitEnablerRuleLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  enabler mapping lookup service for the given catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return a <code> CanonicalUnitEnablerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitEnablerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitEnablerRuleLookup() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.offering.rules.CanonicalUnitEnablerRuleLookupSession getCanonicalUnitEnablerRuleLookupSessionForCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  enabler assignment service. 
     *
     *  @return a <code> CanonicalUnitEnablerRuleApplicationSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitEnablerRuleApplication() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitEnablerRuleApplication() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.offering.rules.CanonicalUnitEnablerRuleApplicationSession getCanonicalUnitEnablerRuleApplicationSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  enabler assignment service for the given catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return a <code> CanonicalUnitEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitEnablerRuleApplication() </code> or 
     *          <code> supportsVisibleFederation() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitEnablerRuleApplication() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.offering.rules.CanonicalUnitEnablerRuleApplicationSession getCanonicalUnitEnablerRuleApplicationSessionForCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  processor lookup service. 
     *
     *  @return a <code> CanonicalUnitProcessorLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitProcessorLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitProcessorLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorLookupSession getCanonicalUnitProcessorLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  processor lookup service for the given catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return a <code> CanonicalUnitProcessorLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitProcessorLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitProcessorLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorLookupSession getCanonicalUnitProcessorLookupSessionForCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  processor query service. 
     *
     *  @return a <code> CanonicalUnitProcessorQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitProcessorQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitProcessorQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorQuerySession getCanonicalUnitProcessorQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  processor query service for the given catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return a <code> CanonicalUnitProcessorQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitProcessorQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitProcessorQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorQuerySession getCanonicalUnitProcessorQuerySessionForCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  processor search service. 
     *
     *  @return a <code> CanonicalUnitProcessorSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitProcessorSearch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitProcessorSearch() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorSearchSession getCanonicalUnitProcessorSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  processor earch service for the given catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return a <code> CanonicalUnitProcessorSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitProcessorSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitProcessorSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorSearchSession getCanonicalUnitProcessorSearchSessionForCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  processor administration service. 
     *
     *  @return a <code> CanonicalUnitProcessorAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitProcessorAdmin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitProcessorAdmin() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorAdminSession getCanonicalUnitProcessorAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  processor administration service for the given catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return a <code> CanonicalUnitProcessorAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitProcessorAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitProcessorAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorAdminSession getCanonicalUnitProcessorAdminSessionForCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  processor notification service. 
     *
     *  @param  canonicalUnitProcessorReceiver the notification callback 
     *  @return a <code> CanonicalUnitProcessorNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          canonicalUnitProcessorReceiver </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitProcessorNotification() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitProcessorNotification() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorNotificationSession getCanonicalUnitProcessorNotificationSession(org.osid.offering.rules.CanonicalUnitProcessorReceiver canonicalUnitProcessorReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  processor notification service for the given catalogue. 
     *
     *  @param  canonicalUnitProcessorReceiver the notification callback 
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return a <code> CanonicalUnitProcessorNotificationSession </code> 
     *  @throws org.osid.NotFoundException no catalogue found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          canonicalUnitProcessorReceiver </code> or <code> catalogueId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitProcessorNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitProcessorNotification() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorNotificationSession getCanonicalUnitProcessorNotificationSessionForCatalogue(org.osid.offering.rules.CanonicalUnitProcessorReceiver canonicalUnitProcessorReceiver, 
                                                                                                                                      org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup canonical unit 
     *  processor/catalogue mappings for canonical unit processors. 
     *
     *  @return a <code> CanonicalUnitProcessorCatalogueSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitProcessorCatalogue() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitProcessorCatalogue() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorCatalogueSession getCanonicalUnitProcessorCatalogueSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning 
     *  canonical unit processor to catalogues. 
     *
     *  @return a <code> CanonicalUnitProcessorCatalogueAssignmentSession 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitProcessorCatalogueAssignment() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitProcessorCatalogueAssignment() 
     *              </code> is <code> true. </code> 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorCatalogueAssignmentSession getCanonicalUnitProcessorCatalogueAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage canonical unit processor 
     *  smart catalogues. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return a <code> CanonicalUnitProcessorSmartCatalogueSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitProcessorSmartCatalogue() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitProcessorSmartCatalogue() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorSmartCatalogueSession getCanonicalUnitProcessorSmartCatalogueSession(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  processor canonical unit mapping lookup service for looking up the 
     *  rules applied to the catalogue. 
     *
     *  @return a <code> CanonicalUnitProcessorRuleLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitProcessorRuleLookup() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitProcessorRuleLookup() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorRuleLookupSession getCanonicalUnitProcessorRuleLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  processor mapping lookup service for the given catalogue for looking 
     *  up rules applied to a catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return a <code> CanonicalUnitProcessorRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitProcessorRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitProcessorRuleLookup() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorRuleLookupSession getCanonicalUnitProcessorRuleLookupSessionForCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  processor assignment service. 
     *
     *  @return a <code> CanonicalUnitProcessorRuleApplicationSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitProcessorRuleApplication() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitProcessorRuleApplication() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorRuleApplicationSession getCanonicalUnitProcessorRuleApplicationSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  processor assignment service for the given catalogue to apply to 
     *  catalogues. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return a <code> CanonicalUnitProcessorRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitProcessorRuleApplication() </code> or 
     *          <code> supportsVisibleFederation() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitProcessorRuleApplication() </code> 
     *              and <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorRuleApplicationSession getCanonicalUnitProcessorRuleApplicationSessionForCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  processor enabler lookup service. 
     *
     *  @return a <code> CanonicalUnitProcessorEnablerLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitProcessorEnablerLookup() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitProcessorEnablerLookup() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorEnablerLookupSession getCanonicalUnitProcessorEnablerLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  processor enabler lookup service for the given catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return a <code> CanonicalUnitProcessorEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitProcessorEnablerLookup() </code> or 
     *          <code> supportsVisibleFederation() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitProcessorEnablerLookup() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorEnablerLookupSession getCanonicalUnitProcessorEnablerLookupSessionForCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  processor enabler query service. 
     *
     *  @return a <code> CanonicalUnitProcessorEnablerQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitProcessorEnablerQuery() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitProcessorEnablerQuery() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorEnablerQuerySession getCanonicalUnitProcessorEnablerQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  processor enabler query service for the given catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return a <code> CanonicalUnitProcessorEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitProcessorEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitProcessorEnablerQuery() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorEnablerQuerySession getCanonicalUnitProcessorEnablerQuerySessionForCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  processor enabler search service. 
     *
     *  @return a <code> CanonicalUnitProcessorEnablerSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitProcessorEnablerSearch() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitProcessorEnablerSearch() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorEnablerSearchSession getCanonicalUnitProcessorEnablerSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  processor enablers earch service for the given catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return a <code> CanonicalUnitProcessorEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitProcessorEnablerSearch() </code> or 
     *          <code> supportsVisibleFederation() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitProcessorEnablerSearch() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorEnablerSearchSession getCanonicalUnitProcessorEnablerSearchSessionForCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  processor enabler administration service. 
     *
     *  @return a <code> CanonicalUnitProcessorEnablerAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitProcessorEnablerAdmin() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitProcessorEnablerAdmin() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorEnablerAdminSession getCanonicalUnitProcessorEnablerAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  processor enabler administration service for the given catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return a <code> CanonicalUnitProcessorEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitProcessorEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitProcessorEnablerAdmin() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorEnablerAdminSession getCanonicalUnitProcessorEnablerAdminSessionForCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  processor enabler notification service. 
     *
     *  @param  canonicalUnitProcessorEnablerReceiver the notification 
     *          callback 
     *  @return a <code> CanonicalUnitProcessorEnablerNotificationSession 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          canonicalUnitProcessorEnablerReceiver </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitProcessorEnablerNotification() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitProcessorEnablerNotification() 
     *              </code> is <code> true. </code> 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorEnablerNotificationSession getCanonicalUnitProcessorEnablerNotificationSession(org.osid.offering.rules.CanonicalUnitProcessorEnablerReceiver canonicalUnitProcessorEnablerReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  processor enabler notification service for the given catalogue. 
     *
     *  @param  canonicalUnitProcessorEnablerReceiver the notification 
     *          callback 
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return a <code> CanonicalUnitProcessorEnablerNotificationSession 
     *          </code> 
     *  @throws org.osid.NotFoundException no catalogue found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          canonicalUnitProcessorEnablerReceiver </code> or <code> 
     *          catalogueId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitProcessorEnablerNotification() </code> or 
     *          <code> supportsVisibleFederation() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitProcessorEnablerNotification() 
     *              </code> and <code> supportsVisibleFederation() </code> are 
     *              <code> true. </code> 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorEnablerNotificationSession getCanonicalUnitProcessorEnablerNotificationSessionForCatalogue(org.osid.offering.rules.CanonicalUnitProcessorEnablerReceiver canonicalUnitProcessorEnablerReceiver, 
                                                                                                                                                    org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup canonical unit processor 
     *  enabler/catalogue mappings for canonical unit processor enablers. 
     *
     *  @return a <code> CanonicalUnitProcessorEnablerCatalogueSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitProcessorEnablerCatalogue() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitProcessorEnablerCatalogue() </code> 
     *              is <code> true. </code> 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorEnablerCatalogueSession getCanonicalUnitProcessorEnablerCatalogueSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning 
     *  canonical unit processor enablers to catalogues. 
     *
     *  @return a <code> 
     *          CanonicalUnitProcessorEnablerCatalogueAssignmentSession 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitProcessorEnablerCatalogueAssignment() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitProcessorEnablerCatalogueAssignment() 
     *              </code> is <code> true. </code> 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorEnablerCatalogueAssignmentSession getCanonicalUnitProcessorEnablerCatalogueAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage canonical unit processor 
     *  enabler smart catalogues. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return a <code> CanonicalUnitProcessorEnablerSmartCatalogueSession 
     *          </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitProcessorEnablerSmartCatalogue() </code> 
     *          is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitProcessorEnablerSmartCatalogue() 
     *              </code> is <code> true. </code> 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorEnablerSmartCatalogueSession getCanonicalUnitProcessorEnablerSmartCatalogueSession(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  processor enabler mapping lookup service. 
     *
     *  @return a <code> CanonicalUnitProcessorEnablerRuleLookupSession 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitProcessorEnablerRuleLookup() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitProcessorEnablerRuleLookup() </code> 
     *              is <code> true. </code> 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorEnablerRuleLookupSession getCanonicalUnitProcessorEnablerRuleLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  processor enabler mapping lookup service. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return a <code> CanonicalUnitProcessorEnablerRuleLookupSession 
     *          </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitProcessorEnablerRuleLookup() </code> or 
     *          <code> supportsVisibleFederation() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitProcessorEnablerRuleLookup() </code> 
     *              and <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorEnablerRuleLookupSession getCanonicalUnitProcessorEnablerRuleLookupSessionForCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  processor enabler assignment service. 
     *
     *  @return a <code> CanonicalUnitProcessorEnablerRuleApplicationSession 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitProcessorEnablerRuleApplication() </code> 
     *          is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitProcessorEnablerRuleApplication() 
     *              </code> is <code> true. </code> 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorEnablerRuleApplicationSession getCanonicalUnitProcessorEnablerRuleApplicationSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  processor enabler assignment service for the given catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return z <code> CanonicalUnitProcessorEnablerRuleApplicationSession 
     *          </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitProcessorEnablerRuleApplication() </code> 
     *          or <code> supportsVisibleFederation() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitProcessorEnablerRuleApplication() 
     *              </code> and <code> supportsVisibleFederation() </code> are 
     *              <code> true. </code> 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorEnablerRuleApplicationSession getCanonicalUnitProcessorEnablerRuleApplicationSessionForCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offering 
     *  constrainer lookup service. 
     *
     *  @return an <code> OfferingConstrainerLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfferingConstrainerLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingConstrainerLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.offering.rules.OfferingConstrainerLookupSession getOfferingConstrainerLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offering 
     *  constrainer lookup service for the given catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return an <code> OfferingConstrainerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfferingConstrainerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingConstrainerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.offering.rules.OfferingConstrainerLookupSession getOfferingConstrainerLookupSessionForCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offering 
     *  constrainer query service. 
     *
     *  @return an <code> OfferingConstrainerQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfferingConstrainerQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingConstrainerQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.offering.rules.OfferingConstrainerQuerySession getOfferingConstrainerQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offering 
     *  constrainer query service for the given catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return an <code> OfferingConstrainerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfferingConstrainerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingConstrainerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.offering.rules.OfferingConstrainerQuerySession getOfferingConstrainerQuerySessionForCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offering 
     *  constrainer search service. 
     *
     *  @return an <code> OfferingConstrainerSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfferingConstrainerSearch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingConstrainerSearch() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.offering.rules.OfferingConstrainerSearchSession getOfferingConstrainerSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offering 
     *  constrainer earch service for the given catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return an <code> OfferingConstrainerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfferingConstrainerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingConstrainerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.offering.rules.OfferingConstrainerSearchSession getOfferingConstrainerSearchSessionForCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offering 
     *  constrainer administration service. 
     *
     *  @return an <code> OfferingConstrainerAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfferingConstrainerAdmin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingConstrainerAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.offering.rules.OfferingConstrainerAdminSession getOfferingConstrainerAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offering 
     *  constrainer administration service for the given catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return an <code> OfferingConstrainerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfferingConstrainerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingConstrainerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.offering.rules.OfferingConstrainerAdminSession getOfferingConstrainerAdminSessionForCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offering 
     *  constrainer notification service. 
     *
     *  @param  offeringConstrainerReceiver the notification callback 
     *  @return an <code> OfferingConstrainerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          offeringConstrainerReceiver </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfferingConstrainerNotification() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingConstrainerNotification() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.offering.rules.OfferingConstrainerNotificationSession getOfferingConstrainerNotificationSession(org.osid.offering.rules.OfferingConstrainerReceiver offeringConstrainerReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offering 
     *  constrainer notification service for the given catalogue. 
     *
     *  @param  offeringConstrainerReceiver the notification callback 
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return an <code> OfferingConstrainerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no catalogue found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          offeringConstrainerReceiver </code> or <code> catalogueId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfferingConstrainerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingConstrainerNotification() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.offering.rules.OfferingConstrainerNotificationSession getOfferingConstrainerNotificationSessionForCatalogue(org.osid.offering.rules.OfferingConstrainerReceiver offeringConstrainerReceiver, 
                                                                                                                                org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup offering 
     *  constrainer/catalogue mappings for offering constrainers. 
     *
     *  @return an <code> OfferingConstrainerCatalogueSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfferingConstrainerCatalogue() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingConstrainerCatalogue() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.offering.rules.OfferingConstrainerCatalogueSession getOfferingConstrainerCatalogueSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning offering 
     *  constrainer to catalogues. 
     *
     *  @return an <code> OfferingConstrainerCatalogueAssignmentSession 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfferingConstrainerCatalogueAssignment() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingConstrainerCatalogueAssignment() </code> 
     *              is <code> true. </code> 
     */

    public org.osid.offering.rules.OfferingConstrainerCatalogueAssignmentSession getOfferingConstrainerCatalogueAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage offering constrainer 
     *  smart catalogues. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return an <code> OfferingConstrainerSmartCatalogueSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfferingConstrainerSmartCatalogue() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingConstrainerSmartCatalogue() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.offering.rules.OfferingConstrainerSmartCatalogueSession getOfferingConstrainerSmartCatalogueSession(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offering 
     *  constrainer canonical unit mapping lookup service for looking up the 
     *  rules applied to the catalogue. 
     *
     *  @return an <code> OfferingConstrainerRuleLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfferingConstrainerRuleLookup() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingConstrainerRuleLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.offering.rules.OfferingConstrainerRuleLookupSession getOfferingConstrainerRuleLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offering 
     *  constrainer mapping lookup service for the given catalogue for looking 
     *  up rules applied to a catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return an <code> OfferingConstrainerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfferingConstrainerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingConstrainerRuleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.offering.rules.OfferingConstrainerRuleLookupSession getOfferingConstrainerRuleLookupSessionForCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offering 
     *  constrainer assignment service to apply to catalogues. 
     *
     *  @return an <code> OfferingConstrainerRuleApplicationSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfferingConstrainerRuleApplication() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingConstrainerRuleApplication() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.offering.rules.OfferingConstrainerRuleApplicationSession getOfferingConstrainerRuleApplicationSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offering 
     *  constrainer assignment service for the given catalogue to apply to 
     *  catalogues. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return an <code> OfferingConstrainerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfferingConstrainerRuleApplication() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingConstrainerRuleApplication() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.offering.rules.OfferingConstrainerRuleApplicationSession getOfferingConstrainerRuleApplicationSessionForCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offering 
     *  constrainer enabler lookup service. 
     *
     *  @return an <code> OfferingConstrainerEnablerLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfferingConstrainerEnablerLookup() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingConstrainerEnablerLookup() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.offering.rules.OfferingConstrainerEnablerLookupSession getOfferingConstrainerEnablerLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offering 
     *  constrainer enabler lookup service for the given catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return an <code> OfferingConstrainerEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfferingConstrainerEnablerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingConstrainerEnablerLookup() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.offering.rules.OfferingConstrainerEnablerLookupSession getOfferingConstrainerEnablerLookupSessionForCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offering 
     *  constrainer enabler query service. 
     *
     *  @return an <code> OfferingConstrainerEnablerQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfferingConstrainerEnablerQuery() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingConstrainerEnablerQuery() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.offering.rules.OfferingConstrainerEnablerQuerySession getOfferingConstrainerEnablerQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offering 
     *  constrainer enabler query service for the given catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return an <code> OfferingConstrainerEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfferingConstrainerEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingConstrainerEnablerQuery() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.offering.rules.OfferingConstrainerEnablerQuerySession getOfferingConstrainerEnablerQuerySessionForCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offering 
     *  constrainer enabler search service. 
     *
     *  @return an <code> OfferingConstrainerEnablerSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfferingConstrainerEnablerSearch() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingConstrainerEnablerSearch() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.offering.rules.OfferingConstrainerEnablerSearchSession getOfferingConstrainerEnablerSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offering 
     *  constrainer enablers earch service for the given catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return an <code> OfferingConstrainerEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfferingConstrainerEnablerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingConstrainerEnablerSearch() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.offering.rules.OfferingConstrainerEnablerSearchSession getOfferingConstrainerEnablerSearchSessionForCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offering 
     *  constrainer enabler administration service. 
     *
     *  @return an <code> OfferingConstrainerEnablerAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfferingConstrainerEnablerAdmin() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingConstrainerEnablerAdmin() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.offering.rules.OfferingConstrainerEnablerAdminSession getOfferingConstrainerEnablerAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offering 
     *  constrainer enabler administration service for the given catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return an <code> OfferingConstrainerEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfferingConstrainerEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingConstrainerEnablerAdmin() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.offering.rules.OfferingConstrainerEnablerAdminSession getOfferingConstrainerEnablerAdminSessionForCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offering 
     *  constrainer enabler notification service. 
     *
     *  @param  offeringConstrainerEnablerReceiver the notification callback 
     *  @return an <code> OfferingConstrainerEnablerNotificationSession 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          offeringConstrainerEnablerReceiver </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfferingConstrainerEnablerNotification() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingConstrainerEnablerNotification() </code> 
     *              is <code> true. </code> 
     */

    public org.osid.offering.rules.OfferingConstrainerEnablerNotificationSession getOfferingConstrainerEnablerNotificationSession(org.osid.offering.rules.OfferingConstrainerEnablerReceiver offeringConstrainerEnablerReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offering 
     *  constrainer enabler notification service for the given catalogue. 
     *
     *  @param  offeringConstrainerEnablerReceiver the notification callback 
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return an <code> OfferingConstrainerEnablerNotificationSession 
     *          </code> 
     *  @throws org.osid.NotFoundException no catalogue found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          offeringConstrainerEnablerReceiver </code> or <code> 
     *          catalogueId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfferingConstrainerEnablerNotification() </code> or 
     *          <code> supportsVisibleFederation() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingConstrainerEnablerNotification() </code> 
     *              and <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.offering.rules.OfferingConstrainerEnablerNotificationSession getOfferingConstrainerEnablerNotificationSessionForCatalogue(org.osid.offering.rules.OfferingConstrainerEnablerReceiver offeringConstrainerEnablerReceiver, 
                                                                                                                                              org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup offering constrainer 
     *  enabler/catalogue mappings for offering constrainer enablers. 
     *
     *  @return an <code> OfferingConstrainerEnablerCatalogueSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfferingConstrainerEnablerCatalogue() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingConstrainerEnablerCatalogue() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.offering.rules.OfferingConstrainerEnablerCatalogueSession getOfferingConstrainerEnablerCatalogueSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning offering 
     *  constrainer enablers to catalogues. 
     *
     *  @return an <code> OfferingConstrainerEnablerCatalogueAssignmentSession 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfferingConstrainerEnablerCatalogueAssignment() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingConstrainerEnablerCatalogueAssignment() 
     *              </code> is <code> true. </code> 
     */

    public org.osid.offering.rules.OfferingConstrainerEnablerCatalogueAssignmentSession getOfferingConstrainerEnablerCatalogueAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage offering constrainer 
     *  enabler smart catalogues. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return an <code> OfferingConstrainerEnablerSmartCatalogueSession 
     *          </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfferingConstrainerEnablerSmartCatalogue() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingConstrainerEnablerSmartCatalogue() </code> 
     *              is <code> true. </code> 
     */

    public org.osid.offering.rules.OfferingConstrainerEnablerSmartCatalogueSession getOfferingConstrainerEnablerSmartCatalogueSession(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offering 
     *  constrainer enabler mapping lookup service. 
     *
     *  @return an <code> OfferingConstrainerEnablerRuleLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfferingConstrainerEnablerRuleLookup() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingConstrainerEnablerRuleLookup() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.offering.rules.OfferingConstrainerEnablerRuleLookupSession getOfferingConstrainerEnablerRuleLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offering 
     *  constrainer enabler mapping lookup service for the given catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return an <code> OfferingConstrainerEnablerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfferingConstrainerEnablerRuleLookup() </code> or 
     *          <code> supportsVisibleFederation() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingConstrainerEnablerRuleLookup() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.offering.rules.OfferingConstrainerEnablerRuleLookupSession getOfferingConstrainerEnablerRuleLookupSessionForCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offering 
     *  constrainer enabler assignment service. 
     *
     *  @return an <code> OfferingConstrainerEnablerRuleApplicationSession 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfferingConstrainerEnablerRuleApplication() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingConstrainerEnablerRuleApplication() 
     *              </code> is <code> true. </code> 
     */

    public org.osid.offering.rules.OfferingConstrainerEnablerRuleApplicationSession getOfferingConstrainerEnablerRuleApplicationSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offering 
     *  constrainer enabler assignment service for the given catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return an <code> OfferingConstrainerEnablerRuleApplicationSession 
     *          </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfferingConstrainerEnablerRuleApplication() </code> or 
     *          <code> supportsVisibleFederation() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingConstrainerEnablerRuleApplication() 
     *              </code> and <code> supportsVisibleFederation() </code> are 
     *              <code> true. </code> 
     */

    public org.osid.offering.rules.OfferingConstrainerEnablerRuleApplicationSession getOfferingConstrainerEnablerRuleApplicationSessionForCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;
}
