//
// org.osid.ontology.OntologyProfile
//
//     The OSID Java specification for org.osid.ontology.OntologyProfile.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ontology;


/**
 *  <p>The <code> OntologyProfile </code> describes the interoperability among 
 *  ontology services. </p>
 */

public interface OntologyProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if federation is visible. 
     *
     *  @return <code> true </code> if visible federation is supported <code> 
     *          , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if a subject lookup service is supported. a subject lookup 
     *  service defines methods to access subjects. 
     *
     *  @return true if subject lookup is supported, false otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSubjectLookup();


    /**
     *  Tests if a subject query service is supported. 
     *
     *  @return <code> true </code> if subject query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSubjectQuery();


    /**
     *  Tests if a subject search service is supported. 
     *
     *  @return <code> true </code> if subject search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSubjectSearch();


    /**
     *  Tests if a subject administrative service is supported. 
     *
     *  @return <code> true </code> if subject admin is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSubjectAdmin();


    /**
     *  Tests if subject notification is supported. Messages may be sent when 
     *  subjects are created, modified, or deleted. 
     *
     *  @return <code> true </code> if subject notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSubjectNotification();


    /**
     *  Tests if a subject hierarchy traversal is supported. 
     *
     *  @return <code> true </code> if a subject hierarchy traversal is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSubjectHierarchy();


    /**
     *  Tests if subject hierarchy design is supported. 
     *
     *  @return <code> true </code> if a subject hierarchy design is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSubjectHierarchyDesign();


    /**
     *  Tests if a subject to ontology lookup session is available. 
     *
     *  @return <code> true </code> if subject ontology lookup session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSubjectOntology();


    /**
     *  Tests if a subject to ontology assignment session is available. 
     *
     *  @return <code> true </code> if subject ontology assignment is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSubjectOntologyAssignment();


    /**
     *  Tests if a subject smart ontology session is available. 
     *
     *  @return <code> true </code> if subject smart ontology session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSubjectSmartOntology();


    /**
     *  Tests if a subject relevancy lookup service is supported. 
     *
     *  @return <code> true </code> if relevancy lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelevancyLookup();


    /**
     *  Tests if a relevancy query service is supported. 
     *
     *  @return <code> true </code> if relevancy query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelevancyQuery();


    /**
     *  Tests if a relevancy search service is supported. 
     *
     *  @return <code> true </code> if relevancy search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelevancySearch();


    /**
     *  Tests if a relevancy administrative service is supported. 
     *
     *  @return <code> true </code> if relevancy admin is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelevancyAdmin();


    /**
     *  Tests if relevancy notification is supported. Messages may be sent 
     *  when subject relevancies are created, modified, or deleted. 
     *
     *  @return <code> true </code> if relevancy notification is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelevancyNotification();


    /**
     *  Tests if an ontology lookup service is supported. 
     *
     *  @return <code> true </code> if ontology lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOntologyLookup();


    /**
     *  Tests if a relevancy to ontology lookup session is available. 
     *
     *  @return <code> true </code> if relevancy ontology lookup session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelevancyOntology();


    /**
     *  Tests if a relevancy to ontology assignment session is available. 
     *
     *  @return <code> true </code> if relevancy ontology assignment is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelevancyOntologyAssignment();


    /**
     *  Tests if a relevancy smart ontology session is available. 
     *
     *  @return <code> true </code> if relevancy smart ontology session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelevancySmartOntology();


    /**
     *  Tests if an ontology query service is supported. 
     *
     *  @return <code> true </code> if ontology query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOntologyQuery();


    /**
     *  Tests if an ontology search service is supported. 
     *
     *  @return <code> true </code> if ontology search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOntologySearch();


    /**
     *  Tests if an ontology administrative service is supported. 
     *
     *  @return <code> true </code> if ontology admin is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOntologyAdmin();


    /**
     *  Tests if ontology notification is supported. Messages may be sent when 
     *  ontologies are created, modified, or deleted. 
     *
     *  @return <code> true </code> if ontology notification is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOntologyNotification();


    /**
     *  Tests if an ontology hierarchy traversal is supported. 
     *
     *  @return <code> true </code> if an ontology hierarchy traversal is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOntologyHierarchy();


    /**
     *  Tests if ontology hierarchy design is supported. 
     *
     *  @return <code> true </code> if an ontology hierarchy design is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOntologyHierarchyDesign();


    /**
     *  Tests if <code> Ids </code> can be asssigned to ontologies. 
     *
     *  @return <code> true </code> if an ontology hassignment is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOntologyAssignment();


    /**
     *  Tests if an ontology batch service is supported. 
     *
     *  @return <code> true </code> if ontology batch is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOntologyBatch();


    /**
     *  Tests if an ontology rules service is supported. 
     *
     *  @return <code> true </code> if ontology rules is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOntologyRules();


    /**
     *  Gets the supported <code> Subject </code> record types. 
     *
     *  @return a list containing the supported <code> Subject </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSubjectRecordTypes();


    /**
     *  Tests if the given <code> Subject </code> record type is supported. 
     *
     *  @param  subjectRecordType a <code> Type </code> indicating a <code> 
     *          Subject </code> record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> subjectRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSubjectRecordType(org.osid.type.Type subjectRecordType);


    /**
     *  Gets the supported <code> Subject </code> search record types. 
     *
     *  @return a list containing the supported <code> Subject </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSubjectSearchRecordTypes();


    /**
     *  Tests if the given <code> Subject </code> search record type is 
     *  supported. 
     *
     *  @param  subjectSearchRecordType a <code> Type </code> indicating a 
     *          <code> Subject </code> search record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> subjectSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSubjectSearchRecordType(org.osid.type.Type subjectSearchRecordType);


    /**
     *  Gets the supported <code> Relevancy </code> record types. 
     *
     *  @return a list containing the supported <code> Relevancy </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getRelevancyRecordTypes();


    /**
     *  Tests if the given <code> Relevancy </code> record type is supported. 
     *
     *  @param  relevancyRecordType a <code> Type </code> indicating a <code> 
     *          Relevnacy </code> record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> relevancyRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelevancyRecordType(org.osid.type.Type relevancyRecordType);


    /**
     *  Gets the supported <code> Relevancy </code> search record types. 
     *
     *  @return a list containing the supported <code> Relevancy </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getRelevancySearchRecordTypes();


    /**
     *  Tests if the given <code> Relevancy </code> search record type is 
     *  supported. 
     *
     *  @param  relevancySearchRecordType a <code> Type </code> indicating a 
     *          <code> Relevancy </code> search record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          relevancySearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelevancySearchRecordType(org.osid.type.Type relevancySearchRecordType);


    /**
     *  Gets the supported <code> Ontology </code> record types. 
     *
     *  @return a list containing the supported <code> Ontology </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getOntologyRecordTypes();


    /**
     *  Tests if the given <code> Ontology </code> record type is supported. 
     *
     *  @param  ontologyRecordType a <code> Type </code> indicating an <code> 
     *          Ontology </code> type 
     *  @return <code> true </code> if the given ontology record <code> Type 
     *          </code> is supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> ontologyRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOntologyRecordType(org.osid.type.Type ontologyRecordType);


    /**
     *  Gets the supported ontology search record types. 
     *
     *  @return a list containing the supported <code> Ontology </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getOntologySearchRecordTypes();


    /**
     *  Tests if the given ontology search record type is supported. 
     *
     *  @param  ontologySearchRecordType a <code> Type </code> indicating an 
     *          <code> Ontology </code> search record type 
     *  @return <code> true </code> if the given search record <code> Type 
     *          </code> is supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> ontologySearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOntologySearchRecordType(org.osid.type.Type ontologySearchRecordType);
}
