//
// org.osid.ontology.OntologyProxyManager
//
//     The OSID Java specification for org.osid.ontology.OntologyProxyManager.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ontology;


/**
 *  <p>The authentication manager provides access to ontology sessions and 
 *  provides interoperability tests for various aspects of this service. 
 *  Methods in this manager support the passing of a <code> Proxy. </code> The 
 *  sessions included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> SubjectLookupSession: </code> a session to look up 
 *      subjects </li> 
 *      <li> <code> SubjectQuerySession: </code> a session to query subjects 
 *      <code> </code> </li> 
 *      <li> <code> SubjectSearchSession: </code> a session to search subjects 
 *      </li> 
 *      <li> <code> SubjectAdminSession: </code> a session to create, modify 
 *      and delete subjects <code> </code> </li> 
 *      <li> <code> SubjectNotificationSession: a </code> session to receive 
 *      messages pertaining to subject <code> </code> changes </li> 
 *      <li> <code> SubjectHierarchySession: </code> a session to traverse 
 *      subject hierarchies </li> 
 *      <li> <code> SubjectHierarchyDesignSession: </code> a sesion to manage 
 *      subject hierarchies </li> 
 *      <li> <code> SubjectOntologySession: </code> a session for retriieving 
 *      subject and ontology mappings </li> 
 *      <li> <code> SubjectOntologyAssignmentSession: </code> a session for 
 *      managing subject and ontology mappings </li> 
 *      <li> <code> SubjectSmartOntologySession: </code> a session to manage 
 *      dynamic ontologies of subjects </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> RelevancyLookupSession: </code> a session to look up 
 *      subject relevancies </li> 
 *      <li> <code> RelevancyQuerySession: </code> a session to query subject 
 *      relevancies <code> </code> </li> 
 *      <li> <code> RelevancySearchSession: </code> a session to search 
 *      subject relevancies </li> 
 *      <li> <code> RelevancyAdminSession: </code> a session to create, modify 
 *      and delete subject relevancies <code> </code> </li> 
 *      <li> <code> RelevancyNotificationSession: a </code> session to receive 
 *      messages pertaining to subject relevancy <code> </code> changes </li> 
 *      <li> <code> RelevancyOntologySession: </code> a session for 
 *      retriieving relevancy and ontology mappings </li> 
 *      <li> <code> RelevancyOntologyAssignmentSession: </code> a session for 
 *      managing relevancy and ontology mappings </li> 
 *      <li> <code> RelevancySmartOntologySession: </code> a session to manage 
 *      dynamic ontologies of relevancies </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> OntologyLookupSession: </code> a session to lookup 
 *      ontologies </li> 
 *      <li> <code> OntologyQuerySession: </code> a session to search 
 *      ontologies </li> 
 *      <li> <code> OntologySearchSession </code> : a session to search 
 *      ontologies </li> 
 *      <li> <code> OntologyAdminSession </code> : a session to create, modify 
 *      and delete ontologies </li> 
 *      <li> <code> OntologyNotificationSession </code> : a session to receive 
 *      messages pertaining to ontology changes </li> 
 *      <li> <code> OntologyHierarchySession: </code> a session to traverse 
 *      the ontology hierarchy </li> 
 *      <li> <code> OntologyHierarchyDesignSession: </code> a session to 
 *      manage the ontology hierarchy </li> 
 *  </ul>
 *  
 */

public interface OntologyProxyManager
    extends org.osid.OsidProxyManager,
            org.osid.ontology.OntologyProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the subject lookup 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> SubjectLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsSubjectLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubjectLookup() </code> is <code> true. </code> 
     */

    public org.osid.ontology.SubjectLookupSession getSubjectLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the subject lookup 
     *  service for the given ontology. 
     *
     *  @param  ontologyId the <code> Id </code> of the ontology 
     *  @param  proxy a proxy 
     *  @return <code> a SubjectLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> ontologyId </code> not found 
     *  @throws org.osid.NullArgumentException <code> ontologyId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsSubjectLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubjectLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.ontology.SubjectLookupSession getSubjectLookupSessionForOntology(org.osid.id.Id ontologyId, 
                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the subject lookup 
     *  service for the given <code> Id </code> assigned using the <code> 
     *  OntologyAssignmentSession. </code> 
     *
     *  @param  id an <code> Id </code> 
     *  @param  proxy a proxy 
     *  @return <code> a SubjectLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> id </code> not found 
     *  @throws org.osid.NullArgumentException <code> id </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsSubjectLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubjectLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.ontology.SubjectLookupSession getSubjectLookupSessionForId(org.osid.id.Id id, 
                                                                               org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the subject query 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> SubjectQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsSubjecQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubjectQuery() </code> is <code> true. </code> 
     */

    public org.osid.ontology.SubjectQuerySession getSubjectQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the subject query 
     *  service for the given ontology. 
     *
     *  @param  ontologyId the <code> Id </code> of the ontology 
     *  @param  proxy a proxy 
     *  @return a <code> SubjectQuerySession </code> 
     *  @throws org.osid.NotFoundException <code> ontologyId </code> not found 
     *  @throws org.osid.NullArgumentException <code> ontologyId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsSubjectQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubjectQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.ontology.SubjectQuerySession getSubjectQuerySessionForOntology(org.osid.id.Id ontologyId, 
                                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the subject search 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> SubjectSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsSubjectSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubjectSearch() </code> is <code> true. </code> 
     */

    public org.osid.ontology.SubjectSearchSession getSubjectSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the subject search 
     *  service for the given ontology. 
     *
     *  @param  ontologyId the <code> Id </code> of the ontology 
     *  @param  proxy a proxy 
     *  @return <code> a SubjectSearchSession </code> 
     *  @throws org.osid.NotFoundException <code> ontologyId </code> not found 
     *  @throws org.osid.NullArgumentException <code> ontologyId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsSubjectSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubjectSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.ontology.SubjectSearchSession getSubjectSearchSessionForOntology(org.osid.id.Id ontologyId, 
                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the subject 
     *  administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> SubjectAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsSubjectAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubjectAdmin() </code> is <code> true. </code> 
     */

    public org.osid.ontology.SubjectAdminSession getSubjectAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the subject admin 
     *  service for the given ontology. 
     *
     *  @param  ontologyId the <code> Id </code> of the ontology 
     *  @param  proxy a proxy 
     *  @return <code> a SubjectAdminSession </code> 
     *  @throws org.osid.NotFoundException <code> ontologyId </code> not found 
     *  @throws org.osid.NullArgumentException <code> ontologyId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsSubjectAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubjectAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.ontology.SubjectAdminSession getSubjectAdminSessionForOntology(org.osid.id.Id ontologyId, 
                                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to subject 
     *  changes. 
     *
     *  @param  subjectReceiver the subject receiver 
     *  @param  proxy a proxy 
     *  @return a <code> SubjectNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> subjectReceiver </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubjectNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubjectNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.ontology.SubjectNotificationSession getSubjectNotificationSession(org.osid.ontology.SubjectReceiver subjectReceiver, 
                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the subject 
     *  notification service for the given ontology. 
     *
     *  @param  subjectReceiver the subject receiver 
     *  @param  ontologyId the <code> Id </code> of the ontology 
     *  @param  proxy a proxy 
     *  @return <code> a SubjectNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> ontologyId </code> not found 
     *  @throws org.osid.NullArgumentException <code> subjectReceiver, 
     *          ontologyId </code> or <code> proxy </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubjectNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubjectNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.ontology.SubjectNotificationSession getSubjectNotificationSessionForOntology(org.osid.ontology.SubjectReceiver subjectReceiver, 
                                                                                                 org.osid.id.Id ontologyId, 
                                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session traversing subject hierarchies. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> SubjectHierarchySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubjectHierarchy() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubjectHierarchy() </code> is true. 
     */

    public org.osid.ontology.SubjectHierarchySession getSubjectHierarchySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the subject 
     *  heirarchy traversal service for the given ontology. 
     *
     *  @param  ontologyId the <code> Id </code> of the ontology 
     *  @param  proxy a proxy 
     *  @return a <code> SubjectHierarchySession </code> 
     *  @throws org.osid.NotFoundException <code> ontologyId </code> not found 
     *  @throws org.osid.NullArgumentException <code> ontologyId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubjectHierarchy() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubjectHierarchy() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.ontology.SubjectHierarchySession getSubjectHierarchySessionForOntology(org.osid.id.Id ontologyId, 
                                                                                           org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the hierarchy session for the given <code> Id </code> assigned 
     *  using the <code> OntologyAssignmentSession. </code> 
     *
     *  @param  id an <code> Id </code> 
     *  @param  proxy a proxy 
     *  @return a <code> SubjectHierarchySession </code> 
     *  @throws org.osid.NotFoundException <code> id </code> not found 
     *  @throws org.osid.NullArgumentException <code> id </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubjectHierarchy() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubjectHierarchy() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.ontology.SubjectHierarchySession getSubjectHierarchySessionForId(org.osid.id.Id id, 
                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session designing subject hierarchies. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> SubjectHierarchyDesignSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubjectHierarchyDesign() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubjectHierarchyDesign() </code> is true. 
     */

    public org.osid.ontology.SubjectHierarchyDesignSession getSubjectHierarchyDesignSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the subject 
     *  heirarchy design service for the given ontology. 
     *
     *  @param  ontologyId the <code> Id </code> of the ontology 
     *  @param  proxy a proxy 
     *  @return a <code> SubjectHierarchyDesignSession </code> 
     *  @throws org.osid.NotFoundException <code> ontologyId </code> not found 
     *  @throws org.osid.NullArgumentException <code> ontologyId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubjectHierarchyDesign() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubjectHierarchyDesign() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.ontology.SubjectHierarchyDesignSession getSubjectHierarchyDesignSessionForOntology(org.osid.id.Id ontologyId, 
                                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session retrieving subject ontology mappings. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> SubjectOntologySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubjectOntology() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubjectOntology() </code> is true. 
     */

    public org.osid.ontology.SubjectOntologySession getSubjectOntologySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session managing subject ontology mappings. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> SubjectOntologyAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubjectOntologyAssignment() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubjectOntologyAssignment() </code> is true. 
     */

    public org.osid.ontology.SubjectOntologyAssignmentSession getSubjectOntologyAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session managing subject smart ontologies. 
     *
     *  @param  ontologyId the <code> Id </code> of the ontology 
     *  @param  proxy a proxy 
     *  @return a <code> SubjectSmartOntologySession </code> 
     *  @throws org.osid.NotFoundException <code> ontologyId </code> not found 
     *  @throws org.osid.NullArgumentException <code> ontologyId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubjectSmartOntology() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubjectSmartOntology() </code> is true. 
     */

    public org.osid.ontology.SubjectOntologySession getSubjectSmartOntologySession(org.osid.id.Id ontologyId, 
                                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the relevancy 
     *  lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RelevancyLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelevancyLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelevancyLookup() </code> is <code> true. </code> 
     */

    public org.osid.ontology.RelevancyLookupSession getRelevancyLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the relevancy 
     *  lookup service for the given ontology. 
     *
     *  @param  ontologyId the <code> Id </code> of the ontology 
     *  @param  proxy a proxy 
     *  @return <code> a RelevancyLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> ontologyId </code> not found 
     *  @throws org.osid.NullArgumentException <code> ontologyId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelevancyLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelevancyLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.ontology.RelevancyLookupSession getRelevancyLookupSessionForOntology(org.osid.id.Id ontologyId, 
                                                                                         org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the relevancy 
     *  query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RelevancyQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelevancyQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelevancyQuery() </code> is <code> true. </code> 
     */

    public org.osid.ontology.RelevancyQuerySession getRelevancyQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the relevancy 
     *  query service for the given ontology. 
     *
     *  @param  ontologyId the <code> Id </code> of the ontology 
     *  @param  proxy a proxy 
     *  @return <code> a RelevancyQuerySession </code> 
     *  @throws org.osid.NotFoundException <code> ontologyId </code> not found 
     *  @throws org.osid.NullArgumentException <code> ontologyId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelevancyQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelevancyQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.ontology.RelevancyQuerySession getRelevancyQuerySessionForOntology(org.osid.id.Id ontologyId, 
                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the relevancy 
     *  search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RelevanctSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelevancySearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelevancySearch() </code> is <code> true. </code> 
     */

    public org.osid.ontology.RelevancySearchSession getRelevancySearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the relevancy 
     *  search service for the given ontology. 
     *
     *  @param  ontologyId the <code> Id </code> of the ontology 
     *  @param  proxy a proxy 
     *  @return <code> a RelevancySearchSession </code> 
     *  @throws org.osid.NotFoundException <code> ontologyId </code> not found 
     *  @throws org.osid.NullArgumentException <code> ontologyId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelevancySearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelevancySearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.ontology.RelevancySearchSession getRelevancySearchSessionForOntology(org.osid.id.Id ontologyId, 
                                                                                         org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the relevancy 
     *  administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RelvancyAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelevancyAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelevancyAdmin() </code> is <code> true. </code> 
     */

    public org.osid.ontology.RelevancyAdminSession getRelevancyAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the relevancy 
     *  admin service for the given ontology. 
     *
     *  @param  ontologyId the <code> Id </code> of the ontology 
     *  @param  proxy a proxy 
     *  @return <code> a RelevancyAdminSession </code> 
     *  @throws org.osid.NotFoundException <code> ontologyId </code> not found 
     *  @throws org.osid.NullArgumentException <code> ontologyId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelevancyAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelevancyAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.ontology.RelevancyAdminSession getRelevancyAdminSessionForOntology(org.osid.id.Id ontologyId, 
                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to 
     *  relevancy changes. 
     *
     *  @param  relevancyReceiver the relevancy receiver 
     *  @param  proxy a proxy 
     *  @return <code> a RelevancyNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> relevancyReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelevancyNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelevancyNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.ontology.RelevancyNotificationSession getRelevancyNotificationSession(org.osid.ontology.RelevancyReceiver relevancyReceiver, 
                                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the relevancy 
     *  notification service for the given ontology. 
     *
     *  @param  relevancyReceiver the subject receiver 
     *  @param  ontologyId the <code> Id </code> of the ontology 
     *  @param  proxy a proxy 
     *  @return <code> a RelevancyNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> ontologyId </code> not found 
     *  @throws org.osid.NullArgumentException <code> relevancyReceiver, 
     *          ontologyId </code> or <code> proxy </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelevancyNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelevancyNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.ontology.RelevancyNotificationSession getRelevancyNotificationSessionForOntology(org.osid.ontology.RelevancyReceiver relevancyReceiver, 
                                                                                                     org.osid.id.Id ontologyId, 
                                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session retrieving relevancy ontology mappings. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RelevancyOntologySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelevancyOntology() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelevancyOntology() </code> is true. 
     */

    public org.osid.ontology.RelevancyOntologySession getRelevancyOntologySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session managing relevancy ontology mappings. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RelevancyOntologyAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelevancyOntologyAssignment() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelevancyOntologyAssignment() </code> is true. 
     */

    public org.osid.ontology.RelevancyOntologyAssignmentSession getRelevancyOntologyAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session managing relevancy smart ontologies. 
     *
     *  @param  ontologyId the <code> Id </code> of the ontology 
     *  @param  proxy a proxy 
     *  @return a <code> RelevancySmartOntologySession </code> 
     *  @throws org.osid.NotFoundException <code> ontologyId </code> not found 
     *  @throws org.osid.NullArgumentException <code> ontologyId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelevancySmartOntology() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelevancySmartOntology() </code> is true. 
     */

    public org.osid.ontology.RelevancySmartOntologySession getRelevancySmartOntologySession(org.osid.id.Id ontologyId, 
                                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the OsidSession associated with the ontology lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> OntologyLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOntologyLookup() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOntologyLookup() </code> is true. 
     */

    public org.osid.ontology.OntologyLookupSession getOntologyLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the OsidSession associated with the ontology query service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> OntologyQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsOntologyQuery() 
     *          is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOntologyQuery() </code> is true. 
     */

    public org.osid.ontology.OntologyQuerySession getOntologyQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the OsidSession associated with the ontology search service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> OntologySearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOntologySearch() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOntologySearch() </code> is true. 
     */

    public org.osid.ontology.OntologySearchSession getOntologySearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the OsidSession associated with the ontology administration 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> OntologyAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsOntologyAdmin() 
     *          is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOntologyAdmin() </code> is true. 
     */

    public org.osid.ontology.OntologyAdminSession getOntologyAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to ontology 
     *  service changes. 
     *
     *  @param  ontologyReceiver the ontology receiver 
     *  @param  proxy a proxy 
     *  @return an <code> OntologyNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> ontologyReceiver </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOntologyNotification() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOntologyNotification() </code> is true. 
     */

    public org.osid.ontology.OntologyNotificationSession getOntologyNotificationSession(org.osid.ontology.OntologyReceiver ontologyReceiver, 
                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session traversing ontology hierarchies. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> OntologyHierarchySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOntologyHierarchy() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOntologyHierarchy() </code> is true. 
     */

    public org.osid.ontology.OntologyHierarchySession getOntologyHierarchySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session designing ontology hierarchies. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> OntologyHierarchyDesignSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOntologyHierarchyDesign() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOntologyHierarchyDesign() </code> is true. 
     */

    public org.osid.ontology.OntologyHierarchyDesignSession getOntologyHierarchyDesignSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session to assign <code> Ids </code> to ontologies. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> OntologyAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOntologyAssignment() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOntologyAssignment() </code> is true. 
     */

    public org.osid.ontology.OntologyAssignmentSession getOntologyAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the ontology batch service. 
     *
     *  @return an <code> OntologyBatchProxyManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsOntologyBatch() 
     *          is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOntologyBatch() </code> is true. 
     */

    public org.osid.ontology.batch.OntologyBatchProxyManager getOntologyBatchProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the ontology rules service. 
     *
     *  @return an <code> OntologyRulesProxyManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsOntologyRules() 
     *          is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOntologyRules() </code> is true. 
     */

    public org.osid.ontology.rules.OntologyRulesProxyManager getOntologyRulesProxyManager()
        throws org.osid.OperationFailedException;
}
