//
// org.osid.ontology.OntologyQueryInspector
//
//     The OSID Java specification for org.osid.ontology.OntologyQueryInspector.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ontology;


/**
 *  <p>This is the query inspector for examining ontology queries. </p>
 */

public interface OntologyQueryInspector
    extends org.osid.OsidCatalogQueryInspector {


    /**
     *  Gets the subject <code> Id </code> terms. 
     *
     *  @return the subject <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getSubjectIdTerms();


    /**
     *  Gets the subject terms. 
     *
     *  @return the subject terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.SubjectQueryInspector[] getSubjectTerms();


    /**
     *  Gets the relevancy <code> Id </code> terms. 
     *
     *  @return the relevancy <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getRelevancyIdTerms();


    /**
     *  Gets the relevancy terms. 
     *
     *  @return the relevancy terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.RelevancyQueryInspector[] getRelevancyTerms();


    /**
     *  Gets the ancestor ontology <code> Id </code> terms. 
     *
     *  @return the ancestor ontology <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getAncestorOntologyIdTerms();


    /**
     *  Gets the ancestor ontology terms. 
     *
     *  @return the ancestor ontology terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.OntologyQueryInspector[] getAncestorOntologyTerms();


    /**
     *  Gets the descendant ontology <code> Id </code> terms. 
     *
     *  @return the descendant ontology <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getDescendantOntologyIdTerms();


    /**
     *  Gets the descendant ontology terms. 
     *
     *  @return the descendant ontology terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.OntologyQueryInspector[] getDescendantOntologyTerms();


    /**
     *  Gets the ontology query inspector record corresponding to the given 
     *  <code> Ontology </code> record <code> Type. </code> 
     *
     *  @param  ontologyRecordType an ontology record type 
     *  @return the ontology query inspector record 
     *  @throws org.osid.NullArgumentException <code> ontologyRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(ontologyRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.records.OntologyQueryInspectorRecord getOntologyQueryInspectorRecord(org.osid.type.Type ontologyRecordType)
        throws org.osid.OperationFailedException;
}
