//
// org.osid.ontology.OntologySearchSession
//
//     The OSID Java specification for org.osid.ontology.OntologySearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ontology;


/**
 *  <p>This session provides methods for searching among <code> Ontology 
 *  </code> objects. The search query is constructed using the <code> 
 *  OntologyQuery. </code> </p> 
 *  
 *  <p> <code> getOntologiesByQuery() </code> is the basic search method and 
 *  returns a list of <code> Ontology </code> objects.A more advanced search 
 *  may be performed with <code> getOntologiesBySearch(). </code> It accepts 
 *  an <code> OntologySearch </code> in addition to the query for the purpose 
 *  of specifying additional options affecting the entire search, such as 
 *  ordering. <code> getOntologiesBySearch() </code> returns an <code> 
 *  OntologySearchResults </code> that can be used to access the resulting 
 *  <code> OntologyList </code> or be used to perform a search within the 
 *  result set through <code> OntologySearch. </code> </p> 
 *  
 *  <p> Ontologies may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> OntologyQuery. 
 *  </code> </p>
 */

public interface OntologySearchSession
    extends org.osid.ontology.OntologyQuerySession {


    /**
     *  Gets an ontology search. 
     *
     *  @return an ontology search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.OntologySearch getOntologySearch();


    /**
     *  Gets an ontology search order. The <code> OntologySearchOrder </code> 
     *  is supplied to an <code> OntologySearch </code> to specify the 
     *  ordering of results. 
     *
     *  @return the ontology search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.OntologySearchOrder getOntologySearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  ontologyQuery the ontology query 
     *  @param  ontologySearch the ontology search 
     *  @return the ontology search results 
     *  @throws org.osid.NullArgumentException <code> ontologyQuery </code> or 
     *          <code> ontologySearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> ontologyQuery </code> or 
     *          <code> ontologySearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.OntologySearchResults getOntologiesBySearch(org.osid.ontology.OntologyQuery ontologyQuery, 
                                                                         org.osid.ontology.OntologySearch ontologySearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an ontology query from an inspector. The inspector is available 
     *  from an <code> OntologySearchResults. </code> 
     *
     *  @param  ontologyQueryInspector an ontology query inspector 
     *  @return the ontology query 
     *  @throws org.osid.NullArgumentException <code> ontologyQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> ontologyQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.OntologyQuery getOntologyQueryFromInspector(org.osid.ontology.OntologyQueryInspector ontologyQueryInspector);
}
