//
// org.osid.ontology.RelevancyNotificationSession
//
//     The OSID Java specification for org.osid.ontology.RelevancyNotificationSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ontology;


/**
 *  <p>This session defines methods to receive asynchronous notifications on 
 *  adds/changes to subject relevancies. This session is intended for 
 *  consumers needing to synchronize their state with this service without the 
 *  use of polling. Notifications are cancelled when this session is closed. 
 *  </p> 
 *  
 *  <p> The views defined in this session correspond to the views in the 
 *  <code> RelevancyLookupSession. </code> </p>
 */

public interface RelevancyNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Ontology </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Ontology Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getOntologyId();


    /**
     *  Gets the <code> Ontology </code> associated with this session. 
     *
     *  @return the <code> Ontology </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.Ontology getOntology()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can register for <code> Relevancy </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForRelevancyNotifications();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include notifications for relevancies in ontologies which are children 
     *  of this ontology in the ontology hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedOntologyView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts notifications to this ontology only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedOntologyView();


    /**
     *  Reliable notifications are desired. In reliable mode, notifications 
     *  are to be acknowledged using <code> acknowledgeRelevancyNotification() 
     *  </code> . 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void reliableRelevancyNotifications();


    /**
     *  Unreliable notifications are desired. In unreliable mode, 
     *  notifications do not need to be acknowledged. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void unreliableRelevancyNotifications();


    /**
     *  Acknowledge a relevancy notification. 
     *
     *  @param  notificationId the <code> Id </code> of the notification 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void acknowledgeRelevancyNotification(org.osid.id.Id notificationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new relevancies. <code> 
     *  RelevancyReceiver.newRelevancies() </code> is invoked when a new 
     *  relevancy is created. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewRelevancies()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new relevancies by the given genus type. 
     *  <code> RelevancyReceiver.newRelevancies() </code> is invoked when a 
     *  new relevancy is created. 
     *
     *  @param  relevancyGenusType the relevancy genus type 
     *  @throws org.osid.NullArgumentException <code> relevancyGenusType is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewRelevanciesByGenusType(org.osid.type.Type relevancyGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new relevancies for the given subject. 
     *  <code> RelevancyReceiver.newRelevancies() </code> is invoked when a 
     *  new relevancy is created. 
     *
     *  @param  subjectId the <code> Id </code> of the <code> Subject </code> 
     *          to monitor 
     *  @throws org.osid.NullArgumentException <code> subjectId is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewRelevanciesForSubject(org.osid.id.Id subjectId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new relevancies for the given mapped 
     *  <code> Id. </code> <code> RelevancyReceiver.newRelevancies() </code> 
     *  is invoked when a new relevancy is created. 
     *
     *  @param  id the <code> Id </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> id is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewRelevanciesForId(org.osid.id.Id id)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated relevancies. <code> 
     *  RelevancyReceiver.changedRelevancies() </code> is invoked when a 
     *  relevancy is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedRelevancies()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of changed relevancies of the given genus 
     *  type. <code> RelevancyReceiver.changedRelevancies() </code> is invoked 
     *  when a relevancy is changed. 
     *
     *  @param  relevancyGenusType the relevancy genus type 
     *  @throws org.osid.NullArgumentException <code> relevancyGenusType is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedRelevanciesByGenusType(org.osid.type.Type relevancyGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of changed relevancies for the given 
     *  subject. <code> RelevancyReceiver.changedRelevancies() </code> is 
     *  invoked when a relevancy is changed. 
     *
     *  @param  subjectId the <code> Id </code> of the <code> Subject </code> 
     *          to monitor 
     *  @throws org.osid.NullArgumentException <code> subjectId is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedRelevanciesForSubject(org.osid.id.Id subjectId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of changed relevancies for the given <code> 
     *  Id. </code> <code> RelevancyReceiver.changedRelevancies() </code> is 
     *  invoked when a relevancy is changed. 
     *
     *  @param  id the <code> Id </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> id is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedRelevanciesForId(org.osid.id.Id id)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated relevancy. <code> 
     *  RelevancyReceiver.changedRelevancies() </code> is invoked when the 
     *  specified relevancy is changed. 
     *
     *  @param  relevancyId the <code> Id </code> of the <code> Relevancy 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> relevancyId is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedRelevancy(org.osid.id.Id relevancyId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted relevancies. <code> 
     *  RelevancyReceiver.deletedRelevancies() </code> is invoked when a 
     *  relevancy is deleted. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedRelevancies()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of deleted relevancies of the given genus 
     *  type. <code> RelevancyReceiver.deletedRelevancies() </code> is invoked 
     *  when a relevancy is deleted. 
     *
     *  @param  relevancyGenusType the relevancy genus type 
     *  @throws org.osid.NullArgumentException <code> relevancyGenusType is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedRelevanciesByGenusType(org.osid.type.Type relevancyGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of deleted relevancies for the given 
     *  subject. <code> RelevancyReceiver.deletedRelevancies() </code> is 
     *  invoked when a relevancy is deleted. 
     *
     *  @param  subjectId the <code> Id </code> of the <code> Subject </code> 
     *          to monitor 
     *  @throws org.osid.NullArgumentException <code> subjectId is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedRelevanciesForSubject(org.osid.id.Id subjectId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of deleted relevancies for the given <code> 
     *  Id. </code> <code> RelevancyReceiver.deletedRelevancies() </code> is 
     *  invoked when a relevancy is deleted. 
     *
     *  @param  id the <code> Id </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> id is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedRelevanciesForId(org.osid.id.Id id)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted relevancy. <code> 
     *  RelevancyReceiver.changedRelevancies() </code> is invoked when the 
     *  specified relevancy is deleted. 
     *
     *  @param  relevancyId the <code> Id </code> of the <code> Relevancy 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> relevancyId is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedRelevancy(org.osid.id.Id relevancyId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
