//
// org.osid.ontology.RelevancyQuery
//
//     The OSID Java specification for org.osid.ontology.RelevancyQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ontology;


/**
 *  <p>This is the query for searching relevancies. Each method match request 
 *  produces an <code> AND </code> term while multiple invocations of a method 
 *  produces a nested <code> OR. </code> </p>
 */

public interface RelevancyQuery
    extends org.osid.OsidRelationshipQuery {


    /**
     *  Sets the subject <code> Id </code> for this query. 
     *
     *  @param  subjectId a subject <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> subjectId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSubjectId(org.osid.id.Id subjectId, boolean match);


    /**
     *  Clears the subject <code> Id </code> terms for this query. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSubjectIdTerms();


    /**
     *  Tests if a <code> SubjectQuery </code> is available. 
     *
     *  @return <code> true </code> if a subject query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSubjectQuery();


    /**
     *  Gets the query for an subject. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the subject query 
     *  @throws org.osid.UnimplementedException <code> supportsSubjectQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubjectQuery() </code> is <code> true. </code> 
     */

    public org.osid.ontology.SubjectQuery getSubjectQuery();


    /**
     *  Clears the subject terms for this query. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSubjectTerms();


    /**
     *  Sets the mapped <code> Id </code> for this query. 
     *
     *  @param  id an <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> id </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMappedId(org.osid.id.Id id, boolean match);


    /**
     *  Clears the mapped <code> Id </code> terms for this query. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMappedIdTerms();


    /**
     *  Sets the ontology <code> Id </code> for this query. 
     *
     *  @param  ontologyId a ontology <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> ontologyId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchOntologyId(org.osid.id.Id ontologyId, boolean match);


    /**
     *  Clears the ontology <code> Id </code> terms for this query. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOntologyIdTerms();


    /**
     *  Tests if a <code> OntologyQuery </code> is available for querying 
     *  ontologies. 
     *
     *  @return <code> true </code> if a ontology query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOntologyQuery();


    /**
     *  Gets the query for a ontology. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the ontology query 
     *  @throws org.osid.UnimplementedException <code> supportsOntologyQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOntologyQuery() </code> is <code> true. </code> 
     */

    public org.osid.ontology.OntologyQuery getOntologyQuery();


    /**
     *  Clears the ontology terms for this query. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOntologyTerms();


    /**
     *  Gets the relevancy query record corresponding to the given <code> 
     *  Relevancy </code> record <code> Type. </code> Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @param  relevancytRecordType an relevancy query record type 
     *  @return the relevancy query record 
     *  @throws org.osid.NullArgumentException <code> relevancyRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(relevancyRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.records.RelevancyQueryRecord getRelevancyQueryRecord(org.osid.type.Type relevancytRecordType)
        throws org.osid.OperationFailedException;
}
