//
// org.osid.ontology.SubjectLookupSession
//
//     The OSID Java specification for org.osid.ontology.SubjectLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ontology;


/**
 *  <p>This session provides methods for retrieving <code> Subject </code> s. 
 *  </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated ontology view: All subject methods in this session 
 *      operate, retrieve and pertain to subjects defined explicitly in the 
 *      current ontology. Using an isolated view is useful for managing 
 *      subjects with the <code> SubjectAdminSession. </code> </li> 
 *      <li> federated ontology view: All subject methods in this session 
 *      operate, retrieve and pertain to all subjects defined in this ontology 
 *      and any other ontologies implicitly available in this ontology through 
 *      ontology inheritence. </li> 
 *  </ul>
 *  
 *  
 *  <p> Subjects may have an additional records indicated by their respective 
 *  record types. The record may not be accessed through a cast of the <code> 
 *  Subject. </code> </p>
 */

public interface SubjectLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Ontology </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Ontology Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getOntologyId();


    /**
     *  Gets the <code> Ontology </code> associated with this session. 
     *
     *  @return the <code> Ontology </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.Ontology getOntology()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Subject </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupSubjects();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeSubjectView();


    /**
     *  A complete view of the <code> Subject </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenarySubjectView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include subjects in ontologies which are children of this ontology in 
     *  the ontology hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedOntologyView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this ontology only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedOntologyView();


    /**
     *  Gets the <code> Subject </code> specified by its <code> Id. </code> In 
     *  plenary mode, the exact <code> Id </code> is found or a <code> 
     *  NOT_FOUND </code> results. Otherwise, the returned <code> Subject 
     *  </code> may have a different <code> Id </code> than requested, such as 
     *  the case where a duplicate <code> Id </code> was assigned to a <code> 
     *  Subject </code> and retained for compatibility. 
     *
     *  @param  subjectId <code> Id </code> of the <code> Subject </code> 
     *  @return the subject 
     *  @throws org.osid.NotFoundException <code> subjectId </code> not found 
     *  @throws org.osid.NullArgumentException <code> subjectId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.ontology.Subject getSubject(org.osid.id.Id subjectId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SubjectList </code> corresponding to the given <code> 
     *  IdList. </code> In plenary mode, the returned list contains all of the 
     *  subjects specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Subjects </code> may be omitted from the list and 
     *  may present the elements in any order including returning a unique 
     *  set. 
     *
     *  @param  subjectIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Subject </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> subjectIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.SubjectList getSubjectsByIds(org.osid.id.IdList subjectIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SubjectList </code> corresponding to the given subject 
     *  genus <code> Type </code> which does not include subjects of genus 
     *  types derived from the specified <code> Type. </code> In plenary mode, 
     *  the returned list contains all known subjects or an error results. 
     *  Otherwise, the returned list may contain only those subjects that are 
     *  accessible through this session. 
     *
     *  @param  subjectGenusType a subject genus type 
     *  @return the returned <code> Subject </code> list 
     *  @throws org.osid.NullArgumentException <code> subjectGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.SubjectList getSubjectsByGenusType(org.osid.type.Type subjectGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SubjectList </code> corresponding to the given subject 
     *  genus <code> Type </code> and include any additional subject with 
     *  genus types derived from the specified <code> Type. </code> In plenary 
     *  mode, the returned list contains all known terms or an error results. 
     *  Otherwise, the returned list may contain only those subjects that are 
     *  accessible through this session. 
     *
     *  @param  subjectGenusType a subject genus type 
     *  @return the returned <code> Subject </code> list 
     *  @throws org.osid.NullArgumentException <code> subjectGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.SubjectList getSubjectsByParentGenusType(org.osid.type.Type subjectGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SubjectList </code> containing the given term record 
     *  <code> Type. </code> In plenary mode, the returned list contains all 
     *  known subjects or an error results. Otherwise, the returned list may 
     *  contain only those subjects that are accessible through this session. 
     *
     *  @param  subjectRecordType a subject record type 
     *  @return the returned <code> Subject </code> list 
     *  @throws org.osid.NullArgumentException <code> subjectRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.SubjectList getSubjectsByRecordType(org.osid.type.Type subjectRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Subjects. </code> In plenary mode, the returned list 
     *  contains all known subjects or an error results. Otherwise, the 
     *  returned list may contain only those subjects that are accessible 
     *  through this session. 
     *
     *  @return a <code> SubjectList </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.SubjectList getSubjects()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
