//
// org.osid.ontology.rules.OntologyRulesProfile
//
//     The OSID Java specification for org.osid.ontology.rules.OntologyRulesProfile.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ontology.rules;


/**
 *  <p>The ontology rules profile describes the interoperability among 
 *  ontology rules services. </p>
 */

public interface OntologyRulesProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any broker federation is exposed. Federation is exposed when 
     *  a specific broker may be identified, selected and used to create a 
     *  lookup or admin session. Federation is not exposed when a set of 
     *  brokers appears as a single broker. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if looking up relevancy enablers is supported. 
     *
     *  @return <code> true </code> if relevancy enabler lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelevancyEnablerLookup();


    /**
     *  Tests if querying relevancy enablers is supported. 
     *
     *  @return <code> true </code> if relevancy enabler query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelevancyEnablerQuery();


    /**
     *  Tests if searching relevancy enablers is supported. 
     *
     *  @return <code> true </code> if relevancy enabler search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelevancyEnablerSearch();


    /**
     *  Tests if a relevancy enabler administrative service is supported. 
     *
     *  @return <code> true </code> if relevancy enabler administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelevancyEnablerAdmin();


    /**
     *  Tests if a relevancy enabler notification service is supported. 
     *
     *  @return <code> true </code> if relevancy enabler notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelevancyEnablerNotification();


    /**
     *  Tests if a relevancy enabler ontology lookup service is supported. 
     *
     *  @return <code> true </code> if a relevancy enabler ontology lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelevancyEnablerOntology();


    /**
     *  Tests if a relevancy enabler ontology service is supported. 
     *
     *  @return <code> true </code> if relevancy enabler ontology assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelevancyEnablerOntologyAssignment();


    /**
     *  Tests if a relevancy enabler ontology lookup service is supported. 
     *
     *  @return <code> true </code> if a relevancy enabler ontology service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelevancyEnablerSmartOntology();


    /**
     *  Tests if a relevancy enabler rule lookup service is supported. 
     *
     *  @return <code> true </code> if a enabler relevancy rule lookup service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelevancyEnablerRuleLookup();


    /**
     *  Tests if a relevancy enabler rule application service is supported. 
     *
     *  @return <code> true </code> if relevancy enabler rule application 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelevancyEnablerRuleApplication();


    /**
     *  Gets the supported <code> RelevancyEnabler </code> record types. 
     *
     *  @return a list containing the supported <code> RelevancyEnabler 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getRelevancyEnablerRecordTypes();


    /**
     *  Tests if the given <code> RelevancyEnabler </code> record type is 
     *  supported. 
     *
     *  @param  relevancyEnablerRecordType a <code> Type </code> indicating a 
     *          <code> RelevancyEnabler </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          relevancyEnablerRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelevancyEnablerRecordType(org.osid.type.Type relevancyEnablerRecordType);


    /**
     *  Gets the supported <code> RelevancyEnabler </code> search record 
     *  types. 
     *
     *  @return a list containing the supported <code> RelevancyEnabler 
     *          </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getRelevancyEnablerSearchRecordTypes();


    /**
     *  Tests if the given <code> RelevancyEnabler </code> search record type 
     *  is supported. 
     *
     *  @param  relevancyEnablerSearchRecordType a <code> Type </code> 
     *          indicating a <code> RelevancyEnabler </code> search record 
     *          type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          relevancyEnablerSearchRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelevancyEnablerSearchRecordType(org.osid.type.Type relevancyEnablerSearchRecordType);
}
