//
// org.osid.ontology.rules.RelevancyEnablerAdminSession
//
//     The OSID Java specification for org.osid.ontology.rules.RelevancyEnablerAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ontology.rules;


/**
 *  <p>This session creates and removes relevancy enablers. The data for 
 *  create and update is provided via the <code> RelevancyEnablerForm. </code> 
 *  </p>
 */

public interface RelevancyEnablerAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Ontology </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Ontology Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getOntologyId();


    /**
     *  Gets the <code> Ontology </code> associated with this session. 
     *
     *  @return the ontology 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.Ontology getOntology()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create relevancy enablers. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> RelevancyEnabler </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer create operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> RelevancyEnabler </code> 
     *          creation is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateRelevancyEnabler();


    /**
     *  Tests if this user can create a single <code> RelevancyEnabler </code> 
     *  using the desired record types. While <code> 
     *  OntologyRulesManager.getRelevancyEnablerRecordTypes() </code> can be 
     *  used to examine which records are supported, this method tests which 
     *  record(s) are required for creating a specific <code> 
     *  RelevancyEnabler. </code> Providing an empty array tests if a <code> 
     *  RelevancyEnabler </code> can be created with no records. 
     *
     *  @param  relevancyEnablerRecordTypes array of relevancy enabler record 
     *          types 
     *  @return <code> true </code> if <code> RelevancyEnabler </code> 
     *          creation using the specified record <code> Types </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          relevancyEnablerRecordTypes </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateRelevancyEnablerWithRecordTypes(org.osid.type.Type[] relevancyEnablerRecordTypes);


    /**
     *  Gets the relevancy enabler form for creating new relevancy enablers. A 
     *  new form should be requested for each create transaction. 
     *
     *  @param  relevancyEnablerRecordTypes array of relevancy enabler record 
     *          types 
     *  @return the relevancy enabler form 
     *  @throws org.osid.NullArgumentException <code> 
     *          relevancyEnablerRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.rules.RelevancyEnablerForm getRelevancyEnablerFormForCreate(org.osid.type.Type[] relevancyEnablerRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> RelevancyEnabler. </code> 
     *
     *  @param  relevancyEnablerForm the form for this <code> RelevancyEnabler 
     *          </code> 
     *  @return the new <code> RelevancyEnabler </code> 
     *  @throws org.osid.IllegalStateException <code> relevancyEnablerForm 
     *          </code> already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> relevancyEnablerForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> relevancyEnablerForm 
     *          </code> did not originate from <code> 
     *          getRelevancyEnablerFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.rules.RelevancyEnabler createRelevancyEnabler(org.osid.ontology.rules.RelevancyEnablerForm relevancyEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update relevancy enablers. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> RelevancyEnabler </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer update operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> RelevancyEnabler </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateRelevancyEnablers();


    /**
     *  Gets the relevancy enabler form for updating an existing relevancy 
     *  enabler. A new relevancy enabler form should be requested for each 
     *  update transaction. 
     *
     *  @param  relevancyEnablerId the <code> Id </code> of the <code> 
     *          RelevancyEnabler </code> 
     *  @return the relevancy enabler form 
     *  @throws org.osid.NotFoundException <code> relevancyEnablerId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> relevancyEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.rules.RelevancyEnablerForm getRelevancyEnablerFormForUpdate(org.osid.id.Id relevancyEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing relevancy enabler. 
     *
     *  @param  relevancyEnablerForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> relevancyEnablerForm 
     *          </code> already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> relevancyEnablerForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> relevancyEnablerForm 
     *          </code> did not originate from <code> 
     *          getRelevancyEnablerFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateRelevancyEnabler(org.osid.ontology.rules.RelevancyEnablerForm relevancyEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete relevancy enablers. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> RelevancyEnabler </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer delete operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> RelevancyEnabler </code> 
     *          deletion is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteRelevancyEnablers();


    /**
     *  Deletes a <code> RelevancyEnabler. </code> 
     *
     *  @param  relevancyEnablerId the <code> Id </code> of the <code> 
     *          RelevancyEnabler </code> to remove 
     *  @throws org.osid.NotFoundException <code> relevancyEnablerId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> relevancyEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteRelevancyEnabler(org.osid.id.Id relevancyEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for relevancy 
     *  enablers. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> RelevancyEnabler </code> 
     *          aliasing is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageRelevancyEnablerAliases();


    /**
     *  Adds an <code> Id </code> to a <code> RelevancyEnabler </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> RelevancyEnabler </code> is determined by the provider. The 
     *  new <code> Id </code> performs as an alias to the primary <code> Id 
     *  </code> . If the alias is a pointer to another relevancy enabler. it 
     *  is reassigned to the given relevancy enabler <code> Id. </code> 
     *
     *  @param  relevancyEnablerId the <code> Id </code> of a <code> 
     *          RelevancyEnabler </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> relevancyEnablerId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> relevancyEnablerId 
     *          </code> or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasRelevancyEnabler(org.osid.id.Id relevancyEnablerId, 
                                      org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
