//
// org.osid.ontology.rules.RelevancyEnablerRuleLookupSession
//
//     The OSID Java specification for org.osid.ontology.rules.RelevancyEnablerRuleLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ontology.rules;


/**
 *  <p>This session provides methods to retrieve <code> RelevancyEnabler 
 *  </code> to <code> Relevancy </code> mappings. A <code> Relevancy </code> 
 *  with multiple <code> RelevancyEnablers </code> means any positive rule 
 *  evaluation across the enablers result in an effective <code> Relevancy. 
 *  </code> </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated ontology view: All methods in this session operate, 
 *      retrieve and pertain relevancy enablers defined explicitly in the 
 *      current ontology </li> 
 *      <li> federated ontology view: All methods in this session operate, 
 *      retrieve and pertain to all relevancy enablers defined in this 
 *      ontology and any other relevancy enablers implicitly available in this 
 *      ontology through ontology inheritence. </li> 
 *  </ul>
 *  
 */

public interface RelevancyEnablerRuleLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Ontology </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Ontology Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getOntologyId();


    /**
     *  Gets the <code> Ontology </code> associated with this session. 
     *
     *  @return the ontology 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.Ontology getOntology()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform lookups of relevancy enabler/relevancy 
     *  mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known lookup 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if looking up mappings is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupRelevancyEnablerRule();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeRelevancyEnablerRuleView();


    /**
     *  A complete view of the <code> RelevancyEnabler </code> and <code> 
     *  Relevancy </code> returns is desired. Methods will return what is 
     *  requested or result in an error. This view is used when greater 
     *  precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryRelevancyEnablerRuleView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include relevancy enablers in ontologies which are children of this 
     *  ontology in the ontology hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedOntologyView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this ontology only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedOntologyView();


    /**
     *  Gets the <code> RelevancyEnabler Id </code> associated with a <code> 
     *  Relevancy. </code> 
     *
     *  @param   relevancyId <code> Id </code> of the <code> Relevancy </code> 
     *  @return the relevancy enabler <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> relevancyId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> relevancyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getRelevancyEnablerIdsForRelevancy(org.osid.id.Id  relevancyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> RelevancyEnabler </code> associated with a <code> 
     *  Relevancy. </code> 
     *
     *  @param  relevancyId <code> Id </code> of the <code> Relevancy </code> 
     *  @return the relevancy enablers 
     *  @throws org.osid.NotFoundException <code> relevancyId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> relevancyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.rules.RelevancyEnablerList getRelevancyEnablersForRelevancy(org.osid.id.Id relevancyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Relevancy </code> <code> Ids </code> mapped to a 
     *  <code> RelevancyEnabler. </code> 
     *
     *  @param  relevancyEnablerId <code> Id </code> of a <code> 
     *          RelevancyEnabler </code> 
     *  @return list of relevancy <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> relevancyEnablerId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> relevancyEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getRelevancyIdsForRelevancyEnabler(org.osid.id.Id relevancyEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Relevancies </code> mapped to a <code> 
     *  RelevancyEnabler. </code> 
     *
     *  @param  relevancyEnablerId <code> Id </code> of a <code> 
     *          RelevancyEnabler </code> 
     *  @return list of relevancies 
     *  @throws org.osid.NotFoundException <code> relevancyEnablerId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> relevancyEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.RelevancyList getRelevanciesForRelevancyEnabler(org.osid.id.Id relevancyEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
