//
// org.osid.ontology.rules.RelevancyEnablerSearchSession
//
//     The OSID Java specification for org.osid.ontology.rules.RelevancyEnablerSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ontology.rules;


/**
 *  <p>This session provides methods for searching among <code> 
 *  RelevancyEnabler </code> objects. The search query is constructed using 
 *  the <code> RelevancyEnableryQuery. </code> </p> 
 *  
 *  <p> <code> getRelevancyEnablersByQuery() </code> is the basic search 
 *  method and returns a list of <code> RelevancyEnablers. </code> A more 
 *  advanced search may be performed with <code> 
 *  getRelevancyEnablersBySearch(). </code> It accepts a <code> 
 *  RelevancyEnablerSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getRelevancyEnablersBySearch() </code> returns a <code> 
 *  RelevancyEnablerSearchResults </code> that can be used to access the 
 *  resulting <code> RelevancyEnablerList </code> or be used to perform a 
 *  search within the result set through <code> RelevancyEnablerSearch. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated ontology view: searches include relevancy enablers in 
 *      ontologies of which this ontology is an ancestor in the ontology 
 *      hierarchy </li> 
 *      <li> isolated ontology view: searches are restricted to relevancy 
 *      enablers in this ontology </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> RelevancyEnablers </code> may have a query record indicated by 
 *  their respective record types. The query record is accessed via the <code> 
 *  RelevancyEnablerQuery. </code> </p>
 */

public interface RelevancyEnablerSearchSession
    extends org.osid.ontology.rules.RelevancyEnablerQuerySession {


    /**
     *  Gets a relevancy enabler search. 
     *
     *  @return the relevancy enabler search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.rules.RelevancyEnablerSearch getRelevancyEnablerSearch();


    /**
     *  Gets a relevancy enabler search order. The <code> 
     *  RelevancyEnablerSearchOrder </code> is supplied to a <code> 
     *  RelevancyEnablerSearch </code> to specify the ordering of results. 
     *
     *  @return the relevancy enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.rules.RelevancyEnablerSearchOrder getRelevancyEnablerSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  relevancyEnablerQuery the relevancy enabler query 
     *  @param  relevancyEnablerSearch the relevancy enabler search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> relevancyEnablerQuery 
     *          </code> or <code> relevancyEnablerSearch </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> relevancyEnablerQuery 
     *          </code> or <code> relevancyEnablerSearch </code> is not of 
     *          this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.rules.RelevancyEnablerSearchResults getRelevancyEnablersBySearch(org.osid.ontology.rules.RelevancyEnablerQuery relevancyEnablerQuery, 
                                                                                              org.osid.ontology.rules.RelevancyEnablerSearch relevancyEnablerSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a relevancy enabler query from an inspector. The inspector is 
     *  available from a <code> RelevancyEnablerSearchResults. </code> 
     *
     *  @param  relevancyEnablerQueryInspector a relevancy enabler query 
     *          inspector 
     *  @return the relevancy enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          relevancyEnablerQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          relevancyEnablerQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.rules.RelevancyEnablerQuery getRelevancyEnablerQueryFromInspector(org.osid.ontology.rules.RelevancyEnablerQueryInspector relevancyEnablerQueryInspector);
}
