//
// org.osid.orchestration.OrchestrationManager
//
//     The OSID Java specification for org.osid.orchestration.OrchestrationManager.
//
// Copyright (C) 2009 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.orchestration;


/**
 *  <p>This manager provides access to the available OSID providers. </p>
 */

public interface OrchestrationManager
    extends org.osid.OsidManager,
            org.osid.orchestration.OrchestrationProfile {


    /**
     *  Gets the manager associated with the Acknowledgement service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAcknowledgementProvider() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAcknowledgementProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.acknowledgement.AcknowledgementManager getAcknowledgementManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Assessment service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.assessment.AssessmentManager getAssessmentManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Authentication service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuthenticationProvider() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuthenticationProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.authentication.AuthenticationManager getAuthenticationManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Authorization service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuthorizationProvider() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuthorizationProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.authorization.AuthorizationManager getAuthorizationManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Bidding service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBiddingProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBiddingProvider() </code> is <code> true. </code> 
     */

    public org.osid.bidding.BiddingManager getBiddingManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Billing service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBillingProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBillingProvider() </code> is <code> true. </code> 
     */

    public org.osid.billing.BillingManager getBillingManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Blogging service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBloggingProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBloggingProvider() </code> is <code> true. </code> 
     */

    public org.osid.blogging.BloggingManager getBloggingManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Calendaring service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCalendaringProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCalendaringProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.CalendaringManager getCalendaringManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Cataloging service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCatalogingProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCatalogingProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.cataloging.CatalogingManager getCatalogingManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Checklist service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsChecklistProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsChecklistProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.checklist.ChecklistManager getChecklistManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Commenting service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommentingProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommentingProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.commenting.CommentingManager getCommentingManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Communication service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommunicationProvider() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommunicationProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.communication.CommunicationManager getCommunicationManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Configuration service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsConfigurationProvider() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsConfigurationProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.configuration.ConfigurationManager getConfigurationManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Contact service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsContactProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsContactProvider() </code> is <code> true. </code> 
     */

    public org.osid.contact.ContactManager getContactManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Control service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsControlProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsControlProvider() </code> is <code> true. </code> 
     */

    public org.osid.control.ControlManager getControlManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Course service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCourseProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCourseProvider() </code> is <code> true. </code> 
     */

    public org.osid.course.CourseManager getCourseManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Dictionary service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDictionaryProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDictionaryProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.dictionary.DictionaryManager getDictionaryManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Filing service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsFilingProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFilingProvider() </code> is <code> true. </code> 
     */

    public org.osid.filing.FilingManager getFilingManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Financials service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsFinancialsProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFinancialsProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.financials.FinancialsManager getFinancialsManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Forum service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsForumProvider() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsForumProvider() </code> is <code> true. </code> 
     */

    public org.osid.forum.ForumManager getForumManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Grading service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradingProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradingProvider() </code> is <code> true. </code> 
     */

    public org.osid.grading.GradingManager getGradingManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Hierarchy service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsHierarchyProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsHierarchyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.hierarchy.HierarchyManager getHierarchyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Hold service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsHoldProvider() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsHoldProvider() </code> is <code> true. </code> 
     */

    public org.osid.hold.HoldManager getHoldManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Id service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsIdProvider() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsIdProvider() </code> is <code> true. </code> 
     */

    public org.osid.id.IdManager getIdManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Inquiry service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInquiryProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInquiryProvider() </code> is <code> true. </code> 
     */

    public org.osid.inquiry.InquiryManager getInquiryManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Installation service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInstallationProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInstallationProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.installation.InstallationManager getInstallationManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Inventory service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInventoryProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInventoryProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.inventory.InventoryManager getInventoryManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Journaling service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJournalingProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJournalingProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.id.IdManager getJournalingManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Learning service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsLearningProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLearningProvider() </code> is <code> true. </code> 
     */

    public org.osid.learning.LearningManager getLearningManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Locale service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsLocaleProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLocaleProvider() </code> is <code> true. </code> 
     */

    public org.osid.locale.LocaleManager getLocaleManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Logging service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsLoggingProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLoggingProvider() </code> is <code> true. </code> 
     */

    public org.osid.logging.LoggingManager getLoggingManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Mapping service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsMappingProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMappingProvider() </code> is <code> true. </code> 
     */

    public org.osid.mapping.MappingManager getMappingManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Messaging service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsMessagingProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMessagingProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.messaging.MessagingManager getMessagingManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Metering service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsMessagingProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMeteringProvider() </code> is <code> true. </code> 
     */

    public org.osid.metering.MeteringManager getMeteringManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Ontology service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfferingProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingProvider() </code> is <code> true. </code> 
     */

    public org.osid.offering.OfferingManager getOfferingManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Offering service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOntologyProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOntologyProvider() </code> is <code> true. </code> 
     */

    public org.osid.ontology.OntologyManager getOntologyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Ordering service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOrderingProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOrderingProvider() </code> is <code> true. </code> 
     */

    public org.osid.ordering.OrderingManager getOrderingManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Personnel service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPersonnelProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPersonnelProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.personnel.PersonnelManager getPersonnelManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Process service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProcessProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcessProvider() </code> is <code> true. </code> 
     */

    public org.osid.process.ProcessManager getProcessManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Profile service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileProvider() </code> is <code> true. </code> 
     */

    public org.osid.profile.ProfileManager getProfileManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Provisioning service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProvisioningProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProvisioningProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.ProvisioningManager getProvisioningManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Proxy service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsProxyProvider() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProxyProvider() </code> is <code> true. </code> 
     */

    public org.osid.proxy.ProxyManager getProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Recipe service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRecipeProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecipieProvider() </code> is <code> true. </code> 
     */

    public org.osid.recipe.RecipeManager getRecipieManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Recognition service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRecognitionProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecognitionProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.recognition.RecognitionManager getRecognitionManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Relationship service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelationshipProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelationshipProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.relationship.RelationshipManager getRelationshipManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Repository service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRepositoryProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRepositoryProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.repository.RepositoryManager getRepositoryManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Resource service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResourceProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceProvider() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceManager getResourceManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Resourcing service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResourcingProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourcingProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.ResourcingManager getResourcingManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Rules service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRulesProvider() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRulesProvider() </code> is <code> true. </code> 
     */

    public org.osid.rules.RulesManager getRulesManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Search service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSearchProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSearchProvider() </code> is <code> true. </code> 
     */

    public org.osid.search.SearchManager getSearchManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Sequencing service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSequencingProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSequencingProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.sequencing.SequencingManager getSequencingManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Subscription service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubscriptionProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubscriptionProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.subscription.SubscriptionManager getSubscriptionManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Topology service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTransportProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTransportProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.topology.TopologyManager getTopologyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Tracking service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTrackingProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTrackingProvider() </code> is <code> true. </code> 
     */

    public org.osid.tracking.TrackingManager getTrackingManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Transaction service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTransactionProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTransactionProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.transaction.TransactionManager getTransactionManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Transport service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTransportProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTransportProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.transport.TransportManager getTransportManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Type service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTopologyProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTopologyProvider() </code> is <code> true. </code> 
     */

    public org.osid.type.TypeManager getTypeManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Voting service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsVotingProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsVotingProvider() </code> is <code> true. </code> 
     */

    public org.osid.voting.VotingManager getVotingManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the manager associated with the Workflow service. 
     *
     *  @return the manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsWorkflowProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsWorkflowProvider() </code> is <code> true. </code> 
     */

    public org.osid.workflow.WorkflowManager getWorkflowManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Acknowledgement service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAcknowledgementProxyProvider() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAcknowledgementProxyProvider() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.acknowledgement.AcknowledgementProxyManager getAcknowledgementProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Assessment service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentProxyProvider() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.assessment.AssessmentProxyManager getAssessmentProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Authentication service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuthenticationProxyProvider() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuthenticationProxyProvider() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.authentication.AuthenticationProxyManager getAuthenticationProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Authorization service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuthorizationProxyProvider() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuthorizationProxyProvider() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.authorization.AuthorizationProxyManager getAuthorizationProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Bidding service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBiddingProxyProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBiddingProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.bidding.BiddingProxyManager getBiddingProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Billing service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBillingProxyProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBillingProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.billing.BillingProxyManager getBillingProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Blogging service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBloggingProxyProvider() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBloggingProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.blogging.BloggingProxyManager getBloggingProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Calendaring service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCalendaringProxyProvider() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCalendaringProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.CalendaringProxyManager getCalendaringProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Cataloging service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCatalogingProxyProvider() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCatalogingProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.cataloging.CatalogingProxyManager getCatalogingProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Checklist service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsChecklistProxyProvider() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsChecklistProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.checklist.ChecklistProxyManager getChecklistProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Commenting service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommentingProxyProvider() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommentingProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.commenting.CommentingProxyManager getCommentingProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Communication service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommunicationProxyProvider() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommunicationProxyProvider() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.communication.CommunicationProxyManager getCommunicationProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Configuration service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsConfigurationProxyProvider() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsConfigurationProxyProvider() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.configuration.ConfigurationProxyManager getConfigurationProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Contact service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsContactProxyProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsContactProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.contact.ContactProxyManager getContactProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Control service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsControlProxyProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsControlProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.ControlProxyManager getControlProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Course service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCourseProxyProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCourseProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.CourseProxyManager getCourseProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Dictionary service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDictionaryProxyProvider() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDictionaryProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.dictionary.DictionaryProxyManager getDictionaryProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Filing service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsFilingProxyProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFilingProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.filing.FilingProxyManager getFilingProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Financials service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsFinancialsProxyProvider() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFinancialsProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.financials.FinancialsManager getFinancialsProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Forum service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsForumProxyProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsForumProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.forum.ForumProxyManager getForumProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Grading service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradingProxyProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradingProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.grading.GradingProxyManager getGradingProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Hierarchy service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsHierarchyProxyProvider() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsHierarchyProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.hierarchy.HierarchyProxyManager getHierarchyProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Hold service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsHoldProxyProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsHoldProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.hold.HoldManager getHoldProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Id service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsIdProxyProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsIdProxyProvider() </code> is <code> true. </code> 
     */

    public org.osid.id.IdProxyManager getIdProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Inquiry service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInquiryProxyProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInquiryProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.InquiryProxyManager getInquiryProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Installation service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInstallationProxyProvider() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInstallationProxyProvider() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.installation.InstallationProxyManager getInstallationProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Inventory service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInventoryProxyProvider() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInventoryProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.inventory.InventoryProxyManager getInventoryProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Journaling service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJournalingProxyProvider() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJournalingProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.id.IdProxyManager getJournalingProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Learning service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsLearningProxyProvider() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLearningProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.learning.LearningProxyManager getLearningProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Locale service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsLocaleProxyProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLocaleProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.locale.LocaleProxyManager getLocaleProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Logging service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsLoggingProxyProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLoggingProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.logging.LoggingProxyManager getLoggingProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Mapping service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsMappingProxyProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMappingProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.mapping.MappingManager getMappingProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Messaging service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsMessagingProxyProvider() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMessagingProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.messaging.MessagingProxyManager getMessagingProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Metering service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsMeteringProxyProvider() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMeteringProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.metering.MeteringProxyManager getMeteringProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Offering service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfferingProxyProvider() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.offering.OfferingProxyManager getOfferingProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Ontology service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOntologyProxyProvider() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOntologyProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.ontology.OntologyProxyManager getOntologyProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Ordering service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOrderingProxyProvider() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOrderingProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.ordering.OrderingProxyManager getOrderingProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Personnel service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPersonnelProxyProvider() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPersonnelProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.personnel.PersonnelProxyManager getPersonnelProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Process service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProcessProxyProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcessProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.process.ProcessProxyManager getProcessProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Profile service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileProxyProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.profile.ProfileProxyManager getProfileProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Provisioning service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProvisioningProxyProvider() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProvisioningProxyProvider() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.ProvisioningProxyManager getProvisioningProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Proxy service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProxyProxyProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProxyProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.proxy.ProxyProxyManager getProxyProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Recipe service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRecipeProxyProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecipeProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.recipe.RecipeProxyManager getRecipeProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Recognition service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRecognitionProxyProvider() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecognitionProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.recognition.RecognitionProxyManager getRecognitionProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Relationship service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelationshipProxyProvider() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelationshipProxyProvider() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.relationship.RelationshipProxyManager getRelationshipProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Repository service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRepositoryProxyProvider() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRepositoryProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.repository.RepositoryProxyManager getRepositoryProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Resource service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResourceProxyProvider() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resource.ResourceProxyManager getResourceProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Resourcing service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResourcingProxyProvider() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourcingProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.ResourcingProxyManager getResourcingProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Rules service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRulesProxyProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRulesProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.rules.RulesProxyManager getRulesProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Search service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSearchProxyProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSearchProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.search.SearchProxyManager getSearchProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Sequencing service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSequencingProxyProvider() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSe1uencingProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.sequencing.SequencingProxyManager getSequencingProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Subscription service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubscriptionProxyProvider() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubscriptionProxyProvider() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.subscription.SubscriptionProxyManager getSubscriptionProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Topology service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTransportProxyProvider() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTransportProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.topology.TopologyProxyManager getTopologyProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Tracking service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTrackingProxyProvider() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTrackingProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.tracking.TrackingManager getTrackingProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Transaction service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTransactionProxyProvider() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTransactionProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.transaction.TransactionProxyManager getTransactionProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Transport service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTransportProxyProvider() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTransportProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.transport.TransportProxyManager getTransportProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Type service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTopologyProxyProvider() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTopologyProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.type.TypeProxyManager getTypeProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Voting service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsVotingProxyProvider() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsVotingProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.voting.VotingProxyManager getVotingProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proxy manager associated with the Workflow service. 
     *
     *  @return the proxy manager 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsWorkflowProxyProvider() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsWorkflowProxyProvider() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.workflow.WorkflowProxyManager getWorkflowProxyManager()
        throws org.osid.OperationFailedException;
}
