//
// org.osid.ordering.Item
//
//     The OSID Java specification for org.osid.ordering.Item.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ordering;


/**
 *  <p>A <code> Item </code> represents a collection of orders. Like all OSID 
 *  objects, a <code> Item </code> is identified by its <code> Id </code> and 
 *  any persisted references should use the <code> Id. </code> </p> 
 *  
 *  <p> <code> </code> An <code> Item </code> may have multiple unit prices 
 *  for different types of currencies, such as one for payment and one for 
 *  credits. Each line item cost type should be lined up with the unit price 
 *  type. </p>
 */

public interface Item
    extends org.osid.OsidRelationship {


    /**
     *  Gets the order <code> Id </code> for this item. 
     *
     *  @return the order <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getOrderId();


    /**
     *  Gets the order for this item. 
     *
     *  @return the order 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.Order getOrder()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if the item is a derived item as opposed to one that has been 
     *  explicitly selected. 
     *
     *  @return <code> true </code> if this item is derived, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isDerived();


    /**
     *  Gets the product <code> Id </code> for this item. 
     *
     *  @return the product <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getProductId();


    /**
     *  Gets the product for this item. 
     *
     *  @return the product 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.Product getProduct()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the price <code> Ids </code> for this item. 
     *
     *  @return the price <code> Ids </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getUnitPriceIds();


    /**
     *  Gets the prices for this item. There may be different price types for 
     *  a single item. 
     *
     *  @return the prices 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.PriceList getUnitPrices()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the quantity of the product. 
     *
     *  @return the quantity of the product 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getQuantity();


    /**
     *  Gets the line item costs. 
     *
     *  @return the costs. 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.CostList getCosts();


    /**
     *  Gets the item record corresponding to the given <code> Item </code> 
     *  record <code> Type. </code> This method is used to retrieve an object 
     *  implementing the requested record. The <code> itemRecordType </code> 
     *  may be the <code> Type </code> returned in <code> getRecordTypes() 
     *  </code> or any of its parents in a <code> Type </code> hierarchy where 
     *  <code> hasRecordType(itemRecordType) </code> is <code> true </code> . 
     *
     *  @param  itemRecordType the type of item record to retrieve 
     *  @return the item record 
     *  @throws org.osid.NullArgumentException <code> itemRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(itemRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.records.ItemRecord getItemRecord(org.osid.type.Type itemRecordType)
        throws org.osid.OperationFailedException;
}
