//
// org.osid.ordering.Order
//
//     The OSID Java specification for org.osid.ordering.Order.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ordering;


/**
 *  <p>An <code> Order. </code> </p>
 */

public interface Order
    extends org.osid.OsidObject,
            org.osid.Aggregateable {


    /**
     *  Gets the <code> Id </code> of the customer. 
     *
     *  @return the customer <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCustomerId();


    /**
     *  Gets the customer. 
     *
     *  @return the customer 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getCustomer()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Ids </code> of the items. 
     *
     *  @return the item <code> Ids </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getItemIds();


    /**
     *  Gets the items. 
     *
     *  @return the items 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.ItemList getItems()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the total cost for this order. 
     *
     *  @return the total cost 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.Currency getTotalCost();


    /**
     *  Tests if all the items are processed atomically. 
     *
     *  @return <code> true </code> if the order is atomic, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isAtomic();


    /**
     *  Tests if all this order has been submitted. 
     *
     *  @return <code> true </code> if the order has been submitted, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isSubmitted();


    /**
     *  Gets the date submitted. 
     *
     *  @return the date submitted 
     *  @throws org.osid.IllegalStateException <code> isSubmitted() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getSubmitDate();


    /**
     *  Gets the resource <code> Id </code> who submitted the order. 
     *
     *  @return the submitting resource <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> isSubmitted() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getSubmitterId();


    /**
     *  Gets the agent who submitted the order. 
     *
     *  @return the submitting resource 
     *  @throws org.osid.IllegalStateException <code> isSubmitted() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getSubmitter()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the agent <code> Id </code> who submitted the order. 
     *
     *  @return the submitting agent <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> isSubmitted() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getSubmittingAgentId();


    /**
     *  Gets the agent who submitted the order. 
     *
     *  @return the submitting agent 
     *  @throws org.osid.IllegalStateException <code> isSubmitted() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.Agent getSubmittingAgent()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if all this order is closed or canceled. 
     *
     *  @return <code> true </code> if the order is closed, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isClosed();


    /**
     *  Gets the date this order has been closed. 
     *
     *  @return the date closed 
     *  @throws org.osid.IllegalStateException <code> isClosed() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getClosedDate();


    /**
     *  Gets the resource <code> Id </code> who closed the order. 
     *
     *  @return the closing resource <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> isClosed() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCloserId();


    /**
     *  Gets the resource who closed the order. 
     *
     *  @return the closing resource 
     *  @throws org.osid.IllegalStateException <code> isClosed() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getCloser()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the agent <code> Id </code> who closed the order. 
     *
     *  @return the closing agent <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> isClosed() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getClosingAgentId();


    /**
     *  Gets the agent who closed the order. 
     *
     *  @return the closing agent 
     *  @throws org.osid.IllegalStateException <code> isClosed() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.Agent getClosingAgent()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the order record corresponding to the given <code> Order </code> 
     *  record <code> Type. </code> This method is used to retrieve an object 
     *  implementing the requested record. The <code> orderRecordType </code> 
     *  may be the <code> Type </code> returned in <code> getRecordTypes() 
     *  </code> or any of its parents in a <code> Type </code> hierarchy where 
     *  <code> hasRecordType(orderRecordType) </code> is <code> true </code> . 
     *
     *  @param  orderRecordType the type of order record to retrieve 
     *  @return the order record 
     *  @throws org.osid.NullArgumentException <code> orderRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(orderRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.records.OrderRecord getOrderRecord(org.osid.type.Type orderRecordType)
        throws org.osid.OperationFailedException;
}
