//
// org.osid.ordering.OrderLookupSession
//
//     The OSID Java specification for org.osid.ordering.OrderLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ordering;


/**
 *  <p>This session defines methods for retrieving orders. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated store view: All order methods in this session operate, 
 *      retrieve and pertain to orders defined explicitly in the current 
 *      store. Using an isolated view is useful for managing orders with the 
 *      <code> OrderAdminSession. </code> </li> 
 *      <li> federated store view: All order lookup methods in this session 
 *      operate, retrieve and pertain to all orders defined in this store and 
 *      any other stores implicitly available in this store through store 
 *      inheritence. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedStoreView() </code> and <code> 
 *  useIsolatedStoreView() </code> behave as a radio group and one should be 
 *  selected before invoking any lookup methods. </p>
 */

public interface OrderLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Store </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Store Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getStoreId();


    /**
     *  Gets the <code> Store </code> associated with this session. 
     *
     *  @return the store 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.Store getStore()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can lookup orders. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer these operations. 
     *
     *  @return <code> false </code> if order lookup methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupOrders();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeOrderView();


    /**
     *  A complete view of the <code> Order </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryOrderView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include orders in stores which are children of this store in the store 
     *  hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedStoreView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this store only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedStoreView();


    /**
     *  Gets the <code> Order </code> specified by its <code> Id. </code> In 
     *  plenary mode, the exact <code> Id </code> is found or a <code> 
     *  NOT_FOUND </code> results. Otherwise, the returned <code> Order 
     *  </code> may have a different <code> Id </code> than requested, such as 
     *  the case where a duplicate <code> Id </code> was assigned to an <code> 
     *  Order </code> and retained for compatibility. 
     *
     *  @param  orderId the <code> Id </code> of the <code> Order </code> to 
     *          retrieve 
     *  @return the returned <code> Order </code> 
     *  @throws org.osid.NotFoundException no <code> Order </code> found with 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> orderId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.Order getOrder(org.osid.id.Id orderId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> OrderList </code> corresponding to the given <code> 
     *  IdList. </code> In plenary mode, the returned list contains all of the 
     *  entries specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible entries may be omitted from the list and may present the 
     *  elements in any order including returning a unique set. 
     *
     *  @param  orderIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Order list </code> 
     *  @throws org.osid.NotFoundException an <code> Id </code> was not found 
     *  @throws org.osid.NullArgumentException <code> orderIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.OrderList getOrdersByIds(org.osid.id.IdList orderIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> OrderList </code> corresponding to the given order 
     *  genus <code> Type </code> which does not include orders of genus types 
     *  derived from the specified <code> Type. </code> In plenary mode, the 
     *  returned list contains all known orders or an error results. 
     *  Otherwise, the returned list may contain only those orders that are 
     *  accessible through this session. 
     *
     *  @param  orderGenusType an order genus type 
     *  @return the returned <code> Order </code> list 
     *  @throws org.osid.NullArgumentException <code> orderGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.OrderList getOrdersByGenusType(org.osid.type.Type orderGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> OrderList </code> corresponding to the given order 
     *  genus <code> Type </code> and include any additional orders with genus 
     *  types derived from the specified <code> Type. </code> In plenary mode, 
     *  the returned list contains all known orders or an error results. 
     *  Otherwise, the returned list may contain only those orders that are 
     *  accessible through this session. 
     *
     *  @param  orderGenusType an order genus type 
     *  @return the returned <code> Order </code> list 
     *  @throws org.osid.NullArgumentException <code> orderGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.OrderList getOrdersByParentGenusType(org.osid.type.Type orderGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> OrderList </code> containing the given repository 
     *  record <code> Type. </code> In plenary mode, the returned list 
     *  contains all known orders or an error results. Otherwise, the returned 
     *  list may contain only those orders that are accessible through this 
     *  session. 
     *
     *  @param  orderRecordType an order record type 
     *  @return the returned <code> Order </code> list 
     *  @throws org.osid.NullArgumentException <code> orderRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.OrderList getOrdersByRecordType(org.osid.type.Type orderRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all orders corresponding to a customer <code> Id. 
     *  </code> In plenary mode, the returned list contains all known orders 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those entries that are accessible through this session. 
     *
     *  @param  resourceId the <code> Id </code> of the customer 
     *  @return the returned <code> OrderList </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.OrderList getOrdersByCustomer(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all orders corresponding to a date range. Entries are 
     *  returned with a submitted date that falsl between the requested dates 
     *  inclusive. In plenary mode, the returned list contains all known 
     *  orders or an error results. Otherwise, the returned list may contain 
     *  only those entries that are accessible through this session. 
     *
     *  @param  from from date 
     *  @param  to to date 
     *  @return the returned <code> OrderList </code> 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.OrderList getOrdersByDate(org.osid.calendaring.DateTime from, 
                                                       org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all orders corresponding to a customer <code> Id 
     *  </code> and date range. Entries are returned with submit dates that 
     *  fall between the requested dates inclusive. In plenary mode, the 
     *  returned list contains all known orders or an error results. 
     *  Otherwise, the returned list may contain only those entries that are 
     *  accessible through this session. 
     *
     *  @param  resourceId the <code> Id </code> of the customer 
     *  @param  from from date 
     *  @param  to to date 
     *  @return the returned <code> OrderList </code> 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, from </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.OrderList getOrdersByCustomerAndDate(org.osid.id.Id resourceId, 
                                                                  org.osid.calendaring.DateTime from, 
                                                                  org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all orders with an item for a product. Entries are 
     *  returned with submit dates that fall between the requested dates 
     *  inclusive. In plenary mode, the returned list contains all known 
     *  orders or an error results. Otherwise, the returned list may contain 
     *  only those entries that are accessible through this session. 
     *
     *  @param  productId a product <code> Id </code> 
     *  @return the returned <code> OrderList </code> 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> productId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.OrderList getOrdersForProduct(org.osid.id.Id productId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all orders with items for a product <code> Id </code> 
     *  and date range. Entries are returned with submit dates that fall 
     *  between the requested dates inclusive. In plenary mode, the returned 
     *  list contains all known orders or an error results. Otherwise, the 
     *  returned list may contain only those entries that are accessible 
     *  through this session. 
     *
     *  @param  productId a product <code> Id </code> 
     *  @param  from from date 
     *  @param  to to date 
     *  @return the returned <code> OrderList </code> 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> productId, from, </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.OrderList getOrdersForProductAndDate(org.osid.id.Id productId, 
                                                                  org.osid.calendaring.DateTime from, 
                                                                  org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all orders. In plenary mode, the returned list contains all known 
     *  entries or an error results. Otherwise, the returned list may contain 
     *  only those entries that are accessible through this session. 
     *
     *  @return a list of orders 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.OrderList getOrders()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all submitted and not closed orders. In plenary mode, the 
     *  returned list contains all known entries or an error results. 
     *  Otherwise, the returned list may contain only those entries that are 
     *  accessible through this session. 
     *
     *  @return a list of orders 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.OrderList getOpenOrders()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all closed orders. In plenary mode, the returned list contains 
     *  all known entries or an error results. Otherwise, the returned list 
     *  may contain only those entries that are accessible through this 
     *  session. 
     *
     *  @return a list of orders 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.OrderList getClosedOrders()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
