//
// org.osid.ordering.OrderQueryInspector
//
//     The OSID Java specification for org.osid.ordering.OrderQueryInspector.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ordering;


/**
 *  <p>The inspector for examining order queries. </p>
 */

public interface OrderQueryInspector
    extends org.osid.OsidObjectQueryInspector,
            org.osid.OsidAggregateableQueryInspector {


    /**
     *  Gets the customer <code> Id </code> terms. 
     *
     *  @return the customer <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getCustomerIdTerms();


    /**
     *  Gets the customer terms. 
     *
     *  @return the customer terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceQueryInspector[] getCustomerTerms();


    /**
     *  Gets the item <code> Id </code> terms. 
     *
     *  @return the item <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getItemIdTerms();


    /**
     *  Gets the item terms. 
     *
     *  @return the item terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.ItemQueryInspector[] getItemTerms();


    /**
     *  Gets the total cost terms. 
     *
     *  @return the total cost terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.CurrencyRangeTerm[] getTotalCostTerms();


    /**
     *  Gets the minimum total cost terms. 
     *
     *  @return the minimum total cost terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.CurrencyTerm[] getMinimumTotalCostTerms();


    /**
     *  Gets the atomic terms. 
     *
     *  @return the atomic terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.BooleanTerm[] getAtomicTerms();


    /**
     *  Gets the submit date terms. 
     *
     *  @return the date range terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DateTimeRangeTerm[] getSubmitDateTerms();


    /**
     *  Gets the submitter resource <code> Id </code> terms. 
     *
     *  @return the resource <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getSubmitterIdTerms();


    /**
     *  Gets the submitter terms. 
     *
     *  @return the resource terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceQueryInspector[] getSubmitterTerms();


    /**
     *  Gets the submitting agent <code> Id </code> terms. 
     *
     *  @return the agent <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getSubmittingAgentIdTerms();


    /**
     *  Gets the submitting agent terms. 
     *
     *  @return the agent terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.AgentQueryInspector[] getSubmittingAgentTerms();


    /**
     *  Gets the closed date terms. 
     *
     *  @return the date range terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DateTimeRangeTerm[] getClosedDateTerms();


    /**
     *  Gets the closer resource <code> Id </code> terms. 
     *
     *  @return the resource <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getCloserIdTerms();


    /**
     *  Gets the closer terms. 
     *
     *  @return the resource terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceQueryInspector[] getCloserTerms();


    /**
     *  Gets the submitting agent <code> Id </code> terms. 
     *
     *  @return the agent <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getClosingAgentIdTerms();


    /**
     *  Gets the closing agent terms. 
     *
     *  @return the agent terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.AgentQueryInspector[] getClosingAgentTerms();


    /**
     *  Gets the store <code> Id </code> terms. 
     *
     *  @return the store <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getStoreIdTerms();


    /**
     *  Gets the store terms. 
     *
     *  @return the store terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.StoreQueryInspector[] getStoreTerms();


    /**
     *  Gets the order query inspector record corresponding to the given 
     *  <code> Order </code> record <code> Type. </code> 
     *
     *  @param  orderRecordType a order record type 
     *  @return the order query inspector record 
     *  @throws org.osid.NullArgumentException <code> orderRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(orderRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.records.OrderQueryInspectorRecord getOrderQueryInspectorRecord(org.osid.type.Type orderRecordType)
        throws org.osid.OperationFailedException;
}
