//
// org.osid.ordering.OrderingManager
//
//     The OSID Java specification for org.osid.ordering.OrderingManager.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ordering;


/**
 *  <p>The order manager provides access to order sessions and provides 
 *  interoperability tests for various aspects of this service. The sessions 
 *  included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> MyOrderSession: </code> a session to lookup orders </li> 
 *      <li> <code> OrderLookupSession: </code> a session to lookup orders 
 *      </li> 
 *      <li> <code> OrderQuerySession: </code> a session to query orders </li> 
 *      <li> <code> OrderSearchSession: </code> a session to search orders 
 *      </li> 
 *      <li> <code> OrderAdminSession: </code> a session to manage orders 
 *      </li> 
 *      <li> <code> OrderNotificationSession: </code> a session to subscribe 
 *      to notifications of order changes </li> 
 *      <li> <code> OrderStoreSession: </code> a session to lookup order store 
 *      mappings </li> 
 *      <li> <code> OrderStoreAssignmentSession: </code> a session to manage 
 *      order store mappings </li> 
 *      <li> <code> OrderSmartStoreSession: </code> a session to manage smart 
 *      stores of orders </li> 
 *      <li> <code> ItemAdminSession: </code> a session to add items to an 
 *      order </li> 
 *      <li> <code> ProductLookupSession: </code> a session to retrieve 
 *      products </li> 
 *      <li> <code> ProductQuerySession: </code> a session to query products 
 *      </li> 
 *      <li> <code> ProductSearchSession: </code> a session to search for 
 *      products </li> 
 *      <li> <code> ProductAdminSession: </code> a session to create, update 
 *      and delete products </li> 
 *      <li> <code> ProductNotificationSession: </code> a session to receive 
 *      notifications for changes in products </li> 
 *      <li> <code> ProductStoreSession: </code> a session to lookup product 
 *      store mappings </li> 
 *      <li> <code> ProductStoreAssignmentSession: </code> a session to manage 
 *      product store mappings </li> 
 *      <li> <code> ProductSmartStoreSession: </code> a session to manage 
 *      smart stores of products </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> PriceScheduleLookupSession: </code> a session to retrieve 
 *      price schedules </li> 
 *      <li> <code> PriceScheduleQuerySession: </code> a session to query 
 *      price schedules </li> 
 *      <li> <code> PriceScheduleSearchSession: </code> a session to search 
 *      for price schedules </li> 
 *      <li> <code> PriceScheduleAdminSession: </code> a session to create, 
 *      update and delete price schedules </li> 
 *      <li> <code> PriceScheduleNotificationSession: </code> a session to 
 *      receive notifications for changes in price schedules </li> 
 *      <li> <code> PriceScheduleStoreSession: </code> a session to lookup 
 *      price schedule store mappings </li> 
 *      <li> <code> PriceScheduleStoreAssignmentSession: </code> a session to 
 *      manage price schedule store mappings </li> 
 *      <li> <code> PriceScheduleSmartStoreSession: </code> a session to 
 *      manage smart stores of price schedules </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> StoreLookupSession: </code> a session to retrieve stores 
 *      </li> 
 *      <li> <code> StoreQuerySession: </code> a session to query stores </li> 
 *      <li> <code> StoreSearchSession: </code> a session to search for stores 
 *      </li> 
 *      <li> <code> StoreAdminSession: </code> a session to create, update and 
 *      delete stores </li> 
 *      <li> <code> StoreNotificationSession: </code> a session to receive 
 *      notifications for changes in stores </li> 
 *      <li> <code> StoreHierarchyTraversalSession: </code> a session to 
 *      traverse hierarchies of stores </li> 
 *      <li> <code> StoreHierarchyDesignSession: </code> a session to manage 
 *      hierarchies of stores </li> 
 *  </ul>
 *  
 *  
 *  <p> The ordering manager also provides a profile for determing the 
 *  supported search types supported by this service. </p>
 */

public interface OrderingManager
    extends org.osid.OsidManager,
            org.osid.ordering.OrderingProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the order lookup 
     *  service for the authenticated agent. 
     *
     *  @return a <code> My </code> Order <code> Session </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsMyOrder() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMyOrder() </code> is <code> true. </code> 
     */

    public org.osid.ordering.MyOrderSession getMyOrderSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the order lookup 
     *  service for the authenticated agent for the given store. 
     *
     *  @param  storeId the <code> Id </code> of the <code> Store </code> 
     *  @return a <code> MyOrderSession </code> 
     *  @throws org.osid.NotFoundException no <code> Store </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> storeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsMyOrder() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMyOrder() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.ordering.MyOrderSession getMyOrderSessionForStore(org.osid.id.Id storeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the order lookup 
     *  service. 
     *
     *  @return an <code> OrderLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsOrderLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOrderLookup() </code> is <code> true. </code> 
     */

    public org.osid.ordering.OrderLookupSession getOrderLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the order lookup 
     *  service for the given store. 
     *
     *  @param  storeId the <code> Id </code> of the <code> Store </code> 
     *  @return an <code> OrderLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Store </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> storeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsOrderLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOrderLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.ordering.OrderLookupSession getOrderLookupSessionForStore(org.osid.id.Id storeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the order query 
     *  service. 
     *
     *  @return an <code> OrderQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsOrderQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOrderQuery() </code> is <code> true. </code> 
     */

    public org.osid.ordering.OrderQuerySession getOrderQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the order query 
     *  service for the given store. 
     *
     *  @param  storeId the <code> Id </code> of the <code> Store </code> 
     *  @return an <code> OrderQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Store </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> storeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsOrderQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOrderQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.ordering.OrderQuerySession getOrderQuerySessionForStore(org.osid.id.Id storeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the order search 
     *  service. 
     *
     *  @return an <code> OrderSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsOrderSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOrderSearch() </code> is <code> true. </code> 
     */

    public org.osid.ordering.OrderSearchSession getOrderSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the order search 
     *  service for the given store. 
     *
     *  @param  storeId the <code> Id </code> of the <code> Store </code> 
     *  @return an <code> OrderSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Store </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> storeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsOrderSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOrderSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.ordering.OrderSearchSession getOrderSearchSessionForStore(org.osid.id.Id storeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the order 
     *  administration service. 
     *
     *  @return an <code> OrderAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsOrderAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOrderAdmin() </code> is <code> true. </code> 
     */

    public org.osid.ordering.OrderAdminSession getOrderAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the order 
     *  administration service for the given store. 
     *
     *  @param  storeId the <code> Id </code> of the <code> Store </code> 
     *  @return an <code> OrderAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Store </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> storeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsOrderAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOrderAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.ordering.OrderAdminSession getOrderAdminSessionForStore(org.osid.id.Id storeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the order 
     *  notification service. 
     *
     *  @param  orderReceiver the receiver 
     *  @return an <code> OrderNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> orderReceiver </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOrderNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOrderNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.ordering.OrderNotificationSession getOrderNotificationSession(org.osid.ordering.OrderReceiver orderReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the order 
     *  notification service for the given store. 
     *
     *  @param  orderReceiver the receiver 
     *  @param  storeId the <code> Id </code> of the <code> Store </code> 
     *  @return an <code> OrderNotificationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Store </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> orderReceiver </code> or 
     *          <code> storeId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOrderNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOrderNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.ordering.OrderNotificationSession getOrderNotificationSessionForStore(org.osid.ordering.OrderReceiver orderReceiver, 
                                                                                          org.osid.id.Id storeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving odrer to store mappings. 
     *
     *  @return an <code> OrderStoreSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsOrderStore() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOrderStore() </code> is <code> true. </code> 
     */

    public org.osid.ordering.OrderStoreSession getOrderStoreSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning order to store mappings. 
     *
     *  @return an <code> OrderStoreAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOrderStoreAssignment() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOrderStoreAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.ordering.OrderStoreAssignmentSession getOrderStoreAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session associated with the order smart store for the given 
     *  store. 
     *
     *  @param  storeId the <code> Id </code> of the store 
     *  @return an <code> OrderSmartStoreSession </code> 
     *  @throws org.osid.NotFoundException <code> storeId </code> not found 
     *  @throws org.osid.NullArgumentException <code> storeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOrderSmartStore() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOrderSmartStore() </code> is <code> true. </code> 
     */

    public org.osid.ordering.OrderSmartStoreSession getOrderSmartStoreSession(org.osid.id.Id storeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the item 
     *  adminsitartive service. 
     *
     *  @return an <code> ItemAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsItemAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsItemAdmin() </code> is <code> true. </code> 
     */

    public org.osid.ordering.ItemAdminSession getItemAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the item admin 
     *  service for the given store. 
     *
     *  @param  storeId the <code> Id </code> of the <code> Store </code> 
     *  @return an <code> ItemAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Store </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> storeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsItemAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsItemAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.ordering.ItemAdminSession getItemAdminSessionForStore(org.osid.id.Id storeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the product lookup 
     *  service. 
     *
     *  @return a <code> ProductLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsProductLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProductLookup() </code> is <code> true. </code> 
     */

    public org.osid.ordering.ProductLookupSession getProductLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the product lookup 
     *  service for the given store. 
     *
     *  @param  storeId the <code> Id </code> of the <code> Store </code> 
     *  @return a <code> ProductLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Store </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> storeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsProductLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProductLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.ordering.ProductLookupSession getProductLookupSessionForStore(org.osid.id.Id storeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the product query 
     *  service. 
     *
     *  @return a <code> ProductQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsProductQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProductQuery() </code> is <code> true. </code> 
     */

    public org.osid.ordering.ProductQuerySession getProductQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the product query 
     *  service for the given store. 
     *
     *  @param  storeId the <code> Id </code> of the <code> Store </code> 
     *  @return a <code> ProductQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Store </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> storeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsProductQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProductQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.ordering.ProductQuerySession getProductQuerySessionForStore(org.osid.id.Id storeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the product search 
     *  service. 
     *
     *  @return a <code> ProductSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsProductSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProductSearch() </code> is <code> true. </code> 
     */

    public org.osid.ordering.ProductSearchSession getProductSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the product search 
     *  service for the given store. 
     *
     *  @param  storeId the <code> Id </code> of the <code> Store </code> 
     *  @return a <code> ProductSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Store </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> storeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsProductSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProductSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.ordering.ProductSearchSession getProductSearchSessionForStore(org.osid.id.Id storeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the product 
     *  administrative service. 
     *
     *  @return a <code> ProductAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsProductAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProductAdmin() </code> is <code> true. </code> 
     */

    public org.osid.ordering.ProductAdminSession getProductAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the product 
     *  administrative service for the given store. 
     *
     *  @param  storeId the <code> Id </code> of the <code> Store </code> 
     *  @return a <code> ProductAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Store </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> storeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsProductAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProductAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.ordering.ProductAdminSession getProductAdminSessionForStore(org.osid.id.Id storeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the product 
     *  notification service. 
     *
     *  @param  productReceiver the receiver 
     *  @return a <code> ProductNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> producteReceiver </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProductNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProductNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.ordering.ProductNotificationSession getProductNotificationSession(org.osid.ordering.ProductReceiver productReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the product 
     *  notification service for the given store. 
     *
     *  @param  productReceiver the receiver 
     *  @param  storeId the <code> Id </code> of the <code> Store </code> 
     *  @return a <code> ProductNotificationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Store </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> productReceiver </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProductNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProductNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.ordering.ProductNotificationSession getProductNotificationSessionForStore(org.osid.ordering.ProductReceiver productReceiver, 
                                                                                              org.osid.id.Id storeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving product to store mappings. 
     *
     *  @return a <code> ProductStoreSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsProductStore() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProductStore() </code> is <code> true. </code> 
     */

    public org.osid.ordering.ProductStoreSession getProductStoreSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning product to store mappings. 
     *
     *  @return a <code> ProductStoreAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProductStoreAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProductStoreAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.ordering.ProductStoreAssignmentSession gerProductStoreAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session associated with the product smart store for the given 
     *  store. 
     *
     *  @param  storeId the <code> Id </code> of the store 
     *  @return a <code> ProductSmartStoreSession </code> 
     *  @throws org.osid.NotFoundException <code> storeId </code> not found 
     *  @throws org.osid.NullArgumentException <code> storeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProductSmartStore() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProductSmartStore() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.ordering.ProductSmartStoreSession getProductSmartStoreSession(org.osid.id.Id storeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the price schedule 
     *  lookup service. 
     *
     *  @return a <code> PriceScheduleLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPriceScheduleLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPriceScheduleLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.ordering.PriceScheduleLookupSession getPriceScheduleLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the price schedule 
     *  lookup service for the given store. 
     *
     *  @param  storeId the <code> Id </code> of the <code> Store </code> 
     *  @return a <code> PriceScheduleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Store </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> storeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPriceScheduleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPriceScheduleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.ordering.PriceScheduleLookupSession getPriceScheduleLookupSessionForStore(org.osid.id.Id storeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the price schedule 
     *  query service. 
     *
     *  @return a <code> PriceScheduleQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPriceScheduleQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPriceScheduleQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.ordering.PriceScheduleQuerySession getPriceScheduleQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the price schedule 
     *  query service for the given store. 
     *
     *  @param  storeId the <code> Id </code> of the <code> Store </code> 
     *  @return a <code> PriceScheduleQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Store </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> storeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPriceScheduleQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPriceScheduleQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.ordering.PriceScheduleQuerySession getPriceScheduleQuerySessionForStore(org.osid.id.Id storeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the price schedule 
     *  search service. 
     *
     *  @return a <code> PriceScheduleSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPriceScheduleSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPriceScheduleSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.ordering.PriceScheduleSearchSession getPriceScheduleSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the price schedule 
     *  search service for the given store. 
     *
     *  @param  storeId the <code> Id </code> of the <code> Store </code> 
     *  @return a <code> PriceScheduleSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Store </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> storeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPriceScheduleSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPriceScheduleSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.ordering.PriceScheduleSearchSession getPriceScheduleSearchSessionForStore(org.osid.id.Id storeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the price schedule 
     *  administrative service. 
     *
     *  @return a <code> PriceScheduleAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPriceScheduleAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPriceScheduleAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.ordering.PriceScheduleAdminSession getPriceScheduleAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the price schedule 
     *  administrative service for the given store. 
     *
     *  @param  storeId the <code> Id </code> of the <code> Store </code> 
     *  @return a <code> PriceScheduleAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Store </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> storeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPriceScheduleAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPriceScheduleAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.ordering.PriceScheduleAdminSession getPriceScheduleAdminSessionForStore(org.osid.id.Id storeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the price schedule 
     *  notification service. 
     *
     *  @param  priceScheduleReceiver the receiver 
     *  @return a <code> PriceScheduleNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> priceScheduleReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPriceScheduleNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPriceScheduleNotification() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.ordering.PriceScheduleNotificationSession getPriceScheduleNotificationSession(org.osid.ordering.PriceScheduleReceiver priceScheduleReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the price schedule 
     *  notification service for the given store. 
     *
     *  @param  priceScheduleReceiver the receiver 
     *  @param  storeId the <code> Id </code> of the <code> Store </code> 
     *  @return a <code> PriceScheduleNotificationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Store </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> priceScheduleReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPriceScheduleNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPriceScheduleNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.ordering.PriceScheduleNotificationSession getPriceScheduleNotificationSessionForStore(org.osid.ordering.PriceScheduleReceiver priceScheduleReceiver, 
                                                                                                          org.osid.id.Id storeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving price schedule to store mappings. 
     *
     *  @return a <code> PriceScheduleStoreSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPriceScheduleStore() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPriceScheduleStore() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.ordering.PriceScheduleStoreSession getPriceScheduleStoreSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning price schedule to store mappings. 
     *
     *  @return a <code> PriceScheduleStoreAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPriceScheduleStoreAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPriceScheduleStoreAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.ordering.PriceScheduleStoreAssignmentSession getPriceScheduleStoreAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session associated with the price schedule smart store for 
     *  the given store. 
     *
     *  @param  storeId the <code> Id </code> of the store 
     *  @return a <code> PriceScheduleSmartStoreSession </code> 
     *  @throws org.osid.NotFoundException <code> storeId </code> not found 
     *  @throws org.osid.NullArgumentException <code> storeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPriceScheduleSmartStore() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPriceScheduleSmartStore() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.ordering.PriceScheduleSmartStoreSession getPriceScheduleSmartStoreSession(org.osid.id.Id storeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the store lookup 
     *  service. 
     *
     *  @return a <code> StoreLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsStoreLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStoreLookup() </code> is <code> true. </code> 
     */

    public org.osid.ordering.StoreLookupSession getStoreLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the store query 
     *  service. 
     *
     *  @return a <code> StoreQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsStoreQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStoreQuery() </code> is <code> true. </code> 
     */

    public org.osid.ordering.StoreQuerySession getStoreQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the store search 
     *  service. 
     *
     *  @return a <code> StoreSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsStoreSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStoreSearch() </code> is <code> true. </code> 
     */

    public org.osid.ordering.StoreSearchSession getStoreSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the store 
     *  administrative service. 
     *
     *  @return a <code> StoreAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsStoreAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStoreAdmin() </code> is <code> true. </code> 
     */

    public org.osid.ordering.StoreAdminSession getStoreAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the store 
     *  notification service. 
     *
     *  @param  storeReceiver the receiver 
     *  @return a <code> StoreNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> storeReceiver </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStoreNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStoreNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.ordering.StoreNotificationSession getStoreNotificationSession(org.osid.ordering.StoreReceiver storeReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the store 
     *  hierarchy service. 
     *
     *  @return a <code> StoreHierarchySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStoreHierarchy() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStoreHierarchy() </code> is <code> true. </code> 
     */

    public org.osid.ordering.StoreHierarchySession getStoreHierarchySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the store 
     *  hierarchy design service. 
     *
     *  @return a <code> StoreHierarchyDesignSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStoreHierarchyDesign() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStoreHierarchyDesign() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.ordering.StoreHierarchyDesignSession getStoreHierarchyDesignSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OrderingBatchManager. </code> 
     *
     *  @return an <code> OrderingBatchManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsOrderingBatch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOrderingBatch() </code> is <code> true. </code> 
     */

    public org.osid.ordering.batch.OrderingBatchManager getOrderingBatchManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OrderingRulesManager. </code> 
     *
     *  @return an <code> OrderingRulesManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsOrderingRules() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOrderingRules() </code> is <code> true. </code> 
     */

    public org.osid.ordering.rules.OrderingRulesManager getOrderingRulesManager()
        throws org.osid.OperationFailedException;
}
