//
// org.osid.ordering.OrderingProfile
//
//     The OSID Java specification for org.osid.ordering.OrderingProfile.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ordering;


/**
 *  <p>The ordering profile describes the interoperability among ordering 
 *  services. </p>
 */

public interface OrderingProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any item federation is exposed. Federation is exposed when a 
     *  specific item may be identified, selected and used to create a lookup 
     *  or admin session. Federation is not exposed when a set of items 
     *  appears as a single item. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests for the availability of a my order lookup service. 
     *
     *  @return <code> true </code> if my order lookup is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMyOrder();


    /**
     *  Tests for the availability of an order lookup service. 
     *
     *  @return <code> true </code> if order lookup is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOrderLookup();


    /**
     *  Tests if querying orders is available. 
     *
     *  @return <code> true </code> if order query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOrderQuery();


    /**
     *  Tests if searching for orders is available. 
     *
     *  @return <code> true </code> if order search is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOrderSearch();


    /**
     *  Tests if searching for orders is available. 
     *
     *  @return <code> true </code> if order search is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOrderAdmin();


    /**
     *  Tests if order notification is available. 
     *
     *  @return <code> true </code> if order notification is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOrderNotification();


    /**
     *  Tests if an order to store lookup session is available. 
     *
     *  @return <code> true </code> if order store lookup session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOrderStore();


    /**
     *  Tests if an order to store assignment session is available. 
     *
     *  @return <code> true </code> if order store assignment is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOrderStoreAssignment();


    /**
     *  Tests if an order smart store session is available. 
     *
     *  @return <code> true </code> if order smart store is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOrderSmartStore();


    /**
     *  Tests if an item admin session is available. 
     *
     *  @return <code> true </code> if an item admin session is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsItemAdmin();


    /**
     *  Tests for the availability of a product lookup service. 
     *
     *  @return <code> true </code> if product lookup is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProductLookup();


    /**
     *  Tests if querying products is available. 
     *
     *  @return <code> true </code> if product query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProductQuery();


    /**
     *  Tests if searching for products is available. 
     *
     *  @return <code> true </code> if product search is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProductSearch();


    /**
     *  Tests for the availability of a product administrative service for 
     *  creating and deleting products. 
     *
     *  @return <code> true </code> if product administration is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProductAdmin();


    /**
     *  Tests for the availability of a product notification service. 
     *
     *  @return <code> true </code> if product notification is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsProductNotification();


    /**
     *  Tests if a product to store lookup session is available. 
     *
     *  @return <code> true </code> if product store lookup session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProductStore();


    /**
     *  Tests if a product to store assignment session is available. 
     *
     *  @return <code> true </code> if product store assignment is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProductStoreAssignment();


    /**
     *  Tests if a product smart store session is available. 
     *
     *  @return <code> true </code> if product smart store is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProductSmartStore();


    /**
     *  Tests for the availability of a price schedule lookup service. 
     *
     *  @return <code> true </code> if price schedule lookup is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPriceScheduleLookup();


    /**
     *  Tests if querying price schedules is available. 
     *
     *  @return <code> true </code> if price schedule query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPriceScheduleQuery();


    /**
     *  Tests if searching for price schedules is available. 
     *
     *  @return <code> true </code> if price schedule search is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPriceScheduleSearch();


    /**
     *  Tests for the availability of a price schedule administrative service 
     *  for creating and deleting price schedules. 
     *
     *  @return <code> true </code> if price schedule administration is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPriceScheduleAdmin();


    /**
     *  Tests for the availability of a price schedule notification service. 
     *
     *  @return <code> true </code> if price schedule notification is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsPriceScheduleNotification();


    /**
     *  Tests if a price schedule to store lookup session is available. 
     *
     *  @return <code> true </code> if price schedule store lookup session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPriceScheduleStore();


    /**
     *  Tests if a price schedule to store assignment session is available. 
     *
     *  @return <code> true </code> if price schedule store assignment is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPriceScheduleStoreAssignment();


    /**
     *  Tests if a price schedule smart store session is available. 
     *
     *  @return <code> true </code> if price schedule smart store is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPriceScheduleSmartStore();


    /**
     *  Tests for the availability of an store lookup service. 
     *
     *  @return <code> true </code> if store lookup is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStoreLookup();


    /**
     *  Tests if querying stores is available. 
     *
     *  @return <code> true </code> if store query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStoreQuery();


    /**
     *  Tests if searching for stores is available. 
     *
     *  @return <code> true </code> if store search is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStoreSearch();


    /**
     *  Tests for the availability of a store administrative service for 
     *  creating and deleting stores. 
     *
     *  @return <code> true </code> if store administration is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStoreAdmin();


    /**
     *  Tests for the availability of a store notification service. 
     *
     *  @return <code> true </code> if store notification is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsStoreNotification();


    /**
     *  Tests for the availability of a store hierarchy traversal service. 
     *
     *  @return <code> true </code> if store hierarchy traversal is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStoreHierarchy();


    /**
     *  Tests for the availability of a store hierarchy design service. 
     *
     *  @return <code> true </code> if store hierarchy design is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsStoreHierarchyDesign();


    /**
     *  Tests for the availability of an ordering batch service. 
     *
     *  @return <code> true </code> if an ordering batch service is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOrderingBatch();


    /**
     *  Tests for the availability of an ordering rules service. 
     *
     *  @return <code> true </code> if an ordering rules service is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOrderingRules();


    /**
     *  Gets the supported <code> Order </code> record types. 
     *
     *  @return a list containing the supported order record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getOrderRecordTypes();


    /**
     *  Tests if the given <code> Order </code> record type is supported. 
     *
     *  @param  orderRecordType a <code> Type </code> indicating an <code> 
     *          Order </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> orderRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOrderRecordType(org.osid.type.Type orderRecordType);


    /**
     *  Gets the supported order search record types. 
     *
     *  @return a list containing the supported order search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getOrderSearchRecordTypes();


    /**
     *  Tests if the given order search record type is supported. 
     *
     *  @param  orderSearchRecordType a <code> Type </code> indicating an 
     *          order record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> orderSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOrderSearchRecordType(org.osid.type.Type orderSearchRecordType);


    /**
     *  Gets the supported <code> Item </code> record types. 
     *
     *  @return a list containing the supported item record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getItemRecordTypes();


    /**
     *  Tests if the given <code> Item </code> record type is supported. 
     *
     *  @param  itemRecordType a <code> Type </code> indicating a <code> Item 
     *          </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> itemRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsItemRecordType(org.osid.type.Type itemRecordType);


    /**
     *  Gets the supported item search record types. 
     *
     *  @return a list containing the supported item search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getItemSearchRecordTypes();


    /**
     *  Tests if the given item search record type is supported. 
     *
     *  @param  itemSearchRecordType a <code> Type </code> indicating an item 
     *          record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> itemSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsItemSearchRecordType(org.osid.type.Type itemSearchRecordType);


    /**
     *  Gets the supported <code> Product </code> record types. 
     *
     *  @return a list containing the supported product record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getProductRecordTypes();


    /**
     *  Tests if the given <code> Product </code> record type is supported. 
     *
     *  @param  productRecordType a <code> Type </code> indicating a <code> 
     *          Product </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> productRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProductRecordType(org.osid.type.Type productRecordType);


    /**
     *  Gets the supported product search record types. 
     *
     *  @return a list containing the supported product search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getProductSearchRecordTypes();


    /**
     *  Tests if the given product search record type is supported. 
     *
     *  @param  productSearchRecordType a <code> Type </code> indicating a 
     *          product record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> productSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProductSearchRecordType(org.osid.type.Type productSearchRecordType);


    /**
     *  Gets the supported <code> PriceSchedule </code> record types. 
     *
     *  @return a list containing the supported price schedule record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getPriceScheduleRecordTypes();


    /**
     *  Tests if the given <code> PriceSchedule </code> record type is 
     *  supported. 
     *
     *  @param  priceScheduleRecordType a <code> Type </code> indicating a 
     *          <code> PriceSchedule </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> priceScheduleRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPriceScheduleRecordType(org.osid.type.Type priceScheduleRecordType);


    /**
     *  Gets the supported price schedule search record types. 
     *
     *  @return a list containing the supported price schedule search record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getPriceScheduleSearchRecordTypes();


    /**
     *  Tests if the given price schedule search record type is supported. 
     *
     *  @param  priceScheduleSearchRecordType a <code> Type </code> indicating 
     *          a price schedule record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          priceScheduleSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPriceScheduleSearchRecordType(org.osid.type.Type priceScheduleSearchRecordType);


    /**
     *  Gets the supported <code> Price </code> record types. 
     *
     *  @return a list containing the supported price record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getPriceRecordTypes();


    /**
     *  Tests if the given <code> Price </code> record type is supported. 
     *
     *  @param  priceRecordType a <code> Type </code> indicating a <code> 
     *          Price </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> priceRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPriceRecordType(org.osid.type.Type priceRecordType);


    /**
     *  Gets the supported <code> Store </code> record types. 
     *
     *  @return a list containing the supported store record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getStoreRecordTypes();


    /**
     *  Tests if the given <code> Store </code> record type is supported. 
     *
     *  @param  storeRecordType a <code> Type </code> indicating a <code> 
     *          Store </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> storeRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStoreRecordType(org.osid.type.Type storeRecordType);


    /**
     *  Gets the supported store search record types. 
     *
     *  @return a list containing the supported store search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getStoreSearchRecordTypes();


    /**
     *  Tests if the given store search record type is supported. 
     *
     *  @param  storeSearchRecordType a <code> Type </code> indicating a store 
     *          record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> storeSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStoreSearchRecordType(org.osid.type.Type storeSearchRecordType);
}
