//
// org.osid.ordering.Price
//
//     The OSID Java specification for org.osid.ordering.Price.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ordering;


/**
 *  <p>A <code> Price. </code> </p>
 */

public interface Price
    extends org.osid.OsidRule,
            org.osid.Subjugateable {


    /**
     *  Gets the price schedule <code> Id </code> to which this price belongs. 
     *
     *  @return the price schedule <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPriceScheduleId();


    /**
     *  Gets the price schedule to which this price belongs. 
     *
     *  @return the price schedule 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.PriceSchedule getPriceSchedule()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this price is restricted by quantity. 
     *
     *  @return <code> true </code> if this price has a quantity range, <code> 
     *          false </code> if this price is the same for any quantity 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasQuantityRange();


    /**
     *  Gets the minium quantity for this price. 
     *
     *  @return the quantity 
     *  @throws org.osid.IllegalStateException <code> hasQuantityRange() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getMinimumQuantity();


    /**
     *  Gets the maximum quantity for this price. 
     *
     *  @return the quantity 
     *  @throws org.osid.IllegalStateException <code> hasQuantityRange() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getMaximumQuantity();


    /**
     *  Tests if this price is restricted by demographic. 
     *
     *  @return <code> true </code> if this price has a demographic, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasDemographic();


    /**
     *  Gets the resource <code> Id </code> representing the demographic. 
     *
     *  @return the resource <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> hasDemographic() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDemographicId();


    /**
     *  Gets the resource representing the demographic. 
     *
     *  @return the resource 
     *  @throws org.osid.IllegalStateException <code> hasDemographic() </code> 
     *          is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getDemographic()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the amount. 
     *
     *  @return the amount 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.Currency getAmount();


    /**
     *  Tests if this price has a recurring charge. 
     *
     *  @return <code> true </code> if this price is recurring, <code> false 
     *          </code> if one-time 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isRecurring();


    /**
     *  Gets the recurring interval. 
     *
     *  @return the interval 
     *  @throws org.osid.IllegalStateException <code> isRecurring() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Duration getRecurringInterval();


    /**
     *  Gets the price record corresponding to the given <code> Product 
     *  </code> record <code> Type. </code> This method is used to retrieve an 
     *  object implementing the requested record. The <code> priceRecordType 
     *  </code> may be the <code> Type </code> returned in <code> 
     *  getRecordTypes() </code> or any of its parents in a <code> Type 
     *  </code> hierarchy where <code> hasRecordType(priceRecordType) </code> 
     *  is <code> true </code> . 
     *
     *  @param  priceRecordType the type of price record to retrieve 
     *  @return the price record 
     *  @throws org.osid.NullArgumentException <code> priceRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(priceRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.records.PriceRecord getPriceRecord(org.osid.type.Type priceRecordType)
        throws org.osid.OperationFailedException;
}
