//
// org.osid.ordering.PriceQuery
//
//     The OSID Java specification for org.osid.ordering.PriceQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ordering;


/**
 *  <p>This is the query for searching for prices. Each method specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface PriceQuery
    extends org.osid.OsidRuleQuery,
            org.osid.OsidSubjugateableQuery {


    /**
     *  Sets the price schedule <code> Id </code> for this query. 
     *
     *  @param  priceScheduleId a price schedule <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> priceScheduleId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchPriceScheduleId(org.osid.id.Id priceScheduleId, 
                                     boolean match);


    /**
     *  Clears the price schedule <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPriceScheduleIdTerms();


    /**
     *  Tests if a price schedule query is available. 
     *
     *  @return <code> true </code> if a price schedule query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPriceScheduleQuery();


    /**
     *  Gets the query for a price schedule. 
     *
     *  @return the price schedule query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPriceScheduleQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPriceScheduleQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.ordering.PriceScheduleQuery getPriceScheduleQuery();


    /**
     *  Clears the price schedule terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPriceScheduleTerms();


    /**
     *  Matches the minimum quantity between the given range inclusive. 
     *
     *  @param  low start of range 
     *  @param  high end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> low </code> is 
     *          greater than <code> high </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMinimumQuantity(long low, long high, boolean match);


    /**
     *  Clears the minimum quantity terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMinimumQuantityTerms();


    /**
     *  Matches the maximum quantity between the given range inclusive. 
     *
     *  @param  low start of range 
     *  @param  high end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> low </code> is 
     *          greater than <code> high </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMaximumQuantity(long low, long high, boolean match);


    /**
     *  Clears the maximum quantity terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMaximumQuantityTerms();


    /**
     *  Sets the resource <code> Id </code> for this query. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> resource </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDemographicId(org.osid.id.Id resourceId, boolean match);


    /**
     *  Clears the resource <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDemographicIdTerms();


    /**
     *  Tests if a resource query is available. 
     *
     *  @return <code> true </code> if a resource query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDemographicQuery();


    /**
     *  Gets the query for a resource. 
     *
     *  @return the resource query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDemographicQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDemographicQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceQuery getDemographicQuery();


    /**
     *  Matches prices with any demographic. 
     *
     *  @param  match <code> true </code> to match prices with any 
     *          demographic, <code> false </code> to match prices with no 
     *          orders 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDemographic(boolean match);


    /**
     *  Clears the resource terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDemographicTerms();


    /**
     *  Matches the amount between the given range inclusive. 
     *
     *  @param  low start of range 
     *  @param  high end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> low </code> is 
     *          greater than <code> high </code> 
     *  @throws org.osid.NullArgumentException <code> low </code> or <code> 
     *          high </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAmount(org.osid.financials.Currency low, 
                            org.osid.financials.Currency high, boolean match);


    /**
     *  Matches items that have any amount set. 
     *
     *  @param  match <code> true </code> to match items with any amount, 
     *          <code> false </code> to match items with no amount 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAmount(boolean match);


    /**
     *  Clears the amount terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAmountTerms();


    /**
     *  Matches the a minimum price amount. 
     *
     *  @param  amount an amount 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMinimumAmount(org.osid.financials.Currency amount, 
                                   boolean match);


    /**
     *  Clears the minimum amount terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMinimumAmountTerms();


    /**
     *  Matches the recurring interval between the given duration range 
     *  inclusive. 
     *
     *  @param  low start of range 
     *  @param  high end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> low </code> is 
     *          greater than <code> high </code> 
     *  @throws org.osid.NullArgumentException <code> low </code> or <code> 
     *          high </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRecurringInterval(org.osid.calendaring.Duration low, 
                                       org.osid.calendaring.Duration high, 
                                       boolean match);


    /**
     *  Matches prices with any recurring interval. 
     *
     *  @param  match <code> true </code> to match prices with any recurring 
     *          interval, <code> false </code> to match one-time prices 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRecurringInterval(boolean match);


    /**
     *  Clears the recurring interval terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRecurringIntervalTerms();


    /**
     *  Sets the item <code> Id </code> for this query. 
     *
     *  @param  itemId an item <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> priceScheduleId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchItemId(org.osid.id.Id itemId, boolean match);


    /**
     *  Clears the item <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearItemIdTerms();


    /**
     *  Tests if an item query is available. 
     *
     *  @return <code> true </code> if an item query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsItemQuery();


    /**
     *  Gets the query for an item. 
     *
     *  @return the item query 
     *  @throws org.osid.UnimplementedException <code> supportsItemQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsItemQuery() </code> is <code> true. </code> 
     */

    public org.osid.ordering.ItemQuery getItemQuery();


    /**
     *  Matches prices used with any item. 
     *
     *  @param  match <code> true </code> to match prices with any order, 
     *          <code> false </code> to match prices with no orders 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyItem(boolean match);


    /**
     *  Clears the item terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearItemTerms();


    /**
     *  Sets the price <code> Id </code> for this query to match orders 
     *  assigned to stores. 
     *
     *  @param  storeId a store <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> storeId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchStoreId(org.osid.id.Id storeId, boolean match);


    /**
     *  Clears the store <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStoreIdTerms();


    /**
     *  Tests if a <code> StoreQuery </code> is available. 
     *
     *  @return <code> true </code> if a store query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStoreQuery();


    /**
     *  Gets the query for a store query. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the store query 
     *  @throws org.osid.UnimplementedException <code> supportsStoreQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStoreQuery() </code> is <code> true. </code> 
     */

    public org.osid.ordering.StoreQuery getStoreQuery();


    /**
     *  Clears the store terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStoreTerms();


    /**
     *  Gets the price query record corresponding to the given <code> Price 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested boolean <code> OR </code> term. 
     *
     *  @param  priceRecordType an price record type 
     *  @return the price query record 
     *  @throws org.osid.NullArgumentException <code> priceRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(priceRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.records.PriceQueryRecord getPriceQueryRecord(org.osid.type.Type priceRecordType)
        throws org.osid.OperationFailedException;
}
