//
// org.osid.ordering.PriceScheduleLookupSession
//
//     The OSID Java specification for org.osid.ordering.PriceScheduleLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ordering;


/**
 *  <p>This session provides methods for retrieving <code> PriceSchedule 
 *  </code> objects. The <code> PriceSchedule </code> represents a collection 
 *  of prices. </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated store view: All order methods in this session operate, 
 *      retrieve and pertain to price schedules defined explicitly in the 
 *      current store. Using an isolated view is useful for managing price 
 *      schedules with the <code> PriceScheduleAdminSession. </code> </li> 
 *      <li> federated store view: All priice schedule lookup methods in this 
 *      session operate, retrieve and pertain to all price schedules defined 
 *      in this store and any other stores implicitly available in this store 
 *      through store inheritence. </li> 
 *  </ul>
 *  
 */

public interface PriceScheduleLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Store </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Store Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getStoreId();


    /**
     *  Gets the <code> Store </code> associated with this session. 
     *
     *  @return the store 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.Store getStore()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Price </code> lookups. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not offer lookup operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupPriceSchedules();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativePriceScheduleView();


    /**
     *  A complete view of the <code> PriceSchedule </code> returns is 
     *  desired. Methods will return what is requested or result in an error. 
     *  This view is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryPriceScheduleView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include price schedules in stores which are children of this store in 
     *  the store hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedStoreView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this store only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedStoreView();


    /**
     *  Gets the <code> PriceSchedule </code> specified by its <code> Id. 
     *  </code> In plenary mode, the exact <code> Id </code> is found or a 
     *  <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  PriceSchedule </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> PriceSchedule </code> and retained for 
     *  compatibility. 
     *
     *  @param  priceScheduleId <code> Id </code> of the <code> PriceSchedule 
     *          </code> 
     *  @return the price schedule 
     *  @throws org.osid.NotFoundException <code> priceScheduleId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> priceScheduleId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.ordering.PriceSchedule getPriceSchedule(org.osid.id.Id priceScheduleId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> PriceSchedule </code> by a <code> Price </code> <code> 
     *  Id. </code> 
     *
     *  @param  priceId <code> Id </code> of a <code> Price </code> 
     *  @return the price schedule 
     *  @throws org.osid.NotFoundException <code> priceId </code> not found 
     *  @throws org.osid.NullArgumentException <code> priceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.ordering.PriceSchedule getPriceScheduleByPrice(org.osid.id.Id priceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PriceScheduleList </code> corresponding to the given 
     *  <code> IdList. </code> In plenary mode, the returned list contains all 
     *  of the price schedules specified in the <code> Id </code> list, in the 
     *  order of the list, including duplicates, or an error results if an 
     *  <code> Id </code> in the supplied list is not found or inaccessible. 
     *  Otherwise, inaccessible <code> PriceSchedules </code> may be omitted 
     *  from the list and may present the elements in any order including 
     *  returning a unique set. 
     *
     *  @param  priceScheduleIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> PriceSchedule </code> list 
     *  @throws org.osid.NotFoundException an <code> Id </code> was not found 
     *  @throws org.osid.NullArgumentException <code> priceScheduleIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.PriceScheduleList getPriceSchedulesByIds(org.osid.id.IdList priceScheduleIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PriceScheduleList </code> corresponding to the given 
     *  price schedule genus <code> Type </code> which does not include price 
     *  schedules of genus types derived from the specified <code> Type. 
     *  </code> In plenary mode, the returned list contains all known price 
     *  schedules or an error results. Otherwise, the returned list may 
     *  contain only those price schedules that are accessible through this 
     *  session. 
     *
     *  @param  priceScheduleGenusType a price schedule genus type 
     *  @return the returned <code> PriceSchedule </code> list 
     *  @throws org.osid.NullArgumentException <code> priceScheduleGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.PriceScheduleList getPriceSchedulesByGenusType(org.osid.type.Type priceScheduleGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PriceScheduleList </code> corresponding to the given 
     *  price schedule genus <code> Type </code> and include any additional 
     *  price schedules with genus types derived from the specified <code> 
     *  Type. </code> In plenary mode, the returned list contains all known 
     *  price schedules or an error results. Otherwise, the returned list may 
     *  contain only those price schedules that are accessible through this 
     *  session. 
     *
     *  @param  priceScheduleGenusType a price schedule genus type 
     *  @return the returned <code> PriceSchedule </code> list 
     *  @throws org.osid.NullArgumentException <code> priceScheduleGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.PriceScheduleList getPriceSchedulesByParentGenusType(org.osid.type.Type priceScheduleGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PriceScheduleList </code> containing the given 
     *  repository record <code> Type. </code> In plenary mode, the returned 
     *  list contains all known price schedules or an error results. 
     *  Otherwise, the returned list may contain only those price schedules 
     *  that are accessible through this session. 
     *
     *  @param  priceScheduleRecordType a price schedule record type 
     *  @return the returned <code> PriceSchedule </code> list 
     *  @throws org.osid.NullArgumentException <code> priceScheduleRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.PriceScheduleList getPriceSchedulesByRecordType(org.osid.type.Type priceScheduleRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> PriceSchedules. </code> In plenary mode, the returned 
     *  list contains all known price schedules or an error results. 
     *  Otherwise, the returned list may contain only those price schedules 
     *  that are accessible through this session. 
     *
     *  @return a list of <code> PriceSchedules </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.PriceScheduleList getPriceSchedules()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
