//
// org.osid.ordering.PriceScheduleNotificationSession
//
//     The OSID Java specification for org.osid.ordering.PriceScheduleNotificationSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ordering;


/**
 *  <p>This session defines methods to receive notifications on adds/changes 
 *  to <code> PriceSchedule </code> objects. This session is intended for 
 *  consumers needing to synchronize their state with this service without the 
 *  use of polling. Notifications are cancelled when this session is closed. 
 *  </p> 
 *  
 *  <p> Notifications are triggered with changes to the <code> PriceSchedule 
 *  </code> object itself. Adding and removing orders result in notifications 
 *  available from the notification session for orders. </p>
 */

public interface PriceScheduleNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Store </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Store Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getStoreId();


    /**
     *  Gets the <code> Store </code> associated with this session. 
     *
     *  @return the store 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.Store getStore()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can register for <code> PriceSchedule </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForPriceScheduleNotifications();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include price schedules in stores which are children of this store in 
     *  the store hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedStoreView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts searches to this store only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedStoreView();


    /**
     *  Register for notifications of new prices. <code> 
     *  PriceScheduleReceiver.newPriceSchedules() </code> is invoked when a 
     *  new <code> PriceSchedule </code> is created. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewPriceSchedules()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated price schedules. <code> 
     *  PriceScheduleReceiver.changedPriceSchedules() </code> is invoked when 
     *  a price schedule is changed or prices are changed within it. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedPriceSchedules()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated price schedule. <code> 
     *  PriceScheduleReceiver.changedPriceSchedules() </code> is invoked when 
     *  the specified price schedule is changed or prices are changed within 
     *  it. 
     *
     *  @param  priceScheduleId the <code> Id </code> of the <code> 
     *          PriceSchedule </code> to monitor 
     *  @throws org.osid.NotFoundException a price schedule was not found 
     *          identified by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> priceScheduleId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedPriceSchedule(org.osid.id.Id priceScheduleId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted price schedules. <code> 
     *  PriceScheduleReceiver.deletedPriceSchedules() </code> is invoked when 
     *  a price schedule is deleted. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedPriceSchedules()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted price schedule. <code> 
     *  PriceScheduleReceiver.deletedPriceSchedules() </code> is invoked when 
     *  the specified price schedule is deleted. 
     *
     *  @param  priceScheduleId the <code> Id </code> of the <code> 
     *          PriceSchedule </code> to monitor 
     *  @throws org.osid.NotFoundException s price schedule was not found 
     *          identified by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> priceScheduleId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedPriceSchedule(org.osid.id.Id priceScheduleId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
