//
// org.osid.ordering.PriceSearchOrder
//
//     The OSID Java specification for org.osid.ordering.PriceSearchOrder.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ordering;


/**
 *  <p>An interface for specifying the ordering of search results. </p>
 */

public interface PriceSearchOrder
    extends org.osid.OsidRuleSearchOrder,
            org.osid.OsidSubjugateableSearchOrder {


    /**
     *  Specifies a preference for ordering the result set by the price 
     *  schedule. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByPriceSchedule(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a price schedule order is available. 
     *
     *  @return <code> true </code> if a price schedule order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPriceScheduleSearchOrder();


    /**
     *  Gets the price schedule order. 
     *
     *  @return the price schedule search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPriceScheduleSearchOrder() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPriceScheduleSearchOrder() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.ordering.PriceScheduleSearchOrder getPriceScheduleSearchOrder();


    /**
     *  Specifies a preference for ordering the result set by the minimum 
     *  quantity. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByMinimumQuantity(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the maximum 
     *  quanttity. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByMaximumQuantity(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the demographic. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByDemographic(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a resource search order is available. 
     *
     *  @return <code> true </code> if a demographic order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDemographicSearchOrder();


    /**
     *  Gets the resource order. 
     *
     *  @return the resource search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDemographicSearchOrder() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDemographicSearchOrder() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resource.ResourceSearchOrder getDemographicSearchOrder();


    /**
     *  Specifies a preference for ordering the result set by the amount. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByAmount(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the recurring 
     *  interval. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByRecurringInterval(org.osid.SearchOrderStyle style);


    /**
     *  Gets the price search order record corresponding to the given price 
     *  record Type. Multiple retrievals return the same underlying object. 
     *
     *  @param  priceRecordType a price record type 
     *  @return the price search order record 
     *  @throws org.osid.NullArgumentException <code> priceRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(priceRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.records.PriceSearchOrderRecord getPriceSearchOrderRecord(org.osid.type.Type priceRecordType)
        throws org.osid.OperationFailedException;
}
