//
// org.osid.ordering.batch.PriceScheduleBatchAdminSession
//
//     The OSID Java specification for org.osid.ordering.batch.PriceScheduleBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ordering.batch;


/**
 *  <p>This session creates, updates, and deletes <code> PriceSchedules 
 *  </code> in bulk. The data for create and update is provided by the 
 *  consumer via the form object. <code> OsidForms </code> are requested for 
 *  each create or update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  PriceSchedule, </code> a <code> PriceScheduleForm </code> is requested 
 *  using <code> getPriceScheduleFormsForCreate() </code> specifying the 
 *  desired record <code> Types </code> or none if no record <code> Types 
 *  </code> are needed. Each of the returned <code> PriceScheduleForms </code> 
 *  will indicate that it is to be used with a create operation and can be 
 *  used to examine metdata or validate data prior to creation. Once a <code> 
 *  PriceScheduleForm </code> is submiited to a create operation, it cannot be 
 *  reused with another create operation unless the first operation was 
 *  unsuccessful. Each <code> PriceScheduleForm </code> corresponds to an 
 *  attempted transaction. </p> 
 *  
 *  <p> The <code> PriceScheduleForms </code> returned from <code> 
 *  getPriceScheduleFormsForCreate() </code> may be linked to the originating 
 *  request through the peer <code> Ids </code> of the <code> 
 *  PriceScheduleForm. </code> In the case where there may be duplicates, any 
 *  <code> PriceScheduleForm </code> of the same peer <code> Ids </code> may 
 *  be used for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> PriceScheduleForms </code> are submitted for 
 *  create, a <code> CreateResponse </code> is returned for each <code> 
 *  PriceScheduleForm, </code> although the ordering is not defined. Only 
 *  errors that pertain to the entire create operation are returned from 
 *  <code> createPriceSchedules(), </code> errors specific to an individual 
 *  <code> PriceScheduleForm </code> are indicated in the corresponding <code> 
 *  CreateResponse. </code> <code> CreateResponses </code> may be linked to 
 *  the originating <code> PriceScheduleForm </code> through the <code> 
 *  PriceScheduleForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> PriceScheduleForms </code> are requested to the 
 *  <code> PriceSchedule </code> <code> Id </code> that is to be updated using 
 *  <code> getPriceScheduleFormsForUpdate() </code> where the reference <code> 
 *  Id </code> in the <code> PriceScheduleForm </code> may be used to link the 
 *  request. Similarly, the <code> PriceScheduleForm </code> has metadata 
 *  about the data that can be updated and it can perform validation before 
 *  submitting the update. The <code> PriceScheduleForm </code> can only be 
 *  used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> PriceScheduleForms </code> are submitted for 
 *  update, an <code> UpdateResponse </code> is returned for each <code> 
 *  PriceScheduleForm, </code> although the ordering is not defined. Only 
 *  errors that pertain to the entire update operation are returned from 
 *  <code> updatePriceSchedules(), </code> errors specific to an individual 
 *  <code> PriceScheduleForm </code> are indicated in the corresponding <code> 
 *  UpdateResponse. </code> <code> UpdateResponses </code> may be linked to 
 *  the originating <code> PriceScheduleForm </code> through the <code> 
 *  PriceScheduleForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> PriceSchedules </code> in bulk. To 
 *  unmap a <code> PriceSchedule </code> from the current <code> Store, 
 *  </code> the <code> PriceScheduleStoreAssignmentSession </code> should be 
 *  used. These delete operations attempt to remove the <code> PriceSchedule 
 *  </code> itself thus removing it from all known <code> Store </code> 
 *  catalogs. Bulk delete operations return the results in <code> 
 *  DeleteResponses. </code> </p>
 */

public interface PriceScheduleBatchAdminSession
    extends org.osid.ordering.PriceScheduleAdminSession {


    /**
     *  Gets the price schedule forms for creating a bunch of new price 
     *  schedules. 
     *
     *  @param  number the number of forms to retrieve 
     *  @param  priceScheduleRecordTypes array of price schedule record types 
     *          to be included in each create operation or an empty list if 
     *          none 
     *  @return the price schedule forms 
     *  @throws org.osid.NullArgumentException <code> priceScheduleRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.batch.PriceScheduleBatchFormList getPriceScheduleFormsForCreate(long number, 
                                                                                             org.osid.type.Type[] priceScheduleRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> PriceSchedules. </code> This method 
     *  returns an error if the entire operation fails. Otherwise, the status 
     *  of an individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  priceScheduleForms the price schedule forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> priceScheduleForms 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createPriceSchedules(org.osid.ordering.batch.PriceScheduleBatchFormList priceScheduleForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the price schedule forms for updating an existing set of price 
     *  schedules. A new price schedule form should be requested for each 
     *  update transaction. 
     *
     *  @param  priceScheduleIds the <code> Ids </code> of the <code> 
     *          PriceSchedules </code> 
     *  @return the price schedule form 
     *  @throws org.osid.NotFoundException a <code> priceScheduleId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> priceScheduleIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.batch.PriceScheduleBatchFormList getPriceScheduleFormsForUpdate(org.osid.id.IdList priceScheduleIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing price schedules. This method returns an error if the 
     *  entire operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  priceScheduleForms the form containing the elements to be 
     *          updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> priceScheduleForms 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updatePriceSchedules(org.osid.ordering.batch.PriceScheduleBatchFormList priceScheduleForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> PriceSchedules </code> in this <code> Store </code> 
     *  . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllPriceSchedules()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes price schedules for the given <code> Ids. </code> 
     *
     *  @param  priceScheduleIds the <code> Ids </code> of the price schedules 
     *          to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> priceScheduleIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deletePriceSchedules(org.osid.id.IdList priceScheduleIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> PriceSchedule </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> PriceSchedule </code> is determined by the provider. The 
     *  new <code> Id </code> is an alias to the primary <code> Id. </code> If 
     *  the alias is a pointer to another price schedule, it is reassigned to 
     *  the given price schedule <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasPriceSchedules(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the price forms for creating a bunch of new prices. A form is 
     *  returned for each supplied price schedule. 
     *
     *  @param  priceScheduleIds a list of price schedule <code> Ids </code> 
     *  @param  priceScheduleRecordTypes array of price schedule record types 
     *          to be included in each create operation or an empty list if 
     *          none 
     *  @return the price schedule forms 
     *  @throws org.osid.NotFoundException a <code> priceScheduleId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> priceScheduleId </code> 
     *          or <code> priceScheduleRecordTypes </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.batch.PriceBatchFormList getPriceFormsForCreate(org.osid.id.IdList priceScheduleIds, 
                                                                             org.osid.type.Type[] priceScheduleRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Prices. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  priceForms the price forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> priceForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createPrices(org.osid.ordering.batch.PriceBatchFormList priceForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the price forms for updating an existing set of prices. A new 
     *  price form should be requested for each update transaction. 
     *
     *  @param  priceIds the <code> Ids </code> of the <code> Prices </code> 
     *  @return the price forms 
     *  @throws org.osid.NotFoundException a <code> priceId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> priceIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.batch.PriceBatchFormList getPriceFormsForUpdate(org.osid.id.IdList priceIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing prices. This method returns an error if the entire 
     *  operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  priceForms the forms containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> priceForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updatePrices(org.osid.ordering.batch.PriceBatchFormList priceForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Prices </code> in this <code> Store </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllPrices()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes prices for the given <code> Ids. </code> 
     *
     *  @param  priceIds the <code> Ids </code> of the price to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> priceIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deletePrices(org.osid.id.IdList priceIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes prices for the given price schedule. 
     *
     *  @param  priceScheduleId the <code> Id </code> ofa price schedule 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> priceScheduleId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deletePricesForPriceSchedule(org.osid.id.Id priceScheduleId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Price </code> for the purpose of 
     *  creating compatibility. The primary <code> Id </code> of the <code> 
     *  Price </code> is determined by the provider. The new <code> Id </code> 
     *  is an alias to the primary <code> Id. </code> If the alias is a 
     *  pointer to another price, it is reassigned to the given price <code> 
     *  Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasPrices(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
