//
// org.osid.ordering.rules.OrderingRulesProxyManager
//
//     The OSID Java specification for org.osid.ordering.rules.OrderingRulesProxyManager.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ordering.rules;


/**
 *  <p>The ordering rules proxy manager provides access to ordering rules 
 *  sessions and provides interoperability tests for various aspects of this 
 *  service. Methods in this manager pass a <code> Proxy </code> for passing 
 *  information from server environments. The sessions included in this 
 *  manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> PriceEnablerLookupSession: </code> a session to retrieve 
 *      price enablers </li> 
 *      <li> <code> PriceEnablerQuerySession: </code> a session to query for 
 *      price enablers </li> 
 *      <li> <code> PriceEnablerSearchSession: </code> a session to search for 
 *      price enablers </li> 
 *      <li> <code> PriceEnablerAdminSession: </code> a session to create and 
 *      delete price enablers </li> 
 *      <li> <code> PriceEnablerNotificationSession: </code> a session to 
 *      receive notifications pertaining to price enabler changes </li> 
 *      <li> <code> PriceEnablerStoreSession: </code> a session to look up 
 *      price enabler store mappings </li> 
 *      <li> <code> PriceEnablerStoreAssignmentSession: </code> a session to 
 *      manage price enabler to store mappings </li> 
 *      <li> <code> PriceEnablerSmartStoreSession: </code> a session to manage 
 *      dynamic stores of price enablers </li> 
 *      <li> <code> PriceEnablerPriceRuleLookupSession: </code> a session to 
 *      look up price enabler to price mappings </li> 
 *      <li> <code> PriceEnablerPriceRuleApplicationSession: </code> a session 
 *      to apply price enablers to prices </li> 
 *  </ul>
 *  
 */

public interface OrderingRulesProxyManager
    extends org.osid.OsidProxyManager,
            org.osid.ordering.rules.OrderingRulesProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the price enabler 
     *  lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PriceEnablerLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPriceEnablerLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPriceEnablerLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.ordering.rules.PriceEnablerLookupSession getPriceEnablerLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the price enabler 
     *  lookup service for the given store. 
     *
     *  @param  storeId the <code> Id </code> of the <code> Store </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PriceEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Store </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> storeId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPriceEnablerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPriceEnablerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.ordering.rules.PriceEnablerLookupSession getPriceEnablerLookupSessionForStore(org.osid.id.Id storeId, 
                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the price enabler 
     *  query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PriceEnablerQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPriceEnablerQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPriceEnablerQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.ordering.rules.PriceEnablerQuerySession getPriceEnablerQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the price enabler 
     *  query service for the given store. 
     *
     *  @param  storeId the <code> Id </code> of the <code> Store </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PriceEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Store </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> storeId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPriceEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPriceEnablerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.ordering.rules.PriceEnablerQuerySession getPriceEnablerQuerySessionForStore(org.osid.id.Id storeId, 
                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the price enabler 
     *  search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PriceEnablerSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPriceEnablerSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPriceEnablerSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.ordering.rules.PriceEnablerSearchSession getPriceEnablerSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the price enablers 
     *  earch service for the given store. 
     *
     *  @param  storeId the <code> Id </code> of the <code> Store </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PriceEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Store </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> storeId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPriceEnablerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPriceEnablerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.ordering.rules.PriceEnablerSearchSession getPriceEnablerSearchSessionForStore(org.osid.id.Id storeId, 
                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the price enabler 
     *  administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PriceEnablerAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPriceEnablerAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPriceEnablerAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.ordering.rules.PriceEnablerAdminSession getPriceEnablerAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the price enabler 
     *  administration service for the given store. 
     *
     *  @param  storeId the <code> Id </code> of the <code> Store </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PriceEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Store </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> storeId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPriceEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPriceEnablerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.ordering.rules.PriceEnablerAdminSession getPriceEnablerAdminSessionForStore(org.osid.id.Id storeId, 
                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the price enabler 
     *  notification service. 
     *
     *  @param  priceEnablerReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> PriceEnablerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> priceEnablerReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPriceEnablerNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPriceEnablerNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.ordering.rules.PriceEnablerNotificationSession getPriceEnablerNotificationSession(org.osid.ordering.rules.PriceEnablerReceiver priceEnablerReceiver, 
                                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the price enabler 
     *  notification service for the given store. 
     *
     *  @param  priceEnablerReceiver the notification callback 
     *  @param  storeId the <code> Id </code> of the <code> Store </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PriceEnablerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no store found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> priceEnablerReceiver, 
     *          storeId </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPriceEnablerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPriceEnablerNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.ordering.rules.PriceEnablerNotificationSession getPriceEnablerNotificationSessionForStore(org.osid.ordering.rules.PriceEnablerReceiver priceEnablerReceiver, 
                                                                                                              org.osid.id.Id storeId, 
                                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup price enabler/store 
     *  mappings for price enablers. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PriceEnablerStoreSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPriceEnablerStore() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPriceEnablerStore() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.ordering.rules.PriceEnablerStoreSession getPriceEnablerStoreSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning price 
     *  enablers to stores for price. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PriceEnablerStoreAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPriceEnablerStoreAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPriceEnablerStoreAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.ordering.rules.PriceEnablerStoreAssignmentSession getPriceEnablerStoreAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage price enabler smart 
     *  stores. 
     *
     *  @param  storeId the <code> Id </code> of the <code> Store </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PriceEnablerSmartStoreSession </code> 
     *  @throws org.osid.NotFoundException no <code> Store </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> storeId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPriceEnablerSmartStore() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPriceEnablerSmartStore() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.ordering.rules.PriceEnablerSmartStoreSession getPriceEnablerSmartStoreSession(org.osid.id.Id storeId, 
                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the price enabler 
     *  price mapping lookup service for looking up the rules applied to the 
     *  store. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PriceEnablerRuleLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPriceEnablerPriceRuleLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPriceEnablerPriceRuleLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.ordering.rules.PriceEnablerRuleLookupSession getPriceEnablerRuleLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the price enabler 
     *  price mapping lookup service for the given store for looking up rules 
     *  applied to an store. 
     *
     *  @param  storeId the <code> Id </code> of the <code> Store </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PriceEnablerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Store </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> storeId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPriceEnablerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPriceEnablerRuleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.ordering.rules.PriceEnablerRuleLookupSession getPriceEnablerRuleLookupSessionForStore(org.osid.id.Id storeId, 
                                                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the price enabler 
     *  price assignment service to apply enablers to stores. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PriceEnablerPricApplicationSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPriceEnablerRuleApplication() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPriceEnablerRuleApplication() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.ordering.rules.PriceEnablerRuleApplicationSession getPriceEnablerRuleApplicationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the price enabler 
     *  price assignment service for the given store to apply enablers to 
     *  stores. 
     *
     *  @param  storeId the <code> Id </code> of the <code> Store </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PriceEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Store </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> storeId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPriceEnablerRuleApplication() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPriceEnablerRuleApplication() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.ordering.rules.PriceEnablerRuleApplicationSession getPriceEnablerRuleApplicationSessionForStore(org.osid.id.Id storeId, 
                                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;
}
