//
// org.osid.ordering.rules.PriceEnablerLookupSession
//
//     The OSID Java specification for org.osid.ordering.rules.PriceEnablerLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ordering.rules;


/**
 *  <p>This session provides methods for retrieving <code> PriceEnablers. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated store view: All price enabler methods in this session 
 *      operate, retrieve and pertain to price enablers defined explicitly in 
 *      the current store. Using an isolated view is useful for managing 
 *      <code> PriceEnablers </code> with the <code> PriceEnablerAdminSession. 
 *      </code> </li> 
 *      <li> federated store view: All price enabler methods in this session 
 *      operate, retrieve and pertain to all price enablers defined in this 
 *      store and any other price enablers implicitly available in this store 
 *      through store inheritence. </li> 
 *      <li> active price enabler view: All price enabler lookup methods 
 *      return active price enablers </li> 
 *      <li> any status price enabler view: price enablers of anyactive or 
 *      inactive status are returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedDistributorView() </code> and <code> 
 *  useIsolatedDistributorView() </code> behave as a radio group and one 
 *  should be selected before invoking the methods in this session. </p>
 */

public interface PriceEnablerLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Store </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Store Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getStoreId();


    /**
     *  Gets the <code> Store </code> associated with this session. 
     *
     *  @return the store 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.Store getStore()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> PriceEnablers </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupPriceEnablers();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativePriceEnablerView();


    /**
     *  A complete view of the <code> PriceEnabler </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryPriceEnablerView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include price enablers in stores which are children of this store in 
     *  the store hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedStoreView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this store only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedStoreView();


    /**
     *  Only active price enablers are returned by methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActivePriceEnablerView();


    /**
     *  All price enablers of any active or inactive status are returned by 
     *  methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusPriceEnablerView();


    /**
     *  Gets the <code> PriceEnabler </code> specified by its <code> Id. 
     *  </code> In plenary mode, the exact <code> Id </code> is found or a 
     *  <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  PriceEnabler </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> PriceEnabler </code> and retained for 
     *  compatibility. 
     *
     *  @param  priceEnablerId <code> Id </code> of the <code> PriceEnabler 
     *          </code> 
     *  @return the price enabler 
     *  @throws org.osid.NotFoundException <code> priceEnablerId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> priceEnablerId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.ordering.rules.PriceEnabler getPriceEnabler(org.osid.id.Id priceEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PriceEnablerList </code> corresponding to the given 
     *  <code> IdList. </code> In plenary mode, the returned list contains all 
     *  of the price enablers specified in the <code> Id </code> list, in the 
     *  order of the list, including duplicates, or an error results if an 
     *  <code> Id </code> in the supplied list is not found or inaccessible. 
     *  Otherwise, inaccessible <code> PriceEnablers </code> may be omitted 
     *  from the list and may present the elements in any order including 
     *  returning a unique set. 
     *
     *  @param  priceEnablerIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> PriceEnabler </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> priceEnablerIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.rules.PriceEnablerList getPriceEnablersByIds(org.osid.id.IdList priceEnablerIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PriceEnablerList </code> corresponding to the given 
     *  price enabler genus <code> Type </code> which does not include price 
     *  enablers of genus types derived from the specified <code> Type. 
     *  </code> In plenary mode, the returned list contains all known price 
     *  enablers or an error results. Otherwise, the returned list may contain 
     *  only those price enablers that are accessible through this session. 
     *
     *  @param  priceEnablerGenusType a price enabler genus type 
     *  @return the returned <code> PriceEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> priceEnablerGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.rules.PriceEnablerList getPriceEnablersByGenusType(org.osid.type.Type priceEnablerGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PriceEnablerList </code> corresponding to the given 
     *  price enabler genus <code> Type </code> and include any additional 
     *  price enablers with genus types derived from the specified <code> 
     *  Type. </code> In plenary mode, the returned list contains all known 
     *  price enablers or an error results. Otherwise, the returned list may 
     *  contain only those price enablers that are accessible through this 
     *  session. 
     *
     *  @param  priceEnablerGenusType a price enabler genus type 
     *  @return the returned <code> PriceEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> priceEnablerGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.rules.PriceEnablerList getPriceEnablersByParentGenusType(org.osid.type.Type priceEnablerGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PriceEnablerList </code> containing the given price 
     *  enabler record <code> Type. </code> In plenary mode, the returned list 
     *  contains all known price enablers or an error results. Otherwise, the 
     *  returned list may contain only those price enablers that are 
     *  accessible through this session. 
     *
     *  @param  priceEnablerRecordType a price enabler record type 
     *  @return the returned <code> PriceEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> priceEnablerRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.rules.PriceEnablerList getPriceEnablersByRecordType(org.osid.type.Type priceEnablerRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PriceEnablerList </code> effective within the given date 
     *  range. <code> </code> In plenary mode, the returned list contains all 
     *  known price enablers or an error results. Otherwise, the returned list 
     *  may contain only those price enablers that are accessible through this 
     *  session. 
     *
     *  @param  from a start date 
     *  @param  to an end date 
     *  @return the returned <code> PriceEnabler </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.rules.PriceEnablerList getPriceEnablersOnDate(org.osid.calendaring.DateTime from, 
                                                                           org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PriceEnablerList </code> effective within the given date 
     *  range. <code> </code> In plenary mode, the returned list contains all 
     *  known price enablers or an error results. Otherwise, the returned list 
     *  may contain only those price enablers that are accessible through this 
     *  session. 
     *
     *  @param  agentId an agent <code> Id </code> 
     *  @param  from a start date 
     *  @param  to an end date 
     *  @return the returned <code> PriceEnabler </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> agentId, from, </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.rules.PriceEnablerList getPriceEnablersOnDateWithAgent(org.osid.id.Id agentId, 
                                                                                    org.osid.calendaring.DateTime from, 
                                                                                    org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> PriceEnablers. </code> In plenary mode, the returned 
     *  list contains all known price enablers or an error results. Otherwise, 
     *  the returned list may contain only those price enablers that are 
     *  accessible through this session. 
     *
     *  @return the returned <code> PriceEnabler </code> list 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.rules.PriceEnablerList getPriceEnablers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
