//
// org.osid.ordering.rules.PriceEnablerRuleApplicationSession
//
//     The OSID Java specification for org.osid.ordering.rules.PriceEnablerRuleApplicationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ordering.rules;


/**
 *  <p>This session provides methods to apply <code> PriceEnablers </code> to 
 *  <code> Prices. </code> A <code> Price </code> with multiple <code> 
 *  PriceEnablers </code> means any positive rule evaluation across the 
 *  enablers result in an effective <code> Price. </code> </p>
 */

public interface PriceEnablerRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Store </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Store Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getStoreId();


    /**
     *  Gets the <code> Store </code> associated with this session. 
     *
     *  @return the store 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.Store getStore()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter price enabler/price mappings. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignPriceEnablers();


    /**
     *  Adds an existing <code> PriceEnabler </code> to a <code> Price. 
     *  </code> 
     *
     *  @param  priceEnablerId the <code> Id </code> of the <code> 
     *          PriceEnabler </code> 
     *  @param  priceId the <code> Id </code> of the <code> Price </code> 
     *  @throws org.osid.AlreadyExistsException <code> priceEnablerId </code> 
     *          is already applied to <code> priceId </code> 
     *  @throws org.osid.NotFoundException <code> priceEnablerId </code> or 
     *          <code> priceId </code> not found 
     *  @throws org.osid.NullArgumentException <code> priceEnablerId </code> 
     *          or <code> priceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignPriceEnablerToPrice(org.osid.id.Id priceEnablerId, 
                                          org.osid.id.Id priceId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> PriceEnabler </code> from a <code> Price. </code> 
     *
     *  @param  priceEnablerId the <code> Id </code> of the <code> 
     *          PriceEnabler </code> 
     *  @param  priceId the <code> Id </code> of the <code> Price </code> 
     *  @throws org.osid.NotFoundException <code> priceEnablerId </code> or 
     *          <code> priceId </code> not found or <code> priceEnablerId 
     *          </code> is not applied to <code> priceId </code> 
     *  @throws org.osid.NullArgumentException <code> priceEnablerId </code> 
     *          or <code> priceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignPriceEnablerFromPrice(org.osid.id.Id priceEnablerId, 
                                              org.osid.id.Id priceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> ProceEnablers. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known sequencing operations will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> PriceEnabler </code> ordering 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequencePriceEnablers();


    /**
     *  Reorders price enablers for a price by moving the specified price 
     *  enabler in front of a reference price enabler. 
     *
     *  @param  priceEnablerId the <code> Id </code> of a <code> PriceEnabler 
     *          </code> 
     *  @param  priceId the <code> Id </code> of a <code> Price </code> 
     *  @param  referenceId the reference price enabler <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> priceEnablerId, priceId, 
     *          </code> or <code> referenceId </code> not found or, <code> 
     *          priceEnablerId </code> or <code> referenceId </code> not 
     *          related to <code> priceId </code> 
     *  @throws org.osid.NullArgumentException <code> priceEnablerId, priceId, 
     *          </code> or <code> referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void movePriceEnablerAhead(org.osid.id.Id priceEnablerId, 
                                      org.osid.id.Id priceId, 
                                      org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders price enablers for a price by moving the specified price 
     *  enabler behind a reference price enabler. 
     *
     *  @param  priceEnablerId the <code> Id </code> of a <code> PriceEnabler 
     *          </code> 
     *  @param  priceId the <code> Id </code> of a <code> Price </code> 
     *  @param  referenceId the reference price enabler <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> priceEnablerId, priceId, 
     *          </code> or <code> referenceId </code> not found or, <code> 
     *          priceEnablerId </code> or <code> referenceId </code> not 
     *          related to <code> priceId </code> 
     *  @throws org.osid.NullArgumentException <code> priceEnablerId, priceId, 
     *          </code> or <code> referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void movePriceEnablerBehind(org.osid.id.Id priceEnablerId, 
                                       org.osid.id.Id priceId, 
                                       org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of price enablers for an price. 
     *
     *  @param  priceEnablerIds the <code> Ids </code> for a set of <code> 
     *          PriceEnablers </code> 
     *  @param  priceId the <code> Id </code> of a <code> Price </code> 
     *  @throws org.osid.NotFoundException <code> priceId </code> not found 
     *          or, a <code> priceEnablerId </code> not related to <code> 
     *          priceId </code> 
     *  @throws org.osid.NullArgumentException <code> priceEnablerIds </code> 
     *          or <code> priceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderPriceEnablers(org.osid.id.Id[] priceEnablerIds, 
                                   org.osid.id.Id priceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
