//
// org.osid.ordering.rules.PriceEnablerSearchSession
//
//     The OSID Java specification for org.osid.ordering.rules.PriceEnablerSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ordering.rules;


/**
 *  <p>This session provides methods for searching among <code> PriceEnabler 
 *  </code> objects. The search query is constructed using the <code> 
 *  PriceEnableryQuery. </code> </p> 
 *  
 *  <p> <code> getPriceEnablersByQuery() </code> is the basic search method 
 *  and returns a list of <code> PriceEnablers. </code> A more advanced search 
 *  may be performed with <code> getPriceEnablersBySearch(). </code> It 
 *  accepts a <code> PriceEnablerSearch </code> in addition to the query for 
 *  the purpose of specifying additional options affecting the entire search, 
 *  such as ordering. <code> getPriceEnablersBySearch() </code> returns a 
 *  <code> PriceEnablerSearchResults </code> that can be used to access the 
 *  resulting <code> PriceEnablerList </code> or be used to perform a search 
 *  within the result set through <code> PriceEnablerSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated store view: searches include price enablers in stores 
 *      of which this store is an ancestor in the store hierarchy </li> 
 *      <li> isolated store view: searches are restricted to price enablers in 
 *      this store </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> PriceEnablers </code> may have a query record indicated by 
 *  their respective record types. The query record is accessed via the <code> 
 *  PriceEnablerQuery. </code> </p>
 */

public interface PriceEnablerSearchSession
    extends org.osid.ordering.rules.PriceEnablerQuerySession {


    /**
     *  Gets a price enabler search. 
     *
     *  @return the price enabler search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.rules.PriceEnablerSearch getPriceEnablerSearch();


    /**
     *  Gets a price enabler search order. The <code> PriceEnablerSearchOrder 
     *  </code> is supplied to a <code> PriceEnablerSearch </code> to specify 
     *  the ordering of results. 
     *
     *  @return the price enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.rules.PriceEnablerSearchOrder getPriceEnablerSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  priceEnablerQuery the price enabler query 
     *  @param  priceEnablerSearch the price enabler search 
     *  @return the price enabler search results 
     *  @throws org.osid.NullArgumentException <code> priceEnablerQuery 
     *          </code> or <code> priceEnablerSearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> priceEnablerQuery </code> 
     *          or <code> priceEnablerSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.rules.PriceEnablerSearchResults getPriceEnablersBySearch(org.osid.ordering.rules.PriceEnablerQuery priceEnablerQuery, 
                                                                                      org.osid.ordering.rules.PriceEnablerSearch priceEnablerSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a price enabler query from an inspector. The inspector is 
     *  available from a <code> PriceEnablerSearchResults. </code> 
     *
     *  @param  priceEnablerQueryInspector a price enabler query inspector 
     *  @return the price enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          priceEnablerQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          priceEnablerQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.rules.PriceEnablerQuery getPriceEnablerQueryFromInspector(org.osid.ordering.rules.PriceEnablerQueryInspector priceEnablerQueryInspector);
}
