//
// org.osid.personnel.Appointment
//
//     The OSID Java specification for org.osid.personnel.Appointment.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.personnel;


/**
 *  <p>An <code> Appointment </code> relates a <code> Position </code> to a 
 *  <code> Position. </code> </p>
 */

public interface Appointment
    extends org.osid.OsidRelationship {


    /**
     *  Gets the <code> Id </code> of the person. 
     *
     *  @return the person <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPersonId();


    /**
     *  Gets the person in this appointment. 
     *
     *  @return the <code> Person </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.Person getPerson()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of the position in this appointment. 
     *
     *  @return the <code> Position </code> <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPositionId();


    /**
     *  Gets the position in this appointment. 
     *
     *  @return the <code> Position </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.Position getPosition()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the percentage commitment (0-100). 
     *
     *  @return the percentage commitment 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getCommitment();


    /**
     *  Gets the title for this appointment. 
     *
     *  @return the title 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getTitle();


    /**
     *  Tests if a salary is available. 
     *
     *  @return <code> true </code> if a salary is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasSalary();


    /**
     *  Gets the salary. 
     *
     *  @return the slaary 
     *  @throws org.osid.IllegalStateException <code> hasSalary() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.Currency getSalary();


    /**
     *  Gets the basis in number of months per year. 
     *
     *  @return the number of months 
     *  @throws org.osid.IllegalStateException <code> hasSalary() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getSalaryBasis();


    /**
     *  Gets the record corresponding to the given <code> Appointment </code> 
     *  record <code> Type. </code> This method is used to retrieve an object 
     *  implementing the requested record. The <code> appointmentRecordType 
     *  </code> may be the <code> Type </code> returned in <code> 
     *  getRecordTypes() </code> or any of its parents in a <code> Type 
     *  </code> hierarchy where <code> hasRecordType(appointmentRecordType) 
     *  </code> is <code> true </code> . 
     *
     *  @param  appointmentRecordType the type of appointment record to 
     *          retrieve 
     *  @return the appointment record 
     *  @throws org.osid.NullArgumentException <code> appointmentRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(appointmentRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.records.AppointmentRecord getAppointmentRecord(org.osid.type.Type appointmentRecordType)
        throws org.osid.OperationFailedException;
}
