//
// org.osid.personnel.AppointmentSearchOrder
//
//     The OSID Java specification for org.osid.personnel.AppointmentSearchOrder.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.personnel;


/**
 *  <p>An interface for specifying the ordering of search results. </p>
 */

public interface AppointmentSearchOrder
    extends org.osid.OsidRelationshipSearchOrder {


    /**
     *  Specifies a preference for ordering the result set by the person. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByPerson(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a person search order is available. 
     *
     *  @return <code> true </code> if a person search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPersonSearchOrder();


    /**
     *  Gets the person search order. 
     *
     *  @return the person search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPersonSearchOrder() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPersonSearchOrder() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.personnel.PersonSearchOrder getPersonSearchOrder();


    /**
     *  Specifies a preference for ordering the result set by the position. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByPosition(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a position search order is available. 
     *
     *  @return <code> true </code> if a position search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPositionSearchOrder();


    /**
     *  Gets the position search order. 
     *
     *  @return the position search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPositionSearchOrder() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPositionSearchOrder() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.personnel.PositionSearchOrder getPositionSearchOrder();


    /**
     *  Specifies a preference for ordering the result set by the commitment. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByCommitment(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the title. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByTitle(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the salary. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderBySalary(org.osid.SearchOrderStyle style);


    /**
     *  Gets the appointment search order record corresponding to the given 
     *  appointment record <code> Type. </code> Multiple retrievals return the 
     *  same underlying object. 
     *
     *  @param  appointmentRecordType an appointment record type 
     *  @return the appointment search order record 
     *  @throws org.osid.NullArgumentException <code> appointmentRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(appointmentRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.records.AppointmentSearchOrderRecord getAppointmentSearchOrderRecord(org.osid.type.Type appointmentRecordType)
        throws org.osid.OperationFailedException;
}
