//
// org.osid.personnel.OrganizationNotificationSession
//
//     The OSID Java specification for org.osid.personnel.OrganizationNotificationSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.personnel;


/**
 *  <p>This session defines methods to receive notifications on adds/changes 
 *  to <code> Organization </code> objects. This session is intended for 
 *  consumers needing to synchronize their state with this service without the 
 *  use of polling. Notifications are cancelled when this session is closed. 
 *  </p>
 */

public interface OrganizationNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Realm </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Realm Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getRealmId();


    /**
     *  Gets the <code> Realm </code> associated with this session. 
     *
     *  @return the realm 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.Realm getRealm()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can register for <code> Organization </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForOrganizationNotifications();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include notifications for organizations in realms which are children 
     *  of this realm in the realm hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedRealmView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts notifications to this realm only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedRealmView();


    /**
     *  Register for notifications of new organizations. <code> 
     *  OrganizationReceiver.newOrganizations() </code> is invoked when a new 
     *  <code> Organization </code> is created. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewOrganizations()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated hierarchy structure that 
     *  introduces a new ancestor of the specified organization. <code> 
     *  OrganizationReceiver.newAncestorOrganization() </code> is invoked when 
     *  the specified organization node gets a new ancestor. 
     *
     *  @param  organizationId the <code> Id </code> of the <code> 
     *          Organization </code> node to monitor 
     *  @throws org.osid.NullArgumentException <code> organizationId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewOrganizationAncestors(org.osid.id.Id organizationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated hierarchy structure that 
     *  introduces a new descendant of the specified organization. <code> 
     *  OrganizationReceiver.newDescendantOrganization() </code> is invoked 
     *  when the specified organization node gets a new descendant. 
     *
     *  @param  organizationId the <code> Id </code> of the <code> 
     *          Organization </code> node to monitor 
     *  @throws org.osid.NullArgumentException <code> organizationId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewOrganizationDescendants(org.osid.id.Id organizationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated organizations. <code> 
     *  OrganizationReceiver.changedOrganizations() </code> is invoked when an 
     *  organization in this realm is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedOrganizations()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated organization. <code> 
     *  OrganizationReceiver.changedOrganizations() </code> is invoked when 
     *  the specified organization in this realm is changed. 
     *
     *  @param  organizationId the <code> Id </code> of the <code> 
     *          Organization </code> to monitor 
     *  @throws org.osid.NotFoundException an organization was not found 
     *          identified by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> organizationId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedOrganization(org.osid.id.Id organizationId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted organizations. <code> 
     *  OrganizationReceiver.deletedOrganizations() </code> is invoked when an 
     *  organization is removed from this realm. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedOrganizations()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted organization. <code> 
     *  OrganizationReceiver.deletedOrganizations() </code> is invoked when 
     *  the specified organization is removed from this realm. 
     *
     *  @param  organizationId the <code> Id </code> of the <code> 
     *          Organization </code> to monitor 
     *  @throws org.osid.NotFoundException an organization was not found 
     *          identified by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> organizationId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedOrganization(org.osid.id.Id organizationId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated hierarchy structure that 
     *  removes an ancestor of the specified organization. <code> 
     *  OrganizationReceiver.deletedAncestorOrganization() </code> is invoked 
     *  when the specified organization node loses an ancestor. 
     *
     *  @param  organizationId the <code> Id </code> of the <code> 
     *          Organization </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> organizationId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedOrganizationAncestors(org.osid.id.Id organizationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated hierarchy structure that 
     *  removes a descendant of the specified organization. Organization 
     *  <code> Receiver.deletedDescendantOrganization() </code> is invoked 
     *  when the specified organization node loses a descendant. 
     *
     *  @param  organizationId the <code> Id </code> of the <code> 
     *          Organization </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> organizationId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedOrganizationDescendants(org.osid.id.Id organizationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
