//
// org.osid.personnel.OrganizationQueryInspector
//
//     The OSID Java specification for org.osid.personnel.OrganizationQueryInspector.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.personnel;


/**
 *  <p>The query inspectors provide a means of accessing the match terms of a 
 *  query. These interfaces are used to examine the actual query terms used in 
 *  a search or that may be used to create a smart catalog. Query inspectors 
 *  may be converted to <code> OsidQuery </code> interfaces for reuse or 
 *  modification in the search sessions. </p>
 */

public interface OrganizationQueryInspector
    extends org.osid.OsidObjectQueryInspector,
            org.osid.OsidFederateableQueryInspector,
            org.osid.OsidTemporalQueryInspector {


    /**
     *  Gets the display label query terms. 
     *
     *  @return the display label terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.StringTerm[] getDisplayLabelTerms();


    /**
     *  Gets the ancestor organization <code> Id </code> query terms. 
     *
     *  @return the ancestor organization <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getAncestorOrganizationIdTerms();


    /**
     *  Gets the ancestor organization query terms. 
     *
     *  @return the ancestor organization terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.OrganizationQueryInspector[] getAncestorOrganizationTerms();


    /**
     *  Gets the descendant organization <code> Id </code> query terms. 
     *
     *  @return the descendant organization <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getDescendantOrganizationIdTerms();


    /**
     *  Gets the descendant organization query terms. 
     *
     *  @return the descendant organization terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.OrganizationQueryInspector[] getDescendantOrganizationTerms();


    /**
     *  Gets the realm <code> Id </code> query terms. 
     *
     *  @return the realm <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getRealmIdTerms();


    /**
     *  Gets the realm query terms. 
     *
     *  @return the realm terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.RealmQueryInspector[] getRealmTerms();


    /**
     *  Gets the organization query inspector record corresponding to the 
     *  given <code> Organization </code> record <code> Type. </code> 
     *
     *  @param  organizationRecordType an organization record type 
     *  @return the organization inspector query record 
     *  @throws org.osid.NullArgumentException <code> organizationRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(organizationRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.records.OrganizationQueryInspectorRecord getOrganizationQueryInspectorRecord(org.osid.type.Type organizationRecordType)
        throws org.osid.OperationFailedException;
}
