//
// org.osid.personnel.Person
//
//     The OSID Java specification for org.osid.personnel.Person.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.personnel;


/**
 *  <p>A <code> Person. </code> </p>
 */

public interface Person
    extends org.osid.OsidObject {


    /**
     *  Gets the title for this person (Mr., Dr., Ms.). 
     *
     *  @return the title 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getSalutation();


    /**
     *  Gets the given name of this person. 
     *
     *  @return the given name 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getGivenName();


    /**
     *  Gets the preferred forename or mononym of this person. 
     *
     *  @return the preferred name 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getPreferredName();


    /**
     *  Gets additional forenames this person is or was known by. 
     *
     *  @return forname aliases 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText[] getForenameAliases();


    /**
     *  Gets the middle names of this person. 
     *
     *  @return the middle names 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText[] getMiddleNames();


    /**
     *  Gets the surname of this person. 
     *
     *  @return the surname 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getSurname();


    /**
     *  Gets additional surnames this person is or was known by. 
     *
     *  @return the surname aliases 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText[] getSurnameAliases();


    /**
     *  Gets the generation qualifier of this person. 
     *
     *  @return the generation qualifier 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getGenerationQualifier();


    /**
     *  Gets the qualification suffix of this person (MD, Phd). 
     *
     *  @return the generation qualifier 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getQualificationSuffix();


    /**
     *  Tests if a birth date is available. 
     *
     *  @return <code> true </code> if a birth date is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasBirthDate();


    /**
     *  Gets the date of birth for this person. 
     *
     *  @return the date of birth 
     *  @throws org.osid.IllegalStateException <code> hasBirthDate() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getBirthDate();


    /**
     *  Tests if this person died. 
     *
     *  @return <code> true </code> if this person is dead, <code> false 
     *          </code> if still kicking 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isDeceased();


    /**
     *  Gets the date of death for this person. 
     *
     *  @return the date of death 
     *  @throws org.osid.IllegalStateException <code> isDead() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getDeathDate();


    /**
     *  Gets the institutional identifier for this person. 
     *
     *  @return the institutional identifier 
     *  @compliance mandatory This method must be implemented. 
     */

    public String getInstitutionalIdentifier();


    /**
     *  Gets the record corresponding to the given <code> Person </code> 
     *  record <code> Type. </code> This method is used to retrieve an object 
     *  implementing the requested record. The <code> personRecordType </code> 
     *  may be the <code> Type </code> returned in <code> getRecordTypes() 
     *  </code> or any of its parents in a <code> Type </code> hierarchy where 
     *  <code> hasRecordType(personRecordType) </code> is <code> true </code> 
     *  . 
     *
     *  @param  personRecordType the type of person record to retrieve 
     *  @return the person record 
     *  @throws org.osid.NullArgumentException <code> personRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(personRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.records.PersonRecord getPersonRecord(org.osid.type.Type personRecordType)
        throws org.osid.OperationFailedException;
}
