//
// org.osid.personnel.PersonLookupSession
//
//     The OSID Java specification for org.osid.personnel.PersonLookupSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.personnel;


/**
 *  <p>This session defines methods for retrieving persons. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated realm view: All person methods in this session operate, 
 *      retrieve and pertain to persons defined explicitly in the current 
 *      realm. Using an isolated view is useful for managing persons with the 
 *      <code> PersonAdminSession. </code> </li> 
 *      <li> federated realm view: All person lookup methods in this session 
 *      operate, retrieve and pertain to all persons defined in this realm and 
 *      any other realms implicitly available in this realm through realm 
 *      inheritence. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedRealmView() </code> and <code> 
 *  useIsolatedRealmView() </code> behave as a radio group and one should be 
 *  selected before invoking any lookup methods. </p>
 */

public interface PersonLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Realm </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Realm Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getRealmId();


    /**
     *  Gets the <code> Realm </code> associated with this session. 
     *
     *  @return the realm 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.Realm getRealm()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can examine this realm. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer these operations. 
     *
     *  @return <code> false </code> if realm reading methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupPersons();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativePersonView();


    /**
     *  A complete view of the <code> Person </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryPersonView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include persons in realms which are children of this realm in the 
     *  realm hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedRealmView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this realm only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedRealmView();


    /**
     *  Gets the <code> Person </code> specified by its <code> Id. </code> In 
     *  plenary mode, the exact <code> Id </code> is found or a <code> 
     *  NOT_FOUND </code> results. Otherwise, the returned <code> Person 
     *  </code> may have a different <code> Id </code> than requested, such as 
     *  the case where a duplicate <code> Id </code> was assigned to a <code> 
     *  Person </code> and retained for compatibility. 
     *
     *  @param  personId the <code> Id </code> of the <code> Person </code> to 
     *          retrieve 
     *  @return the returned <code> Person </code> 
     *  @throws org.osid.NotFoundException no <code> Person </code> found with 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> personId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.Person getPerson(org.osid.id.Id personId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PersonList </code> corresponding to the given <code> 
     *  IdList. </code> In plenary mode, the returned list contains all of the 
     *  persons specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible persons may be omitted from the list and may present the 
     *  elements in any order including returning a unique set. 
     *
     *  @param  personIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Person list </code> 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> personIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.PersonList getPersonsByIds(org.osid.id.IdList personIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PersonList </code> corresponding to the given person 
     *  genus <code> Type </code> which does not include persons of types 
     *  derived from the specified <code> Type. </code> In plenary mode, the 
     *  returned list contains all known persons or an error results. 
     *  Otherwise, the returned list may contain only those persons that are 
     *  accessible through this session. 
     *
     *  @param  personGenusType a persons genus type 
     *  @return the returned <code> Person list </code> 
     *  @throws org.osid.NullArgumentException <code> personGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.PersonList getPersonsByGenusType(org.osid.type.Type personGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PersonList </code> corresponding to the given person 
     *  genus <code> Type </code> and include any additional persons with 
     *  genus types derived from the specified <code> Type. </code> In plenary 
     *  mode, the returned list contains all known persons or an error 
     *  results. Otherwise, the returned list may contain only those persons 
     *  that are accessible through this session. 
     *
     *  @param  personGenusType a person genus type 
     *  @return the returned <code> Person list </code> 
     *  @throws org.osid.NullArgumentException <code> personGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.PersonList getPersonsByParentGenusType(org.osid.type.Type personGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PersonList </code> containing the given person record 
     *  <code> Type. </code> In plenary mode, the returned list contains all 
     *  known persons or an error results. Otherwise, the returned list may 
     *  contain only those persons that are accessible through this session. 
     *
     *  @param  personRecordType a person record type 
     *  @return the returned <code> PersonList </code> 
     *  @throws org.osid.NullArgumentException <code> personRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.PersonList getPersonsByRecordType(org.osid.type.Type personRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all persons. In plenary mode, the returned list contains all 
     *  known persons or an error results. Otherwise, the returned list may 
     *  contain only those persons that are accessible through this session. 
     *
     *  @return a list of persons 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.PersonList getPersons()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
