//
// org.osid.personnel.PersonQuery
//
//     The OSID Java specification for org.osid.personnel.PersonQuery.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.personnel;


/**
 *  <p>This is the query for searching persons. Each method specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface PersonQuery
    extends org.osid.OsidObjectQuery {


    /**
     *  Matches a salutation. 
     *
     *  @param  salutation a salutation 
     *  @param  stringMatchType a string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> salutation </code> is 
     *          not of <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> salutation </code> or 
     *          <code> stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSalutation(String salutation, 
                                org.osid.type.Type stringMatchType, 
                                boolean match);


    /**
     *  Matches persons with any salutation. 
     *
     *  @param  match <code> true </code> to match persons with any 
     *          salutation, <code> false </code> to match persons with no 
     *          salutation 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnySalutation(boolean match);


    /**
     *  Clears all salutation terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSalutationTerms();


    /**
     *  Matches a given name. 
     *
     *  @param  givenName a given name 
     *  @param  stringMatchType a string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> givenName </code> is 
     *          not of <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> givenName </code> or 
     *          <code> stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchGivenName(String givenName, 
                               org.osid.type.Type stringMatchType, 
                               boolean match);


    /**
     *  Matches persons with any given name. 
     *
     *  @param  match <code> true </code> to match persons with any given 
     *          name, <code> false </code> to match persons with no given name 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyGivenName(boolean match);


    /**
     *  Clears all given name terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGivenNameTerms();


    /**
     *  Matches a preferred name. 
     *
     *  @param  preferredName a preferred name 
     *  @param  stringMatchType a string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> preferredName </code> 
     *          is not of <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> preferredName </code> or 
     *          <code> stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchPreferredName(String preferredName, 
                                   org.osid.type.Type stringMatchType, 
                                   boolean match);


    /**
     *  Matches persons with any preferred name. 
     *
     *  @param  match <code> true </code> to match persons with any preferred 
     *          name, <code> false </code> to match persons with no preferred 
     *          name 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyPreferredName(boolean match);


    /**
     *  Clears all preferred name terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPreferredNameTerms();


    /**
     *  Matches a forename alias. 
     *
     *  @param  forenameAlias a forename alias 
     *  @param  stringMatchType a string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> forenameAlias </code> 
     *          is not of <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> forenameAlias </code> or 
     *          <code> stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchForenameAlias(String forenameAlias, 
                                   org.osid.type.Type stringMatchType, 
                                   boolean match);


    /**
     *  Matches persons with any forename alias. 
     *
     *  @param  match <code> true </code> to match persons with any forename 
     *          alias, <code> false </code> to match persons with no forename 
     *          aliases 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyForenameAlias(boolean match);


    /**
     *  Clears all forename alias terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearForenameAliasTerms();


    /**
     *  Matches a middle name. 
     *
     *  @param  middleName a middle name 
     *  @param  stringMatchType a string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> middleName </code> is 
     *          not of <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> middleName </code> or 
     *          <code> stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMiddleName(String middleName, 
                                org.osid.type.Type stringMatchType, 
                                boolean match);


    /**
     *  Matches persons with any middle name. 
     *
     *  @param  match <code> true </code> to match persons with any middle 
     *          name, <code> false </code> to match persons with no middle 
     *          name 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyMiddleName(boolean match);


    /**
     *  Clears all middle name terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMiddleNameTerms();


    /**
     *  Matches a surname. 
     *
     *  @param  surName a surname 
     *  @param  stringMatchType a string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> surName </code> is 
     *          not of <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> surName </code> or 
     *          <code> stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSurname(String surName, 
                             org.osid.type.Type stringMatchType, boolean match);


    /**
     *  Matches persons with any surname. 
     *
     *  @param  match <code> true </code> to match persons with any surname, 
     *          <code> false </code> to match persons with no surname 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnySurname(boolean match);


    /**
     *  Clears all surname terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSurnameTerms();


    /**
     *  Matches a surname alias. 
     *
     *  @param  surnameAlias a surname alias 
     *  @param  stringMatchType a string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> surnameAlias </code> 
     *          is not of <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> surnameAlias </code> or 
     *          <code> stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSurnameAlias(String surnameAlias, 
                                  org.osid.type.Type stringMatchType, 
                                  boolean match);


    /**
     *  Matches persons with any surname alias. 
     *
     *  @param  match <code> true </code> to match persons with any surname 
     *          alias, <code> false </code> to match persons with no surname 
     *          alias 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnySurnameAlias(boolean match);


    /**
     *  Clears all surname alias terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSurnameAliasTerms();


    /**
     *  Matches a generation qualifier. 
     *
     *  @param  generationQualifier a generation qualifier 
     *  @param  stringMatchType a string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> generationQualifier 
     *          </code> is not of <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> generationQualifier 
     *          </code> or <code> stringMatchType </code> is <code> null 
     *          </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchGenerationQualifier(String generationQualifier, 
                                         org.osid.type.Type stringMatchType, 
                                         boolean match);


    /**
     *  Matches persons with any generation qualifier. 
     *
     *  @param  match <code> true </code> to match persons with any generation 
     *          qualifier, <code> false </code> to match persons with no 
     *          generation qualifier 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyGenerationQualifier(boolean match);


    /**
     *  Clears all generation qualifier terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGenerationQualifierTerms();


    /**
     *  Matches a qualification suffix. 
     *
     *  @param  qualificationSuffix a qualification suffix 
     *  @param  stringMatchType a string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> qualificationSuffix 
     *          </code> is not of <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> qualificationSuffix 
     *          </code> or <code> stringMatchType </code> is <code> null 
     *          </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchQualificationSuffix(String qualificationSuffix, 
                                         org.osid.type.Type stringMatchType, 
                                         boolean match);


    /**
     *  Matches persons with any qualification suffix. 
     *
     *  @param  match <code> true </code> to match persons with any 
     *          qualification sufix, <code> false </code> to match persons 
     *          with no qualification suffix 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyQualificationSuffix(boolean match);


    /**
     *  Clears all qualification suffix terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearQualificationSuffixTerms();


    /**
     *  Matches a birth date bwteen the given range inclusive. 
     *
     *  @param  from a starting date 
     *  @param  to an ending date 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBirthDate(org.osid.calendaring.DateTime from, 
                               org.osid.calendaring.DateTime to, boolean match);


    /**
     *  Matches persons with any birth date. 
     *
     *  @param  match <code> true </code> to match persons with any date of 
     *          birth, <code> false </code> to match persons with no date of 
     *          birth 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyBirthDate(boolean match);


    /**
     *  Clears all birth date terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBirthDateTerms();


    /**
     *  Matches a death date between the given range inclusive. 
     *
     *  @param  from a starting date 
     *  @param  to an ending date 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDeathDate(org.osid.calendaring.DateTime from, 
                               org.osid.calendaring.DateTime to, boolean match);


    /**
     *  Matches persons with any death date. 
     *
     *  @param  match <code> true </code> to match persons with any date of 
     *          death, <code> false </code> to match persons who might still 
     *          be alive 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDeathDate(boolean match);


    /**
     *  Clears all death date terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDeathDateTerms();


    /**
     *  Matches a persons alive within the given dates inclusive. 
     *
     *  @param  from a starting date 
     *  @param  to an ending date 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchLivingDate(org.osid.calendaring.DateTime from, 
                                org.osid.calendaring.DateTime to, 
                                boolean match);


    /**
     *  Clears all living date terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLivingDateTerms();


    /**
     *  Matches an institutional identifier. 
     *
     *  @param  identifier an institutional identifier 
     *  @param  stringMatchType a string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> identifier </code> is 
     *          not of <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> identifier </code> or 
     *          <code> stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchInstitutionalIdentifier(String identifier, 
                                             org.osid.type.Type stringMatchType, 
                                             boolean match);


    /**
     *  Matches persons with any institutional identifier. 
     *
     *  @param  match <code> true </code> to match persons with any 
     *          institutional identifier, <code> false </code> to match 
     *          persons with no instituional identifier 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyInstitutionalIdentifier(boolean match);


    /**
     *  Clears all institutional identifier terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearInstitutionalIdentifierTerms();


    /**
     *  Sets the realm <code> Id </code> for this query to match persons 
     *  assigned to realms. 
     *
     *  @param  realmId a realm <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> realmId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRealmId(org.osid.id.Id realmId, boolean match);


    /**
     *  Clears all realm <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRealmIdTerms();


    /**
     *  Tests if a <code> RealmQuery </code> is available. 
     *
     *  @return <code> true </code> if a realm query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRealmQuery();


    /**
     *  Gets the query for a realm query. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the realm query 
     *  @throws org.osid.UnimplementedException <code> supportsRealmQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRealmQuery() </code> is <code> true. </code> 
     */

    public org.osid.personnel.RealmQuery getRealmQuery();


    /**
     *  Clears all realm terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRealmTerms();


    /**
     *  Gets the person query record corresponding to the given <code> Person 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @param  personRecordType a person record type 
     *  @return the person query record 
     *  @throws org.osid.NullArgumentException <code> personRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(personRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.records.PersonQueryRecord getPersonQueryRecord(org.osid.type.Type personRecordType)
        throws org.osid.OperationFailedException;
}
