//
// org.osid.personnel.PersonQueryInspector
//
//     The OSID Java specification for org.osid.personnel.PersonQueryInspector.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.personnel;


/**
 *  <p>The query inspectors provide a means of accessing the match terms of a 
 *  query. These interfaces are used to examine the actual query terms used in 
 *  a search or that may be used to create a smart catalog. Query inspectors 
 *  may be converted to <code> OsidQuery </code> interfaces for reuse or 
 *  modification in the search sessions. </p>
 */

public interface PersonQueryInspector
    extends org.osid.OsidObjectQueryInspector {


    /**
     *  Gets the salutation query terms. 
     *
     *  @return the salutation terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.StringTerm[] getSalutationTerms();


    /**
     *  Gets the given name query terms. 
     *
     *  @return the given name terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.StringTerm[] getGivenNameTerms();


    /**
     *  Gets the preferred name query terms. 
     *
     *  @return the preferred name terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.StringTerm[] getPreferredNameTerms();


    /**
     *  Gets the forename alias query terms. 
     *
     *  @return the forename alias terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.StringTerm[] getForenameAliasTerms();


    /**
     *  Gets the middle name query terms. 
     *
     *  @return the middle name terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.StringTerm[] getMiddleNameTerms();


    /**
     *  Gets the surname query terms. 
     *
     *  @return the surname terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.StringTerm[] getSurnameTerms();


    /**
     *  Gets the surname alias query terms. 
     *
     *  @return the surname alias terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.StringTerm[] getSurnameAliasTerms();


    /**
     *  Gets the generation qualifier query terms. 
     *
     *  @return the generation qualifier terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.StringTerm[] getGenerationQualifierTerms();


    /**
     *  Gets the qualifier suffix query terms. 
     *
     *  @return the qualifier suffix terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.StringTerm[] getQualificationSuffixTerms();


    /**
     *  Gets the birth date query terms. 
     *
     *  @return the birth date terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DateTimeRangeTerm[] getBirthDateTerms();


    /**
     *  Gets the death date query terms. 
     *
     *  @return the death date terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DateTimeRangeTerm[] getDeathDateTerms();


    /**
     *  Gets the living date query terms. 
     *
     *  @return the living date terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DateTimeRangeTerm[] getLivingDateTerms();


    /**
     *  Gets the identifier query terms. 
     *
     *  @return the identifier terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.StringTerm[] getInstitutionalIdentifierTerms();


    /**
     *  Gets the realm <code> Id </code> query terms. 
     *
     *  @return the realm <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getRealmIdTerms();


    /**
     *  Gets the realm query terms. 
     *
     *  @return the realm terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.RealmQueryInspector[] getRealmTerms();


    /**
     *  Gets the person query inspector record corresponding to the given 
     *  <code> Person </code> record <code> Type. </code> 
     *
     *  @param  personRecordType a person record type 
     *  @return the person inspector query record 
     *  @throws org.osid.NullArgumentException <code> personRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(personRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.records.PersonQueryInspectorRecord getPersonQueryInspectorRecord(org.osid.type.Type personRecordType)
        throws org.osid.OperationFailedException;
}
