//
// org.osid.personnel.PersonSmartRealmSession
//
//     The OSID Java specification for org.osid.personnel.PersonSmartRealmSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.personnel;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. A <code> PersonQuery </code> can be retrieved from this session 
 *  and mapped to this <code> Realm </code> to create a virtual collection of 
 *  <code> Persons. </code> The persons may be sequenced using the <code> 
 *  PersonSearchOrder </code> from this session. </p> 
 *  
 *  <p> This <code> Realm </code> has a default query that matches any person 
 *  and a default search order that specifies no sequencing. The queries may 
 *  be examined using a <code> PersonQueryInspector. </code> The query may be 
 *  modified by converting the inspector back to a <code> PersonQuery. </code> 
 *  </p>
 */

public interface PersonSmartRealmSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Realm </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Realm Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getRealmId();


    /**
     *  Gets the <code> Realm </code> associated with this session. 
     *
     *  @return the <code> Realm </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.Realm getRealm()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart realms. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart realm management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartRealms();


    /**
     *  Gets a person query. 
     *
     *  @return the person query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.PersonQuery getPersonQuery();


    /**
     *  Gets a person search order. 
     *
     *  @return the person search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.PersonSearchOrder getPersonSearchOrder();


    /**
     *  Applies a person query to this realm. 
     *
     *  @param  personQuery the person query 
     *  @throws org.osid.NullArgumentException <code> personQuery </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> personQuery </code> not 
     *          of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyPersonQuery(org.osid.personnel.PersonQuery personQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a person query inspector for this realm. 
     *
     *  @return the person query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.PersonQueryInspector inspectPersonQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a person search order to this realm. 
     *
     *  @param  personSearchOrder the person search order 
     *  @throws org.osid.NullArgumentException <code> personSearchOrder 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> personSearchOrder </code> 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyPersonSequencing(org.osid.personnel.PersonSearchOrder personSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a person query from an inspector. 
     *
     *  @param  personQueryInspector a query inspector 
     *  @return the person query 
     *  @throws org.osid.NullArgumentException <code> personQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> personQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.PersonQuery getPersonQueryFromInspector(org.osid.personnel.PersonQueryInspector personQueryInspector);
}
