//
// org.osid.personnel.PositionQuery
//
//     The OSID Java specification for org.osid.personnel.PositionQuery.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.personnel;


/**
 *  <p>This is the query for searching positions. Each method specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface PositionQuery
    extends org.osid.OsidObjectQuery,
            org.osid.OsidTemporalQuery,
            org.osid.OsidSubjugateableQuery {


    /**
     *  Sets an organization <code> Id. </code> 
     *
     *  @param  organizationId an organization <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> organizationId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchOrganizationId(org.osid.id.Id organizationId, 
                                    boolean match);


    /**
     *  Clears all organization <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOrganizationIdTerms();


    /**
     *  Tests if an <code> OrganizationQuery </code> is available. 
     *
     *  @return <code> true </code> if an organization query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOrganizationQuery();


    /**
     *  Gets the query for an organization query. Multiple retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @return the organization query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOrganizationQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOrganizationQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.personnel.OrganizationQuery getOrganizationQuery();


    /**
     *  Clears all organization terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOrganizationTerms();


    /**
     *  Matches a title. 
     *
     *  @param  title a title 
     *  @param  stringMatchType a string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> title </code> is not 
     *          of <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> title </code> or <code> 
     *          stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchTitle(String title, org.osid.type.Type stringMatchType, 
                           boolean match);


    /**
     *  Matches persons with any title. 
     *
     *  @param  match <code> true </code> to match positions with any title, 
     *          <code> false </code> to match positions with no title 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyTitle(boolean match);


    /**
     *  Clears all title terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTitleTerms();


    /**
     *  Sets a grade <code> Id. </code> 
     *
     *  @param  gradeId a grade <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> gradeId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchLevelId(org.osid.id.Id gradeId, boolean match);


    /**
     *  Clears all grade <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLevelIdTerms();


    /**
     *  Tests if a <code> GradeQuery </code> is available. 
     *
     *  @return <code> true </code> if a grade query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLevelQuery();


    /**
     *  Gets the query for a grade query. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the grade query 
     *  @throws org.osid.UnimplementedException <code> supportsLevelQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLevelQuery() </code> is <code> true. </code> 
     */

    public org.osid.grading.GradeQuery getLevelQuery();


    /**
     *  Matches positions with any level. 
     *
     *  @param  match <code> true </code> to match positions with any level, 
     *          <code> false </code> to match positions with no level 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyLevel(boolean match);


    /**
     *  Clears all level terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLevelTerms();


    /**
     *  Sets an objective <code> Id. </code> 
     *
     *  @param  objectiveId an objective <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> objectiveId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchQualificationId(org.osid.id.Id objectiveId, boolean match);


    /**
     *  Clears all objective <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearQualificationIdTerms();


    /**
     *  Tests if an <code> ObjectiveQuery </code> is available. 
     *
     *  @return <code> true </code> if an objective query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQualificationQuery();


    /**
     *  Gets the query for an objective query. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the grade query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQualificationQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQualificationQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.learning.ObjectiveQuery getQualificationQuery();


    /**
     *  Matches positions with any qualification. 
     *
     *  @param  match <code> true </code> to match positions with any 
     *          qualification, <code> false </code> to match positions with no 
     *          qualifications 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyQualification(boolean match);


    /**
     *  Clears all qualification terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearQualificationTerms();


    /**
     *  Matches a target appointments between the given range inclusive. 
     *
     *  @param  from a starting range 
     *  @param  to an ending range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchTargetAppointments(long from, long to, boolean match);


    /**
     *  Matches positions with any target appointments. 
     *
     *  @param  match <code> true </code> to match positions with any target 
     *          appointments, <code> false </code> to match positions with no 
     *          target appointments 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyTargetAppointments(boolean match);


    /**
     *  Clears all target appointments terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTargetAppointmentsTerms();


    /**
     *  Matches a required commitment between the given range inclusive. 
     *
     *  @param  from a starting range 
     *  @param  to an ending range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRequiredCommitment(long from, long to, boolean match);


    /**
     *  Matches positions with any required commitment. 
     *
     *  @param  match <code> true </code> to match positions with any required 
     *          commitment, <code> false </code> to match positions with no 
     *          required commitment 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRequiredCommitment(boolean match);


    /**
     *  Clears all required commitment terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRequiredCommitmentTerms();


    /**
     *  Matches a low salary between the given range inclusive. 
     *
     *  @param  from a starting salary 
     *  @param  to an ending salary 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchLowSalaryRange(org.osid.financials.Currency from, 
                                    org.osid.financials.Currency to, 
                                    boolean match);


    /**
     *  Matches positions with any low salary. 
     *
     *  @param  match <code> true </code> to match positions with any low 
     *          salary range, commitment, <code> false </code> to match 
     *          positions with no low salary range 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyLowSalaryRange(boolean match);


    /**
     *  Clears all low salary terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLowSalaryRangeTerms();


    /**
     *  Matches a midpoint salary between the given range inclusive. 
     *
     *  @param  from a starting salary 
     *  @param  to an ending salary 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMidpointSalaryRange(org.osid.financials.Currency from, 
                                         org.osid.financials.Currency to, 
                                         boolean match);


    /**
     *  Matches positions with any midpoint salary. 
     *
     *  @param  match <code> true </code> to match positions with any midpoint 
     *          salary range, commitment, <code> false </code> to match 
     *          positions with no midpoint salary range 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyMidpointSalaryRange(boolean match);


    /**
     *  Clears all midpoint salary terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMidpointSalaryRangeTerms();


    /**
     *  Matches a high salary between the given range inclusive. 
     *
     *  @param  from a starting salary 
     *  @param  to an ending salary 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchHighSalaryRange(org.osid.financials.Currency from, 
                                     org.osid.financials.Currency to, 
                                     boolean match);


    /**
     *  Matches positions with any high salary. 
     *
     *  @param  match <code> true </code> to match positions with any high 
     *          salary range, <code> false </code> to match positions with no 
     *          high salary range 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyHighSalaryRange(boolean match);


    /**
     *  Clears all high salary terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearHighSalaryRangeTerms();


    /**
     *  Matches a compensation frequency between the given range inclusive. 
     *
     *  @param  low low range of time frequency 
     *  @param  high high range of time frequency 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> low </code> is 
     *          greater than <code> high </code> 
     *  @throws org.osid.NullArgumentException <code> frequency </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCompensationFrequency(org.osid.calendaring.Duration low, 
                                           org.osid.calendaring.Duration high, 
                                           boolean match);


    /**
     *  Matches positions with any compensation frequency. 
     *
     *  @param  match <code> true </code> to match positions with any 
     *          compensation frequency, <code> false </code> to match 
     *          positions with no compensation frequency 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCompensationFrequency(boolean match);


    /**
     *  Clears all compensation frequency terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCompensationFrequencyTerms();


    /**
     *  Matches exempt positions. 
     *
     *  @param  match <code> true </code> to match exempt positions, <code> 
     *          false </code> to match non-exempt positions 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchExempt(boolean match);


    /**
     *  Matches positions with any exempt flag set. 
     *
     *  @param  match <code> true </code> to match positions with any exempt 
     *          status,, <code> false </code> to match positions with no 
     *          exempt status 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyExempt(boolean match);


    /**
     *  Clears all exempt terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearExemptTerms();


    /**
     *  Matches a benefits type. 
     *
     *  @param  type a benefits type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> type </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBenefitsType(org.osid.type.Type type, boolean match);


    /**
     *  Matches positions with any benefits type. 
     *
     *  @param  match <code> true </code> to match positions with any benefits 
     *          type, <code> false </code> to match positions with no benefits 
     *          type 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyBenefitsType(boolean match);


    /**
     *  Clears all benefits type terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBenefitsTypeTerms();


    /**
     *  Sets the realm <code> Id </code> for this query to match positions 
     *  assigned to realms. 
     *
     *  @param  realmId a realm <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> realmId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRealmId(org.osid.id.Id realmId, boolean match);


    /**
     *  Clears all realm <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRealmIdTerms();


    /**
     *  Tests if a <code> RealmQuery </code> is available. 
     *
     *  @return <code> true </code> if a realm query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRealmQuery();


    /**
     *  Gets the query for a realm query. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the realm query 
     *  @throws org.osid.UnimplementedException <code> supportsRealmQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRealmQuery() </code> is <code> true. </code> 
     */

    public org.osid.personnel.RealmQuery getRealmQuery();


    /**
     *  Clears all realm terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRealmTerms();


    /**
     *  Gets the position query record corresponding to the given <code> 
     *  Position </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  positionRecordType a position record type 
     *  @return the position query record 
     *  @throws org.osid.NullArgumentException <code> positionRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(positionRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.records.PositionQueryRecord getPositionQueryRecord(org.osid.type.Type positionRecordType)
        throws org.osid.OperationFailedException;
}
