//
// org.osid.personnel.PositionQueryInspector
//
//     The OSID Java specification for org.osid.personnel.PositionQueryInspector.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.personnel;


/**
 *  <p>The query inspectors provide a means of accessing the match terms of a 
 *  query. These interfaces are used to examine the actual query terms used in 
 *  a search or that may be used to create a smart catalog. Query inspectors 
 *  may be converted to <code> OsidQuery </code> interfaces for reuse or 
 *  modification in the search sessions. </p>
 */

public interface PositionQueryInspector
    extends org.osid.OsidObjectQueryInspector,
            org.osid.OsidTemporalQueryInspector,
            org.osid.OsidSubjugateableQueryInspector {


    /**
     *  Gets the organization <code> Id </code> query terms. 
     *
     *  @return the organization <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getOrganizationIdTerms();


    /**
     *  Gets the organization query terms. 
     *
     *  @return the organization terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.OrganizationQueryInspector[] getOrganizationTerms();


    /**
     *  Gets the title query terms. 
     *
     *  @return the title terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.StringTerm[] getTitleTerms();


    /**
     *  Gets the grade level <code> Id </code> query terms. 
     *
     *  @return the grade level <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getLevelIdTerms();


    /**
     *  Gets the grade level query terms. 
     *
     *  @return the grade level terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeQueryInspector[] getLevelTerms();


    /**
     *  Gets the qualification <code> Id </code> query terms. 
     *
     *  @return the objective <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getQualificationIdTerms();


    /**
     *  Gets the qualification query terms. 
     *
     *  @return the objective terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveQueryInspector[] getQualificationTerms();


    /**
     *  Gets the target appointments query terms. 
     *
     *  @return the target appointments terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.CardinalRangeTerm[] getTargetAppointmentsTerms();


    /**
     *  Gets the required commitment query terms. 
     *
     *  @return the commitment terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.CardinalRangeTerm[] getRequiredCommitmentTerms();


    /**
     *  Gets the low salary query terms. 
     *
     *  @return the low salary terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.CurrencyRangeTerm[] getLowSalaryRangeTerms();


    /**
     *  Gets the midpoint salary query terms. 
     *
     *  @return the midpoint salary terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.CurrencyRangeTerm[] getMidpointSalaryRangeTerms();


    /**
     *  Gets the high salary query terms. 
     *
     *  @return the high salary terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.CurrencyRangeTerm[] getHighSalaryRangeTerms();


    /**
     *  Gets the compensation frequency terms. 
     *
     *  @return the frequency terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DurationRangeTerm[] getCompensationFrequencyTerms();


    /**
     *  Gets the exempt terms. 
     *
     *  @return the exempt terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.BooleanTerm[] getExemptTerms();


    /**
     *  Gets the benefits type terms. 
     *
     *  @return the benefit type terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.TypeTerm[] getBenefitsTypeTerms();


    /**
     *  Gets the realm <code> Id </code> query terms. 
     *
     *  @return the realm <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getRealmIdTerms();


    /**
     *  Gets the realm query terms. 
     *
     *  @return the realm terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.RealmQueryInspector[] getRealmTerms();


    /**
     *  Gets the position query inspector record corresponding to the given 
     *  <code> Position </code> record <code> Type. </code> 
     *
     *  @param  positionRecordType a position record type 
     *  @return the position inspector query record 
     *  @throws org.osid.NullArgumentException <code> positionRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(positionRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.records.PositionQueryInspectorRecord getPositionQueryInspectorRecord(org.osid.type.Type positionRecordType)
        throws org.osid.OperationFailedException;
}
