//
// org.osid.personnel.PositionRealmAssignmentSession
//
//     The OSID Java specification for org.osid.personnel.PositionRealmAssignmentSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.personnel;


/**
 *  <p>This session provides methods to re-assign <code> Positions </code> to 
 *  <code> Bilings. </code> A <code> Position </code> may map to multiple 
 *  <code> Realms </code> and removing the last reference to a <code> Position 
 *  </code> is the equivalent of deleting it. Each <code> Realm </code> may 
 *  have its own authorizations governing who is allowed to operate on it. 
 *  </p> 
 *  
 *  <p> Adding a reference of a <code> Position </code> to another <code> 
 *  Realm </code> is not a copy operation (eg: does not change its <code> Id 
 *  </code> ). </p>
 */

public interface PositionRealmAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter position/realm mappings. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignPositions();


    /**
     *  Tests if this user can alter position/realm mappings. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @param  realmId the <code> Id </code> of the <code> Realm </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> realmId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignPositionsToRealm(org.osid.id.Id realmId);


    /**
     *  Gets a list of realms including and under the given realm node in 
     *  which any position can be assigned. 
     *
     *  @param  realmId the <code> Id </code> of the <code> Realm </code> 
     *  @return list of assignable realm <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> realmId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableRealmIds(org.osid.id.Id realmId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of realms including and under the given realm node in 
     *  which a specific position can be assigned. 
     *
     *  @param  realmId the <code> Id </code> of the <code> Realm </code> 
     *  @param  positionId the <code> Id </code> of the <code> Position 
     *          </code> 
     *  @return list of assignable realm <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> realmId </code> or 
     *          <code> positionId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableRealmIdsForPosition(org.osid.id.Id realmId, 
                                                               org.osid.id.Id positionId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> Position </code> to a <code> Realm. </code> 
     *
     *  @param  positionId the <code> Id </code> of the <code> Position 
     *          </code> 
     *  @param  realmId the <code> Id </code> of the <code> Realm </code> 
     *  @throws org.osid.AlreadyExistsException <code> positionId </code> 
     *          already assigned to <code> realmId </code> 
     *  @throws org.osid.NotFoundException <code> positionId </code> or <code> 
     *          realmId </code> not found 
     *  @throws org.osid.NullArgumentException <code> positionId </code> or 
     *          <code> realmId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignPositionToRealm(org.osid.id.Id positionId, 
                                      org.osid.id.Id realmId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> Position </code> from a <code> Realm. </code> 
     *
     *  @param  positionId the <code> Id </code> of the <code> Position 
     *          </code> 
     *  @param  realmId the <code> Id </code> of the <code> Realm </code> 
     *  @throws org.osid.NotFoundException <code> positionId </code> or <code> 
     *          realmId </code> not found or <code> positionId </code> not 
     *          mapped to <code> realmId </code> 
     *  @throws org.osid.NullArgumentException <code> positionId </code> or 
     *          <code> realmId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignPositionFromRealm(org.osid.id.Id positionId, 
                                          org.osid.id.Id realmId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
