//
// org.osid.personnel.PositionSearchOrder
//
//     The OSID Java specification for org.osid.personnel.PositionSearchOrder.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.personnel;


/**
 *  <p>An interface for specifying the ordering of search results. </p>
 */

public interface PositionSearchOrder
    extends org.osid.OsidObjectSearchOrder,
            org.osid.OsidTemporalSearchOrder,
            org.osid.OsidSubjugateableSearchOrder {


    /**
     *  Specifies a preference for ordering the result set by the 
     *  organization. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByOrganization(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a organization search order is available. 
     *
     *  @return <code> true </code> if a organization search order is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOrganizationSearchOrder();


    /**
     *  Gets the organization search order. 
     *
     *  @return the organization search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOrganizationSearchOrder() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOrganizationSearchOrder() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.personnel.OrganizationSearchOrder getOrganizationSearchOrder();


    /**
     *  Specifies a preference for ordering the result set by the title. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByTitle(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the level. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByLevel(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a grade level search order is available. 
     *
     *  @return <code> true </code> if a level search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLevelSearchOrder();


    /**
     *  Gets the level search order. 
     *
     *  @return the level search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsLevelSearchOrder() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLevelSearchOrder() </code> is <code> true. </code> 
     */

    public org.osid.grading.GradeSearchOrder getLevelSearchOrder();


    /**
     *  Specifies a preference for ordering the result set by the target 
     *  appointments. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByTargetAppointments(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the required 
     *  commitment. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByRequiredCommitment(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the low salary. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByLowSalaryRange(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the midpoint 
     *  salary. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByMidpointSalaryRange(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the high salary. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByHighSalaryRange(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the compensation 
     *  frequency. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByCompensationFrequency(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the exempt flag. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByExempt(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the benefits 
     *  type. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByBenefitsType(org.osid.SearchOrderStyle style);


    /**
     *  Gets the position search order record corresponding to the given 
     *  position record <code> Type. </code> Multiple retrievals return the 
     *  same underlying object. 
     *
     *  @param  positionRecordType a position record type 
     *  @return the position search order record 
     *  @throws org.osid.NullArgumentException <code> positionRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(positionRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.records.PositionSearchOrderRecord getPositionSearchOrderRecord(org.osid.type.Type positionRecordType)
        throws org.osid.OperationFailedException;
}
