//
// org.osid.personnel.RealmNotificationSession
//
//     The OSID Java specification for org.osid.personnel.RealmNotificationSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.personnel;


/**
 *  <p>This session defines methods to receive notifications on adds/changes 
 *  to <code> Realm </code> objects. This session is intended for consumers 
 *  needing to synchronize their state with this service without the use of 
 *  polling. Notifications are cancelled when this session is closed. </p> 
 *  
 *  <p> Notifications are triggered with changes to the <code> Realm </code> 
 *  object itself. Adding and removing persons result in notifications 
 *  available from the notification session for persons. </p>
 */

public interface RealmNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can register for <code> Realm </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForRealmNotifications();


    /**
     *  Register for notifications of new realms. <code> 
     *  RealmReceiver.newRealm() </code> is invoked when a new <code> Realm 
     *  </code> is created. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewRealms()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated hierarchy structure that 
     *  introduces a new ancestor of the specified realm. <code> 
     *  RealmReceiver.newAncestorRealms() </code> is invoked when the 
     *  specified realm node gets a new ancestor. 
     *
     *  @param  realmId the <code> Id </code> of the <code> Realm </code> node 
     *          to monitor 
     *  @throws org.osid.NullArgumentException <code> realmId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewRealmAncestors(org.osid.id.Id realmId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated hierarchy structure that 
     *  introduces a new descendant of the specified realm. <code> 
     *  RealmReceiver.newDescendantRealm() </code> is invoked when the 
     *  specified realm node gets a new descendant. 
     *
     *  @param  realmId the <code> Id </code> of the <code> Realm </code> node 
     *          to monitor 
     *  @throws org.osid.NullArgumentException <code> realmId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewRealmDescendants(org.osid.id.Id realmId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated realms. <code> 
     *  RealmReceiver.changedRealms() </code> is invoked when a realm is 
     *  changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedRealms()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated realm. <code> 
     *  RealmReceiver.changedRealms() </code> is invoked when the specified 
     *  realm is changed. 
     *
     *  @param  realmId the <code> Id </code> of the <code> Realm </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> realmId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedRealm(org.osid.id.Id realmId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted realms. <code> 
     *  RealmReceiver.deletedRealms() </code> is invoked when a realm is 
     *  deleted. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedRealms()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted realm. <code> 
     *  RealmReceiver.deletedRealms() </code> is invoked when the specified 
     *  realm is deleted. 
     *
     *  @param  realmId the <code> Id </code> of the <code> Realm </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> realmId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedRealm(org.osid.id.Id realmId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated hierarchy structure that 
     *  removes an ancestor of the specified realm. <code> 
     *  RealmReceiver.deletedAncestorRealm() </code> is invoked when the 
     *  specified realm node loses an ancestor. 
     *
     *  @param  realmId the <code> Id </code> of the <code> Realm </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> realmId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedRealmAncestors(org.osid.id.Id realmId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated hierarchy structure that 
     *  removes a descendant of the specified realm. <code> 
     *  RealmReceiver.deletedDescendantRealm() </code> is invoked when the 
     *  specified realm node loses a descendant. 
     *
     *  @param  realmId the <code> Id </code> of the <code> Realm </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> realmId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedRealmDescendants(org.osid.id.Id realmId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
