//
// org.osid.personnel.RealmReceiver
//
//     The OSID Java specification for org.osid.personnel.RealmReceiver.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.personnel;


/**
 *  <p>The realm receiver is the consumer supplied interface for receiving 
 *  notifications pertaining to new, updated or deleted <code> Realm </code> 
 *  objects. </p>
 */

public interface RealmReceiver
    extends org.osid.OsidReceiver {


    /**
     *  The callback for notifications of new realms. 
     *
     *  @param  realmIds the <code> Ids </code> of the new <code> Realms 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newRealms(org.osid.id.IdList realmIds);


    /**
     *  The callback for notifications of new ancestors of a realm. 
     *
     *  @param  realmId the <code> Id </code> of the registered <code> Realm 
     *          </code> 
     *  @param  ancestorId the Id of the new ancestor realm 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newAncestorRealm(org.osid.id.Id realmId, 
                                 org.osid.id.Id ancestorId);


    /**
     *  The callback for notifications of new descendant of a realm. 
     *
     *  @param  realmId the <code> Id </code> of the registered <code> Realm 
     *          </code> 
     *  @param  descendantId the Id of the new descendant realm 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newDescendantRealm(org.osid.id.Id realmId, 
                                   org.osid.id.Id descendantId);


    /**
     *  The callback for notification of updated realms. 
     *
     *  @param  realmIds the <code> Ids </code> of the updated <code> Realms 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void changedRealms(org.osid.id.IdList realmIds);


    /**
     *  the callback for notification of deleted realms. 
     *
     *  @param  realmIds the <code> Ids </code> of the registered <code> 
     *          Realms </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedRealms(org.osid.id.IdList realmIds);


    /**
     *  The callback for notifications of deleted ancestors of a realm. 
     *
     *  @param  realmId the <code> Id </code> of the registered <code> Realm 
     *          </code> 
     *  @param  ancestorId the Id of the removed ancestor realm 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedAncestorRealm(org.osid.id.Id realmId, 
                                     org.osid.id.Id ancestorId);


    /**
     *  The callback for notifications of deleted descendants of a realm. 
     *
     *  @param  realmId the <code> Id </code> of the registered <code> Realm 
     *          </code> 
     *  @param  descendantId the Id of the deleted descendant realm 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedDescendantRealm(org.osid.id.Id realmId, 
                                       org.osid.id.Id descendantId);


    /**
     *  The callback for notifications of changes to a realm hierarchy where 
     *  the hierarchy needs to refreshed. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void restructuredRealmHierarchy();
}
