//
// org.osid.personnel.RealmSearchSession
//
//     The OSID Java specification for org.osid.personnel.RealmSearchSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.personnel;


/**
 *  <p>This session provides methods for searching <code> Realm </code> 
 *  objects. The search query is constructed using the <code> RealmQuery. 
 *  </code> The realm record <code> Type </code> also specifies the realm 
 *  query record for the realm query. </p> 
 *  
 *  <p> <code> getRealmsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Realm </code> elements. A more advanced search 
 *  may be performed with <code> getRealmsBySearch(). </code> It accepts a 
 *  <code> RealmSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getRealmsBySearch() </code> returns a <code> 
 *  RealmSearchResults </code> that can be used to access the resulting <code> 
 *  RealmList </code> or be used to perform a search within the result set 
 *  through <code> RealmSearch. </code> </p> 
 *  
 *  <p> Realms may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> RealmQuery. </code> The 
 *  returns in this session may not be cast directly to these interfaces. </p>
 */

public interface RealmSearchSession
    extends org.osid.personnel.RealmQuerySession {


    /**
     *  Gets a realm search. 
     *
     *  @return the realm search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.RealmSearch getRealmSearch();


    /**
     *  Gets a realm search order. The <code> RealmSearchOrder </code> is 
     *  supplied to a <code> RealmSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the realm search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.RealmSearchOrder getRealmSearchOrder();


    /**
     *  Gets the search results matching the given search. 
     *
     *  @param  realmQuery the realm query 
     *  @param  realmSearch the realm search 
     *  @return the search results 
     *  @throws org.osid.NullArgumentException <code> realmQuery </code> or 
     *          <code> realmSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> realmQuery </code> or 
     *          <code> realmSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.RealmSearchResults getRealmsBySearch(org.osid.personnel.RealmQuery realmQuery, 
                                                                   org.osid.personnel.RealmSearch realmSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a realm query from an inspector. The inspector is available from 
     *  a <code> RealmSearchResults. </code> 
     *
     *  @param  realmQueryInspector a realm query inspector 
     *  @return the realm query 
     *  @throws org.osid.NullArgumentException <code> realmQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> irealmQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.RealmQuery getRealmQueryFromInspector(org.osid.personnel.RealmQueryInspector realmQueryInspector);
}
