//
// org.osid.personnel.batch.AppointmentBatchAdminSession
//
//     The OSID Java specification for org.osid.personnel.batch.AppointmentBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.personnel.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Appointments </code> 
 *  in bulk. The data for create and update is provided by the consumer via 
 *  the form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create an 
 *  <code> Appointment, </code> an <code> AppointmentForm </code> is requested 
 *  using <code> getAppointmentFormsForCreate() </code> specifying the desired 
 *  position, person, record <code> Types </code> or none if no record <code> 
 *  Types </code> are needed. Each of the returned <code> AppointmentForms 
 *  </code> will indicate that it is to be used with a create operation and 
 *  can be used to examine metdata or validate data prior to creation. Once an 
 *  <code> AppointmentForm </code> is submiited to a create operation, it 
 *  cannot be reused with another create operation unless the first operation 
 *  was unsuccessful. Each <code> AppointmentForm </code> corresponds to an 
 *  attempted transaction. </p> 
 *  
 *  <p> The <code> AppointmentForms </code> returned from <code> 
 *  getAppointmentFormsForCreate() </code> may be linked to the originating 
 *  request through the peer <code> Ids </code> of the <code> AppointmentForm. 
 *  </code> In the case where there may be duplicates, any <code> 
 *  AppointmentForm </code> of the same peer <code> Ids </code> may be used 
 *  for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> AppointmentForms </code> are submitted for 
 *  create, a <code> CreateResponse </code> is returned for each <code> 
 *  AppointmentForm, </code> although the ordering is not defined. Only errors 
 *  that pertain to the entire create operation are returned from <code> 
 *  createAppointments(), </code> errors specific to an individual <code> 
 *  AppointmentForm </code> are indicated in the corresponding <code> 
 *  CreateResponse. </code> <code> CreateResponses </code> may be linked to 
 *  the originating <code> AppointmentForm </code> through the <code> 
 *  AppointmentForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> AppointmentForms </code> are requested to the 
 *  <code> Appointment </code> <code> Id </code> that is to be updated using 
 *  <code> getAppointmentFormsForUpdate() </code> where the reference <code> 
 *  Id </code> in the <code> AppointmentForm </code> may be used to link the 
 *  request. Similarly, the <code> AppointmentForm </code> has metadata about 
 *  the data that can be updated and it can perform validation before 
 *  submitting the update. The <code> AppointmentForm </code> can only be used 
 *  once for a successful update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> AppointmentForms </code> are submitted for 
 *  update, an <code> UpdateResponse </code> is returned for each <code> 
 *  AppointmentForm, </code> although the ordering is not defined. Only errors 
 *  that pertain to the entire update operation are returned from <code> 
 *  updateAppointments(), </code> errors specific to an individual <code> 
 *  AppointmentForm </code> are indicated in the corresponding <code> 
 *  UpdateResponse. </code> <code> UpdateResponses </code> may be linked to 
 *  the originating <code> AppointmentForm </code> through the <code> 
 *  AppointmentForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> Appointments </code> in bulk. To 
 *  unmap an <code> Appointment </code> from the current <code> Realm, </code> 
 *  the <code> AppointmentRealmAssignmentSession </code> should be used. These 
 *  delete operations attempt to remove the <code> Appointment </code> itself 
 *  thus removing it from all known <code> Realm </code> catalogs. Bulk delete 
 *  operations return the results in <code> DeleteResponses. </code> </p>
 */

public interface AppointmentBatchAdminSession
    extends org.osid.personnel.AppointmentAdminSession {


    /**
     *  Gets the appointment forms for creating a bunch of new appointments. A 
     *  form is returned for each supplied position and resource pair. 
     *
     *  @param  peers the relationship peers 
     *  @param  appointmentRecordTypes array of appointment record types to be 
     *          included in each create operation or an empty list if none 
     *  @return the appointment forms 
     *  @throws org.osid.NotFoundException a <code> personId </code> or <code> 
     *          positionId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> peers </code> or <code> 
     *          appointmentRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.batch.AppointmentBatchFormList getAppointmentFormsForCreate(org.osid.personnel.batch.AppointmentPeerList peers, 
                                                                                          org.osid.type.Type[] appointmentRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Appointments. </code> This method returns 
     *  an error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  appointmentForms the appointment forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> appointmentForms </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createAppointments(org.osid.personnel.batch.AppointmentBatchFormList appointmentForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the appointment forms for updating an existing set of 
     *  appointments. A new appointment form should be requested for each 
     *  update transaction. 
     *
     *  @param  appointmentIds the <code> Ids </code> of the <code> 
     *          Appointment </code> 
     *  @return the appointment form 
     *  @throws org.osid.NotFoundException an <code> appointmentId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> appointmentIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.batch.AppointmentBatchFormList getAppointmentFormsForUpdate(org.osid.id.IdList appointmentIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing appointments. This method returns an error if the 
     *  entire operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  appointmentForms the form containing the elements to be 
     *          updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> appointmentForms </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateAppointments(org.osid.personnel.batch.AppointmentBatchFormList appointmentForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Appointments </code> in this <code> Realm </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllAppointments()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes appointments for the given <code> Ids. </code> 
     *
     *  @param  appointmentIds the <code> Ids </code> of the appointments to 
     *          delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> appointmentIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAppointments(org.osid.id.IdList appointmentIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes appointments for the given person. 
     *
     *  @param  personId an <code> Id </code> of a person 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> personId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAppointmentsForPerson(org.osid.id.Id personId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes appointments for the given position. 
     *
     *  @param  positionId an <code> Id </code> of a position 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> positionId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAppointmentsForPosition(org.osid.id.Id positionId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes appointments expired before the given date. 
     *
     *  @param  date a date 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteIneffectiveAppointmentsByDate(org.osid.calendaring.DateTime date)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to an <code> Appointment </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Appointment </code> is determined by the provider. The new 
     *  <code> Id </code> is an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another appointment, it is reassigned to the 
     *  given appointment <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasAppointments(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
