//
// org.osid.personnel.batch.OrganizationBatchAdminSession
//
//     The OSID Java specification for org.osid.personnel.batch.OrganizationBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.personnel.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Organizations </code> 
 *  in bulk. The data for create and update is provided by the consumer via 
 *  the form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create an 
 *  <code> Organization, </code> an <code> OrganizationForm </code> is 
 *  requested using <code> getOrganizationFormsForCreate() </code> specifying 
 *  the desired record <code> Types </code> or none if no record <code> Types 
 *  </code> are needed. Each of the returned <code> OrganizationForms </code> 
 *  will indicate that it is to be used with a create operation and can be 
 *  used to examine metdata or validate data prior to creation. Once an <code> 
 *  OrganizationForm </code> is submiited to a create operation, it cannot be 
 *  reused with another create operation unless the first operation was 
 *  unsuccessful. Each <code> OrganizationForm </code> corresponds to an 
 *  attempted transaction. </p> 
 *  
 *  <p> The <code> OrganizationForms </code> returned from <code> 
 *  getOrganizationFormsForCreate() </code> may be linked to the originating 
 *  request through the peer <code> Ids </code> of the <code> 
 *  OrganizationForm. </code> In the case where there may be duplicates, any 
 *  <code> OrganizationForm </code> of the same peer <code> Ids </code> may be 
 *  used for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> OrganizationForms </code> are submitted for 
 *  create, a <code> CreateResponse </code> is returned for each <code> 
 *  OrganizationForm, </code> although the ordering is not defined. Only 
 *  errors that pertain to the entire create operation are returned from 
 *  <code> createOrganizations(), </code> errors specific to an individual 
 *  <code> OrganizationForm </code> are indicated in the corresponding <code> 
 *  CreateResponse. </code> <code> CreateResponses </code> may be linked to 
 *  the originating <code> OrganizationForm </code> through the <code> 
 *  OrganizationForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> OrganizationForms </code> are requested to the 
 *  <code> Organization </code> <code> Id </code> that is to be updated using 
 *  <code> getOrganizationFormsForUpdate() </code> where the reference <code> 
 *  Id </code> in the <code> OrganizationForm </code> may be used to link the 
 *  request. Similarly, the <code> OrganizationForm </code> has metadata about 
 *  the data that can be updated and it can perform validation before 
 *  submitting the update. The <code> OrganizationForm </code> can only be 
 *  used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> OrganizationForms </code> are submitted for 
 *  update, an <code> UpdateResponse </code> is returned for each <code> 
 *  OrganizationForm, </code> although the ordering is not defined. Only 
 *  errors that pertain to the entire update operation are returned from 
 *  <code> updateOrganizations(), </code> errors specific to an individual 
 *  <code> OrganizationForm </code> are indicated in the corresponding <code> 
 *  UpdateResponse. </code> <code> UpdateResponses </code> may be linked to 
 *  the originating <code> OrganizationForm </code> through the <code> 
 *  OrganizationForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> Organizations </code> in bulk. To 
 *  unmap an <code> Organization </code> from the current <code> Realm, 
 *  </code> the <code> OrganizationRealmAssignmentSession </code> should be 
 *  used. These delete operations attempt to remove the <code> Organization 
 *  </code> itself thus removing it from all known <code> Realm </code> 
 *  catalogs. Bulk delete operations return the results in <code> 
 *  DeleteResponses. </code> </p>
 */

public interface OrganizationBatchAdminSession
    extends org.osid.personnel.OrganizationAdminSession {


    /**
     *  Gets the organization forms for creating a bunch of new organizations. 
     *
     *  @param  number the number of forms to retrieve 
     *  @param  organizationRecordTypes array of organization record types to 
     *          be included in each create operation or an empty list if none 
     *  @return the organization forms 
     *  @throws org.osid.NullArgumentException <code> organizationRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.batch.OrganizationBatchFormList getOrganizationFormsForCreate(long number, 
                                                                                            org.osid.type.Type[] organizationRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Organizations. </code> This method returns 
     *  an error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  organizationForms the organization forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> organizationForms 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createOrganizations(org.osid.personnel.batch.OrganizationBatchFormList organizationForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the organization forms for updating an existing set of 
     *  organizations. A new organization form should be requested for each 
     *  update transaction. 
     *
     *  @param  organizationIds the <code> Ids </code> of the <code> 
     *          Organization </code> 
     *  @return the organization form 
     *  @throws org.osid.NotFoundException an <code> organizationId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> organizationIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.batch.OrganizationBatchFormList getOrganizationFormsForUpdate(org.osid.id.IdList organizationIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing organizations. This method returns an error if the 
     *  entire operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  organizationForms the form containing the elements to be 
     *          updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> organizationForms 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateOrganizations(org.osid.personnel.batch.OrganizationBatchFormList organizationForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Organizations </code> in this <code> Realm </code> 
     *  . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllOrganizations()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes organizations for the given <code> Ids. </code> 
     *
     *  @param  organizationIds the <code> Ids </code> of the organizations to 
     *          delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> organizationIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteOrganizations(org.osid.id.IdList organizationIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all organizations for the given resource. 
     *
     *  @param  resourceId an <code> Id </code> of a resource 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteOrganizationsForResource(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes organizations expired before the given date. 
     *
     *  @param  date a date 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteIneffectiveOrganizationsByDate(org.osid.calendaring.DateTime date)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to an <code> Organization </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Organization </code> is determined by the provider. The new 
     *  <code> Id </code> is an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another organization, it is reassigned to the 
     *  given organization <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasOrganizations(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
