/**
 * <p>The Open Service Interface Definitions for the org.osid.personnel
 * service.</p>
 * 
 * <p>The Personnel OSID defines people and organizations. </p> 
 * <h4> Persons </h4> 
 * 
 * <p> A <code> Person </code> is a people. <code> Persons </code> define 
 * identification information such as names and institutional identifiers. 
 * </p> 
 * <h4> Organization </h4> 
 * 
 * <p> An <code> Organization </code> is a hierarchical structure of 
 * organizational units. Every OsidCatalog has one organization hierarchy </p> 
 * <h4> Position </h4> 
 * 
 * <p> A <code> Position </code> is a job description performed in the context 
 * of an <code> Organization. </code> A <code> Position </code> has a job 
 * level represented using a Grade, optional salary range, as well as a set of 
 * learning <code> Objectives </code> used to convey the desired 
 * qualifications for the position. </p> 
 * 
 * <p> <code> Positions </code> are not canonical in that they belong to a 
 * specific <code> Organization </code> although <code> Positions </code> from 
 * parent <code> Organizations </code> may be visible to its sub 
 * organizational units. A canonical position that can be reused across 
 * Organizations can be represented with a combination of the <code> 
 * Positition </code> genus <code> Type </code> and <code> Grade </code> 
 * level. </p> 
 * <h4> Appointment </h4> 
 * 
 * <p> An <code> Appointment </code> is an <code> OsidRelationship </code> 
 * relating <code> Persons </code> to <code> Positions. </code> The effective 
 * dates of an <code> Appointment </code> may be used to indicate the term of 
 * employment. </p> 
 * <h4> Example </h4> 
 * 
 * <p> A software company is an <code> Organization </code> with each of a 
 * Sales, Marketing, and Engineering organizational unit. The Engineering 
 * <code> Organization </code> has 10 "level 6" programming <code> Positions 
 * </code> requiring a <code> Proficiency </code> in Java with a salary range 
 * of $110-$130K. Cathy holds one of these positions with a full-time <code> 
 * Appointment </code> at $125K and job title of "senior developer" busgeted 
 * under the Engineering department financial <code> Activity. </code> </p> 
 * <h4> Resource OSID Orchestration </h4> 
 * 
 * <p> OSIDs reference <code> Resources </code> for people, places, and 
 * things. The <code> Resource </code> provides a lightweight simple 
 * abstraction to satisfy the common case of resolving an OSID <code> Id 
 * </code> into a display name, genus <code> Type, </code> or description. In 
 * many cases, the <code> Resource </code> implies a <code> Person </code> or 
 * an <code> Organization. </code> </p> 
 * 
 * <p> The Personnel OSID provides a more detailed view of <code> Persons 
 * </code> and <code> Organizations </code> as well as capturing the 
 * relationships between employees and their organizational units. The 
 * Personnel OSID may supply the backing for a Resource OSID where it is 
 * desired to use these entities throughout other services. </p> 
 * <h4> Realm Cataloging </h4> 
 * 
 * <p> <code> Persons, Organizations, Positions </code> , and <code> 
 * Appointments </code> are mapped to <code> Realms </code> for organization. 
 * <code> Realms </code> can be managed hierarchically to federate multiple 
 * collections of <code> Persons </code> . </p> 
 * 
 * <p> Every <code> Realm </code> has one organization hierarchy. By selecting 
 * the <code> Realm is, </code> in effect, selecting the organizational 
 * hierarchy. Each hierarchy may expose multiple organizational roots that do 
 * not have to be related. Looking up and searching <code> Organizations 
 * </code> exposes all of their organizational units. It may be helpful to 
 * retrieve the organizational roots for a <code> Realm </code> and navigating 
 * from there. </p>
 * 
 * <br/><hr/><br/>
 * 
 * <p>Copyright &copy; 2012 Ingenescus. All Rights Reserved. </p>
 * 
 * <p>This Work is being provided by the copyright holder(s) subject to the 
 * following license. By obtaining, using and/or copying this Work, you agree 
 * that you have read, understand, and will comply with the following terms 
 * and conditions. </p> 
 * 
 * <p> Permission to use, copy and distribute unmodified versions of this 
 * Work, for any purpose, without fee or royalty is hereby granted, provided 
 * that you include the above copyright notices and the terms of this license 
 * on ALL copies of the Work or portions thereof. </p> 
 * 
 * <p> You may modify or create Derivatives of this Work only for your 
 * internal purposes. You shall not distribute or transfer any such Derivative 
 * of this Work to any location or to any third party. For the purposes of 
 * this license, "Derivative" shall mean any derivative of the Work as defined 
 * in the United States Copyright Act of 1976, such as a translation or 
 * modification. </p> 
 * 
 * <p> This Work and the information contained herein is provided on an "AS 
 * IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT 
 * NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR 
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT 
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN 
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN 
 * CONNECTION WITH THE WORK OR THE USE OR OTHER DEALINGS IN THE WORK. </p> 
 * 
 * <p> The export of software employing encryption technology may require a 
 * specific license from the United States Government. It is the 
 * responsibility of any person or organization contemplating export to obtain 
 * such a license before exporting this Work. </p>
 */

package org.osid.personnel;
