//
// org.osid.process.ProcessNotificationSession
//
//     The OSID Java specification for org.osid.process.ProcessNotificationSession.
//
// Copyright (C) 2009 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.process;


/**
 *  <p>This session defines methods to receive notifications on adds/changes 
 *  to <code> Process </code> objects. This session is intended for consumers 
 *  needing to synchronize their state with this service without the use of 
 *  polling. Notifications are cancelled when this session is closed. </p>
 */

public interface ProcessNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can register for <code> Process </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForProcessNotifications();


    /**
     *  Reliable notifications are desired. In reliable mode, notifications 
     *  are to be acknowledged using <code> acknowledgeProcessNotification() 
     *  </code> . 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void reliableProcessNotifications();


    /**
     *  Unreliable notifications are desired. In unreliable mode, 
     *  notifications do not need to be acknowledged. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void unreliableProcessNotifications();


    /**
     *  Acknowledge a process notification. 
     *
     *  @param  notificationId the <code> Id </code> of the notification 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void acknowledgeProcessNotification(org.osid.id.Id notificationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new processes. <code> 
     *  ProcessReceiver.newProcesses() </code> is invoked when a new <code> 
     *  Process </code> is created. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewProcesses()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated processes. <code> 
     *  ProcessReceiver.changedProcesses() </code> is invoked when a process 
     *  is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedProcesses()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated process. <code> 
     *  ProcessReceiver.changedProcesses() </code> is invoked when the 
     *  specified process is changed. 
     *
     *  @param  processId the <code> Id </code> of the Process to monitor 
     *  @throws org.osid.NullArgumentException <code> processId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedProcess(org.osid.id.Id processId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted processes. <code> 
     *  ProcessReceiver.deletedProcesses() </code> is invoked when a process 
     *  is deleted. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedProcesses()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted process. <code> 
     *  ProcessReceiver.deletedProcesses() </code> is invoked when the 
     *  specified process is deleted. 
     *
     *  @param  processId the <code> Id </code> of the <code> Process </code> 
     *          to monitor 
     *  @throws org.osid.NullArgumentException <code> processId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedProcess(org.osid.id.Id processId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated process hierarchy structure. 
     *  <code> ProcessReceiver.changedChildOfProcesses() </code> is invoked 
     *  when a node experiences a change in its children. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedProcessHierarchy()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated process hierarchy structure. 
     *  <code> ProcessReceiver.changedChildOfProcesss() </code> is invoked 
     *  when the specified node or any of its ancestors experiences a change 
     *  in its children. 
     *
     *  @param  processId the <code> Id </code> of the <code> Process </code> 
     *          node to monitor 
     *  @throws org.osid.NullArgumentException <code> processId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedProcessHierarchyForAncestors(org.osid.id.Id processId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated process hierarchy structure. 
     *  <code> ProcessReceiver.changedChildOfProcesses() </code> is invoked 
     *  when the specified node or any of its descendants experiences a change 
     *  in its children. 
     *
     *  @param  processId the <code> Id </code> of the <code> Process </code> 
     *          node to monitor 
     *  @throws org.osid.NullArgumentException <code> processId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedProcessHierarchyForDescendants(org.osid.id.Id processId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
