//
// org.osid.process.ProcessProfile
//
//     The OSID Java specification for org.osid.process.ProcessProfile.
//
// Copyright (C) 2009 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.process;


/**
 *  <p>The state profile describes interoperability among state services. </p>
 */

public interface ProcessProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if federation is visible. 
     *
     *  @return <code> true </code> if visible federation is supported <code> 
     *          , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if retrieving mappings of state and <code> Ids </code> is 
     *  supported. 
     *
     *  @return <code> true </code> if state mapping retrieval is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsState();


    /**
     *  Tests if managing mappings of states and <code> Ids </code> is 
     *  supported. 
     *
     *  @return <code> true </code> if state assignment is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStateAssignment();


    /**
     *  Tests if subscirbing to state change notifications is supported. 
     *
     *  @return <code> true </code> if state change notification is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStateChangeNotification();


    /**
     *  Tests if state lookup is supported. 
     *
     *  @return <code> true </code> if state lookup is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStateLookup();


    /**
     *  Tests if state query is supported. 
     *
     *  @return <code> true </code> if state query is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStateQuery();


    /**
     *  Tests if state search is supported. 
     *
     *  @return <code> true </code> if state search is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStateSearch();


    /**
     *  Tests if state administration is supported. 
     *
     *  @return <code> true </code> if state administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStateAdmin();


    /**
     *  Tests if state sequencing is supported. 
     *
     *  @return <code> true </code> if state sequencing is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStateSequencing();


    /**
     *  Tests if state notification is supported. Messages may be sent when 
     *  states are created, modified, or deleted. 
     *
     *  @return <code> true </code> if state notification is supported <code> 
     *          , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStateNotification();


    /**
     *  Tests if process lookup is supported. 
     *
     *  @return <code> true </code> if process lookup is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcessLookup();


    /**
     *  Tests if process query is supported. 
     *
     *  @return <code> true </code> if process query is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcessQuery();


    /**
     *  Tests if process search is supported. 
     *
     *  @return <code> true </code> if process search is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcessSearch();


    /**
     *  Tests if process administration is supported. 
     *
     *  @return <code> true </code> if process administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcessAdmin();


    /**
     *  Tests if process notification is supported. Messages may be sent when 
     *  <code> Process </code> objects are created, deleted or updated. 
     *  Notifications for states within processes are sent via the state 
     *  notification session. 
     *
     *  @return <code> true </code> if process notification is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcessNotification();


    /**
     *  Tests if a process hierarchy traversal is supported. 
     *
     *  @return <code> true </code> if a process hierarchy traversal is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcessHierarchy();


    /**
     *  Tests if a process hierarchy design is supported. 
     *
     *  @return <code> true </code> if a process hierarchy design is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcessHierarchyDesign();


    /**
     *  Gets all the state record types supported. 
     *
     *  @return the list of supported state record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getStateRecordTypes();


    /**
     *  Tests if a given state record type is supported. 
     *
     *  @param  stateRecordType the state type 
     *  @return <code> true </code> if the state record type is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> stateRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStateRecordType(org.osid.type.Type stateRecordType);


    /**
     *  Gets all the state search record types supported. 
     *
     *  @return the list of supported state search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getStateSearchRecordTypes();


    /**
     *  Tests if a given state search type is supported. 
     *
     *  @param  stateSearchRecordType the state search type 
     *  @return <code> true </code> if the state search record type is 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> stateRecordSearchType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStateSearchRecordType(org.osid.type.Type stateSearchRecordType);


    /**
     *  Gets all the process record types supported. 
     *
     *  @return the list of supported process record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getProcessRecordTypes();


    /**
     *  Tests if a given process record type is supported. 
     *
     *  @param  processRecordType the process record type 
     *  @return <code> true </code> if the process record type is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> processRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcessRecordType(org.osid.type.Type processRecordType);


    /**
     *  Gets all the process search record types supported. 
     *
     *  @return the list of supported process search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getProcessSearchRecordTypes();


    /**
     *  Tests if a given process search record type is supported. 
     *
     *  @param  processSearchRecordType the process search record type 
     *  @return <code> true </code> if the process search record type is 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> processSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcessSearchRecordType(org.osid.type.Type processSearchRecordType);
}
