//
// org.osid.process.ProcessQueryInspector
//
//     The OSID Java specification for org.osid.process.ProcessQueryInspector.
//
// Copyright (C) 2009 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.process;


/**
 *  <p>This is the query inspector for examining process queries. </p>
 */

public interface ProcessQueryInspector
    extends org.osid.OsidCatalogQueryInspector {


    /**
     *  Gets the state <code> Id </code> terms. 
     *
     *  @return the state <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getStateIdTerms();


    /**
     *  Gets the state terms. 
     *
     *  @return the state terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.process.StateQueryInspector[] getStateTerms();


    /**
     *  Gets the ancestor process <code> Id </code> terms. 
     *
     *  @return the ancestor process <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getAncestorProcessIdTerms();


    /**
     *  Gets the ancestor process terms. 
     *
     *  @return the ancestor process terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.process.ProcessQueryInspector[] getAncestorProcessTerms();


    /**
     *  Gets the descendant process <code> Id </code> terms. 
     *
     *  @return the descendant process <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getDescendantProcessIdTerms();


    /**
     *  Gets the descendant process terms. 
     *
     *  @return the descendant process terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.process.ProcessQueryInspector[] getDescendantProcessTerms();


    /**
     *  Gets the process query inspector record corresponding to the given 
     *  <code> Process </code> record <code> Type. </code> 
     *
     *  @param  processRecordType a process record type 
     *  @return the process query inspector record 
     *  @throws org.osid.NullArgumentException <code> processRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(processRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.process.records.ProcessQueryInspectorRecord getProcessQueryInspectorRecord(org.osid.type.Type processRecordType)
        throws org.osid.OperationFailedException;
}
