/**
 * <p>The Open Service Interface Definitions for the org.osid.process
 * service.</p>
 * 
 * <p>The Process OSID is an auxiliary service that manage <code> Processes 
 * </code> and mapping of external OSID <code> Ids </code> to </p> 
 * 
 * <p> <code> States. </code> </p> 
 * 
 * <p> Objects may take part in multiple processes simulataneously, and while 
 * an object can only be in one state within a process, an object may have 
 * more than one state across processes. An externally mapped <code> Id 
 * </code> is restricted to one <code> State </code> per <code> Process. 
 * </code> </p> 
 * <h4> Process </h4> 
 * 
 * <p> A <code> Process </code> is a collection of <code> States. </code> 
 * States are mapped to a Process to form a finite state machine. The 
 * StateSequencingSession can be used to design the FSM by specifying 
 * sequential set of next valid States. </p> 
 * <h4> State </h4> 
 * 
 * <p> A <code> State </code> is a simple <code> OsidObject </code> that 
 * captures the name and description of a state. A <code> State </code> 
 * belongs to a single <code> Process. </code> A process for representing the 
 * lifecycle of <code> Assets </code> and another process for representing the 
 * lifecycle of <code> Courses </code> may each define a "draft" state. Two 
 * <code> States </code> need to be created to represent the draft state of a 
 * course in the course lifecycle process and the draft state of an asset in 
 * the asset lifecycle process. </p> 
 * <h4> Process Catalog </h4> 
 * 
 * <p> A <code> Process </code> is an <code> OsidCatalog </code> of <code> 
 * States. </code> </p> 
 * 
 * <p> The standard catalog federating pattern was blindly applied which can 
 * create views of combined processes. What this means in practice is anyone's 
 * guess. </p> 
 * 
 * <p> As an auxiliary orchestrated service, a <code> Process </code> 
 * represents not only a collection of <code> States </code> but also the 
 * implicit object type of the mapped <code> Ids. </code> For example, the 
 * "Publishing Asset" process manages <code> Asset </code> <code> Ids </code> 
 * where all <code> Assets </code> in the orchestrated repository are known 
 * and already in some initial <code> State. </code> </p> 
 * <h4> Workflow </h4> 
 * 
 * <p> The Workflow OSID defines a service to move <code> Work </code> through 
 * a series of <code> Steps </code> in a <code> Process. </code> The Process 
 * OSID is the flip side of the Workflow OSID where the <code> Work </code> is 
 * the external <code> Id </code> and the <code> Step </code> is the State. 
 * The Process OSID can be considered a view geared toward a state model where 
 * it is desirable to understand what is occurring from the object's point of 
 * view. The Resourcing OSID is the other service in this trinity defining the 
 * service from the worker's point of view. </p>
 * 
 * <br/><hr/><br/>
 * 
 * <p>Copyright &copy; 2009 Massachusetts Institute of Technology. </p> 
 * 
 * <p> Copyright &copy; 2010 Ingenescus All Rights Reserved. </p>
 * 
 * <p>This Work is being provided by the copyright holder(s) subject to the 
 * following license. By obtaining, using and/or copying this Work, you agree 
 * that you have read, understand, and will comply with the following terms 
 * and conditions. </p> 
 * 
 * <p> Permission to use, copy and distribute unmodified versions of this 
 * Work, for any purpose, without fee or royalty is hereby granted, provided 
 * that you include the above copyright notices and the terms of this license 
 * on ALL copies of the Work or portions thereof. </p> 
 * 
 * <p> You may nodify or create Derivatives of this Work only for your 
 * internal purposes. You shall not distribute or transfer any such Derivative 
 * of this Work to any location or to any third party. For the purposes of 
 * this license, "Derivative" shall mean any derivative of the Work as defined 
 * in the United States Copyright Act of 1976, such as a translation or 
 * modification. </p> 
 * 
 * <p> This Work and the information contained herein is provided on an "AS 
 * IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT 
 * NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR 
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT 
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN 
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN 
 * CONNECTION WITH THE WORK OR THE USE OR OTHER DEALINGS IN THE WORK. </p> 
 * 
 * <p> The export of software employing encryption technology may require a 
 * specific license from the United States Government. It is the 
 * responsibility of any person or organization contemplating export to obtain 
 * such a license before exporting this Work. </p>
 */

package org.osid.process;
