//
// org.osid.profile.ProfileEntry
//
//     The OSID Java specification for org.osid.profile.ProfileEntry.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.profile;


/**
 *  <p>An ProfileEntry is a mapping among an <code> Agent </code> or <code> 
 *  Resource, </code> and a <code> ProfileItem. </code> This interface is not 
 *  required for performing a profile check but is used for examining and 
 *  managing profiles. </p> 
 *  
 *  <p> The actor of an profile may be specified in a variety of forms. </p> 
 *  
 *  <ul>
 *      <li> <code> Agent </code> </li> 
 *      <li> <code> Resource: </code> the profile provider uses all the <code> 
 *      Agents </code> associated with a <code> Resource </code> for matching 
 *      profiles </li> 
 *  </ul>
 *  
 *  
 *  <p> An explicit <code> ProfileEntry </code> represents the mappings as 
 *  they are specified in the profile provdier. Implicit profile entries may 
 *  be retrieved which are profile entries inferred through the <code> 
 *  ProfileItem </code> hierarchy. An implicit <code> ProfileEntry </code> is 
 *  one where <code> isImplicit() </code> is true and should not be used for 
 *  modification as it is only available for auditing purposes. </p> 
 *  
 *  <p> An <code> ProfileEntry </code> containing a <code> Resource </code> 
 *  may also provide the associated Agent in a request for implicit profiles 
 *  or for all the profiles, both explicit and implicit, for a given <code> 
 *  Agent. </code> </p>
 */

public interface ProfileEntry
    extends org.osid.OsidRelationship {


    /**
     *  Tests if this profile entry is implicitly generated. 
     *
     *  @return <code> true </code> if this profile entry is implicit, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isImplicit();


    /**
     *  Tests if this profile entry has a <code> Resource. </code> 
     *
     *  @return <code> true </code> if this profile entry has a <code> 
     *          Resource, </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasResource();


    /**
     *  Gets the <code> resource Id </code> for this profile entry. 
     *
     *  @return the <code> Resource Id </code> 
     *  @throws org.osid.IllegalStateException <code> hasResource() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getResourceId();


    /**
     *  Gets the <code> Resource </code> for this profile ebtry. 
     *
     *  @return the <code> Resource </code> 
     *  @throws org.osid.IllegalStateException <code> hasResource() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getResource()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this profile entry has an <code> Agent. </code> An implied 
     *  profile entry may have an <code> Agent </code> in addition to a 
     *  specified <code> Resource. </code> 
     *
     *  @return <code> true </code> if this profile entry has an <code> Agent, 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasAgent();


    /**
     *  Gets the <code> Agent Id </code> for this profile entry. 
     *
     *  @return the <code> Agent Id </code> 
     *  @throws org.osid.IllegalStateException <code> hasAgent() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAgentId();


    /**
     *  Gets the <code> Agent </code> for this profile entry. 
     *
     *  @return the <code> Agent </code> 
     *  @throws org.osid.IllegalStateException <code> hasAgent() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.Agent getAgent()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> ProfileItem </code> <code> Id </code> for this profile 
     *  entry. 
     *
     *  @return the profile item <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getProfileItemId();


    /**
     *  Gets the <code> ProfileItem </code> for this profile entry. 
     *
     *  @return the profile item 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileItem getProfileItem()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the proile entry record corresponding to the given <code> 
     *  ProfileEntry </code> record <code> Type. </code> This method ie used 
     *  to retrieve an object implementing the requested record. The <code> 
     *  profileEntryRecordType </code> may be the <code> Type </code> returned 
     *  in <code> getRecordTypes() </code> or any of its parents in a <code> 
     *  Type </code> hierarchy where <code> 
     *  hasRecordType(profileEntryRecordType) </code> is <code> true </code> . 
     *
     *  @param  profileEntryRecordType the type of the record to retrieve 
     *  @return the profile entry record 
     *  @throws org.osid.NullArgumentException <code> profileEntryRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(profileEntryRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.records.ProfileEntryRecord getProfileEntryRecord(org.osid.type.Type profileEntryRecordType)
        throws org.osid.OperationFailedException;
}
