//
// org.osid.profile.ProfileEntryLookupSession
//
//     The OSID Java specification for org.osid.profile.ProfileEntryLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.profile;


/**
 *  <p>This session defines methods to search and retrieve <code> ProfileEntry 
 *  </code> mappings. </p> 
 *  
 *  <p> This lookup session defines two sets of views: </p> 
 *  
 *  <ul>
 *      <li> isolated profile view: All profile methods in this session 
 *      operate, retrieve and pertain to <code> ProfileEntries </code> defined 
 *      explicitly in the current <code> Profile. </code> Using an isolated 
 *      view is useful for managing <code> ProfileEntries </code> with the 
 *      <code> ProfileEntryAdminSession. </code> </li> 
 *      <li> federated profile view; All profile methods in this session 
 *      operate, retrieve and pertain to all profile entries defined in this 
 *      profile and any other entries implicitly available in this profile 
 *      through profile inheritence. </li> 
 *      <li> effective profile entry view: All profil eentry lookup methods 
 *      return edges where the current dates falls in between the effective 
 *      dates inclusive. </li> 
 *      <li> any effective profile entry edge view: Profil eentries of any 
 *      effective date are returned. </li> 
 *      <li> explicit profile entry view: All profile methods in this session 
 *      operate, retrieve and pertain to only those profile entries that have 
 *      been explicitly defined and not derived from <code> Resource </code> 
 *      groups. </li> 
 *      <li> implicit profile entry view; All profile entry methods in this 
 *      session operate, retrieve and pertain to all profile entries including 
 *      those derived from <code> Resource </code> groups. </li> 
 *      <li> explicit resource view: Only show profile entries explicitly 
 *      mapped to the given resource when looking up profile entries by 
 *      resource. </li> 
 *      <li> implicit resource view: Include all profile entries related to 
 *      the resource including profile entries using any agent of the 
 *      resource. </li> 
 *  </ul>
 *  
 *  
 *  <p> The view methods such as <code> useExplicitProfileEntryView() </code> 
 *  and <code> useImplicitProfileEntryView() </code> behave as a radio group 
 *  and one should be selected before invoking any lookup methods. </p>
 */

public interface ProfileEntryLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Profile </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Profile Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getProfileId();


    /**
     *  Gets the <code> Profile </code> associated with this session. 
     *
     *  @return the <code> Profile </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.Profile getProfile()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform profile lookups. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupProfileEntries();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeProfileEntryView();


    /**
     *  A complete view of the <code> ProfileEntry </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryProfileEntryView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include profile entries in profiles which are children of this profile 
     *  in the profile hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedProfileView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this profile only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedProfileView();


    /**
     *  Only profile entries whose effective dates are current are returned by 
     *  methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useEffectiveProfileEntryView();


    /**
     *  All profile entries of any effective dates are returned by all methods 
     *  in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyEffectiveProfileEntryView();


    /**
     *  Sets the view for methods in this session to implicit profile entries. 
     *  An implicit view will include profile entries derived from other 
     *  entries as a result of the <code> ProfileItem </code> or <code> 
     *  Resource </code> hierarchies. This method is the opposite of <code> 
     *  explicitProfileEntryView(). </code> 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useImplicitProfileEntryView();


    /**
     *  Sets the view for methods in this session to explicit profile entries. 
     *  An explicit view includes only those profile entries that were 
     *  explicitly defined and not implied. This method is the opposite of 
     *  <code> implicitProfileEntryView(). </code> 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useExplicitProfileEntryView();


    /**
     *  Include profile entries of any agent of a resource when looking up 
     *  profile entries by resource. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useImplicitResourceView();


    /**
     *  Only include profile entries explicitly mapped to the given resource 
     *  when looking up profile entries by resource. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useExplicitResourceView();


    /**
     *  Gets the <code> ProfileEntry </code> specified by its <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  ProfileEntry </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to an <code> ProfileEntry </code> and retained for 
     *  compatibility. 
     *  
     *  In effective mode, profile entries are returned that are currently 
     *  effective. In any effective mode, effective profile entries and those 
     *  currently expired are returned. 
     *
     *  @param  profileEntryId the <code> Id </code> of the <code> 
     *          ProfileEntry </code> to retrieve 
     *  @return the returned <code> ProfileEntry </code> 
     *  @throws org.osid.NotFoundException no <code> ProfileEntry </code> 
     *          found with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> profileEntryId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileEntry getProfileEntry(org.osid.id.Id profileEntryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ProfileEntryList </code> corresponding to the given 
     *  <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  entries specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> ProfileEntries </code> may be omitted from the 
     *  list and may present the elements in any order including returning a 
     *  unique set. 
     *  
     *  In effective mode, profile entries are returned that are currently 
     *  effective. In any effective mode, effective profile entries and those 
     *  currently expired are returned. 
     *
     *  @param  profileEntryIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> ProfileEntry list </code> 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> profileEntryIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileEntryList getProfileEntriesByIds(org.osid.id.IdList profileEntryIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProfileEntryList </code> corresponding to the given 
     *  profile entry genus <code> Type </code> which does not include profile 
     *  entries of genus types derived from the specified <code> Type. </code> 
     *  
     *  In plenary mode, the returned list contains all known profile entries 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those profile ebtries that are accessible through this session. 
     *  
     *  In effective mode, profile entries are returned that are currently 
     *  effective. In any effective mode, effective profile entries and those 
     *  currently expired are returned. 
     *
     *  @param  profileEntryGenusType a profile entry genus type 
     *  @return the returned <code> ProfileEntry </code> list 
     *  @throws org.osid.NullArgumentException <code> profileEntryGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileEntryList getProfileEntriesByGenusType(org.osid.type.Type profileEntryGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProfileEntryList </code> corresponding to the given 
     *  profile entry genus <code> Type and </code> include profile entries of 
     *  genus types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  profile entries or an error results. Otherwise, the returned list may 
     *  contain only those profile ebtries that are accessible through this 
     *  session. 
     *  
     *  In effective mode, profile entries are returned that are currently 
     *  effective. In any effective mode, effective profile entries and those 
     *  currently expired are returned. 
     *
     *  @param  profileEntryGenusType a profile entry genus type 
     *  @return the returned <code> ProfileEntry </code> list 
     *  @throws org.osid.NullArgumentException <code> profileEntryGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileEntryList getProfileEntriesByParentGenusType(org.osid.type.Type profileEntryGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProfileEntryList </code> containing the given profile 
     *  entry record <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  profile entries or an error results. Otherwise, the returned list may 
     *  contain only those profile entries that are accessible through this 
     *  session. 
     *  
     *  In effective mode, profile entries are returned that are currently 
     *  effective. In any effective mode, effective profile entries and those 
     *  currently expired are returned. 
     *
     *  @param  profileEntryRecordType a profile entry record type 
     *  @return the returned <code> ProfileEntry </code> list 
     *  @throws org.osid.NullArgumentException <code> profileEntryRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileEntryList getProfileEntriesByRecordType(org.osid.type.Type profileEntryRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProfileEntryList </code> effective date during the 
     *  entire given date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known authorizations 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those authorizations that are accessible through this session. 
     *  
     *  In effective mode, profile entries are returned that are currently 
     *  effective in addition to being effective durting the date range. In 
     *  any effective mode, effective profile entries and those currently 
     *  expired are returned. 
     *
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> ProfileEntry </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileEntryList getProfileEntriesOnDate(org.osid.calendaring.DateTime from, 
                                                                     org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of <code> ProfileEntries </code> associated for entries 
     *  related to a given resource. 
     *  
     *  In explicit resource view, only include entries with the given 
     *  resource. In implicit resource view, also include entries using any 
     *  agent of the given resource. 
     *  
     *  In plenary mode, the returned list contains all known profile entries 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those profile ebtries that are accessible through this session. 
     *  
     *  In effective mode, profile entries are returned that are currently 
     *  effective. In any effective mode, effective profile entries and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @return the returned <code> ProfileEntry list </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileEntryList getProfileEntriesForResource(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProfileEntryList </code> for entries explicitly mapped 
     *  to a given resource and effective during the entire given date range 
     *  inclusive but not confined to the date range. 
     *  
     *  In explicit resource view, only include entries with the given 
     *  resource. In implicit resource view, also include entries using any 
     *  agent of the given resource. 
     *  
     *  In plenary mode, the returned list contains all known authorizations 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those authorizations that are accessible through this session. 
     *  
     *  In effective mode, profile entries are returned that are currently 
     *  effective. In any effective mode, effective profile entries and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> ProfileEntry </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, from </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileEntryList getProfileEntriesForResourceOnDate(org.osid.id.Id resourceId, 
                                                                                org.osid.calendaring.DateTime from, 
                                                                                org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of <code> ProfileEntries </code> associated with a given 
     *  agent. 
     *  
     *  In plenary mode, the returned list contains all known profile entries 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those profile ebtries that are accessible through this session. 
     *  
     *  In effective mode, profile entries are returned that are currently 
     *  effective. In any effective mode, effective profile entries and those 
     *  currently expired are returned. 
     *
     *  @param  agentId an agent <code> Id </code> 
     *  @return the returned <code> ProfileEntry list </code> 
     *  @throws org.osid.NullArgumentException <code> agentId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileEntryList getProfileEntriesForAgent(org.osid.id.Id agentId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProfileEntryList </code> for the given agent and 
     *  effective during the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known authorizations 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those authorizations that are accessible through this session. 
     *  
     *  In effective mode, profile entries are returned that are currently 
     *  effective in addition to being effective during the date range. In any 
     *  effective mode, effective profile entries and those currently expired 
     *  are returned. 
     *
     *  @param  agentId an agent <code> Id </code> 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> ProfileEntry </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> agentId, from </code> or 
     *          <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileEntryList getProfileEntriesForAgentOnDate(org.osid.id.Id agentId, 
                                                                             org.osid.calendaring.DateTime from, 
                                                                             org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProfileEntryList </code> for a given profile item. 
     *  
     *  In plenary mode, the returned list contains all known profile entries 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those profile entries that are accessible through this session. 
     *  
     *  In effective mode, profile entries are returned that are currently 
     *  effective. In any effective mode, effective profile entries and those 
     *  currently expired are returned. 
     *
     *  @param  profileItemId a profile item <code> Id </code> 
     *  @return the returned <code> ProfileEntry list </code> 
     *  @throws org.osid.NullArgumentException <code> profileItemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileEntryList getProfileEntriesForProfileItem(org.osid.id.Id profileItemId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProfileEntryList </code> for the given profile item and 
     *  effective during the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known authorizations 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those authorizations that are accessible through this session. 
     *  
     *  In effective mode, profile entries are returned that are currently 
     *  effectiv in addition to being effective during the date range. In any 
     *  effective mode, effective profile entries and those currently expired 
     *  are returned. 
     *
     *  @param  profileItemId a profile item <code> Id </code> 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> ProfileEntry </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> profileItemId, from 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileEntryList getProfileEntriesForProfileItemOnDate(org.osid.id.Id profileItemId, 
                                                                                   org.osid.calendaring.DateTime from, 
                                                                                   org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of <code> ProfileEntries </code> associated for entries 
     *  explicitly mapped to a given resource and profile item. 
     *  
     *  In explicit resource view, only include entries with the given 
     *  resource. In implicit resource view, also include entries using any 
     *  agent of the given resource. 
     *  
     *  In plenary mode, the returned list contains all known profile entries 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those profile ebtries that are accessible through this session. 
     *  
     *  In effective mode, profile entries are returned that are currently 
     *  effective. In any effective mode, effective profile entries and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  profileItemId a profile item <code> Id </code> 
     *  @return the returned <code> ProfileEntry list </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> or 
     *          <code> profileItemId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileEntryList getProfileEntriesForResourceAndProfileItem(org.osid.id.Id resourceId, 
                                                                                        org.osid.id.Id profileItemId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProfileEntryList </code> for entries explicitly mapped 
     *  to a given resource and profile item and effective during the entire 
     *  given date range inclusive but not confined to the date range. 
     *  
     *  In explicit resource view, only include entries with the given 
     *  resource. In implicit resource view, also include entries using any 
     *  agent of the given resource. 
     *  
     *  In plenary mode, the returned list contains all known authorizations 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those authorizations that are accessible through this session. 
     *  
     *  In effective mode, profile entries are returned that are currently 
     *  effective. In any effective mode, effective profile entries and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  profileItemId a profile item <code> Id </code> 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> ProfileEntry </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, 
     *          profileItemId, from </code> or <code> to </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileEntryList getProfileEntriesForResourceAndProfileItemOnDate(org.osid.id.Id resourceId, 
                                                                                              org.osid.id.Id profileItemId, 
                                                                                              org.osid.calendaring.DateTime from, 
                                                                                              org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of <code> ProfileEntries </code> associated for entries 
     *  explicitly mapped to a given agent and profile item. 
     *  
     *  In plenary mode, the returned list contains all known profile entries 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those profile ebtries that are accessible through this session. 
     *  
     *  In effective mode, profile entries are returned that are currently 
     *  effective. In any effective mode, effective profile entries and those 
     *  currently expired are returned. 
     *
     *  @param  agentId an agent <code> Id </code> 
     *  @param  profileItemId a profile item <code> Id </code> 
     *  @return the returned <code> ProfileEntry list </code> 
     *  @throws org.osid.NullArgumentException <code> agentId </code> or 
     *          <code> profileItemId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileEntryList getProfileEntriesForAgentAndProfileItem(org.osid.id.Id agentId, 
                                                                                     org.osid.id.Id profileItemId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProfileEntryList </code> for entries explicitly mapped 
     *  to a given agent and profile item and effective during the entire 
     *  given date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known authorizations 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those authorizations that are accessible through this session. 
     *  
     *  In effective mode, profile entries are returned that are currently 
     *  effective. In any effective mode, effective profile entries and those 
     *  currently expired are returned. 
     *
     *  @param  agentId an agent <code> Id </code> 
     *  @param  profileItemId a profile item <code> Id </code> 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> ProfileEntry </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> agentId, profileItemId, 
     *          from </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileEntryList getProfileEntriesForAgentAndProfileItemOnDate(org.osid.id.Id agentId, 
                                                                                           org.osid.id.Id profileItemId, 
                                                                                           org.osid.calendaring.DateTime from, 
                                                                                           org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the explicit <code> ProfileEntry </code> that generated the given 
     *  implicit profile entry. If the given <code> ProfileEntry </code> is 
     *  explicit, then the same <code> ProfileEntry </code> is returned. 
     *
     *  @param  profileEntryId a profile entry 
     *  @return the explicit <code> ProfileEntry </code> 
     *  @throws org.osid.NotFoundException <code> profileEntryId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> profileEntryId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileEntry getExplicitProfileEntry(org.osid.id.Id profileEntryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Geta all <code> ProfileEntries. </code> 
     *  
     *  In plenary mode, the returned list contains all known profile entries 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those profile ebtries that are accessible through this session. 
     *  
     *  In effective mode, profile entries are returned that are currently 
     *  effective. In any effective mode, effective profile entries and those 
     *  currently expired are returned. 
     *
     *  @return a list of <code> ProfileEntries </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileEntryList getProfileEntries()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
