//
// org.osid.profile.ProfileEntryProfileAssignmentSession
//
//     The OSID Java specification for org.osid.profile.ProfileEntryProfileAssignmentSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.profile;


/**
 *  <p>This session provides methods to re-assign profile entries to <code> 
 *  Profile. </code> A <code> ProfileEntry </code> may map to multiple <code> 
 *  Profile </code> objects and removing the last reference to a <code> 
 *  ProfileEntry </code> is the equivalent of deleting it. Each <code> Profile 
 *  </code> may have its own authorizations governing who is allowed to 
 *  operate on it. </p> 
 *  
 *  <p> Moving or adding a reference of a <code> ProfileEntry </code> to 
 *  another <code> Profile </code> is not a copy operation (eg: does not 
 *  change its <code> Id </code> ). </p>
 */

public interface ProfileEntryProfileAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter profile entry/profile mappings. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignProfileEntries();


    /**
     *  Tests if this user can alter profile entry/profile mappings. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @param  profileId the <code> Id </code> of the <code> Profile </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> profileId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignProfileEntriesToProfile(org.osid.id.Id profileId);


    /**
     *  Gets a list of profile including and under the given profile node in 
     *  which any profile entry can be assigned. 
     *
     *  @param  profileId the <code> Id </code> of the <code> Profile </code> 
     *  @return list of assignable profile <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> profileId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableProfileIds(org.osid.id.Id profileId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of profile including and under the given profile node in 
     *  which a specific profile entry can be assigned. 
     *
     *  @param  profileId the <code> Id </code> of the <code> Profile </code> 
     *  @param  profileEntryId the <code> Id </code> of the <code> 
     *          ProfileEntry </code> 
     *  @return list of assignable profile <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> profileId </code> or 
     *          <code> profileEntryId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableProfileIdsForProfileEntry(org.osid.id.Id profileId, 
                                                                     org.osid.id.Id profileEntryId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> ProfileEntry </code> to a <code> Profile. 
     *  </code> 
     *
     *  @param  profileEntryId the <code> Id </code> of the <code> 
     *          ProfileEntry </code> 
     *  @param  profileId the <code> Id </code> of the <code> Profile </code> 
     *  @throws org.osid.AlreadyExistsException <code> profileEntryId </code> 
     *          is already assigned to <code> profileId </code> 
     *  @throws org.osid.NotFoundException <code> profileEntryId </code> or 
     *          <code> profileId </code> not found 
     *  @throws org.osid.NullArgumentException <code> profileEntryId </code> 
     *          or <code> profileId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignProfileEntryToProfile(org.osid.id.Id profileEntryId, 
                                            org.osid.id.Id profileId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> ProfileEntry </code> from a <code> Profile. </code> 
     *
     *  @param  profileEntryId the <code> Id </code> of the <code> 
     *          ProfileEntry </code> 
     *  @param  profileId the <code> Id </code> of the <code> Profile </code> 
     *  @throws org.osid.NotFoundException <code> profileEntryId </code> or 
     *          <code> profileId </code> not found or <code> profileEntryId 
     *          </code> not assigned to <code> profileId </code> 
     *  @throws org.osid.NullArgumentException <code> profileEntryId </code> 
     *          or <code> profileId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignProfileEntryFromProfile(org.osid.id.Id profileEntryId, 
                                                org.osid.id.Id profileId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Moves a <code> ProfileEntry </code> from one <code> Profile </code> to 
     *  another. Mappings to other <code> Profiles </code> are unaffected. 
     *
     *  @param  profileEntryId the <code> Id </code> of the <code> 
     *          ProfileEntry </code> 
     *  @param  fromProfileId the <code> Id </code> of the current <code> 
     *          Profile </code> 
     *  @param  toProfileId the <code> Id </code> of the destination <code> 
     *          Profile </code> 
     *  @throws org.osid.NotFoundException <code> profileEntryId, 
     *          fromProfileId, </code> or <code> toProfileId </code> not found 
     *          or <code> profileEntryId </code> not mapped to <code> 
     *          fromProfileId </code> 
     *  @throws org.osid.NullArgumentException <code> profileEntryId, 
     *          fromProfileId, </code> or <code> toProfileId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void reassignProfileEntryToProfile(org.osid.id.Id profileEntryId, 
                                              org.osid.id.Id fromProfileId, 
                                              org.osid.id.Id toProfileId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
