//
// org.osid.profile.ProfileEntryProfileSession
//
//     The OSID Java specification for org.osid.profile.ProfileEntryProfileSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.profile;


/**
 *  <p>This session provides methods to retrieve <code> ProfileEntry </code> 
 *  to <code> Profile </code> mappings. A <code> ProfileEntry </code> may 
 *  appear in multiple <code> Profile.s </code> Each <code> Profile </code> 
 *  may have its own authorizations governing who is allowed to look at it. 
 *  </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *  </ul>
 *  
 */

public interface ProfileEntryProfileSession
    extends org.osid.OsidSession {


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeProfileView();


    /**
     *  A complete view of the <code> ProfileEntry </code> and <code> Profile 
     *  </code> returns is desired. Methods will return what is requested or 
     *  result in an error. This view is used when greater precision is 
     *  desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryProfileView();


    /**
     *  Tests if this user can perform lookups of profile entry/profile 
     *  mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known lookup 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if looking up mappings is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupProfileEntryProfileMappings();


    /**
     *  Gets the list of <code> ProfileEntry </code> <code> Ids </code> 
     *  associated with a <code> Profile. </code> 
     *
     *  @param  profileId <code> Id </code> of a <code> Profile </code> 
     *  @return list of related profile entry <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> profileId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> profileId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getProfileEntryIdsByProfile(org.osid.id.Id profileId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> ProfileEntries </code> associated with a 
     *  <code> Profile. </code> 
     *
     *  @param  profileId <code> Id </code> of a <code> Profile </code> 
     *  @return list of related profile entry 
     *  @throws org.osid.NotFoundException <code> profileId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> profileId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileEntryList getProfileEntriesByProfile(org.osid.id.Id profileId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> ProfileEntry Ids </code> corresponding to a 
     *  list of <code> Profile </code> objects. 
     *
     *  @param  profileIds list of profile <code> Ids </code> 
     *  @return list of profile entry <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> profileIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getProfileEntriesIdsByProfile(org.osid.id.IdList profileIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> ProfileEntries </code> corresponding to a list 
     *  of <code> Profile. </code> 
     *
     *  @param  profileIds list of profile <code> Ids </code> 
     *  @return list of profile entries 
     *  @throws org.osid.NullArgumentException <code> profileIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileEntryList getProfileEntriesByProfile(org.osid.id.IdList profileIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> Profile </code> <code> Ids </code> mapped to a 
     *  <code> ProfileEntry. </code> 
     *
     *  @param  profileEntryId <code> Id </code> of a <code> ProfileEntry 
     *          </code> 
     *  @return list of profile <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> profileEntryId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> profileEntryId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getProfileIdsByProfileEntry(org.osid.id.Id profileEntryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> Profile </code> objects mapped to a <code> 
     *  ProfileEntry. </code> 
     *
     *  @param  profileEntryId <code> Id </code> of a <code> ProfileEntry 
     *          </code> 
     *  @return list of profile 
     *  @throws org.osid.NotFoundException <code> profileEntryId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> profileEntryId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileList getProfileByProfileEntry(org.osid.id.Id profileEntryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
