//
// org.osid.profile.ProfileEntryQuery
//
//     The OSID Java specification for org.osid.profile.ProfileEntryQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.profile;


/**
 *  <p>The query for profile entries. </p>
 */

public interface ProfileEntryQuery
    extends org.osid.OsidRelationshipQuery {


    /**
     *  Matches implicit profile entries. 
     *
     *  @param  match <code> true </code> ito match implicit profile entries, 
     *          <code> false </code> to match implciit profile entries 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchImplicit(boolean match);


    /**
     *  Clears the implicit profile entries query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearImplicitTerms();


    /**
     *  Adds an <code> Id </code> to match an explicit or implicitly related 
     *  profile entries depending on <code> matchExplicitProfileEntries(). 
     *  </code> Multiple <code> Ids </code> can be added to perform a boolean 
     *  <code> OR </code> among them. 
     *
     *  @param  id <code> Id </code> to match 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> id </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRelatedProfileEntryId(org.osid.id.Id id, boolean match);


    /**
     *  Clears the related profile entry <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRelatedProfileEntryIdTerms();


    /**
     *  Tests if a <code> ProfileEntryQuery </code> is available. 
     *
     *  @return <code> true </code> if a profile entry query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelatedProfileEntryQuery();


    /**
     *  Gets the query for a profile entry. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the profile entry query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelatedProfileEntryQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelatedProfileEntryQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.profile.ProfileEntryQuery getRelatedProfileEntryQuery();


    /**
     *  Clears the related profile entry query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRelatedProfileEntryTerms();


    /**
     *  Matches the resource identified by the given <code> Id. </code> 
     *
     *  @param  resourceId the Id of the <code> Resource </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchResourceId(org.osid.id.Id resourceId, boolean match);


    /**
     *  Clears the resource <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearResourceIdTerms();


    /**
     *  Tests if a <code> ResourceQuery </code> is available. 
     *
     *  @return <code> true </code> if a resource query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceQuery();


    /**
     *  Gets the resource query. 
     *
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @return the <code> ResourceQuery </code> 
     *  @throws org.osid.UnimplementedException <code> supportsResourceQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceQuery getResourceQuery(boolean match);


    /**
     *  Clears the resource terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearResourceTerms();


    /**
     *  Matches the agent identified by the given <code> Id. </code> 
     *
     *  @param  agentId the Id of the <code> Agent </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> agentId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAgentId(org.osid.id.Id agentId, boolean match);


    /**
     *  Clears the agent <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAgentIdTerms();


    /**
     *  Tests if an <code> AgentQuery </code> is available. 
     *
     *  @return <code> true </code> if an agent query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAgentQuery();


    /**
     *  Gets the agent query. 
     *
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @return the <code> AgentQuery </code> 
     *  @throws org.osid.UnimplementedException <code> supportsAgentQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAgentQuery() </code> is <code> true. </code> 
     */

    public org.osid.authentication.AgentQuery getAgentQuery(boolean match);


    /**
     *  Clears the agent terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAgentTerms();


    /**
     *  Matches the profile item identified by the given <code> Id. </code> 
     *
     *  @param  profileItemId the Id of the <code> ProfileItem </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> profileItemId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchProfileItemId(org.osid.id.Id profileItemId, boolean match);


    /**
     *  Clears the profile item <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProfileItemIdTerms();


    /**
     *  Tests if a <code> ProfileItemQuery </code> is available. 
     *
     *  @return <code> true </code> if a profile item query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProfileItemQuery();


    /**
     *  Gets the profile item query. 
     *
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @return the <code> FunctinQuery </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileItemQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileItemQuery() </code> is <code> true. </code> 
     */

    public org.osid.profile.ProfileItemQuery getProfileItemQuery(boolean match);


    /**
     *  Clears the profile item terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProfileItemTerms();


    /**
     *  Sets the profile <code> Id </code> for this query. 
     *
     *  @param  profileId a profile <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> profileId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchProfileId(org.osid.id.Id profileId, boolean match);


    /**
     *  Clears the profile <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProfileIdTerms();


    /**
     *  Tests if a <code> ProfileQuery </code> is available. 
     *
     *  @return <code> true </code> if a profile query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProfileQuery();


    /**
     *  Gets the query interface for a profile. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the profile query 
     *  @throws org.osid.UnimplementedException <code> supportsProfileQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileQuery() </code> is <code> true. </code> 
     */

    public org.osid.profile.ProfileQuery getProfileQuery();


    /**
     *  Clears the profile entry query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProfileTerms();


    /**
     *  Gets the profile entry query record corresponding to the given <code> 
     *  ProfileEntry </code> record <code> Type. </code> Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @param  profileEntryRecordType a profile entry record type 
     *  @return the profile entry query record 
     *  @throws org.osid.NullArgumentException <code> profileEntryRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(profileEntryRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.records.ProfileEntryQueryRecord getProfileEntryQueryRecord(org.osid.type.Type profileEntryRecordType)
        throws org.osid.OperationFailedException;
}
