//
// org.osid.profile.ProfileEntrySearchSession
//
//     The OSID Java specification for org.osid.profile.ProfileEntrySearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.profile;


/**
 *  <p>This session provides methods for searching <code> ProfileEntry </code> 
 *  objects. The search query is constructed using the <code> 
 *  ProfileEntryQuery. </code> </p> 
 *  
 *  <p> <code> getProfileEntriesByQuery() </code> is the basic search method 
 *  and returns a list of <code> ProfileEntries. </code> A more advanced 
 *  search may be performed with <code> getProfileEntriesBySearch(). </code> 
 *  It accepts an <code> ProfileEntrySearch </code> in addition to the query 
 *  for the purpose of specifying additional options affecting the entire 
 *  search, such as ordering. <code> getProfileEntriesBySearch() </code> 
 *  returns an <code> ProfileEntrySearchResults </code> that can be used to 
 *  access the resulting <code> ProfileEntryList </code> or be used to perform 
 *  a search within the result set through <code> ProfileEntrySearch. </code> 
 *  </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated profile view: searches include profile entries in 
 *      <code> Profiles </code> of which this profile is a ancestor in the 
 *      profile hierarchy </li> 
 *      <li> isolated profile view: searches are restricted to entries in this 
 *      <code> Profile </code> </li> 
 *  </ul>
 *  
 */

public interface ProfileEntrySearchSession
    extends org.osid.profile.ProfileEntryQuerySession {


    /**
     *  Gets a profile entry search. 
     *
     *  @return the profile entry search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileEntrySearch getProfileEntrySearch();


    /**
     *  Gets a profile entry search order. The <code> ProfileEntrySearchOrder 
     *  </code> is supplied to an <code> ProfileEntrySearch </code> to specify 
     *  the ordering of results. 
     *
     *  @return the profile entry search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileEntrySearchOrder getProfileEntrySearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  profileEntryQuery the profile entry query 
     *  @param  profileEntrySearch the profile entry search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> profileEntryQuery 
     *          </code> or <code> profileEntrySearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> profileEntryQuery </code> 
     *          or <code> profileEntrySearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileEntrySearchResults getProfileEntriesBySearch(org.osid.profile.ProfileEntryQuery profileEntryQuery, 
                                                                                org.osid.profile.ProfileEntrySearch profileEntrySearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a profile entry query from an inspector. The inspector is 
     *  available from an <code> PofileEntrySearchResults. </code> 
     *
     *  @param  profileEntryQueryInspector a profile entry query inspector 
     *  @return the profile entry query 
     *  @throws org.osid.NullArgumentException <code> 
     *          profileEntryQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> pofileEntryQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileEntryQuery getProfileEntryQueryFromInspector(org.osid.profile.ProfileEntryQueryInspector profileEntryQueryInspector);
}
