//
// org.osid.profile.ProfileEntrySmartProfileSession
//
//     The OSID Java specification for org.osid.profile.ProfileEntrySmartProfileSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.profile;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. A <code> ProfileEntryQuery </code> can be retrieved from this 
 *  session and mapped to this <code> Profile </code> to create a virtual 
 *  collection of profile entries. The profile entries may be sequenced using 
 *  the <code> ProfileEntrySearchOrder </code> from this session. </p> 
 *  
 *  <p> This <code> Profile </code> has a default query that matches any 
 *  profile Item and a default search order that specifies no sequencing. The 
 *  queries may be examined using a <code> ProfileEntryQueryInspector. </code> 
 *  The query may be modified by converting the inspector back to a <code> 
 *  ProfileEntryQuery. </code> </p>
 */

public interface ProfileEntrySmartProfileSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Profile </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Profile Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getProfileId();


    /**
     *  Gets the <code> Profile </code> associated with this session. 
     *
     *  @return the <code> Profile </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.Profile getProfile()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart profiles. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart profile management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartProfiles();


    /**
     *  Gets a profile entry query. 
     *
     *  @return the profile entry query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileEntryQuery getProfileEntryQuery();


    /**
     *  Gets a profile entry search order. 
     *
     *  @return the profile entry search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileEntrySearchOrder getProfileEntrySearchOrder();


    /**
     *  Applies a profile entry query to this profile. 
     *
     *  @param  profileEntryQuery the profile entry query 
     *  @throws org.osid.NullArgumentException <code> profileEntryQuery 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> profileEntryQuery </code> 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyProfileEntryQuery(org.osid.profile.ProfileEntryQuery profileEntryQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a profile entry query inspector for this profile. 
     *
     *  @return the profile entry query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileEntryQueryInspector inspectProfileEntryQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a profile entry search order to this profile. 
     *
     *  @param  profileEntrySearchOrder the profile entry search order 
     *  @throws org.osid.NullArgumentException <code> profileEntrySearchOrder 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> profileEntrySearchOrder 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyProfileEntrySequencing(org.osid.profile.ProfileEntrySearchOrder profileEntrySearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a profile entry query from an inspector. 
     *
     *  @param  profileEntryQueryInspector a profile entry query inspector 
     *  @return the profile entry query 
     *  @throws org.osid.NullArgumentException <code> 
     *          profileEntryQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          profileEntryQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileItemQuery getProfileEntryQueryFromInspector(org.osid.profile.ProfileEntryQueryInspector profileEntryQueryInspector);
}
