//
// org.osid.profile.ProfileItemQuerySession
//
//     The OSID Java specification for org.osid.profile.ProfileItemQuerySession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.profile;


/**
 *  <p>This session provides methods for searching <code> ProfileItem </code> 
 *  objects. The search query is constructed using the <code> 
 *  ProfileItemQuery. </code> The profile item record <code> Type </code> also 
 *  specifies the record interface for the profil eitem query. </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated profile view: searches include profile item in profiles 
 *      of which this profile is a ancestor in the profile hierarchy </li> 
 *      <li> isolated profile view: searches are restricted to profile items 
 *      in this profile </li> 
 *  </ul>
 *  
 *  
 *  <p> Profile items may have a profile item query record indicated by their 
 *  respective record types. The profile item query record is accessed via the 
 *  <code> ProfileItemQuery. </code> </p>
 */

public interface ProfileItemQuerySession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Profile </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Profile Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getProfileId();


    /**
     *  Gets the <code> Profile </code> associated with this session. 
     *
     *  @return the <code> Profile </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.Profile getProfile()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> ProfileItem </code> searches. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer search operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if search methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSearchProfileItems();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include profile items in profiles which are children of this profile 
     *  in the profile hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedProfileView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts searches to this profile only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedProfileView();


    /**
     *  Gets a profile item query. 
     *
     *  @return the profile item query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileItemQuery getProfileItemQuery();


    /**
     *  Gets a list of <code> ProfileItems </code> matching the given profile 
     *  item query interface. 
     *
     *  @param  profileItemQuery the profile item query 
     *  @return the returned <code> ProfileItemList </code> 
     *  @throws org.osid.NullArgumentException <code> profileItemQuery </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> profileItemQuery </code> 
     *          is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileItemList getProfileItemsByQuery(org.osid.profile.ProfileItemQuery profileItemQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
