//
// org.osid.profile.ProfileManager
//
//     The OSID Java specification for org.osid.profile.ProfileManager.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.profile;


/**
 *  <p>The profile manager provides access to profile sessions and provides 
 *  interoperability tests for various aspects of this service. The sessions 
 *  included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> ProfilingSession: </code> a session to performs profile 
 *      checks </li> 
 *      <li> <code> ProfileEntryLookupSession: </code> a session to look up 
 *      <code> ProfileEntries </code> </li> 
 *      <li> <code> ProfileEntryQuerySession: a session to query 
 *      ProfileEntries </code> </li> 
 *      <li> <code> ProfileEntrySearchSession: </code> a session to search 
 *      <code> ProfileEntries </code> </li> 
 *      <li> <code> ProfileEntryAdminSession: </code> a session to create, 
 *      modify and delete <code> ProfileEntries </code> </li> 
 *      <li> <code> ProfileEntryNotificationSession: a </code> session to 
 *      receive messages pertaining to <code> ProfileEntry </code> changes 
 *      </li> 
 *      <li> <code> ProfileEntryProfileSession: </code> a session to look up 
 *      profile entry to profile mappings </li> 
 *      <li> <code> ProfileEntryProfileAssignmentSession: </code> a session to 
 *      manage profile entry to profile mappings </li> 
 *      <li> <code> ProfileEntrySmartProfileSession: </code> a session to 
 *      manage smart profile entry profiles </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> ProfileItemLookupSession: </code> a session to look up 
 *      <code> ProfileItems </code> </li> 
 *      <li> <code> ProfileQuerySearchSession: a session to query ProfileItems 
 *      </code> </li> 
 *      <li> <code> ProfileItemSearchSession: </code> a session to search 
 *      <code> ProfileItems </code> </li> 
 *      <li> <code> ProfileItemAdminSession: </code> a session to create, 
 *      modify and delete <code> ProfileItems </code> </li> 
 *      <li> <code> ProfileItemNotificationSession: a </code> session to 
 *      receive messages pertaining to <code> ProfileItem </code> changes 
 *      </li> 
 *      <li> <code> ProfileItemProfileSession: </code> a session for looking 
 *      up profile item and profile mappings </li> 
 *      <li> <code> ProfileItemProfileAssignmentSession: </code> a session for 
 *      managing profile item and profile mappings </li> 
 *      <li> <code> ProfileItemSmartProfileSession: </code> a session to 
 *      manage smart profile item profiles </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> ProfileLookupSession: </code> a session to lookup profiles 
 *      </li> 
 *      <li> <code> ProfileQuerySession: </code> a session to query profiles 
 *      </li> 
 *      <li> <code> ProfileSearchSession </code> : a session to search 
 *      profiles </li> 
 *      <li> <code> ProfileAdminSession </code> : a session to create, modify 
 *      and delete profiles </li> 
 *      <li> <code> ProfileNotificationSession </code> : a session to receive 
 *      messages pertaining to <code> Profile </code> changes </li> 
 *      <li> <code> ProfileHierarchySession </code> : a session to traverse 
 *      the <code> Profile </code> hierarchy </li> 
 *      <li> <code> ProfileHierarchyDesignSession </code> : a session to 
 *      manage the <code> Profile </code> hierarchy </li> 
 *  </ul>
 *  
 */

public interface ProfileManager
    extends org.osid.OsidManager,
            org.osid.profile.ProfileProfile {


    /**
     *  Gets a <code> ProfilingSession </code> which is responsible for 
     *  performing profile checks. 
     *
     *  @return a profiling session for this service 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsProfiling() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfiling() </code> is <code> true. </code> 
     */

    public org.osid.profile.ProfilingSession getProfilingSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a <code> ProfilingSession </code> which is responsible for 
     *  performing profile checks for the given profile. 
     *
     *  @param  profileId the <code> Id </code> of the profile 
     *  @return <code> a ProfilingSession </code> 
     *  @throws org.osid.NotFoundException <code> profileId </code> 
     *  @throws org.osid.NullArgumentException <code> profileId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsProfiling() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfiling() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.profile.ProfilingSession getProfilingSessionForProfile(org.osid.id.Id profileId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the profile entry 
     *  lookup service. 
     *
     *  @return a <code> ProfileEntryLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileEntryLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileEntryLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.profile.ProfileEntryLookupSession getProfileEntryLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the profile entry 
     *  lookup service for the given profile. 
     *
     *  @param  profileId the <code> Id </code> of the profile 
     *  @return <code> a ProfileEntryLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> profileId </code> not found 
     *  @throws org.osid.NullArgumentException <code> profileId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileEntryLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileEntryLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.profile.ProfileEntryLookupSession getProfileEntryLookupSessionForProfile(org.osid.id.Id profileId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the profile entry 
     *  query service. 
     *
     *  @return a <code> ProfileEntryQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileEntryQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileEntryQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.profile.ProfileEntryQuerySession getProfileEntryQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the profile entry 
     *  query service for the given profile. 
     *
     *  @param  profileId the <code> Id </code> of the <code> Profile </code> 
     *  @return a <code> ProfileEntryQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Profile </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> profileId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileEntryQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileEntryQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.profile.ProfileEntryQuerySession getProfileEntryQuerySessionForProfile(org.osid.id.Id profileId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the profile entry 
     *  search service. 
     *
     *  @return a <code> ProfileEntrySearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileEntrySearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileEntrySearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.profile.ProfileEntrySearchSession getProfileEntrySearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the profile entry 
     *  search service for the given profile. 
     *
     *  @param  profileId the <code> Id </code> of the profile 
     *  @return <code> a ProfileEntrySearchSession </code> 
     *  @throws org.osid.NotFoundException <code> profileId </code> not found 
     *  @throws org.osid.NullArgumentException <code> profileId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileEntrySearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileEntrySearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.profile.ProfileEntrySearchSession getProfileEntrySearchSessionForProfile(org.osid.id.Id profileId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the profile entry 
     *  administration service. 
     *
     *  @return a <code> ProfileEntryAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileEntryAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileEntryAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.profile.ProfileEntryAdminSession getProfileEntryAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the profile entry 
     *  admin service for the given profile. 
     *
     *  @param  profileId the <code> Id </code> of the profile 
     *  @return <code> a ProfileEntryAdminSession </code> 
     *  @throws org.osid.NotFoundException <code> profileId </code> not found 
     *  @throws org.osid.NullArgumentException <code> profileId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileEntryAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileEntryAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.profile.ProfileEntryAdminSession getProfileEntryAdminSessionForProfile(org.osid.id.Id profileId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to profile 
     *  entry changes. 
     *
     *  @param  profileEntryReceiver the profile entry receiver 
     *  @return a <code> ProfileEntryNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> profileEntryReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileEntryNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileEntryNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.profile.ProfileEntryNotificationSession getProfileEntryNotificationSession(org.osid.profile.ProfileEntryReceiver profileEntryReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the profile entry 
     *  notification service for the given profile. 
     *
     *  @param  profileEntryReceiver the profile entry receiver 
     *  @param  profileId the <code> Id </code> of the profile 
     *  @return <code> a ProfileEntryNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> profileId </code> not found 
     *  @throws org.osid.NullArgumentException <code> profileEntryReceiver 
     *          </code> or <code> profileId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileEntryNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileEntryNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.profile.ProfileEntryNotificationSession getProfileEntryNotificationSessionForProfile(org.osid.profile.ProfileEntryReceiver profileEntryReceiver, 
                                                                                                         org.osid.id.Id profileId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving profile entry to profile mappings. 
     *
     *  @return a <code> ProfileEntryProfileSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileEntryProfile() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileEntryProfile() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.profile.ProfileEntryProfileSession getProfileEntryProfileSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning profile entries to profile mappings. 
     *
     *  @return a <code> ProfileEntryProfileAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileEntryProfileAssignment() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileEntryProfileAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.profile.ProfileEntryProfileAssignmentSession getProfileEntryProfileAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for managing dynamic profile entry profiles. 
     *
     *  @param  profileId the <code> Id </code> of the profile 
     *  @return a <code> ProfileEntrySmartProfileSession </code> 
     *  @throws org.osid.NotFoundException <code> profileId </code> not found 
     *  @throws org.osid.NullArgumentException <code> profileId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileEntrySmartProfile() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileEntrySmartProfile() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.profile.ProfileEntrySmartProfileSession getProfileEntrySmartProfileSession(org.osid.id.Id profileId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the profile item 
     *  lookup service. 
     *
     *  @return a <code> ProfileItemLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileItemLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileItemLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.profile.ProfileItemLookupSession getProfileItemLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the profile item 
     *  lookup service for the given profile. 
     *
     *  @param  profileId the <code> Id </code> of the profile 
     *  @return <code> a ProfileItemLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> profileId </code> not found 
     *  @throws org.osid.NullArgumentException <code> profileId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileItemLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileItemLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.profile.ProfileItemLookupSession getProfileItemLookupSessionForProfile(org.osid.id.Id profileId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets a profile item query session. 
     *
     *  @return <code> a ProfileItemQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileItemQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileItemQuery() </code> is <code> true. </code> 
     */

    public org.osid.profile.ProfileItemQuerySession getProfileItemQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a profile item query session for the given profile. 
     *
     *  @param  profileId the <code> Id </code> of the profile 
     *  @return <code> a ProfileItemQuerySession </code> 
     *  @throws org.osid.NotFoundException <code> profileId </code> not found 
     *  @throws org.osid.NullArgumentException <code> profileId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileItemQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileItemQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.profile.ProfileItemQuerySession getProfileItemQuerySessionForProfile(org.osid.id.Id profileId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the profile item 
     *  search service. 
     *
     *  @return a <code> ProfileItemSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileItemSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileItemSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.profile.ProfileItemSearchSession getProfileItemSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the profile item 
     *  search service for the given profile. 
     *
     *  @param  profileId the <code> Id </code> of the profile 
     *  @return a <code> ProfileItemSearchSession </code> 
     *  @throws org.osid.NotFoundException <code> profileId </code> not found 
     *  @throws org.osid.NullArgumentException <code> profileId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileItemSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileItemSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.profile.ProfileItemSearchSession getProfileItemSearchSessionForProfile(org.osid.id.Id profileId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the profile item 
     *  administration service. 
     *
     *  @return a <code> ProfileItemAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileItemAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileItemAdmin() </code> is <code> true. </code> 
     */

    public org.osid.profile.ProfileItemAdminSession getProfileItemAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the profile item 
     *  admin service for the given profile. 
     *
     *  @param  profileId the <code> Id </code> of the profile 
     *  @return <code> a ProfileItemAdminSession </code> 
     *  @throws org.osid.NotFoundException <code> profileId </code> not found 
     *  @throws org.osid.NullArgumentException <code> profileId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileItemAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileItemAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.profile.ProfileItemAdminSession getProfileItemAdminSessionForProfile(org.osid.id.Id profileId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to profile 
     *  item changes. 
     *
     *  @param  profileItemReceiver the profile item receiver 
     *  @return a <code> ProfileItemNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> profileItemReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileItemNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileItemNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.profile.ProfileItemNotificationSession getProfileItemNotificationSession(org.osid.profile.ProfileItemReceiver profileItemReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the profile item 
     *  notification service for the given profile. 
     *
     *  @param  profileItemReceiver the profile item receiver 
     *  @param  profileId the <code> Id </code> of the profile 
     *  @return <code> a ProfileItemNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> profileId </code> not found 
     *  @throws org.osid.NullArgumentException <code> profileItemReceiver 
     *          </code> or <code> profileId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileItemNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileItemNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.profile.ProfileItemNotificationSession getProfileItemNotificationSessionForProfile(org.osid.profile.ProfileItemReceiver profileItemReceiver, 
                                                                                                       org.osid.id.Id profileId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving profile item to profile mappings. 
     *
     *  @return a <code> ProfileItemProfileSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileItemProfile() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileItemProfile() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.profile.ProfileItemProfileSession getProfileItemProfileSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning profile item to profile mappings. 
     *
     *  @return a <code> ProfileItemProfileAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileItemProfileAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileItemProfileAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.profile.ProfileItemProfileSession getProfileItemProfileAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for managing dynamic profile item profile. 
     *
     *  @param  profileId the <code> Id </code> of the profile 
     *  @return a <code> ProfileItemSmartProfileSession </code> 
     *  @throws org.osid.NotFoundException <code> profileId </code> not found 
     *  @throws org.osid.NullArgumentException <code> profileId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileItemSmartProfile() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileItemSmartProfile() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.profile.ProfileItemSmartProfileSession getProfileItemSmartProfileSession(org.osid.id.Id profileId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the OsidSession associated with the profile lookup service. 
     *
     *  @return a <code> ProfileLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsProfileLookup() 
     *          is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileLookup() </code> is true. 
     */

    public org.osid.profile.ProfileLookupSession getProfileLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the profile query session. 
     *
     *  @return a <code> ProfileQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsProfileQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileQuery() </code> is <code> true. </code> 
     */

    public org.osid.profile.ProfileQuerySession getProfileQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the OsidSession associated with the profile search service. 
     *
     *  @return a <code> ProfileSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsProfileSearch() 
     *          is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileSearch() </code> is true. 
     */

    public org.osid.profile.ProfileSearchSession getProfileSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the OsidSession associated with the profile administration 
     *  service. 
     *
     *  @return a <code> ProfileAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsProfileAdmin() 
     *          is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileAdmin() </code> is true. 
     */

    public org.osid.profile.ProfileAdminSession getProfileAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to profile 
     *  service changes. 
     *
     *  @param  profileReceiver the profile receiver 
     *  @return a <code> ProfileNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> profileReceiver </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileNotification() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileNotification() </code> is true. 
     */

    public org.osid.profile.ProfileNotificationSession getProfileNotificationSession(org.osid.profile.ProfileReceiver profileReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session traversing profile hierarchies. 
     *
     *  @return a <code> ProfileHierarchySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileHierarchy() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileHierarchy() </code> is true. 
     */

    public org.osid.profile.ProfileHierarchySession getProfileHierarchySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session designing profile hierarchies. 
     *
     *  @return a <code> ProfileHierarchyDesignSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileHierarchyDesign() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileHierarchyDesign() </code> is true. 
     */

    public org.osid.profile.ProfileHierarchyDesignSession getProfileHierarchyDesignSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a <code> ProfileBatchManager. </code> 
     *
     *  @return a <code> ProfileBatchManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsProfileBatch() 
     *          is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileBatch() </code> is true. 
     */

    public org.osid.profile.batch.ProfileBatchManager getProfileBatchManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a <code> ProfileRulesManager. </code> 
     *
     *  @return a <code> ProfileRulesManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsProfileRules() 
     *          is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileRules() </code> is true. 
     */

    public org.osid.profile.rules.ProfileRulesManager getProfileRulesManager()
        throws org.osid.OperationFailedException;
}
