//
// org.osid.profile.batch.ProfileEntryBatchAdminSession
//
//     The OSID Java specification for org.osid.profile.batch.ProfileEntryBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.profile.batch;


/**
 *  <p>This session creates, updates, and deletes <code> ProfileEntries 
 *  </code> in bulk. The data for create and update is provided by the 
 *  consumer via the form object. <code> OsidForms </code> are requested for 
 *  each create or update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  ProfileEntry, </code> a <code> ProfileEntryForm </code> is requested using 
 *  <code> getProfileEntryFormsForCreate() </code> specifying the desired 
 *  work, resource, and record <code> Types </code> or none if no record 
 *  <code> Types </code> are needed. Each of the returned <code> 
 *  ProfileEntryForms </code> will indicate that it is to be used with a 
 *  create operation and can be used to examine metdata or validate data prior 
 *  to creation. Once a <code> ProfileEntryForm </code> is submiited to a 
 *  create operation, it cannot be reused with another create operation unless 
 *  the first operation was unsuccessful. Each <code> ProfileEntryForm </code> 
 *  corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> ProfileEntryForms </code> returned from <code> 
 *  getProfileEntryFormsForCreate() </code> may be linked to the originating 
 *  request through the peer <code> Ids </code> of the <code> 
 *  ProfileEntryForm. </code> In the case where there may be duplicates, any 
 *  <code> ProfileEntryForm </code> of the same peer <code> Ids </code> may be 
 *  used for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> ProfileEntryForms </code> are submitted for 
 *  create, a <code> CreateResponse </code> is returned for each <code> 
 *  ProfileEntryForm, </code> although the ordering is not defined. Only 
 *  errors that pertain to the entire create operation are returned from 
 *  <code> createProfileEntries(), </code> errors specific to an individual 
 *  <code> ProfileEntryForm </code> are indicated in the corresponding <code> 
 *  CreateResponse. </code> <code> CreateResponses </code> may be linked to 
 *  the originating <code> ProfileEntryForm </code> through the <code> 
 *  ProfileEntryForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> ProfileEntryForms </code> are requested to the 
 *  <code> ProfileEntry </code> <code> Id </code> that is to be updated using 
 *  <code> getProfileEntryFormsForUpdate() </code> where the reference <code> 
 *  Id </code> in the <code> ProfileEntryForm </code> may be used to link the 
 *  request. Similarly, the <code> ProfileEntryForm </code> has metadata about 
 *  the data that can be updated and it can perform validation before 
 *  submitting the update. The <code> ProfileEntryForm </code> can only be 
 *  used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> ProfileEntryForms </code> are submitted for 
 *  update, an <code> UpdateResponse </code> is returned for each <code> 
 *  ProfileEntryForm, </code> although the ordering is not defined. Only 
 *  errors that pertain to the entire update operation are returned from 
 *  <code> updateProfileEntries(), </code> errors specific to an individual 
 *  <code> ProfileEntryForm </code> are indicated in the corresponding <code> 
 *  UpdateResponse. </code> <code> UpdateResponses </code> may be linked to 
 *  the originating <code> ProfileEntryForm </code> through the <code> 
 *  ProfileEntryForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> ProfileEntries </code> in bulk. To 
 *  unmap a <code> ProfileEntry </code> from the current <code> Profile, 
 *  </code> the <code> ProfileEntryProfileAssignmentSession </code> should be 
 *  used. These delete operations attempt to remove the <code> ProfileEntry 
 *  </code> itself thus removing it from all known <code> Profile </code> 
 *  catalogs. Bulk delete operations return the results in <code> 
 *  DeleteResponses. </code> </p>
 */

public interface ProfileEntryBatchAdminSession
    extends org.osid.profile.ProfileEntryAdminSession {


    /**
     *  Gets the profile entry forms for creating a bunch of new profile 
     *  entries. A form is returned for each agent and profile item pair. 
     *
     *  @param  peers the relationship peers 
     *  @param  profileEntryRecordTypes array of profile entry record types to 
     *          be included in each create operation or an empty list if none 
     *  @return the profile entry forms 
     *  @throws org.osid.NotFoundException an <code> agentId </code> or <code> 
     *          profileItemId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> peers </code> or <code> 
     *          profileEntryRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.batch.ProfileEntryBatchFormList getProfileEntryFormsForCreateForAgents(org.osid.profile.batch.ProfileEntryAgentPeerList peers, 
                                                                                                   org.osid.type.Type[] profileEntryRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the profile entry forms for creating a bunch of new profile 
     *  entries. A form is returned for each resource and profile item pair. 
     *
     *  @param  peers the relationship peers 
     *  @param  profileEntryRecordTypes array of profile entry record types to 
     *          be included in each create operation or an empty list if none 
     *  @return the profile entry forms 
     *  @throws org.osid.NotFoundException a <code> resourceId </code> or 
     *          <code> profileItemId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> peers </code> or <code> 
     *          profileEntryRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.batch.ProfileEntryBatchFormList getProfileEntryFormsForCreateForResources(org.osid.profile.batch.ProfileEntryResourcePeerList peers, 
                                                                                                      org.osid.type.Type[] profileEntryRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> ProfileEntries. </code> This method 
     *  returns an error if the entire operation fails. Otherwise, the status 
     *  of an individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  profileEntryForms the profile entry forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> profileEntryForms 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createProfileEntries(org.osid.profile.batch.ProfileEntryBatchFormList profileEntryForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the profile entry forms for updating an existing set of profile 
     *  entries. A new profile entry form should be requested for each update 
     *  transaction. 
     *
     *  @param  profileEntryIds the <code> Ids </code> of the <code> 
     *          ProfileEntry </code> 
     *  @return the profile entry form 
     *  @throws org.osid.NotFoundException a <code> profileEntryId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> profileEntryIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.batch.ProfileEntryBatchFormList getProfileEntryFormsForUpdate(org.osid.id.IdList profileEntryIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing profile entries. This method returns an error if the 
     *  entire operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  profileEntryForms the form containing the elements to be 
     *          updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> profileEntryForms 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateProfileEntries(org.osid.profile.batch.ProfileEntryBatchFormList profileEntryForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> ProfileEntries </code> in this <code> Profile 
     *  </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllProfileEntries()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes profile entries for the given <code> Ids. </code> 
     *
     *  @param  profileEntryIds the <code> Ids </code> of the profile entries 
     *          to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> profileEntryIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteProfileEntries(org.osid.id.IdList profileEntryIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes profile entries for the given profile item. 
     *
     *  @param  profileItemId the <code> Id </code> of a profile item 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> profileItemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteProfileEntriesForProfileItem(org.osid.id.Id profileItemId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes profile entries for the given resource. 
     *
     *  @param  resourceId the <code> Id </code> of a resource 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteProfileEntriesForResource(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes profile entries expired before the given date. 
     *
     *  @param  date a date 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteIneffectiveProfileEntriesByDate(org.osid.calendaring.DateTime date)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> ProfileEntry </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> ProfileEntry </code> is determined by the provider. The new 
     *  <code> Id </code> is an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another profile entry, it is reassigned to the 
     *  given profile entry <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasProfileEntries(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
