//
// org.osid.profile.rules.ProfileEntryEnablerAdminSession
//
//     The OSID Java specification for org.osid.profile.rules.ProfileEntryEnablerAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.profile.rules;


/**
 *  <p>This session creates and removes profile entry enablers. The data for 
 *  create and update is provided via the <code> ProfileEntryEnablerForm. 
 *  </code> </p>
 */

public interface ProfileEntryEnablerAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Profile </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Profile Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getProfileId();


    /**
     *  Gets the <code> Profile </code> associated with this session. 
     *
     *  @return the profile 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.Profile getProfile()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create profile entry enablers. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> ProfileEntryEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer create 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> ProfileEntryEnabler </code> 
     *          creation is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateProfileEntryEnabler();


    /**
     *  Tests if this user can create a single <code> ProfileEntryEnabler 
     *  </code> using the desired record types. While <code> 
     *  ProfileRulesManager.getProfileEntryEnablerRecordTypes() </code> can be 
     *  used to examine which records are supported, this method tests which 
     *  record(s) are required for creating a specific <code> 
     *  ProfileEntryEnabler. </code> Providing an empty array tests if a 
     *  <code> ProfileEntryEnabler </code> can be created with no records. 
     *
     *  @param  profileEntryEnablerRecordTypes array of profile entry enabler 
     *          types 
     *  @return <code> true </code> if <code> ProfileEntryEnabler </code> 
     *          creation using the specified record <code> Types </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          profileEntryEnablerRecordTypes </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateProfileEntryEnablerWithRecordTypes(org.osid.type.Type[] profileEntryEnablerRecordTypes);


    /**
     *  Gets the profile entry enabler form for creating new profile entry 
     *  enablers. A new form should be requested for each create transaction. 
     *
     *  @param  profileEntryEnablerRecordTypes array of profile entry enabler 
     *          types 
     *  @return the profile entry enabler form 
     *  @throws org.osid.NullArgumentException <code> 
     *          profileEntryEnablerRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unabel to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.rules.ProfileEntryEnablerForm getProfileEntryEnablerFormForCreate(org.osid.type.Type[] profileEntryEnablerRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> ProfileEntryEnabler. </code> 
     *
     *  @param  profileEntryEnablerForm the form for this <code> 
     *          ProfileEntryEnabler </code> 
     *  @return the new <code> ProfileEntryEnabler </code> 
     *  @throws org.osid.IllegalStateException <code> profileEntryEnablerForm 
     *          </code> already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> profileEntryEnablerForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> profileEntryEnablerForm 
     *          </code> did not originate from <code> 
     *          getProfileEntryEnablerFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.rules.ProfileEntryEnabler createProfileEntryEnabler(org.osid.profile.rules.ProfileEntryEnablerForm profileEntryEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update profile entry enablers. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> ProfileEntryEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer update 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> ProfileEntryEnabler </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateProfileEntryEnablers();


    /**
     *  Gets the profile entry enabler form for updating an existing profile 
     *  entry enabler. A new profile entry enabler form should be requested 
     *  for each update transaction. 
     *
     *  @param  profileEntryEnablerId the <code> Id </code> of the <code> 
     *          ProfileEntryEnabler </code> 
     *  @return the profile entry enabler form 
     *  @throws org.osid.NotFoundException <code> profileEntryEnablerId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> profileEntryEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.rules.ProfileEntryEnablerForm getProfileEntryEnablerFormForUpdate(org.osid.id.Id profileEntryEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing profile entry enabler. 
     *
     *  @param  profileEntryEnablerForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> profileEntryEnablerForm 
     *          </code> already used in an upate transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> profileEntryEnablerForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> profileEntryEnablerForm 
     *          </code> did not originate from <code> 
     *          getProfileEntryEnablerFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateProfileEntryEnabler(org.osid.profile.rules.ProfileEntryEnablerForm profileEntryEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete profile entry enablers. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> ProfileEntryEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer delete 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> ProfileEntryEnabler </code> 
     *          deletion is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteProfileEntryEnablers();


    /**
     *  Deletes a <code> ProfileEntryEnabler. </code> 
     *
     *  @param  profileEntryEnablerId the <code> Id </code> of the <code> 
     *          ProfileEntryEnabler </code> to remove 
     *  @throws org.osid.NotFoundException <code> profileEntryEnablerId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> profileEntryEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteProfileEntryEnabler(org.osid.id.Id profileEntryEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for profile 
     *  entry enablers. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> ProfileEntryEnabler </code> 
     *          aliasing is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageProfileEntryEnablerAliases();


    /**
     *  Adds an <code> Id </code> to a <code> ProfileEntryEnabler </code> for 
     *  the purpose of creating compatibility. The primary <code> Id </code> 
     *  of the <code> ProfileEntryEnabler </code> is determined by the 
     *  provider. The new <code> Id </code> performs as an alias to the 
     *  primary <code> Id </code> . If the alias is a pointer to another 
     *  profile entry enabler. it is reassigned to the given profile entry 
     *  enabler <code> Id. </code> 
     *
     *  @param  profileEntryEnablerId the <code> Id </code> of a <code> 
     *          ProfileEntryEnabler </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> profileEntryEnablerId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> profileEntryEnablerId 
     *          </code> or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasProfileEntryEnabler(org.osid.id.Id profileEntryEnablerId, 
                                         org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
