//
// org.osid.profile.rules.ProfileEntryEnablerQuery
//
//     The OSID Java specification for org.osid.profile.rules.ProfileEntryEnablerQuery.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.profile.rules;


/**
 *  <p>This is the query for searching profile entry enablers. Each method 
 *  match specifies an <code> AND </code> term while multiple invocations of 
 *  the same method produce a nested <code> OR. </code> </p>
 */

public interface ProfileEntryEnablerQuery
    extends org.osid.OsidEnablerQuery {


    /**
     *  Matches enablers mapped to the profile entry. 
     *
     *  @param  profileEntryId the profile entry <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> profileEntryId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRuledProfileEntryId(org.osid.id.Id profileEntryId, 
                                         boolean match);


    /**
     *  Clears the profile entry <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRuledProfileEntryIdTerms();


    /**
     *  Tests if a <code> ProfileEntryQuery </code> is available. 
     *
     *  @return <code> true </code> if a profile entry query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRuledProfileEntryQuery();


    /**
     *  Gets the query for a profile entry. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the profile entry query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRuledProfileEntryQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRuledProfileEntryQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.profile.ProfileEntryQuery getRuledProfileEntryQuery();


    /**
     *  Matches enablers mapped to any profile entry. 
     *
     *  @param  match <code> true </code> for enablers mapped to any profile 
     *          entry, <code> false </code> to match enablers mapped to no 
     *          profile entry 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRuledProfileEntry(boolean match);


    /**
     *  Clears the profile entry query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRuledProfileEntryTerms();


    /**
     *  Matches enablers mapped to the profile. 
     *
     *  @param  profileId the profile <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> profileId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchProfileId(org.osid.id.Id profileId, boolean match);


    /**
     *  Clears the profile <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProfileIdTerms();


    /**
     *  Tests if a <code> ProfileQuery </code> is available. 
     *
     *  @return <code> true </code> if a profile query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProfileQuery();


    /**
     *  Gets the query for a profile. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the profile query 
     *  @throws org.osid.UnimplementedException <code> supportsProfileQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileQuery() </code> is <code> true. </code> 
     */

    public org.osid.profile.ProfileQuery getProfileQuery();


    /**
     *  Clears the profile query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProfileTerms();


    /**
     *  Gets the profile entry enabler query record corresponding to the given 
     *  <code> ProfileEntryEnabler </code> record <code> Type. </code> 
     *  Multiple record retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  profileEntryEnablerRecordType a profile entry enabler record 
     *          type 
     *  @return the profile entry enabler query record 
     *  @throws org.osid.NullArgumentException <code> 
     *          profileEntryEnablerRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(profileEntryEnablerRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.rules.records.ProfileEntryEnablerQueryRecord getProfileEntryEnablerQueryRecord(org.osid.type.Type profileEntryEnablerRecordType)
        throws org.osid.OperationFailedException;
}
