//
// org.osid.profile.rules.ProfileEntryEnablerSearchSession
//
//     The OSID Java specification for org.osid.profile.rules.ProfileEntryEnablerSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.profile.rules;


/**
 *  <p>This session provides methods for searching among <code> 
 *  ProfileEntryEnabler </code> objects. The search query is constructed using 
 *  the <code> ProfileEntryEnableryQuery. </code> </p> 
 *  
 *  <p> <code> getProfileEntryEnablersByQuery() </code> is the basic search 
 *  method and returns a list of <code> ProfileEntryEnablers. </code> A more 
 *  advanced search may be performed with <code> 
 *  getProfileEntryEnablersBySearch(). </code> It accepts a <code> 
 *  ProfileEntryEnablerSearch </code> in addition to the query for the purpose 
 *  of specifying additional options affecting the entire search, such as 
 *  ordering. <code> getProfileEntryEnablersBySearch() </code> returns a 
 *  <code> ProfileEntryEnablerSearchResults </code> that can be used to access 
 *  the resulting <code> ProfileEntryEnablerList </code> or be used to perform 
 *  a search within the result set through <code> ProfileEntryEnablerSearch. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated profile view: searches include profile entry enablers 
 *      in profiles of which this profile is an ancestor in the profile 
 *      hierarchy </li> 
 *      <li> isolated profile view: searches are restricted to profile entry 
 *      enablers in this profile </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> ProfileEntryEnablers </code> may have a query record indicated 
 *  by their respective record types. The query record is accessed via the 
 *  <code> ProfileEntryEnablerQuery. </code> </p>
 */

public interface ProfileEntryEnablerSearchSession
    extends org.osid.profile.rules.ProfileEntryEnablerQuerySession {


    /**
     *  Gets a profile entry enabler search. 
     *
     *  @return the profile entry enabler search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.rules.ProfileEntryEnablerSearch getProfileEntryEnablerSearch();


    /**
     *  Gets a profile entry enabler search order. The <code> 
     *  ProfileEntryEnablerSearchOrder </code> is supplied to a <code> 
     *  ProfileEntryEnablerSearch </code> to specify the ordering of results. 
     *
     *  @return the profile entry enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.rules.ProfileEntryEnablerSearchOrder getProfileEntryEnablerSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  profileEntryEnablerQuery the profile entry enabler query 
     *  @param  profileEntryEnablerSearch the profile entry enabler search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> profileEntryEnablerQuery 
     *          </code> or <code> profileEntryEnablerSearch </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> profileEntryEnablerQuery 
     *          </code> or <code> profileEntryEnablerSearch </code> is not of 
     *          this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.rules.ProfileEntryEnablerSearchResults getProfileEntryEnablersBySearch(org.osid.profile.rules.ProfileEntryEnablerQuery profileEntryEnablerQuery, 
                                                                                                   org.osid.profile.rules.ProfileEntryEnablerSearch profileEntryEnablerSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a profile entry enabler query from an inspector. The inspector is 
     *  available from a <code> ProfileEntryEnablerSearchResults. </code> 
     *
     *  @param  profileEntryEnablerQueryInspector a profile entry enabler 
     *          query inspector 
     *  @return the profile entry enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          profileEntryEnablerQueryInspector </code> is <code> null 
     *          </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          profileEntryEnablerQueryInspector </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.rules.ProfileEntryEnablerQuery getProfileEntryEnablerQueryFromInspector(org.osid.profile.rules.ProfileEntryEnablerQueryInspector profileEntryEnablerQueryInspector);
}
