//
// org.osid.profile.rules.ProfileRulesProxyManager
//
//     The OSID Java specification for org.osid.profile.rules.ProfileRulesProxyManager.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.profile.rules;


/**
 *  <p>The profile rules proxy manager provides access to profile rules 
 *  sessions and provides interoperability tests for various aspects of this 
 *  service. Methods in this manager pass a <code> Proxy </code> for passing 
 *  information from server environments. The sessions included in this 
 *  manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> ProfileEntryEnablerLookupSession: </code> a session to 
 *      retrieve profile entry enablers </li> 
 *      <li> <code> ProfileEntryEnablerQuerySession: </code> a session to 
 *      query for profile entry enablers </li> 
 *      <li> <code> ProfileEntryEnablerSearchSession: </code> a session to 
 *      search for profile entry enablers </li> 
 *      <li> <code> ProfileEntryEnablerAdminSession: </code> a session to 
 *      create and delete profile entry enablers </li> 
 *      <li> <code> ProfileEntryEnablerNotificationSession: </code> a session 
 *      to receive notifications pertaining to profile entry enabler changes 
 *      </li> 
 *      <li> <code> ProfileEntryEnablerProfileSession: </code> a session to 
 *      look up profile entry enabler profile mappings </li> 
 *      <li> <code> ProfileEntryEnablerProfileAssignmentSession: </code> a 
 *      session to manage profile entry enabler to profile mappings </li> 
 *      <li> <code> ProfileEntryEnablerSmartProfileSession: </code> a session 
 *      to manage dynamic profiles of profile entry enablers </li> 
 *      <li> <code> ProfileEntryEnablerRuleLookupSession: </code> a session to 
 *      look up profile entry enabler to profile entry mappings </li> 
 *      <li> <code> ProfileEntryEnablerRuleApplicationSession: </code> a 
 *      session to apply profile entry enablers to profile entries </li> 
 *  </ul>
 *  
 */

public interface ProfileRulesProxyManager
    extends org.osid.OsidProxyManager,
            org.osid.profile.rules.ProfileRulesProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the profile entry 
     *  enabler lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ProfileEntryEnablerLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileEntryEnablerLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileEntryEnablerLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.profile.rules.ProfileEntryEnablerLookupSession getProfileEntryEnablerLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the profile entry 
     *  enabler lookup service for the given profile. 
     *
     *  @param  profileId the <code> Id </code> of the <code> Profile </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ProfileEntryEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Profile </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> profileId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileEntryEnablerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileEntryEnablerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.profile.rules.ProfileEntryEnablerLookupSession getProfileEntryEnablerLookupSessionForProfile(org.osid.id.Id profileId, 
                                                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the profile entry 
     *  enabler query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ProfileEntryEnablerQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileEntryEnablerQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileEntryEnablerQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.profile.rules.ProfileEntryEnablerQuerySession getProfileEntryEnablerQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the profile entry 
     *  enabler query service for the given profile. 
     *
     *  @param  profileId the <code> Id </code> of the <code> Profile </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ProfileEntryEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Profile </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> profileId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileEntryEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileEntryEnablerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.profile.rules.ProfileEntryEnablerQuerySession getProfileEntryEnablerQuerySessionForProfile(org.osid.id.Id profileId, 
                                                                                                               org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the profile entry 
     *  enabler search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ProfileEntryEnablerSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileEntryEnablerSearch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileEntryEnablerSearch() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.profile.rules.ProfileEntryEnablerSearchSession getProfileEntryEnablerSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the profile entry 
     *  enablers earch service for the given profile. 
     *
     *  @param  profileId the <code> Id </code> of the <code> Profile </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ProfileEntryEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Profile </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> profileId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileEntryEnablerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileEntryEnablerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.profile.rules.ProfileEntryEnablerSearchSession getProfileEntryEnablerSearchSessionForProfile(org.osid.id.Id profileId, 
                                                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the profile entry 
     *  enabler administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ProfileEntryEnablerAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileEntryEnablerAdmin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileEntryEnablerAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.profile.rules.ProfileEntryEnablerAdminSession getProfileEntryEnablerAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the profile entry 
     *  enabler administration service for the given profile. 
     *
     *  @param  profileId the <code> Id </code> of the <code> Profile </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ProfileEntryEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Profile </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> profileId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileEntryEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileEntryEnablerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.profile.rules.ProfileEntryEnablerAdminSession getProfileEntryEnablerAdminSessionForProfile(org.osid.id.Id profileId, 
                                                                                                               org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the profile entry 
     *  enabler notification service. 
     *
     *  @param  profileEntryEnablerReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> ProfileEntryEnablerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          profileEntryEnablerReceiver </code> or <code> proxy </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileEntryEnablerNotification() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileEntryEnablerNotification() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.profile.rules.ProfileEntryEnablerNotificationSession getProfileEntryEnablerNotificationSession(org.osid.profile.rules.ProfileEntryEnablerReceiver profileEntryEnablerReceiver, 
                                                                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the profile entry 
     *  enabler notification service for the given profile. 
     *
     *  @param  profileEntryEnablerReceiver the notification callback 
     *  @param  profileId the <code> Id </code> of the <code> Profile </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ProfileEntryEnablerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no profile found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          profileEntryEnablerReceiver, profileId </code> or <code> proxy 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileEntryEnablerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileEntryEnablerNotification() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.profile.rules.ProfileEntryEnablerNotificationSession getProfileEntryEnablerNotificationSessionForProfile(org.osid.profile.rules.ProfileEntryEnablerReceiver profileEntryEnablerReceiver, 
                                                                                                                             org.osid.id.Id profileId, 
                                                                                                                             org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup profile entry 
     *  enabler/profile mappings for profile entry enablers. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ProfileEntryEnablerProfileSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileEntryEnablerProfile() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileEntryEnablerProfile() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.profile.rules.ProfileEntryEnablerProfileSession getProfileEntryEnablerProfileSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning profile 
     *  entry enablers to profiles for profile entry. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ProfileEntryEnablerProfileAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileEntryEnablerProfileAssignment() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileEntryEnablerProfileAssignment() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.profile.rules.ProfileEntryEnablerProfileAssignmentSession getProfileEntryEnablerProfileAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage profile entry enabler 
     *  smart profiles. 
     *
     *  @param  profileId the <code> Id </code> of the <code> Profile </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ProfileEntryEnablerSmartProfileSession </code> 
     *  @throws org.osid.NotFoundException no <code> Profile </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> profileId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileEntryEnablerSmartProfile() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileEntryEnablerSmartProfile() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.profile.rules.ProfileEntryEnablerSmartProfileSession getProfileEntryEnablerSmartProfileSession(org.osid.id.Id profileId, 
                                                                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the profile entry 
     *  enabler mapping lookup service for looking up the rules applied to the 
     *  profile. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ProfileEntryEnablerRuleLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileEntryEnablerRuleLookup() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileEntryEnablerRuleLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.profile.rules.ProfileEntryEnablerRuleLookupSession getProfileEntryEnablerRuleLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the profile entry 
     *  enabler mapping lookup service for the given profile for looking up 
     *  rules applied to a profile. 
     *
     *  @param  profileId the <code> Id </code> of the <code> Profile </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ProfileEntryEnablerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Profile </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> profileId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileEntryEnableRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileEntryEnablerRuleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.profile.rules.ProfileEntryEnablerRuleLookupSession getProfileEntryEnablerRuleLookupSessionForProfile(org.osid.id.Id profileId, 
                                                                                                                         org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the profile entry 
     *  enabler assignment service to apply enablers to profiles. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ProfileEntryEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileEntryEnablerRuleApplication() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileEntryEnablerRuleApplication() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.profile.rules.ProfileEntryEnablerRuleApplicationSession getProfileEntryEnablerRuleApplicationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the profile entry 
     *  enabler assignment service for the given profile to apply enablers to 
     *  profiles. 
     *
     *  @param  profileId the <code> Id </code> of the <code> Profile </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ProfileEntryEnableryRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Profile </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> profileId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileEntryEnablerRuleApplication() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileEntryEnablerRuleApplication() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.profile.rules.ProfileEntryEnablerRuleApplicationSession getProfileEntryEnablerRuleApplicationSessionForProfile(org.osid.id.Id profileId, 
                                                                                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;
}
