//
// org.osid.provisioning.BrokerSearchSession
//
//     The OSID Java specification for org.osid.provisioning.BrokerSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning;


/**
 *  <p>This session provides methods for searching among <code> Broker </code> 
 *  objects. The search query is constructed using the <code> BrokerQuery. 
 *  </code> </p> 
 *  
 *  <p> <code> getBrokersByQuery() </code> is the basic search method and 
 *  returns a list of <code> Brokers. </code> A more advanced search may be 
 *  performed with <code> getBrokersBySearch(). </code> It accepts a <code> 
 *  BrokerSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getBrokersBySearch() </code> returns a <code> 
 *  BrokerSearchResults </code> that can be used to access the resulting 
 *  <code> BrokerList </code> or be used to perform a search within the result 
 *  set through <code> BrokerSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated distributor view: searches include brokers in 
 *      distributors of which this distributor is an ancestor in the 
 *      distributor hierarchy </li> 
 *      <li> isolated distributor view: searches are restricted to brokers in 
 *      this distributor </li> 
 *  </ul>
 *  
 *  
 *  <p> Brokers may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> BrokerQuery. </code> 
 *  </p>
 */

public interface BrokerSearchSession
    extends org.osid.provisioning.BrokerQuerySession {


    /**
     *  Gets a broker search. 
     *
     *  @return the broker search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.BrokerSearch getBrokerSearch();


    /**
     *  Gets a broker search order. The <code> BrokerSearchOrder </code> is 
     *  supplied to a <code> BrokerSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the broker search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.BrokerSearchOrder getBrokerSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  brokerQuery the broker query 
     *  @param  brokerSearch the broker search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> brokerQuery </code> or 
     *          <code> brokerSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> brokerQuery </code> or 
     *          <code> brokerSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.BrokerSearchResults getBrokersBySearch(org.osid.provisioning.BrokerQuery brokerQuery, 
                                                                        org.osid.provisioning.BrokerSearch brokerSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a broker query from an inspector. The inspector is available from 
     *  a <code> BrokerSearchResults. </code> 
     *
     *  @param  brokerQueryInspector a broker query inspector 
     *  @return the broker query 
     *  @throws org.osid.NullArgumentException <code> brokerQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> brokerQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.BrokerQuery getBrokerQueryFromInspector(org.osid.provisioning.BrokerQueryInspector brokerQueryInspector);
}
