//
// org.osid.provisioning.BrokerSmartDistributorSession
//
//     The OSID Java specification for org.osid.provisioning.BrokerSmartDistributorSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. A <code> BrokerQuery </code> can be retrieved from this session 
 *  and mapped to this <code> Distributor </code> to create a virtual 
 *  collection of <code> Brokers. </code> The brokers may be sequenced using 
 *  the <code> BrokerSearchOrder </code> from this session. </p> 
 *  
 *  <p> This <code> Distributor </code> has a default query that matches any 
 *  broker and a default search order that specifies no sequencing. The 
 *  queries may be examined using a <code> BrokerQueryInspector. </code> The 
 *  query may be modified by converting the inspector back to a <code> 
 *  BrokerQuery. </code> </p>
 */

public interface BrokerSmartDistributorSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Distributor </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Distributor Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDistributorId();


    /**
     *  Gets the <code> Distributor </code> associated with this session. 
     *
     *  @return the distributor 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.Distributor getDistributor()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart distributors. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known methods in this session will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart distributor management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartDistributors();


    /**
     *  Gets a broker query. 
     *
     *  @return the broker query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.BrokerQuery getBrokerQuery();


    /**
     *  Gets a broker search order. 
     *
     *  @return the broker search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.BrokerSearchOrder getBrokerSearchOrder();


    /**
     *  Applies a broker query to this distributor. 
     *
     *  @param  brokerQuery the broker query 
     *  @throws org.osid.NullArgumentException <code> brokerQuery </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> brokerQuery </code> not 
     *          of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyBrokerQuery(org.osid.provisioning.BrokerQuery brokerQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a broker query inspector for this distributor. 
     *
     *  @return the broker query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.BrokerQueryInspector inspectBrokerQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a broker search order to this distributor. 
     *
     *  @param  brokerSearchOrder the broker search order 
     *  @throws org.osid.NullArgumentException <code> brokerSearchOrder 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> brokerSearchOrder </code> 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyBrokerSequencing(org.osid.provisioning.BrokerSearchOrder brokerSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a broker query from an inspector. 
     *
     *  @param  brokerQueryInspector a broker query inspector 
     *  @return the broker query 
     *  @throws org.osid.NullArgumentException <code> brokerQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> brokerQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.BrokerQuery getBrokerQueryFromInspector(org.osid.provisioning.BrokerQueryInspector brokerQueryInspector);
}
