//
// org.osid.provisioning.DistributorQuery
//
//     The OSID Java specification for org.osid.provisioning.DistributorQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning;


/**
 *  <p>This is the query for searching distributors. Each method match 
 *  specifies an <code> AND </code> term while multiple invocations of the 
 *  same method produce a nested <code> OR. </code> </p>
 */

public interface DistributorQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Sets the broker <code> Id </code> for this query. 
     *
     *  @param  brokerId the broker <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> brokerId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBrokerId(org.osid.id.Id brokerId, boolean match);


    /**
     *  Clears the broker <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBrokerIdTerms();


    /**
     *  Tests if an <code> BrokerQuery </code> is available. 
     *
     *  @return <code> true </code> if a broker query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerQuery();


    /**
     *  Gets the query for a broker. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the broker query 
     *  @throws org.osid.UnimplementedException <code> supportsBrokerQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerQuery() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.BrokerQuery getBrokerQuery();


    /**
     *  Matches distributors with any broker. 
     *
     *  @param  match <code> true </code> to match distributors with any 
     *          broker, <code> false </code> to match distributors with no 
     *          broker 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyBroker(boolean match);


    /**
     *  Clears the broker query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBrokerTerms();


    /**
     *  Sets the queue <code> Id </code> for this query. 
     *
     *  @param  queueId the queue <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> queueId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchQueueId(org.osid.id.Id queueId, boolean match);


    /**
     *  Clears the queue <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearQueueIdTerms();


    /**
     *  Tests if a <code> QueueQuery </code> is available. 
     *
     *  @return <code> true </code> if a queue query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueQuery();


    /**
     *  Gets the query for a queue. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the queue query 
     *  @throws org.osid.UnimplementedException <code> supportsQueueQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueQuery() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.QueueQuery getQueueQuery();


    /**
     *  Matches distributors with any queue. 
     *
     *  @param  match <code> true </code> to match distributors with any 
     *          queue, <code> false </code> to match distributors with no 
     *          queue 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyQueue(boolean match);


    /**
     *  Clears the queue query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearQueueTerms();


    /**
     *  Sets the pool <code> Id </code> for this query. 
     *
     *  @param  poolId the pool <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> poolId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchPoolId(org.osid.id.Id poolId, boolean match);


    /**
     *  Clears the pool <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPoolIdTerms();


    /**
     *  Tests if a <code> PoolQuery </code> is available. 
     *
     *  @return <code> true </code> if a pool query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolQuery();


    /**
     *  Gets the query for a pool. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the pool query 
     *  @throws org.osid.UnimplementedException <code> supportsPoolQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolQuery() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.PoolQuery getPoolQuery();


    /**
     *  Matches brokers with any pool. 
     *
     *  @param  match <code> true </code> to match distributors with any pool, 
     *          <code> false </code> to match distributors with no pool 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyPool(boolean match);


    /**
     *  Clears the pool query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPoolTerms();


    /**
     *  Sets the provision <code> Id </code> for this query to match 
     *  distributors that have a related provision. 
     *
     *  @param  provisionId a provision <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for negative match 
     *  @throws org.osid.NullArgumentException <code> provisionId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchProvisionId(org.osid.id.Id provisionId, boolean match);


    /**
     *  Clears the provision <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProvisionIdTerms();


    /**
     *  Tests if a <code> ProvisionQuery </code> is available. 
     *
     *  @return <code> true </code> if a provision query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProvisionQuery();


    /**
     *  Gets the query for a provision. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the provision query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProvisionQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProvisionQuery() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.ProvisionQuery getProvisionQuery();


    /**
     *  Matches distributors that have any provision. 
     *
     *  @param  match <code> true </code> to match distributors with any 
     *          provision, <code> false </code> to match distributors with no 
     *          provision 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyProvision(boolean match);


    /**
     *  Clears the provision query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProvisionTerms();


    /**
     *  Sets the distributor <code> Id </code> for this query to match 
     *  distributors that have the specified distributor as an ancestor. 
     *
     *  @param  distributorId a distributor <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for negative match 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorDistributorId(org.osid.id.Id distributorId, 
                                           boolean match);


    /**
     *  Clears the ancestor distributor <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorDistributorIdTerms();


    /**
     *  Tests if a <code> DistributorQuery </code> is available. 
     *
     *  @return <code> true </code> if a distributor query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorDistributorQuery();


    /**
     *  Gets the query for a distributor. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the distributor query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorDistributorQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorDistributorQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.DistributorQuery getAncestorDistributorQuery();


    /**
     *  Matches distributors with any ancestor. 
     *
     *  @param  match <code> true </code> to match distributors with any 
     *          ancestor, <code> false </code> to match root distributors 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorDistributor(boolean match);


    /**
     *  Clears the ancestor distributor query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorDistributorTerms();


    /**
     *  Sets the distributor <code> Id </code> for this query to match 
     *  distributors that have the specified distributor as a descendant. 
     *
     *  @param  distributorId a distributor <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for negative match 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantDistributorId(org.osid.id.Id distributorId, 
                                             boolean match);


    /**
     *  Clears the descendant distributor <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantDistributorIdTerms();


    /**
     *  Tests if a <code> DistributorQuery </code> is available. 
     *
     *  @return <code> true </code> if a distributor query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantDistributorQuery();


    /**
     *  Gets the query for a distributor/ Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the distributor query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantDistributorQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantDistributorQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.DistributorQuery getDescendantDistributorQuery();


    /**
     *  Matches distributors with any descendant. 
     *
     *  @param  match <code> true </code> to match distributors with any 
     *          descendant, <code> false </code> to match leaf distributors 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantDistributor(boolean match);


    /**
     *  Clears the descendant distributor query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantDistributorTerms();


    /**
     *  Gets the distributor query record corresponding to the given <code> 
     *  Distributor </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  distributorRecordType a distributor record type 
     *  @return the distributor query record 
     *  @throws org.osid.NullArgumentException <code> distributorRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(distributorRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.records.DistributorQueryRecord getDistributorQueryRecord(org.osid.type.Type distributorRecordType)
        throws org.osid.OperationFailedException;
}
