//
// org.osid.provisioning.MyProvisionSession
//
//     The OSID Java specification for org.osid.provisioning.MyProvisionSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning;


/**
 *  <p>This session defines methods for retrieving supplied provisions related 
 *  to the queueing of the resource related to the authenticated agent. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> effective provision view: All lookup methods return provisions 
 *      and requests where the current date falls in between the effective 
 *      dates inclusive. </li> 
 *      <li> any effective provision view: Provisions and requests of any 
 *      effective date are returned from methods. </li> 
 *  </ul>
 *  
 */

public interface MyProvisionSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Distributor </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Distributor Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDistributorId();


    /**
     *  Gets the <code> Distributor </code> associated with this session. 
     *
     *  @return the distributor 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.Distributor getDistributor()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Provisions </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupMyProvision();


    /**
     *  Only provisionables requests and pools whose effective dates are 
     *  current are returned by methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useEffectiveProvisionView();


    /**
     *  All provisionables requests and pools of any effective dates are 
     *  returned by methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyEffectiveProvisionView();


    /**
     *  Gets the provisions for the resource related to this agent. 
     *
     *  @return the returned <code> ProvisionList </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionList getMyProvisions()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all the queues in which the resource related to the authenticated 
     *  agent is on. 
     *
     *  @return the returned <code> Queue </code> list 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.QueueList getMyQueues()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all the requests in which the resource related to the 
     *  authenticated agent. 
     *
     *  @return the returned <code> Request </code> list 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.RequestList getMyRequests()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
