//
// org.osid.provisioning.PoolLookupSession
//
//     The OSID Java specification for org.osid.provisioning.PoolLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning;


/**
 *  <p>This session provides methods for retrieving <code> Pool </code> 
 *  objects. The <code> Pool </code> represents a fixed connection between two 
 *  <code> Provisionables. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated broker view: All pool methods in this session operate, 
 *      retrieve and pertain to pools defined explicitly in the current 
 *      broker. Using an isolated view is useful for managing <code> Pools 
 *      </code> with the <code> PoolAdminSession. </code> </li> 
 *      <li> federated broker view: All pool methods in this session operate, 
 *      retrieve and pertain to all pools defined in this broker and any other 
 *      pools implicitly available in this broker through broker inheritence. 
 *      </li> 
 *      <li> active pool view: active pools are returned from methods in this 
 *      session </li> 
 *      <li> any status pool view: active and inactive pools are returned from 
 *      methods in this session </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedDistributorView() </code> and <code> 
 *  useIsolatedDistributorView() </code> behave as a radio group and one 
 *  should be selected before invoking any lookup methods. </p>
 */

public interface PoolLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Distributor </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Distributor Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDistributorId();


    /**
     *  Gets the <code> Distributor </code> associated with this session. 
     *
     *  @return the distributor 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.Distributor getDistributor()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Pool </code> lookups. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupPools();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativePoolView();


    /**
     *  A complete view of the <code> Pool </code> returns is desired. Methods 
     *  will return what is requested or result in an error. This view is used 
     *  when greater precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryPoolView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include pools in distributors which are children of this broker in the 
     *  distributor hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedDistributorView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this distributor only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedDistributorView();


    /**
     *  Only active pools are returned from methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActivePoolView();


    /**
     *  Borth active and inactive pools are returned from methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusPoolView();


    /**
     *  Gets the <code> Pool </code> specified by its <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Pool </code> may have a different <code> Id </code> than requested, 
     *  such as the case where a duplicate <code> Id </code> was assigned to a 
     *  <code> Pool </code> and retained for compatibility. 
     *  
     *  In active mode, pools are returned that are currently active. In any 
     *  status mode, active and inactive pool are returned. 
     *
     *  @param  poolId <code> Id </code> of the <code> Pool </code> 
     *  @return the pool 
     *  @throws org.osid.NotFoundException <code> poolId </code> not found 
     *  @throws org.osid.NullArgumentException <code> poolId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.provisioning.Pool getPool(org.osid.id.Id poolId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PoolList </code> corresponding to the given <code> 
     *  IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  pools specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Pools </code> may be omitted from the list and may 
     *  present the elements in any order including returning a unique set. 
     *  
     *  In active mode, pools are returned that are currently active. In any 
     *  status mode, active and inactive pool are returned. 
     *
     *  @param  poolIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Pool </code> list 
     *  @throws org.osid.NotFoundException an <code> Id </code> was not found 
     *  @throws org.osid.NullArgumentException <code> poolIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.PoolList getPoolsByIds(org.osid.id.IdList poolIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PoolList </code> corresponding to the given pool genus 
     *  <code> Type </code> which does not include pools of genus types 
     *  derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  pools or an error results. Otherwise, the returned list may contain 
     *  only those pools that are accessible through this session. 
     *  
     *  In active mode, pools are returned that are currently active. In any 
     *  status mode, active and inactive pool are returned. 
     *
     *  @param  poolGenusType a pool genus type 
     *  @return the returned <code> Pool </code> list 
     *  @throws org.osid.NullArgumentException <code> poolGenusType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.PoolList getPoolsByGenusType(org.osid.type.Type poolGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PoolList </code> corresponding to the given pool genus 
     *  <code> Type </code> and include any additional pools with genus types 
     *  derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  pools or an error results. Otherwise, the returned list may contain 
     *  only those pools that are accessible through this session. 
     *  
     *  In active mode, pools are returned that are currently active. In any 
     *  status mode, active and inactive pool are returned. 
     *
     *  @param  poolGenusType a pool genus type 
     *  @return the returned <code> Pool </code> list 
     *  @throws org.osid.NullArgumentException <code> poolGenusType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.PoolList getPoolsByParentGenusType(org.osid.type.Type poolGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PoolList </code> containing the given pool record <code> 
     *  Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  pools or an error results. Otherwise, the returned list may contain 
     *  only those pools that are accessible through this session. 
     *  
     *  In active mode, pools are returned that are currently active. In any 
     *  status mode, active and inactive pool are returned. 
     *
     *  @param  poolRecordType a pool record type 
     *  @return the returned <code> Pool </code> list 
     *  @throws org.osid.NullArgumentException <code> poolRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.PoolList getPoolsByRecordType(org.osid.type.Type poolRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PoolList </code> by broker <code> . </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  pools or an error results. Otherwise, the returned list may contain 
     *  only those pools that are accessible through this session. 
     *  
     *  In active mode, pools are returned that are currently active. In any 
     *  status mode, active and inactive pool are returned. 
     *
     *  @param  brokerId a broker <code> Id </code> 
     *  @return the returned <code> Pool </code> list 
     *  @throws org.osid.NullArgumentException <code> brokerId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.PoolList getPoolsForBroker(org.osid.id.Id brokerId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PoolList </code> by provider. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  pools or an error results. Otherwise, the returned list may contain 
     *  only those pools that are accessible through this session. 
     *  
     *  In active mode, pools are returned that are currently active. In any 
     *  status mode, active and inactive pool are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @return the returned <code> Pool </code> list 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.PoolList getPoolsByProvider(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Pools. </code> 
     *  
     *  In plenary mode, the returned list contains all known pools or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  pools that are accessible through this session. 
     *  
     *  In active mode, pools are returned that are currently active. In any 
     *  status mode, active and inactive pool are returned. 
     *
     *  @return a list of <code> Pools </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.PoolList getPools()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
