//
// org.osid.provisioning.Provision
//
//     The OSID Java specification for org.osid.provisioning.Provision.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning;


/**
 *  <p>A <code> Provision </code> is a relationship between a provisionable 
 *  and a recipient governed by a broker. </p>
 */

public interface Provision
    extends org.osid.OsidRelationship {


    /**
     *  Gets the <code> Id </code> of the broker. 
     *
     *  @return the broker <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBrokerId();


    /**
     *  Gets the broker. 
     *
     *  @return the broker 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.Broker getBroker()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of the provisionable. 
     *
     *  @return the provisionable <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getProvisionableId();


    /**
     *  Gets the provisionable. 
     *
     *  @return the provisionable 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.Provisionable getProvisionable()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of the recipient. 
     *
     *  @return the resource <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getRecipientId();


    /**
     *  Gets the recipient. 
     *
     *  @return the resource 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getRecipient()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this provision has a request. 
     *
     *  @return <code> true </code> if a request is available, false otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean provisionedByRequest();


    /**
     *  Gets the <code> Id </code> of the request. 
     *
     *  @return the request <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> provisionedByRequest() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getRequestId();


    /**
     *  Gets the request. 
     *
     *  @return the request 
     *  @throws org.osid.IllegalStateException <code> provisionedByRequest() 
     *          </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.Request getRequest()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the date this was provisioned. The provision date may differ from 
     *  the effective dates of this provision. 
     *
     *  @return the provision date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getProvisionDate();


    /**
     *  Tests if this provision is temporary. The lease ends when the 
     *  provision expires or is returned. 
     *
     *  @return <code> true </code> if this is a lease, <code> false </code> 
     *          if the provision is permanent 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isLeased();


    /**
     *  Tests if this provision is must be returned. 
     *
     *  @return <code> true </code> if this is must be returned, <code> false 
     *          </code> otherwise 
     *  @throws org.osid.IllegalStateException <code> isLeased() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean mustReturn();


    /**
     *  Tests if this provision is must be returned and has a due date. 
     *
     *  @return <code> true </code> if this is must be returned, <code> false 
     *          </code> otherwise 
     *  @throws org.osid.IllegalStateException <code> mustReturn() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasDueDate();


    /**
     *  Gets the due date for the return. 
     *
     *  @return the due date 
     *  @throws org.osid.IllegalStateException <code> hasDueDate() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getDueDate();


    /**
     *  Tests if this provision has a total cost. If this is a lease with an 
     *  expected return than it is the cost for the time period. 
     *
     *  @return <code> true </code> if there is a cost, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasCost();


    /**
     *  Gets the cost. 
     *
     *  @return the cost 
     *  @throws org.osid.IllegalStateException <code> hasCost() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.Currency getCost();


    /**
     *  Tests if this provision has a rate per time period. 
     *
     *  @return <code> true </code> if there is a rate, false otherwise 
     *  @throws org.osid.IllegalStateException <code> hasRate() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasRate();


    /**
     *  Gets the rate amount. 
     *
     *  @return the rate amount 
     *  @throws org.osid.IllegalStateException <code> hasRate() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.Currency getRateAmount();


    /**
     *  Gets the rate period. 
     *
     *  @return the time period 
     *  @throws org.osid.IllegalStateException <code> hasRate() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Duration getRatePeriod();


    /**
     *  Tests if this provision has been returned. 
     *
     *  @return <code> true </code> if this provision has been returned, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isReturned();


    /**
     *  Gets the provision return that has any data that may have been 
     *  captured in the return process. 
     *
     *  @return the return 
     *  @throws org.osid.IllegalStateException <code> isReturned() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionReturn getProvisionReturn();


    /**
     *  Gets the provision record corresponding to the given <code> Provision 
     *  </code> record <code> Type. </code> This method is used to retrieve an 
     *  object implementing the requested record. The <code> 
     *  provisionRecordType </code> may be the <code> Type </code> returned in 
     *  <code> getRecordTypes() </code> or any of its parents in a <code> Type 
     *  </code> hierarchy where <code> hasRecordType(provisionRecordType) 
     *  </code> is <code> true </code> . 
     *
     *  @param  provisionRecordType the type of provision record to retrieve 
     *  @return the provision record 
     *  @throws org.osid.NullArgumentException <code> provisionRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(provisionRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.records.ProvisionRecord getProvisionRecord(org.osid.type.Type provisionRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
