//
// org.osid.provisioning.ProvisionLookupSession
//
//     The OSID Java specification for org.osid.provisioning.ProvisionLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning;


/**
 *  <p>This session provides methods for retrieving <code> Provision </code> 
 *  objects. The <code> Provision </code> represents a fixed connection 
 *  between two <code> Provisions. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated distributor view: All provision methods in this session 
 *      operate, retrieve and pertain to provisions defined explicitly in the 
 *      current distributor. Using an isolated view is useful for managing 
 *      <code> Provisions </code> with the <code> ProvisionAdminSession. 
 *      </code> </li> 
 *      <li> federated distributor view: All provision methods in this session 
 *      operate, retrieve and pertain to all provisions defined in this 
 *      distributor and any other provisions implicitly available in this 
 *      distributor through distributor inheritence. </li> 
 *      <li> effective provision view: All provision lookup methods return 
 *      provisions where the current date falls in between the effective dates 
 *      inclusive. </li> 
 *      <li> any effective provision view: Provisions of any effective date 
 *      are returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedDistributorView() </code> and <code> 
 *  useIsolatedDistributorView() </code> behave as a radio group and one 
 *  should be selected before invoking any lookup methods. </p>
 */

public interface ProvisionLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Distributor </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Distributor Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDistributorId();


    /**
     *  Gets the <code> Distributor </code> associated with this session. 
     *
     *  @return the distributor 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.Distributor getDistributor()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Provision </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupProvisions();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeProvisionView();


    /**
     *  A complete view of the <code> Provision </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryProvisionView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include provisions in distributors which are children of this 
     *  distributor in the distributor hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedDistributorView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this distributor only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedDistributorView();


    /**
     *  Only provisions whose effective dates are current are returned by 
     *  methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useEffectiveProvisionView();


    /**
     *  All provisions of any effective dates are returned by methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyEffectiveProvisionView();


    /**
     *  Gets the <code> Provision </code> specified by its <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Provision </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> Provision </code> and retained for compatibility. 
     *  
     *  In effective mode, provisions are returned that are currently 
     *  effective. In any effective mode, effective provisions and those 
     *  currently expired are returned. 
     *
     *  @param  provisionId <code> Id </code> of the <code> Provision </code> 
     *  @return the provision 
     *  @throws org.osid.NotFoundException <code> provisionId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> provisionId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.provisioning.Provision getProvision(org.osid.id.Id provisionId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProvisionList </code> corresponding to the given <code> 
     *  IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  provisions specified in the <code> Id </code> list, in the order of 
     *  the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Provisions </code> may be omitted from the list 
     *  and may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In effective mode, provisions are returned that are currently 
     *  effective. In any effective mode, effective provisions and those 
     *  currently expired are returned. 
     *
     *  @param  provisionIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Provision </code> list 
     *  @throws org.osid.NotFoundException an <code> Id </code> was not found 
     *  @throws org.osid.NullArgumentException <code> provisionIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionList getProvisionsByIds(org.osid.id.IdList provisionIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProvisionList </code> corresponding to the given 
     *  provision genus <code> Type </code> which does not include provisions 
     *  of genus types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  provisions or an error results. Otherwise, the returned list may 
     *  contain only those provisions that are accessible through this 
     *  session. 
     *  
     *  In effective mode, provisions are returned that are currently 
     *  effective. In any effective mode, effective provisions and those 
     *  currently expired are returned. 
     *
     *  @param  provisionGenusType a provision genus type 
     *  @return the returned <code> Provision </code> list 
     *  @throws org.osid.NullArgumentException <code> provisionGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionList getProvisionsByGenusType(org.osid.type.Type provisionGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProvisionList </code> corresponding to the given 
     *  provision genus <code> Type </code> and include any additional 
     *  provisions with genus types derived from the specified <code> Type. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  provisions or an error results. Otherwise, the returned list may 
     *  contain only those provisions that are accessible through this 
     *  session. 
     *  
     *  In effective mode, provisions are returned that are currently 
     *  effective. In any effective mode, effective provisions and those 
     *  currently expired are returned. 
     *
     *  @param  provisionGenusType a provision genus type 
     *  @return the returned <code> Provision </code> list 
     *  @throws org.osid.NullArgumentException <code> provisionGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionList getProvisionsByParentGenusType(org.osid.type.Type provisionGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProvisionList </code> containing the given provision 
     *  record <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  provisions or an error results. Otherwise, the returned list may 
     *  contain only those provisions that are accessible through this 
     *  session. 
     *  
     *  In effective mode, provisions are returned that are currently 
     *  effective. In any effective mode, effective provisions and those 
     *  currently expired are returned. 
     *
     *  @param  provisionRecordType a provision record type 
     *  @return the returned <code> Provision </code> list 
     *  @throws org.osid.NullArgumentException <code> provisionRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionList getProvisionsByRecordType(org.osid.type.Type provisionRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of provisions effective during the entire given date range 
     *  inclusive but not confined to the date range. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  provisions or an error results. Otherwise, the returned list may 
     *  contain only those provisions that are accessible through this 
     *  session. 
     *  
     *  In effective mode, provisions are returned that are currently 
     *  effective in addition to being effective in the guven date range. In 
     *  any effective mode, effective provisions and those currently expired 
     *  are returned. 
     *
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Provision </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionList getProvisionsOnDate(org.osid.calendaring.DateTime from, 
                                                                   org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of provisions for a supplied broker. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  provisions or an error results. Otherwise, the returned list may 
     *  contain only those provisions that are accessible through this 
     *  session. 
     *  
     *  In effective mode, provisions are returned that are currently 
     *  effective. In any effective mode, effective provisions and those 
     *  currently expired are returned. 
     *
     *  @param  brokerId a broker <code> Id </code> 
     *  @return the returned <code> Provision </code> list 
     *  @throws org.osid.NullArgumentException <code> brokerId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionList getProvisionsForBroker(org.osid.id.Id brokerId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of provisions for a supplied broker. and effective during 
     *  the entire given date range inclusive but not confined to the date 
     *  range. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  provisions or an error results. Otherwise, the returned list may 
     *  contain only those provisions that are accessible through this 
     *  session. 
     *  
     *  In effective mode, provisions are returned that are currently 
     *  effective in addition to being effective in the guven date range. In 
     *  any effective mode, effective provisions and those currently expired 
     *  are returned. 
     *
     *  @param  brokerId a broker <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Provision </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> brokerId, from </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionList getProvisionsForBrokerOnDate(org.osid.id.Id brokerId, 
                                                                            org.osid.calendaring.DateTime from, 
                                                                            org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of provisions for a provisionable. 
     *  
     *  In plenary mode, the returned list contains all known provisions or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  provisions that are accessible through this session. 
     *  
     *  In effective mode, provisions are returned that are currently 
     *  effective. In any effective mode, effective provisions and those 
     *  currently expired are returned. 
     *
     *  @param  provisionableId a provisionable <code> Id </code> 
     *  @return the returned <code> Provision </code> list 
     *  @throws org.osid.NullArgumentException <code> provisionableId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionList getProvisionsForProvisionable(org.osid.id.Id provisionableId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of provisions for a provisionable and effective during the 
     *  entire given date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known provisions or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  provisions that are accessible through this session. 
     *  
     *  In effective mode, provisions are returned that are currently 
     *  effective in addition to being effective in the guven date range. In 
     *  any effective mode, effective provisions and those currently expired 
     *  are returned. 
     *
     *  @param  provisionableId a provisionable <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Provision </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> provisionableId, from 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionList getProvisionsForProvisionableOnDate(org.osid.id.Id provisionableId, 
                                                                                   org.osid.calendaring.DateTime from, 
                                                                                   org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of provisions for a recipient resource. 
     *  
     *  In plenary mode, the returned list contains all known provisions or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  provisions that are accessible through this session. 
     *  
     *  In effective mode, provisions are returned that are currently 
     *  effective. In any effective mode, effective provisions and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @return the returned <code> Provision </code> list 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionList getProvisionsForRecipient(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of provisions for a recipient resource and effective 
     *  during the entire given date range inclusive but not confined to the 
     *  date range. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  provisions or an error results. Otherwise, the returned list may 
     *  contain only those provisions that are accessible through this 
     *  session. 
     *  
     *  In effective mode, provisions are returned that are currently 
     *  effective in addition to being effective in the guven date range. In 
     *  any effective mode, effective provisions and those currently expired 
     *  are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Provision </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, from </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionList getProvisionsForRecipientOnDate(org.osid.id.Id resourceId, 
                                                                               org.osid.calendaring.DateTime from, 
                                                                               org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of provisions for a resource and recipient. 
     *  
     *  In plenary mode, the returned list contains all known provisions or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  provisions that are accessible through this session. 
     *  
     *  In effective mode, provisions are returned that are currently 
     *  effective. In any effective mode, effective provisions and those 
     *  currently expired are returned. 
     *
     *  @param  provisionableId a provisionable <code> Id </code> 
     *  @param  recipientId a recipient resource <code> Id </code> 
     *  @return the returned <code> Provision </code> list 
     *  @throws org.osid.NullArgumentException <code> provisionableId </code> 
     *          or <code> recipientId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionList getProvisionsForProvisionableAndRecipient(org.osid.id.Id provisionableId, 
                                                                                         org.osid.id.Id recipientId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of provisions for a resource and request and effective 
     *  during the entire given date range inclusive but not confined to the 
     *  date range. 
     *  
     *  In plenary mode, the returned list contains all known provisions or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  provisions that are accessible through this session. 
     *  
     *  In effective mode, provisions are returned that are currently 
     *  effective in addition to being effective in the guven date range. In 
     *  any effective mode, effective provisions and those currently expired 
     *  are returned. 
     *
     *  @param  provisionableId a provisionable <code> Id </code> 
     *  @param  recipientId a recipient resource <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Provision </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> provisionableId, 
     *          recipientId, from </code> or <code> to </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionList getProvisionsForProvisionableAndRecipientOnDate(org.osid.id.Id provisionableId, 
                                                                                               org.osid.id.Id recipientId, 
                                                                                               org.osid.calendaring.DateTime from, 
                                                                                               org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of provisions for a request. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  provisions or an error results. Otherwise, the returned list may 
     *  contain only those provisions that are accessible through this 
     *  session. 
     *  
     *  In effective mode, provisions are returned that are currently 
     *  effective. In any effective mode, effective provisions and those 
     *  currently expired are returned. 
     *
     *  @param  requestId a request <code> Id </code> 
     *  @return the returned <code> Provision </code> list 
     *  @throws org.osid.NullArgumentException <code> requestId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionList getProvisionsForRequest(org.osid.id.Id requestId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Provisions. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  provisions or an error results. Otherwise, the returned list may 
     *  contain only those provisions that are accessible through this 
     *  session. 
     *  
     *  In effective mode, provisions are returned that are currently 
     *  effective. In any effective mode, effective provisions and those 
     *  currently expired are returned. 
     *
     *  @return a list of <code> Provisions </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionList getProvisions()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
