//
// org.osid.provisioning.ProvisionReturn
//
//     The OSID Java specification for org.osid.provisioning.ProvisionReturn.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning;


/**
 *  <p>A <code> ProvisionReturn </code> captures data related to the return of 
 *  a provision. </p>
 */

public interface ProvisionReturn
    extends org.osid.OsidObject,
            org.osid.Subjugateable {


    /**
     *  Gets the date returned. The return date is the effective end date of 
     *  the provision when the return is processed. 
     *
     *  @return the date returned 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getReturnDate();


    /**
     *  Gets the <code> Id </code> of the returner resource. 
     *
     *  @return the resource <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getReturnerId();


    /**
     *  Gets the returner. 
     *
     *  @return the returner 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getReturner()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of the returning agent. 
     *
     *  @return the resource <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getReturningAgentId();


    /**
     *  Gets the returning agent. 
     *
     *  @return the agent 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.Agent getReturningAgent()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the provision return record corresponding to the given <code> 
     *  ProvisionReturn </code> record <code> Type. </code> This method is 
     *  used to retrieve an object implementing the requested record. The 
     *  <code> provisionReturnRecordType </code> may be the <code> Type 
     *  </code> returned in <code> getRecordTypes() </code> or any of its 
     *  parents in a <code> Type </code> hierarchy where <code> 
     *  hasRecordType(provisionReturnRecordType) </code> is <code> true 
     *  </code> . 
     *
     *  @param  provisionReturnRecordType the type of provision return record 
     *          to retrieve 
     *  @return the provision return record 
     *  @throws org.osid.NullArgumentException <code> 
     *          provisionReturnRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(provisionReturnRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.records.ProvisionReturnRecord getProvisionReturnRecord(org.osid.type.Type provisionReturnRecordType)
        throws org.osid.OperationFailedException;
}
