//
// org.osid.provisioning.ProvisionReturnSession
//
//     The OSID Java specification for org.osid.provisioning.ProvisionReturnSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning;


/**
 *  <p>This session creates, updates, and deletes <code> ProvisionReturns. 
 *  </code> The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  ProvisionReturns, </code> a <code> ProvisionReturnForm </code> is 
 *  requested using <code> getProvisionReturnFormForCreate() </code> 
 *  specifying the desired record <code> Types </code> or none if no record 
 *  <code> Types </code> are needed. The returned <code> ProvisionReturnForm 
 *  </code> will indicate that it is to be used with a create operation and 
 *  can be used to examine metdata or validate data prior to creation. Once 
 *  the <code> ProvisionReturnForm </code> is submiited to a create operation, 
 *  it cannot be reused with another create operation unless the first 
 *  operation was unsuccessful. Each <code> ProvisionReturnForm </code> 
 *  corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> ProvisionReturnForms </code> are requested to the 
 *  <code> ProvisionReturn </code> <code> Id </code> that is to be updated 
 *  using <code> getProvisionReturnFormForUpdate(). </code> Similarly, the 
 *  <code> ProvisionReturnForm </code> has metadata about the data that can be 
 *  updated and it can perform validation before submitting the update. The 
 *  <code> ProvisionReturnForm </code> can only be used once for a successful 
 *  update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> ProvisionReturns. </code> To unmap 
 *  a <code> ProvisionReturn </code> from the current <code> Distributor, 
 *  </code> the <code> RProvisionReturnDistributorAssignmentSession </code> 
 *  should be used. These delete operations attempt to remove the <code> 
 *  ProvisionReturn </code> itself thus removing it from all known <code> 
 *  Distributor </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface ProvisionReturnSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Broker </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Broker Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBrokerId();


    /**
     *  Gets the <code> Broker </code> associated with this session. 
     *
     *  @return the broker 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.Broker getBroker()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can return <code> Provisions. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> Provision </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer return operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Provision </code> return is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateProvisionReturns();


    /**
     *  Tests if this user can create a single <code> ProvisionReturn </code> 
     *  using the desired record types. While <code> 
     *  ProvisioningManager.getProvisionRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> Provision. </code> 
     *  Providing an empty array tests if a <code> Provision </code> can be 
     *  created with no records. 
     *
     *  @param  provisionReturnRecordTypes array of provision return record 
     *          types 
     *  @return <code> true </code> if <code> ProvisionReturn </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          provisionReturnRecordTypes </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateProvisionReturnWithRecordTypes(org.osid.type.Type[] provisionReturnRecordTypes);


    /**
     *  Gets the provision return form for creating new provisions. A new form 
     *  should be requested for each return transaction. 
     *
     *  @param  provisionId the <code> Id </code> for the provision 
     *  @param  provisionReturnRecordTypes array of provision return record 
     *          types 
     *  @return the provision return form 
     *  @throws org.osid.NotFoundException <code> provisionId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> provisionId </code> or 
     *          <code> provisionReturnRecordTypes </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionReturnForm getProvisionReturnFormForCreate(org.osid.id.Id provisionId, 
                                                                                     org.osid.type.Type[] provisionReturnRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> ProvisionReturn. </code> 
     *
     *  @param  provisionReturnForm the form for this <code> ProvisionReturn 
     *          </code> 
     *  @return the new <code> ProvisionReturn </code> 
     *  @throws org.osid.IllegalStateException <code> provisionForm </code> is 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> provisionReturnForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> provisionReturnForm 
     *          </code> did not oroginate from <code> 
     *          getProvisionFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionReturn createProvisionReturn(org.osid.provisioning.ProvisionReturnForm provisionReturnForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> ProvisionReturns. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known updating a <code> ProvisionReturn 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer update 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> ProvisionReturn </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateProvisionReturns();


    /**
     *  Gets the provision form for updating an existing provision return. A 
     *  new provision return form should be requested for each update 
     *  transaction. 
     *
     *  @param  provisionReturnId the <code> Id </code> of the <code> 
     *          ProvisionReturn </code> 
     *  @return the provision return form 
     *  @throws org.osid.NotFoundException <code> provisionReturnId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> provisionReturnId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionReturnForm getProvisionReturnFormForUpdate(org.osid.id.Id provisionReturnId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Updates an existing provision return. 
     *
     *  @param  provisionReturnForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NotFoundException <code> provisionReturnId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> provisionReturnForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> provisionReturnForm 
     *          </code> did not originate from <code> 
     *          getProvisionReturnFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateProvisionReturn(org.osid.provisioning.ProvisionReturnForm provisionReturnForm)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> ProvisionReturns. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known deleting a <code> ProvisionReturn 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer delete 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Provision </code> deletion is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteProvisionReturns();


    /**
     *  Deletes a <code> ProvisionReturn. </code> The delete operation deletes 
     *  the provision return data but does not undo the returned status of the 
     *  provision. 
     *
     *  @param  provisionReturnId the <code> Id </code> of the <code> 
     *          ProvisionReturn </code> to remove 
     *  @throws org.osid.NotFoundException <code> provisionReturnId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> provisionReturnId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteProvisionReturn(org.osid.id.Id provisionReturnId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
