//
// org.osid.provisioning.ProvisionSearchOrder
//
//     The OSID Java specification for org.osid.provisioning.ProvisionSearchOrder.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning;


/**
 *  <p>An interface for specifying the ordering of search results. </p>
 */

public interface ProvisionSearchOrder
    extends org.osid.OsidRelationshipSearchOrder {


    /**
     *  Orders the results by the broker. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByBroker(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a broker search order is available. 
     *
     *  @return <code> true </code> if a broker search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerSearchOrder();


    /**
     *  Gets the broker search order. 
     *
     *  @return the broker search order 
     *  @throws org.osid.IllegalStateException <code> 
     *          supportsBrokerSearchOrder() </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.BrokerSearchOrder getBrokerSearchOrder();


    /**
     *  Orders the results by the provisionable. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByProvisionable(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a provisionable search order is available. 
     *
     *  @return <code> true </code> if a provisionable search order is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProvisionableSearchOrder();


    /**
     *  Gets the provisionable search order. 
     *
     *  @return the provisionable search order 
     *  @throws org.osid.IllegalStateException <code> 
     *          supportsProvisionableSearchOrder() </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionableSearchOrder getProvisionableSearchOrder();


    /**
     *  Orders the results by the recipient. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByRecipient(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a resource search order is available. 
     *
     *  @return <code> true </code> if a resource search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRecipientSearchOrder();


    /**
     *  Gets the resource search order. 
     *
     *  @return the resource search order 
     *  @throws org.osid.IllegalStateException <code> 
     *          supportsRecipientSearchOrder() </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceSearchOrder getRecipientSearchOrder();


    /**
     *  Orders the results by the request. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByRequest(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a request search order is available. 
     *
     *  @return <code> true </code> if a request search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRequestSearchOrder();


    /**
     *  Gets the request search order. 
     *
     *  @return the request search order 
     *  @throws org.osid.IllegalStateException <code> 
     *          supportsRequestSearchOrder() </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.RequestSearchOrder getRequestSearchOrder();


    /**
     *  Orders the results by the provision date. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByProvisionDate(org.osid.SearchOrderStyle style);


    /**
     *  Orders the results by the leased flag. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByLeased(org.osid.SearchOrderStyle style);


    /**
     *  Orders the results by the must return flag. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByMustReturn(org.osid.SearchOrderStyle style);


    /**
     *  Orders the results by the due date. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByDueDate(org.osid.SearchOrderStyle style);


    /**
     *  Orders the results by the cost. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByCost(org.osid.SearchOrderStyle style);


    /**
     *  Orders the results by the rate amount and period. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByRate(org.osid.SearchOrderStyle style);


    /**
     *  Orders the results by returned. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByProvisionReturn(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a provision return search order is available. 
     *
     *  @return <code> true </code> if a provision return search order is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProvisionReturnSearchOrder();


    /**
     *  Gets the provision return search order. 
     *
     *  @return the provision return search order 
     *  @throws org.osid.IllegalStateException <code> 
     *          supportsProvisionReturnSearchOrder() </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionReturnSearchOrder getProvisionReturnSearchOrder();


    /**
     *  Gets the provision search order record corresponding to the given 
     *  provision record <code> Type. </code> Multiple retrievals return the 
     *  same underlying object. 
     *
     *  @param  provisionRecordType a provision record type 
     *  @return the provision search order record 
     *  @throws org.osid.NullArgumentException <code> provisionRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(provisionRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.records.ProvisionSearchOrderRecord getProvisionSearchOrderRecord(org.osid.type.Type provisionRecordType)
        throws org.osid.OperationFailedException;
}
