//
// org.osid.provisioning.ProvisioningProfile
//
//     The OSID Java specification for org.osid.provisioning.ProvisioningProfile.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning;


/**
 *  <p>The provisioning profile describes the interoperability among 
 *  provisioning services. </p>
 */

public interface ProvisioningProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any broker federation is exposed. Federation is exposed when 
     *  a specific broker may be identified, selected and used to create a 
     *  lookup or admin session. Federation is not exposed when a set of 
     *  brokers appears as a single broker. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if a my provision service is supported for the current agent. 
     *
     *  @return <code> true </code> if my provision is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMyProvision();


    /**
     *  Tests if a my supplier service is supported for the current agent. 
     *
     *  @return <code> true </code> if my supplier is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMySupplier();


    /**
     *  Tests if a my provision notification service is supported for the 
     *  current agent. 
     *
     *  @return <code> true </code> if my provision notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMyProvisionNotification();


    /**
     *  Tests if looking up provisions is supported. 
     *
     *  @return <code> true </code> if provision lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProvisionLookup();


    /**
     *  Tests if querying provisions is supported. 
     *
     *  @return <code> true </code> if provision query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProvisionQuery();


    /**
     *  Tests if searching provisions is supported. 
     *
     *  @return <code> true </code> if provision search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProvisionSearch();


    /**
     *  Tests if a provision administrative service is supported. 
     *
     *  @return <code> true </code> if provision administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProvisionAdmin();


    /**
     *  Tests if a provision <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if provision notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProvisionNotification();


    /**
     *  Tests if a provision distributor lookup service is supported. 
     *
     *  @return <code> true </code> if a provision distributor lookup service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProvisionDistributor();


    /**
     *  Tests if a provision distributor assignment service is supported. 
     *
     *  @return <code> true </code> if a provision to distributor assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProvisionDistributorAssignment();


    /**
     *  Tests if a provision smart distributor service is supported. 
     *
     *  @return <code> true </code> if an v smart distributor service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProvisionSmartDistributor();


    /**
     *  Tests if returning provisions is supported. 
     *
     *  @return <code> true </code> if returning provisions is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProvisionReturn();


    /**
     *  Tests if looking up queues is supported. 
     *
     *  @return <code> true </code> if queue lookup is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueLookup();


    /**
     *  Tests if querying queues is supported. 
     *
     *  @return <code> true </code> if queue query is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueQuery();


    /**
     *  Tests if searching queues is supported. 
     *
     *  @return <code> true </code> if queue search is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueSearch();


    /**
     *  Tests if queue administrative service is supported. 
     *
     *  @return <code> true </code> if queue administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueAdmin();


    /**
     *  Tests if a queue notification service is supported. 
     *
     *  @return <code> true </code> if queue notification is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueNotification();


    /**
     *  Tests if a queue broker lookup service is supported. 
     *
     *  @return <code> true </code> if a queue broker lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueBroker();


    /**
     *  Tests if a queue broker service is supported. 
     *
     *  @return <code> true </code> if queue to broker assignment service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueBrokerAssignment();


    /**
     *  Tests if a queue smart broker lookup service is supported. 
     *
     *  @return <code> true </code> if a queue smart broker service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueSmartBroker();


    /**
     *  Tests if looking up requests is supported. 
     *
     *  @return <code> true </code> if request lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRequestLookup();


    /**
     *  Tests if querying requests is supported. 
     *
     *  @return <code> true </code> if request query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRequestQuery();


    /**
     *  Tests if searching requests is supported. 
     *
     *  @return <code> true </code> if request search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRequestSearch();


    /**
     *  Tests if request administrative service is supported. 
     *
     *  @return <code> true </code> if request administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRequestAdmin();


    /**
     *  Tests if a request notification service is supported. 
     *
     *  @return <code> true </code> if request notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRequestNotification();


    /**
     *  Tests if a request distributor lookup service is supported. 
     *
     *  @return <code> true </code> if a request distributor lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRequestDistributor();


    /**
     *  Tests if a request distributor service is supported. 
     *
     *  @return <code> true </code> if request to distributor assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRequestDistributorAssignment();


    /**
     *  Tests if a request smart distributor lookup service is supported. 
     *
     *  @return <code> true </code> if a request smart distributor service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRequestSmartDistributor();


    /**
     *  Tests if looking up request transactions is supported. 
     *
     *  @return <code> true </code> if request transaction lookup is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRequestTransactionLookup();


    /**
     *  Tests if request transaction administrative service is supported. 
     *
     *  @return <code> true </code> if request transaction administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRequestTransactionAdmin();


    /**
     *  Tests if exchanging provisions is supported. 
     *
     *  @return <code> true </code> if exchange is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsExchange();


    /**
     *  Tests if looking up pools is supported. 
     *
     *  @return <code> true </code> if pool lookup is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolLookup();


    /**
     *  Tests if querying pools is supported. 
     *
     *  @return <code> true </code> if pool query is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolQuery();


    /**
     *  Tests if searching pools is supported. 
     *
     *  @return <code> true </code> if pool search is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolSearch();


    /**
     *  Tests if a pool administrative service is supported. 
     *
     *  @return <code> true </code> if pool administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolAdmin();


    /**
     *  Tests if a pool <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if pool notification is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolNotification();


    /**
     *  Tests if a pool distributor lookup service is supported. 
     *
     *  @return <code> true </code> if a pool distributor lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolDistributor();


    /**
     *  Tests if a pool distributor assignment service is supported. 
     *
     *  @return <code> true </code> if a pool to distributor assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolDistributorAssignment();


    /**
     *  Tests if a pool smart distributor service is supported. 
     *
     *  @return <code> true </code> if a smart distributor service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolSmartDistributor();


    /**
     *  Tests if looking up provisionables is supported. 
     *
     *  @return <code> true </code> if provisionable lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProvisionableLookup();


    /**
     *  Tests if querying provisionables is supported. 
     *
     *  @return <code> true </code> if provisionable query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProvisionableQuery();


    /**
     *  Tests if searching provisionables is supported. 
     *
     *  @return <code> true </code> if provisionable search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProvisionableSearch();


    /**
     *  Tests if provisionable <code> </code> administrative service is 
     *  supported. 
     *
     *  @return <code> true </code> if provisionable administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProvisionableAdmin();


    /**
     *  Tests if a provisionable <code> </code> notification service is 
     *  supported. 
     *
     *  @return <code> true </code> if provisionable notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProvisionableNotification();


    /**
     *  Tests if a provisionable distributor lookup service is supported. 
     *
     *  @return <code> true </code> if a provisionable distributor lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProvisionableDistributor();


    /**
     *  Tests if a provisionable distributor assignment service is supported. 
     *
     *  @return <code> true </code> if a provisionable to distributor 
     *          assignment service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProvisionableDistributorAssignment();


    /**
     *  Tests if a provisionable smart distributor service is supported. 
     *
     *  @return <code> true </code> if a provisionable smart distributor 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProvisionableSmartDistributor();


    /**
     *  Tests if looking up brokers is supported. 
     *
     *  @return <code> true </code> if broker lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerLookup();


    /**
     *  Tests if querying brokers is supported. 
     *
     *  @return <code> true </code> if a broker query service is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerQuery();


    /**
     *  Tests if searching brokers is supported. 
     *
     *  @return <code> true </code> if broker search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerSearch();


    /**
     *  Tests if broker administrative service is supported. 
     *
     *  @return <code> true </code> if broker administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerAdmin();


    /**
     *  Tests if a broker <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if broker notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerNotification();


    /**
     *  Tests if a broker distributor lookup service is supported. 
     *
     *  @return <code> true </code> if a broker distributor lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerDistributor();


    /**
     *  Tests if a broker distributor service is supported. 
     *
     *  @return <code> true </code> if broker to distributor assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerDistributorAssignment();


    /**
     *  Tests if a broker smart distributor lookup service is supported. 
     *
     *  @return <code> true </code> if a broker smart distributor service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerSmartDistributor();


    /**
     *  Tests if looking up distributors is supported. 
     *
     *  @return <code> true </code> if distributor lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDistributorLookup();


    /**
     *  Tests if querying distributors is supported. 
     *
     *  @return <code> true </code> if a distributor query service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDistributorQuery();


    /**
     *  Tests if searching distributors is supported. 
     *
     *  @return <code> true </code> if distributor search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDistributorSearch();


    /**
     *  Tests if distributor administrative service is supported. 
     *
     *  @return <code> true </code> if distributor administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDistributorAdmin();


    /**
     *  Tests if a distributor <code> </code> notification service is 
     *  supported. 
     *
     *  @return <code> true </code> if distributor notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDistributorNotification();


    /**
     *  Tests for the availability of a distributor hierarchy traversal 
     *  service. 
     *
     *  @return <code> true </code> if distributor hierarchy traversal is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsDistributorHierarchy();


    /**
     *  Tests for the availability of a distributor hierarchy design service. 
     *
     *  @return <code> true </code> if distributor hierarchy design is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDistributorHierarchyDesign();


    /**
     *  Tests for the availability of a provisioning batch service. 
     *
     *  @return <code> true </code> if provisioning batch service is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProvisioningBatch();


    /**
     *  Tests for the availability of a provisioning rules service. 
     *
     *  @return <code> true </code> if provisioning rules service is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProvisioningRules();


    /**
     *  Gets the supported <code> Provision </code> record types. 
     *
     *  @return a list containing the supported <code> Provision </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getProvisionRecordTypes();


    /**
     *  Tests if the given <code> Provision </code> record type is supported. 
     *
     *  @param  provisionRecordType a <code> Type </code> indicating a <code> 
     *          Provision </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> provisionRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProvisionRecordType(org.osid.type.Type provisionRecordType);


    /**
     *  Gets the supported <code> Provision </code> search types. 
     *
     *  @return a list containing the supported <code> Provision </code> 
     *          search types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getProvisionSearchRecordTypes();


    /**
     *  Tests if the given <code> Provision </code> search type is supported. 
     *
     *  @param  provisionSearchRecordType a <code> Type </code> indicating a 
     *          <code> Provision </code> search type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          provisionSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProvisionSearchRecordType(org.osid.type.Type provisionSearchRecordType);


    /**
     *  Gets the supported <code> ProvisionReturn </code> record types. 
     *
     *  @return a list containing the supported <code> ProvisionReturn </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getProvisionReturnRecordTypes();


    /**
     *  Tests if the given <code> ProvisionReturn </code> record type is 
     *  supported. 
     *
     *  @param  provisionReturnRecordType a <code> Type </code> indicating a 
     *          <code> ProvisionReturn </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          provisionReturnRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProvisionReturnRecordType(org.osid.type.Type provisionReturnRecordType);


    /**
     *  Gets the supported <code> Queue </code> record types. 
     *
     *  @return a list containing the supported <code> Queue </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getQueueRecordTypes();


    /**
     *  Tests if the given <code> Queue </code> record type is supported. 
     *
     *  @param  queueRecordType a <code> Type </code> indicating a <code> 
     *          Queue </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> queueRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueRecordType(org.osid.type.Type queueRecordType);


    /**
     *  Gets the supported <code> Queue </code> search record types. 
     *
     *  @return a list containing the supported <code> Queue </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getQueueSearchRecordTypes();


    /**
     *  Tests if the given <code> Queue </code> search record type is 
     *  supported. 
     *
     *  @param  queueSearchRecordType a <code> Type </code> indicating a 
     *          <code> Queue </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> queueSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueSearchRecordType(org.osid.type.Type queueSearchRecordType);


    /**
     *  Gets the supported <code> Request </code> record types. 
     *
     *  @return a list containing the supported <code> Request </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getRequestRecordTypes();


    /**
     *  Tests if the given <code> Request </code> record type is supported. 
     *
     *  @param  requestRecordType a <code> Type </code> indicating a <code> 
     *          Request </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> requestRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRequestRecordType(org.osid.type.Type requestRecordType);


    /**
     *  Gets the supported <code> Request </code> search record types. 
     *
     *  @return a list containing the supported <code> Request </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getRequestSearchRecordTypes();


    /**
     *  Tests if the given <code> Request </code> search record type is 
     *  supported. 
     *
     *  @param  requestSearchRecordType a <code> Type </code> indicating a 
     *          <code> Request </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> requestSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRequestSearchRecordType(org.osid.type.Type requestSearchRecordType);


    /**
     *  Gets the supported <code> RequestTransaction </code> record types. 
     *
     *  @return a list containing the supported <code> RequestTransaction 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getRequestTransactionRecordTypes();


    /**
     *  Tests if the given <code> RequestTransaction </code> record type is 
     *  supported. 
     *
     *  @param  requestTransactionRecordType a <code> Type </code> indicating 
     *          a <code> RequestTransaction </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          requestTransactionRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRequestTransactionRecordType(org.osid.type.Type requestTransactionRecordType);


    /**
     *  Gets the supported <code> Pool </code> record types. 
     *
     *  @return a list containing the supported <code> Pool </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getPoolRecordTypes();


    /**
     *  Tests if the given <code> Pool </code> record type is supported. 
     *
     *  @param  poolRecordType a <code> Type </code> indicating a <code> Pool 
     *          </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> poolRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolRecordType(org.osid.type.Type poolRecordType);


    /**
     *  Gets the supported <code> Pool </code> search types. 
     *
     *  @return a list containing the supported <code> Pool </code> search 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getPoolSearchRecordTypes();


    /**
     *  Tests if the given <code> Pool </code> search type is supported. 
     *
     *  @param  poolSearchRecordType a <code> Type </code> indicating a <code> 
     *          Pool </code> search type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> poolSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolSearchRecordType(org.osid.type.Type poolSearchRecordType);


    /**
     *  Gets the supported <code> Provisionable </code> record types. 
     *
     *  @return a list containing the supported <code> Provisionable </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getProvisionableRecordTypes();


    /**
     *  Tests if the given <code> Provisionable </code> record type is 
     *  supported. 
     *
     *  @param  provisionableRecordType a <code> Type </code> indicating a 
     *          <code> Provisionable </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> provisionableRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProvisionableRecordType(org.osid.type.Type provisionableRecordType);


    /**
     *  Gets the supported <code> Provisionable </code> search types. 
     *
     *  @return a list containing the supported <code> Provisionable </code> 
     *          search types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getProvisionableSearchRecordTypes();


    /**
     *  Tests if the given <code> Provisionable </code> search type is 
     *  supported. 
     *
     *  @param  provisionableSearchRecordType a <code> Type </code> indicating 
     *          a <code> Provisionable </code> search type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          provisionableSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProvisionableSearchRecordType(org.osid.type.Type provisionableSearchRecordType);


    /**
     *  Gets the supported <code> Broker </code> record types. 
     *
     *  @return a list containing the supported <code> Broker </code> types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getBrokerRecordTypes();


    /**
     *  Tests if the given <code> Broker </code> record type is supported. 
     *
     *  @param  brokerRecordType a <code> Type </code> indicating a <code> 
     *          Broker </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> brokerRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerRecordType(org.osid.type.Type brokerRecordType);


    /**
     *  Gets the supported <code> Broker </code> search record types. 
     *
     *  @return a list containing the supported <code> Broker </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getBrokerSearchRecordTypes();


    /**
     *  Tests if the given <code> Broker </code> search record type is 
     *  supported. 
     *
     *  @param  brokerSearchRecordType a <code> Type </code> indicating a 
     *          <code> Broker </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> brokerSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerSearchRecordType(org.osid.type.Type brokerSearchRecordType);


    /**
     *  Gets the supported <code> Distributor </code> record types. 
     *
     *  @return a list containing the supported <code> Distributor </code> 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getDistributorRecordTypes();


    /**
     *  Tests if the given <code> Distributor </code> record type is 
     *  supported. 
     *
     *  @param  distributorRecordType a <code> Type </code> indicating a 
     *          <code> Distributor </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> distributorRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDistributorRecordType(org.osid.type.Type distributorRecordType);


    /**
     *  Gets the supported <code> Distributor </code> search record types. 
     *
     *  @return a list containing the supported <code> Distributor </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getDistributorSearchRecordTypes();


    /**
     *  Tests if the given <code> Distributor </code> search record type is 
     *  supported. 
     *
     *  @param  distributorSearchRecordType a <code> Type </code> indicating a 
     *          <code> Distributor </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          distributorSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDistributorSearchRecordType(org.osid.type.Type distributorSearchRecordType);
}
