//
// org.osid.provisioning.ProvisioningProxyManager
//
//     The OSID Java specification for org.osid.provisioning.ProvisioningProxyManager.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning;


/**
 *  <p>The provisioning proxy manager provides access to provisioning sessions 
 *  and provides interoperability tests for various aspects of this service. 
 *  Methods in this manager pass a <code> Proxy </code> for passing 
 *  information from server environments. The sessions included in this 
 *  manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> MyProvisionSession: </code> a session for looking up queue 
 *      information for authenticated agent </li> 
 *      <li> <code> MySupplierSession: </code> a session for looking up pool 
 *      information for authenticated agent </li> 
 *      <li> <code> MyProvisionNotificationSession: </code> a session for 
 *      subscribing to provision changes for authenticated agent </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> ProvisionLookupSession: </code> a session to retrieve 
 *      provisions </li> 
 *      <li> <code> ProvisionQuerySession: </code> a session to query for 
 *      provisionss </li> 
 *      <li> <code> ProvisionSearchSession: </code> a session to search for 
 *      provisions </li> 
 *      <li> <code> ProvisionAdminSession: </code> a session to create and 
 *      delete provisions </li> 
 *      <li> <code> ProvisionNotificationSession: </code> a session to receive 
 *      notifications pertaining to provision changes </li> 
 *      <li> <code> ProvisionDistributorSession: </code> a session to look up 
 *      provision distributor mappings </li> 
 *      <li> <code> ProvisionDistributorAssignmentSession: </code> a session 
 *      to manage provision to distributor mappings </li> 
 *      <li> <code> ProvisionSmartDistributorSession: </code> a session to 
 *      manage dynamic distributors of provisions </li> 
 *      <li> <code> ProvisionReturnSession: </code> a session to return 
 *      provisions </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> QueueLookupSession: </code> a session to retrieve queues 
 *      </li> 
 *      <li> <code> QueueQuerySession: </code> a session to query for queues 
 *      </li> 
 *      <li> <code> QueueSearchSession: </code> a session to search for queues 
 *      </li> 
 *      <li> <code> QueueAdminSession: </code> a session to create and delete 
 *      queues </li> 
 *      <li> <code> QueueNotificationSession: </code> a session to receive 
 *      notifications pertaining to queue changes </li> 
 *      <li> <code> QueueDistributorSession: </code> a session to look up 
 *      queue distributor mappings </li> 
 *      <li> <code> QueueDistributorAssignmentSession: </code> a session to 
 *      manage queue to distributor mappings </li> 
 *      <li> <code> QueueSmartDistributorSession: </code> a session to manage 
 *      dynamic distributors of queues </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> RequestLookupSession: </code> a session to retrieve 
 *      requests </li> 
 *      <li> <code> RequestQuerySession: </code> a session to query for 
 *      requests </li> 
 *      <li> <code> RequestSearchSession: </code> a session to search for 
 *      requests </li> 
 *      <li> <code> RequestAdminSession: </code> a session to create and 
 *      delete requests </li> 
 *      <li> <code> RequestNotificationSession: </code> a session to receive 
 *      notifications pertaining to request changes </li> 
 *      <li> <code> RequestDistributorSession: </code> a session to look up 
 *      request distributor mappings </li> 
 *      <li> <code> RequestDistributorAssignmentSession: </code> a session to 
 *      manage request to distributor mappings </li> 
 *      <li> <code> RequestSmartDistributorSession: </code> a session to 
 *      manage dynamic distributors of requests </li> 
 *      <li> <code> RequestTransactionLookupSession: </code> a session to 
 *      retrieve request transactions </li> 
 *      <li> <code> RequestTransactionAdminSession: </code> a session to 
 *      create and delete request transactions </li> 
 *      <li> <code> ExchangeSession: </code> a session to exchange provisions 
 *      </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> PoolLookupSession: </code> a session to retrieve pools 
 *      </li> 
 *      <li> <code> PoolQuerySession: </code> a session to query for pools 
 *      </li> 
 *      <li> <code> PoolSearchSession: </code> a session to search for pools 
 *      </li> 
 *      <li> <code> PoolAdminSession: </code> a session to create and delete 
 *      pools </li> 
 *      <li> <code> PoolNotificationSession: </code> a session to receive 
 *      notifications pertaining to pool changes </li> 
 *      <li> <code> PoolDistributorSession: </code> a session to look up pool 
 *      distributor mappings </li> 
 *      <li> <code> PoolDistributorAssignmentSession: </code> a session to 
 *      manage pools to distributor mappings </li> 
 *      <li> <code> PoolSmartDistributorSession: </code> a session to manage 
 *      dynamic distributors of pools </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> ProvisionableLookupSession: </code> a session to retrieve 
 *      provisionables </li> 
 *      <li> <code> ProvisionableQuerySession: </code> a session to query for 
 *      provisionables </li> 
 *      <li> <code> ProvisionableSearchSession: </code> a session to search 
 *      for provisionables </li> 
 *      <li> <code> ProvisionableAdminSession: </code> a session to create and 
 *      delete provisionables </li> 
 *      <li> <code> ProvisionableNotificationSession: </code> a session to 
 *      receive notifications pertaining to provisionable changes </li> 
 *      <li> <code> ProvisionableDistributorsSession: </code> a session to 
 *      look up provisionable distributors mappings </li> 
 *      <li> <code> ProvisionableDistributorAssignmentSession: </code> a 
 *      session to manage provisionable to distributor mappings </li> 
 *      <li> <code> ProvisionableSmartDistributorSession: </code> a session to 
 *      manage dynamic distributors of provisionables </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> BrokerLookupSession: </code> a session to retrieve brokers 
 *      </li> 
 *      <li> <code> BrokerQuerySession: </code> a session to query for brokers 
 *      </li> 
 *      <li> <code> BrokerSearchSession: </code> a session to search for 
 *      brokers </li> 
 *      <li> <code> BrokerAdminSession: </code> a session to create and delete 
 *      brokers </li> 
 *      <li> <code> BrokerNotificationSession: </code> a session to receive 
 *      notifications pertaining to broker changes </li> 
 *      <li> <code> BrokerDistributorSession: </code> a session to look up 
 *      mappings of brokers to distributors </li> 
 *      <li> <code> BrokerDistributorAssignmentSession: </code> a session to 
 *      manage broker to distributor mappings </li> 
 *      <li> <code> BrokerSmartDistributorSession: </code> a session to manage 
 *      dynamic distributors of brokers </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> DistributorLookupSession: </code> a session to retrieve 
 *      distributors </li> 
 *      <li> <code> DistributorQuerySession: </code> a session to search for 
 *      distributors </li> 
 *      <li> <code> DistributorSearchSession: </code> a session to search for 
 *      distributors </li> 
 *      <li> <code> DistributorAdminSession: </code> a session to create and 
 *      delete distributors </li> 
 *      <li> <code> DistributorNotificationSession: </code> a session to 
 *      receive notifications pertaining to distributor changes </li> 
 *      <li> <code> DistributorHierarchySession: </code> a session to traverse 
 *      a hierarchy of distributor </li> 
 *      <li> <code> DistributorHierarchyDesignSession: </code> a session to 
 *      manage a distributor hierarchy </li> 
 *  </ul>
 *  
 */

public interface ProvisioningProxyManager
    extends org.osid.OsidProxyManager,
            org.osid.provisioning.ProvisioningProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the my provision 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> MyProvisionSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsMyProvision() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMyProvision() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.MyProvisionSession getMyProvisionSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the my provision 
     *  service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> MyProvisionSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsMyProvision() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMyProvision() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.provisioning.MyProvisionSession getMyProvisionSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the my supplier 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> MySupplierSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsMySupplier() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMySupplier() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.MySupplierSession getMySupplierSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the my Supplier 
     *  service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> MySupplierSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsMySupplier() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMySupplier() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.provisioning.MySupplierSession getMySupplierSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the my provision 
     *  notification service for resources related to the authenticated agent. 
     *
     *  @param  provisionReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> MyProvisionNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> provisionReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsMyProvisionNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMyProvisionNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.MyProvisionNotificationSession getMyProvisionNotificationSession(org.osid.provisioning.ProvisionReceiver provisionReceiver, 
                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the my provision 
     *  notification service for the given distributor for resources related 
     *  to the authenticated agent. 
     *
     *  @param  provisionReceiver the notification callback 
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> MyProvisionNotificationSession </code> 
     *  @throws org.osid.NotFoundException no distributor found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> provisionReceiver, 
     *          distributorId </code> or <code> proxy </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsMyProvisionNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMyProvisionNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.provisioning.MyProvisionNotificationSession getMyProvisionNotificationSessionForDistributor(org.osid.provisioning.ProvisionReceiver provisionReceiver, 
                                                                                                                org.osid.id.Id distributorId, 
                                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the provision 
     *  lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ProvisionLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProvisionLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProvisionLookup() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.ProvisionLookupSession getProvisionLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the provision 
     *  lookup service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ProvisionLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProvisionLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProvisionLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.provisioning.ProvisionLookupSession getProvisionLookupSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the provision 
     *  query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ProvisionQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProvisionQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProvisionQuery() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.ProvisionQuerySession getProvisionQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the provision 
     *  query service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ProvisionQuerySession </code> 
     *  @throws org.osid.NotFoundException no distributor found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProvisionQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProvisionQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.provisioning.ProvisionQuerySession getProvisionQuerySessionForDistributor(org.osid.id.Id distributorId, 
                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the provision 
     *  search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ProvisionSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProvisionSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProvisionSearch() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.ProvisionSearchSession getProvisionSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the provision 
     *  search service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ProvisionSearchSession </code> 
     *  @throws org.osid.NotFoundException no distributor found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProvisionSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProvisionSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.provisioning.ProvisionSearchSession getProvisionSearchSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the provision 
     *  administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ProvisionAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProvisionAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProvisionAdmin() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.ProvisionAdminSession getProvisionAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the provision 
     *  administration service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the distributor 
     *  @param  proxy a proxy 
     *  @return a <code> ProvisionAdminSession </code> 
     *  @throws org.osid.NotFoundException no distributor found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProvisionAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProvisionAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.provisioning.ProvisionAdminSession getProvisionAdminSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the provision 
     *  notification service. 
     *
     *  @param  provisionReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> ProvisionNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> provisionReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProvisionNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProvisionNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.ProvisionNotificationSession getProvisionNotificationSession(org.osid.provisioning.ProvisionReceiver provisionReceiver, 
                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the provision 
     *  notification service for the given distributor. 
     *
     *  @param  provisionReceiver the notification callback 
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ProvisionNotificationSession </code> 
     *  @throws org.osid.NotFoundException no distributor found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> provisionReceiver, 
     *          distributorId </code> or <code> proxy </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProvisionNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProvisionNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.provisioning.ProvisionNotificationSession getProvisionNotificationSessionForDistributor(org.osid.provisioning.ProvisionReceiver provisionReceiver, 
                                                                                                            org.osid.id.Id distributorId, 
                                                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup provision/distributor 
     *  mappings. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ProvisionDistributorSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProvisionDistributor() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProvisionDistributor() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.ProvisionDistributorSession getProvisionDistributorSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning 
     *  provisions to distributors. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ProvisionDistributorAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProvisionDistributorAssignment() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProvisionDistributorAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.ProvisionDistributorAssignmentSession getProvisionDistributorAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage provision smart 
     *  distributors. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ProvisionSmartDistributorSession </code> 
     *  @throws org.osid.NotFoundException no distributor found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProvisionSmartDistributor() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProvisionSmartDistributor() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.ProvisionDistributorSession getProvisionSmartDistributorSession(org.osid.id.Id distributorId, 
                                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the provision 
     *  return service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ProvisionReturnSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProvisionReturn() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProvisionReturn() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.ProvisionReturnSession getProvisionReturnSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the provision 
     *  return service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the distributor 
     *  @param  proxy a proxy 
     *  @return a <code> ProvisionReturnSession </code> 
     *  @throws org.osid.NotFoundException no distributor found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> or 
     *          <code> proxy </code> s <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProvisionReturn() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProvisionReturn() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.provisioning.ProvisionReturnSession getProvisionReturnSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue lookup 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> QueueLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsQueueLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueLookup() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.QueueLookupSession getQueueLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue lookup 
     *  service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> QueueLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsQueueLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.provisioning.QueueLookupSession getQueueLookupSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue query 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> QueueQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsQueueQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueQuery() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.QueueQuerySession getQueueQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue query 
     *  service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> QueueQuerySession </code> 
     *  @throws org.osid.NotFoundException no distributor found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsQueueQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.provisioning.QueueQuerySession getQueueQuerySessionForDistributor(org.osid.id.Id distributorId, 
                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue search 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> QueueSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsQueueSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueSearch() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.QueueSearchSession getQueueSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue search 
     *  service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> QueueSearchSession </code> 
     *  @throws org.osid.NotFoundException no distributor found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsQueueSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.provisioning.QueueSearchSession getQueueSearchSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> QueueAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsQueueAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueAdmin() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.QueueAdminSession getQueueAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  administration service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the distributor 
     *  @param  proxy a proxy 
     *  @return a <code> QueueAdminSession </code> 
     *  @throws org.osid.NotFoundException no distributor found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsQueueAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.provisioning.QueueAdminSession getQueueAdminSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  notification service. 
     *
     *  @param  queueReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> QueueNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> queueReceiver </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.QueueNotificationSession getQueueNotificationSession(org.osid.provisioning.QueueReceiver queueReceiver, 
                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the queue 
     *  notification service for the given distributor. 
     *
     *  @param  queueReceiver the notification callback 
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> QueueNotificationSession </code> 
     *  @throws org.osid.NotFoundException no distributor found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> queueReceiver, 
     *          distributorId </code> or <code> proxy </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.provisioning.QueueNotificationSession getQueueNotificationSessionForDistributor(org.osid.provisioning.QueueReceiver queueReceiver, 
                                                                                                    org.osid.id.Id distributorId, 
                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup queue/distributor 
     *  mappings. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> QueueDistributorSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueDistributor() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueDistributor() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.QueueDistributorSession getQueueDistributorSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning queues 
     *  to distributors. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> QueueDistributorAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueDistributorAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueDistributorAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.QueueDistributorAssignmentSession getQueueDistributorAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage queue smart 
     *  distributors. 
     *
     *  @param  distributorId the <code> Id </code> of the distributor 
     *  @param  proxy a proxy 
     *  @return a <code> QueueSmartDistributorSession </code> 
     *  @throws org.osid.NotFoundException no distributor found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQueueSmartDistributor() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueSmartDistributor() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.QueueSmartDistributorSession getQueueSmartDistributorSession(org.osid.id.Id distributorId, 
                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the request lookup 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RequestLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRequestLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRequestLookup() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.RequestLookupSession getRequestLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the request lookup 
     *  service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RequestLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRequestLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRequestLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.provisioning.RequestLookupSession getRequestLookupSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the request query 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RequestQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRequestQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRequestQuery() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.RequestQuerySession getRequestQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the request query 
     *  service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RequestQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRequestQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRequestQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.provisioning.RequestQuerySession getRequestQuerySessionForDistributor(org.osid.id.Id distributorId, 
                                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the request search 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RequestSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRequestSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRequestSearch() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.RequestSearchSession getRequestSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the request search 
     *  service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RequestSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRequestSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRequestSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.provisioning.RequestSearchSession getRequestSearchSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the request 
     *  administrative service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RequestAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRequestAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRequestAdmin() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.RequestAdminSession getRequestAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the request 
     *  administrative service for the given queue. 
     *
     *  @param  queueId the <code> Id </code> of the <code> Queue </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RequestAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Queue </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> queueId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRequestAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRequestAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.provisioning.RequestAdminSession getRequestAdminSessionForQueue(org.osid.id.Id queueId, 
                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the request 
     *  notification service. 
     *
     *  @param  requestReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> RequestNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> requestReceiver </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRequestNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRequestNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.RequestNotificationSession getRequestNotificationSession(org.osid.provisioning.RequestReceiver requestReceiver, 
                                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the request 
     *  notification service for the given distributor. 
     *
     *  @param  requestReceiver the notification callback 
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RequestNotificationSession </code> 
     *  @throws org.osid.NotFoundException no distributor found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> requestReceiver, 
     *          distributorId </code> or <code> proxy </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRequestNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRequestNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.RequestNotificationSession getRequestNotificationSessionForDistributor(org.osid.provisioning.RequestReceiver requestReceiver, 
                                                                                                        org.osid.id.Id distributorId, 
                                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup request/distributor 
     *  mappings. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RequestDistributorSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRequestDistributor() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRequestyDistributor() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.RequestDistributorSession getRequestDistributorSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning queues 
     *  to distributors. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RequestyDistributorAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRequestDistributorAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRequestDistributorAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.RequestDistributorAssignmentSession getRequestDistributorAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage request smart 
     *  distributors. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RequestSmartDistributorSession </code> 
     *  @throws org.osid.NotFoundException no distributor found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRequestSmartDistributor() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRequestSmartDistributor() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.RequestSmartDistributorSession getRequestSmartDistributorSession(org.osid.id.Id distributorId, 
                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the request 
     *  transaction lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RequestTransactionLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRequestTransactionLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRequestTransactionLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.RequestTransactionLookupSession getRequestTransactionLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the request 
     *  transaction lookup service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RequestTransactionLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRequestTransactionLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRequestTransactionLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.provisioning.RequestTransactionLookupSession getRequestTransactionLookupSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the request 
     *  transaction administrative service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RequestTransactionAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRequestTransactionAdmin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRequestTransactionAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.RequestTransactionAdminSession getRequestTransactionAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the request 
     *  transaction administrative service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the distributor 
     *  @param  proxy a proxy 
     *  @return a <code> RequestTransactionAdminSession </code> 
     *  @throws org.osid.NotFoundException no distributor found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRequestTransactionAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRequestTransactionAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.provisioning.RequestTransactionAdminSession getRequestTransactionAdminSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the exchange 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> ExchangeSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsExchange() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsExchange() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.ExchangeSession getExchangeSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the exchange 
     *  service for the given queue. 
     *
     *  @param  queueId the <code> Id </code> of the <code> Queue </code> 
     *  @param  proxy a proxy 
     *  @return an <code> ExchangeSession </code> 
     *  @throws org.osid.NotFoundException no <code> Queue </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> queueId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsExchange() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsExchange() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.provisioning.ExchangeSession getExchangeSessionForQueue(org.osid.id.Id queueId, 
                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool lookup 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PoolLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsPoolLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolLookup() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.PoolLookupSession getPoolLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool lookup 
     *  service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PoolLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsPoolLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.PoolLookupSession getPoolLookupSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool query 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PoolQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsPoolQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolQuery() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.PoolQuerySession getPoolQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool query 
     *  service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PoolQuerySession </code> 
     *  @throws org.osid.NotFoundException no distributor found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsPoolQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.PoolQuerySession getPoolQuerySessionForDistributor(org.osid.id.Id distributorId, 
                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool search 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PoolSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsPoolSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolSearch() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.PoolSearchSession getPoolSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool search 
     *  service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PoolSearchSession </code> 
     *  @throws org.osid.NotFoundException no distributor found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsPoolSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.provisioning.PoolSearchSession getPoolSearchSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool 
     *  administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PoolAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsPoolAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolAdmin() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.PoolAdminSession getPoolAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool 
     *  administration service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the distributor 
     *  @param  proxy a proxy 
     *  @return a <code> PoolAdminSession </code> 
     *  @throws org.osid.NotFoundException no distributor found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsPoolAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.provisioning.PoolAdminSession getPoolAdminSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool 
     *  notification service. 
     *
     *  @param  poolReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> PoolNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> poolReceiver </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolNotification() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.PoolNotificationSession getPoolNotificationSession(org.osid.provisioning.PoolReceiver poolReceiver, 
                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the pool 
     *  notification service for the given distributor. 
     *
     *  @param  poolReceiver the notification callback 
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PoolNotificationSession </code> 
     *  @throws org.osid.NotFoundException no distributor found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> poolReceiver, 
     *          distributorId </code> or <code> proxy </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.PoolNotificationSession getPoolNotificationSessionForDistributor(org.osid.provisioning.PoolReceiver poolReceiver, 
                                                                                                  org.osid.id.Id distributorId, 
                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup pool/distributor 
     *  mappings. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PoolDistributorSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolDistributor() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolDistributor() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.PoolDistributorSession getPoolDistributorSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning pools to 
     *  distributors. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PoolDistributorAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolDistributorAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolDistributorAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.PoolDistributorAssignmentSession getPoolDistributorAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage pool smart distributors. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PoolSmartDistributorSession </code> 
     *  @throws org.osid.NotFoundException no distributor found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPoolSmartDistributor() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPoolSmartDistributor() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.PoolDistributorSession getPoolSmartDistributorSession(org.osid.id.Id distributorId, 
                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the provisionable 
     *  lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ProvisionableLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProvisionableLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProvisionableLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.RequestLookupSession getProvisionableLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the provisionable 
     *  lookup service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the distributor 
     *  @param  proxy a proxy 
     *  @return a <code> ProvisionableLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProvisionableLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProvisionableLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.RequestLookupSession getProvisionableLookupSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the provisionable 
     *  query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ProvisionableQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProvisionableQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProvisionableQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.RequestQuerySession getProvisionableQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the provisionable 
     *  query service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ProvisionableQuerySession </code> 
     *  @throws org.osid.NotFoundException no distributor found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProvisionableQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProvisionableQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.RequestQuerySession getProvisionableQuerySessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the provisionable 
     *  search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ProvisionableSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProvisionableSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProvisionableSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.RequestSearchSession getProvisionableSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the provisionable 
     *  search service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ProvisionableSearchSession </code> 
     *  @throws org.osid.NotFoundException no distributor found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProvisionableSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProvisionableSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.RequestSearchSession getProvisionableSearchSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the provisionable 
     *  administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ProvisionableAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProvisionableAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProvisionableAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.RequestAdminSession getProvisionableAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the provisionable 
     *  administration service for the given pool. 
     *
     *  @param  poolId the <code> Id </code> of the <code> Pool </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ProvisionableAdminSession </code> 
     *  @throws org.osid.NotFoundException no pool found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> poolId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProvisionableAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProvisionableAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.RequestAdminSession getProvisionableAdminSessionForPool(org.osid.id.Id poolId, 
                                                                                         org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the provisionable 
     *  notification service. 
     *
     *  @param  provisionableReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> ProvisionableNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> provisionableReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProvisionableNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProvisionableNotification() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.RequestNotificationSession getProvisionableNotificationSession(org.osid.provisioning.RequestReceiver provisionableReceiver, 
                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the provisionable 
     *  notification service for the given distributor. 
     *
     *  @param  provisionableReceiver the notification callback 
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ProvisionableNotificationSession </code> 
     *  @throws org.osid.NotFoundException no distributor found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> provisionableReceiver, 
     *          </code> <code> distributorId </code> or <code> proxy </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProvisionableNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProvisionableNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.RequestNotificationSession getProvisionableNotificationSessionForDistributor(org.osid.provisioning.RequestReceiver provisionableReceiver, 
                                                                                                              org.osid.id.Id distributorId, 
                                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup 
     *  provisionable/distributor mappings. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ProvisionableDistributorSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProvisionableDistributor() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProvisionableDistributor() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.RequestDistributorSession getProvisionableDistributorSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning 
     *  provisionables to distributors. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ProvisionableDistributorAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProvisionableDistributorAssignment() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProvisionableDistributorAssignment() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.provisioning.RequestDistributorAssignmentSession getProvisionableDistributorAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage locatin smart 
     *  distributors. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ProvisionableSmartDistributorSession </code> 
     *  @throws org.osid.NotFoundException no distributor found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProvisionableSmartDistributor() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProvisionableSmartDistributor() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.RequestSmartDistributorSession getProvisionableSmartDistributorSession(org.osid.id.Id distributorId, 
                                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker lookup 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BrokerLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBrokerLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerLookup() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.BrokerLookupSession getBrokerLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker lookup 
     *  service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BrokerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Distributor </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBrokerLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.provisioning.BrokerLookupSession getBrokerLookupSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker query 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BrokerQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBrokerQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerQuery() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.BrokerQuerySession getBrokerQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker query 
     *  service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BrokerQuerySession </code> 
     *  @throws org.osid.NotFoundException no distributor found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBrokerQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.provisioning.BrokerQuerySession getBrokerQuerySessionForDistributor(org.osid.id.Id distributorId, 
                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker search 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BrokerSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBrokerSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerSearch() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.BrokerSearchSession getBrokerSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker search 
     *  service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BrokerSearchSession </code> 
     *  @throws org.osid.NotFoundException no distributor found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBrokerSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.provisioning.BrokerSearchSession getBrokerSearchSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BrokerAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBrokerAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerAdmin() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.BrokerAdminSession getBrokerAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  administration service for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BrokerAdminSession </code> 
     *  @throws org.osid.NotFoundException no distributor found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBrokerAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.provisioning.BrokerAdminSession getBrokerAdminSessionForDistributor(org.osid.id.Id distributorId, 
                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  notification service. 
     *
     *  @param  brokerReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> BrokerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> brokerReceiver </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.BrokerNotificationSession getBrokerNotificationSession(org.osid.provisioning.BrokerReceiver brokerReceiver, 
                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the broker 
     *  notification service for the given distributor. 
     *
     *  @param  brokerReceiver the notification callback 
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BrokerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no distributor found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> brokerReceiver, 
     *          distributorId </code> or <code> proxy </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.provisioning.BrokerNotificationSession getBrokerNotificationSessionForDistributor(org.osid.provisioning.BrokerReceiver brokerReceiver, 
                                                                                                      org.osid.id.Id distributorId, 
                                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup broker/distributor 
     *  mappings. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BrokerDistributorSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerDistributor() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerDistributor() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.BrokerDistributorSession getBrokerDistributorSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning brokers 
     *  to distributors. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BrokerDistributorAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerDistributorAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerDistributorAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.BrokerDistributorAssignmentSession getBrokerDistributorAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage broker smart 
     *  distributors. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BrokerSmartDistributorSession </code> 
     *  @throws org.osid.NotFoundException no distributor found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBrokerSmartDistributor() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerSmartDistributor() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.BrokerSmartDistributorSession getBrokerSmartDistributorSession(org.osid.id.Id distributorId, 
                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the distributor 
     *  lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> DistributorLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDistributorLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDistributorLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.DistributorLookupSession getDistributorLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the distributor 
     *  query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> DistributorQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDistributorQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDistributorQuery() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.DistributorQuerySession getDistributorQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the distributor 
     *  search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> DistributorSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDistributorSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDistributorSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.DistributorSearchSession getDistributorSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the distributor 
     *  administrative service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> DistributorAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDistributorAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDistributorAdmin() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.DistributorAdminSession getDistributorAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the distributor 
     *  notification service. 
     *
     *  @param  distributorReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> DistributorNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> distributorReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDistributorNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDistributorNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.DistributorNotificationSession getDistributorNotificationSession(org.osid.provisioning.DistributorReceiver distributorReceiver, 
                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the distributor 
     *  hierarchy service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> DistributorHierarchySession </code> for distributors 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDistributorHierarchy() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDistributorHierarchy() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.DistributorHierarchySession getDistributorHierarchySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the distributor 
     *  hierarchy design service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> HierarchyDesignSession </code> for distributors 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDistributorHierarchyDesign() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDistributorHierarchyDesign() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.DistributorHierarchyDesignSession getDistributorHierarchyDesignSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> ProvisioningBatchProxyManager. </code> 
     *
     *  @return a <code> ProvisioningBatchProxyManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProvisioningBatch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProvisioningBatch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.batch.ProvisioningBatchProxyManager getProvisioningBatchProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> ProvisioningRulesPorxyManager. </code> 
     *
     *  @return a <code> ProvisioningRulesProxyManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProvisioningRules() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProvisioningRules() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.rules.ProvisioningRulesProxyManager getProvisioningRulesProxyManager()
        throws org.osid.OperationFailedException;
}
