//
// org.osid.provisioning.Request
//
//     The OSID Java specification for org.osid.provisioning.Request.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning;


/**
 *  <p>A <code> Request </code> is an entry in a <code> Queue. </code> It is a 
 *  relationship berween a <code> Queue </code> and a <code> Resource </code> 
 *  qualified by a <code> Pool. </code> A request is inactive if the queue is 
 *  disabled. </p>
 */

public interface Request
    extends org.osid.OsidRelationship {


    /**
     *  Gets the <code> Id </code> of the transaction in which this request is 
     *  a part. Requests can be made individually or as part of a transaction 
     *  group to provide an atomic compound request. 
     *
     *  @return the request transaction <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getRequestTransactionId();


    /**
     *  Gets the <code> Id </code> of the transaction in which this request is 
     *  a part. Requests can be made individually or as part of a transaction 
     *  group to provide an atomic compound request. 
     *
     *  @return the request transaction 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.RequestTransaction getRequestTransaction()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of the queue. 
     *
     *  @return the queue <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getQueueId();


    /**
     *  Gets the queue. 
     *
     *  @return the queue 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.Queue getQueue()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the date of the request. 
     *
     *  @return the request date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getRequestDate();


    /**
     *  Gets the <code> Id </code> of the queued resource. 
     *
     *  @return the resource <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getRequesterId();


    /**
     *  Gets the queued resource. 
     *
     *  @return the resource 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getRequester()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of the requesting agent. 
     *
     *  @return the agent <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getRequestingAgentId();


    /**
     *  Gets the requesting agent. 
     *
     *  @return the requesting agent 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.Agent getRequestingAgent()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this request is qualified by a pool. An unqualified request 
     *  may be allocated out of any pool in the broker. 
     *
     *  @return <code> true </code> if this request has a pool, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasPool();


    /**
     *  Gets the <code> Id </code> of the pool. 
     *
     *  @return the pool <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> hasPool() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPoolId();


    /**
     *  Gets the pool. 
     *
     *  @return the pool 
     *  @throws org.osid.IllegalStateException <code> hasPool() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.Pool getPool()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Ids </code> of the requested provisionables. 
     *
     *  @return the requested provisionable <code> Ids </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getRequestedProvisionableIds();


    /**
     *  Gets the requested provisionables. 
     *
     *  @return the requested provisionables 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionableList getRequestedProvisionables()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this request was created to exchange a provision. 
     *
     *  @return <code> true </code> if this request is an exchange request, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isExchange();


    /**
     *  Gets the <code> Id </code> of the provision to be exchanged if this 
     *  request is provisioned. 
     *
     *  @return the exchange provision <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> isExchange() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getExchangeProvisionId();


    /**
     *  Gets the provision to be exchanged if this request is provisioned. 
     *
     *  @return the exchange provision 
     *  @throws org.osid.IllegalStateException <code> isExchange() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.Provision getExchangeProvision()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this request was created as a result of another provision. 
     *
     *  @return <code> true </code> if this request is a provision result, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isProvisionResult();


    /**
     *  Gets the <code> Id </code> of the provision that resulted in this 
     *  request. 
     *
     *  @return the origin provision <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> isProvisionResult() 
     *          </code> is f <code> alse </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getOriginProvisionId();


    /**
     *  Gets the provision that resulted in this request. 
     *
     *  @return the origin provision 
     *  @throws org.osid.IllegalStateException <code> isProvisionResult() 
     *          </code> is f <code> alse </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.Provision getOriginProvision()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this request has a position in the queue. A position may be 
     *  indicate the rank of the request among waiting requests for the same 
     *  pool. 
     *
     *  @return true if this request has a position, false otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasPosition();


    /**
     *  Gets the position of this request in the queue. A position may be 
     *  indicate the rank of the request among waiting request for the same 
     *  pool. 
     *
     *  @return the position 
     *  @throws org.osid.IllegalStateException <code> hasPosition() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getPosition();


    /**
     *  Tests if there is an estimated waiting time for a provision out of the 
     *  pool. 
     *
     *  @return <code> true </code> if this request has an estimated time, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasEWA();


    /**
     *  Gets the estimated waiting time for a provision out of the pool. 
     *
     *  @return the estimated waiting time 
     *  @throws org.osid.IllegalStateException <code> hasEWA() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Duration getEWA();


    /**
     *  Gets the request record corresponding to the given <code> Request 
     *  </code> record <code> Type. </code> This method is used to retrieve an 
     *  object implementing the requested record. The <code> requestRecordType 
     *  </code> may be the <code> Type </code> returned in <code> 
     *  getRecordTypes() </code> or any of its parents in a <code> Type 
     *  </code> hierarchy where <code> hasRecordType(requestRecordType) 
     *  </code> is <code> true </code> . 
     *
     *  @param  requestRecordType the type of request record to retrieve 
     *  @return the request record 
     *  @throws org.osid.NullArgumentException <code> requestRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(requestRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.records.RequestRecord getRequestRecord(org.osid.type.Type requestRecordType)
        throws org.osid.OperationFailedException;
}
