//
// org.osid.provisioning.RequestSearchOrder
//
//     The OSID Java specification for org.osid.provisioning.RequestSearchOrder.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning;


/**
 *  <p>An interface for specifying the ordering of search results. </p>
 */

public interface RequestSearchOrder
    extends org.osid.OsidRelationshipSearchOrder {


    /**
     *  Orders the results by the request transaction. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByRequestTransaction(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a request transaction search order is available. 
     *
     *  @return <code> true </code> if a request transaction search order is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRequestTransactionSearchOrder();


    /**
     *  Gets the request transaction search order. 
     *
     *  @return the request transaction search order 
     *  @throws org.osid.IllegalStateException <code> 
     *          supportsRequestTransactionSearchOrder() </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.RequestTransactionSearchOrder getRequestTransactionSearchOrder();


    /**
     *  Orders the results by queue. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByQueue(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a queue search order is available. 
     *
     *  @return <code> true </code> if a queue search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueSearchOrder();


    /**
     *  Gets the queue search order. 
     *
     *  @return the queue search order 
     *  @throws org.osid.IllegalStateException <code> 
     *          supportsQueueSearchOrder() </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.QueueSearchOrder getQueueSearchOrder();


    /**
     *  Orders the results by request date. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByRequestDate(org.osid.SearchOrderStyle style);


    /**
     *  Orders the results by the requester. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByRequester(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a resource search order is available. 
     *
     *  @return <code> true </code> if a resource search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRequesterSearchOrder();


    /**
     *  Gets the resource search order. 
     *
     *  @return the resource search order 
     *  @throws org.osid.IllegalStateException <code> 
     *          supportsRequesterSearchOrder() </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceSearchOrder getRequesterSearchOrder();


    /**
     *  Orders the results by requesting agent. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByRequestingAgent(org.osid.SearchOrderStyle style);


    /**
     *  Tests if an agent search order is available. 
     *
     *  @return <code> true </code> if an agent search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRequestingAgentSearchOrder();


    /**
     *  Gets the resource search order. 
     *
     *  @return the agent search order 
     *  @throws org.osid.IllegalStateException <code> 
     *          supportsRequestingAgentSearchOrder() </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.AgentSearchOrder getRequestingAgentSearchOrder();


    /**
     *  Orders the results by pool. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByPool(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a pool search order is available. 
     *
     *  @return <code> true </code> if a pool search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolSearchOrder();


    /**
     *  Gets the pool search order. 
     *
     *  @return the pool search order 
     *  @throws org.osid.IllegalStateException <code> 
     *          supportsPoolSearchOrder() </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.PoolSearchOrder getPoolSearchOrder();


    /**
     *  Orders the results by exchange resource. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByExchangeProvision(org.osid.SearchOrderStyle style);


    /**
     *  Tests if an exchange provision search order is available. 
     *
     *  @return <code> true </code> if a provision search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsExchangeProvisionSearchOrder();


    /**
     *  Gets the exchange provision search order. 
     *
     *  @return the provision search order 
     *  @throws org.osid.IllegalStateException <code> 
     *          supportsExchangeProvisionSearchOrder() </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionSearchOrder getExchangeProvisionSearchOrder();


    /**
     *  Orders the results by origin provision. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByOriginProvision(org.osid.SearchOrderStyle style);


    /**
     *  Tests if an origin provision search order is available. 
     *
     *  @return <code> true </code> if a provision search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOriginProvisionSearchOrder();


    /**
     *  Gets the origin provision search order. 
     *
     *  @return the provision search order 
     *  @throws org.osid.IllegalStateException <code> 
     *          supportsOriginProvisionSearchOrder() </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionSearchOrder getOriginProvisionSearchOrder();


    /**
     *  Orders the results by position. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByPosition(org.osid.SearchOrderStyle style);


    /**
     *  Orders the results by the estimated waiting time. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByEWA(org.osid.SearchOrderStyle style);


    /**
     *  Gets the request search order record corresponding to the given 
     *  request record <code> Type. </code> Multiple retrievals return the 
     *  same underlying object. 
     *
     *  @param  requestRecordType a request record type 
     *  @return the request search order record 
     *  @throws org.osid.NullArgumentException <code> requestRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(requestRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.records.RequestSearchOrderRecord getRequestSearchOrderRecord(org.osid.type.Type requestRecordType)
        throws org.osid.OperationFailedException;
}
