//
// org.osid.provisioning.RequestTransaction
//
//     The OSID Java specification for org.osid.provisioning.RequestTransaction.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning;


/**
 *  <p>A <code> RequestTransaction </code> is set of <code> Requests. </code> 
 *  </p>
 */

public interface RequestTransaction
    extends org.osid.OsidRelationship {


    /**
     *  Gets the <code> Id </code> of the broker. 
     *
     *  @return the broker <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBrokerId();


    /**
     *  Gets the broker. 
     *
     *  @return the broker 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.Broker getBroker()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the date this transaction was submitted. The submitted date may 
     *  differ from the effective dates of this provision. 
     *
     *  @return the transaction submit date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getSubmitDate();


    /**
     *  Gets the <code> Id </code> of the submitter. 
     *
     *  @return the resource <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getSubmitterId();


    /**
     *  Gets the submitter. 
     *
     *  @return the resource 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getSubmitter()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of the submitting agent. 
     *
     *  @return the agent <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getSubmittingAgentId();


    /**
     *  Gets the submitting agent. 
     *
     *  @return the submitting agent 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.Agent getSubmittingAgent()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Ids </code> of the requests. 
     *
     *  @return the request <code> Ids </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getRequestIds()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the requests. 
     *
     *  @return the requests 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.RequestList getRequests()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the request transaction record corresponding to the given <code> 
     *  RequestTransaction </code> record <code> Type. </code> This method is 
     *  used to retrieve an object implementing the requested record. The 
     *  <code> requestTransactionRecordType </code> may be the <code> Type 
     *  </code> returned in <code> getRecordTypes() </code> or any of its 
     *  parents in a <code> Type </code> hierarchy where <code> 
     *  hasRecordType(requestTransactionRecordType) </code> is <code> true 
     *  </code> . 
     *
     *  @param  requestTransactionRecordType the type of request transaction 
     *          record to retrieve 
     *  @return the request transaction record 
     *  @throws org.osid.NullArgumentException <code> 
     *          requestTransactionRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(requestTransactionRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.records.RequestTransactionRecord getRequestTransactionRecord(org.osid.type.Type requestTransactionRecordType)
        throws org.osid.OperationFailedException;
}
