//
// org.osid.provisioning.RequestTransactionAdminSession
//
//     The OSID Java specification for org.osid.provisioning.RequestTransactionAdminSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning;


/**
 *  <p>This session creates, updates, and deletes <code> RequestTransactions. 
 *  </code> The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. Once a <code> Request </code> is created, it 
 *  has not been submitted. <code> submitRequestTransaction </code> submits a 
 *  <code> RequesTransactiont </code> for processing. Constraints on update 
 *  and delete may vary between creation and submission. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  RequestTransaction, </code> a <code> RequestTransactionForm </code> is 
 *  requested using <code> getRequestTransactionFormForCreate() </code> 
 *  specifying the desired record <code> Types </code> or none if no record 
 *  <code> Types </code> are needed. The returned <code> 
 *  RequestTransactionForm </code> will indicate that it is to be used with a 
 *  create operation and can be used to examine metdata or validate data prior 
 *  to creation. Once the <code> RequestTransactionForm </code> is submiited 
 *  to a create operation, it cannot be reused with another create operation 
 *  unless the first operation was unsuccessful. Each <code> 
 *  RequestTransactionForm </code> corresponds to an attempted transaction. 
 *  </p> 
 *  
 *  <p> For updates, <code> RequestTransactionForms </code> are requested to 
 *  the <code> RequestTransaction </code> <code> Id </code> that is to be 
 *  updated using <code> getRequestTransactionFormForUpdate(). </code> 
 *  Similarly, the <code> RequestTransactionForm </code> has metadata about 
 *  the data that can be updated and it can perform validation before 
 *  submitting the update. The <code> RequestTransactionForm </code> can only 
 *  be used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> RequestTransactions. </code> To 
 *  unmap a <code> RequestTransaction </code> from the current <code> 
 *  Distributor, </code> the <code> 
 *  RequestTransactionDistributorAssignmentSession </code> should be used. 
 *  These delete operations attempt to remove the <code> ReqeustTransaction 
 *  </code> itself thus removing it from all known <code> Distributor </code> 
 *  catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface RequestTransactionAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Distributor </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Distributor Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDistributorId();


    /**
     *  Gets the <code> Distributor </code> associated with this session. 
     *
     *  @return the distributor 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.Distributor getDistributor()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> RequestTransactions. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known creating a <code> Request </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer transaction 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> RequestTransaction </code> 
     *          creation is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateRequestTransactions();


    /**
     *  Tests if this user can create a single <code> RequestTransaction 
     *  </code> using the desired record types. While <code> 
     *  ProvisioningManager.getRequestTransactionRecordTypes() </code> can be 
     *  used to examine which records are supported, this method tests which 
     *  record(s) are required for creating a specific <code> 
     *  RequestTransaction. </code> Providing an empty array tests if a <code> 
     *  RequestTransaction </code> can be created with no records. 
     *
     *  @param  requestTransactionRecordTypes array of request transaction 
     *          record types 
     *  @return <code> true </code> if <code> RequestTransaction </code> 
     *          creation using the specified record <code> Types </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          requestTransactionRecordTypes </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateRequestTransactionsWithRecordTypes(org.osid.type.Type[] requestTransactionRecordTypes);


    /**
     *  Gets the request transaction form for creating new request 
     *  transactionss. A new form should be requested for each create 
     *  transaction. 
     *
     *  @param  brokerId a broker <code> Id </code> 
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  requestTransactionRecordTypes array of request transaction 
     *          record types 
     *  @return the request transaction form 
     *  @throws org.osid.NotFoundException <code> brokerId </code> or <code> 
     *          resourceId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> brokerId, resourceId, 
     *          </code> or <code> requestTransactionRecordTypes </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.RequestTransactionForm getRequestTransactionFormForCreate(org.osid.id.Id brokerId, 
                                                                                           org.osid.id.Id resourceId, 
                                                                                           org.osid.type.Type[] requestTransactionRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> RequestTransaction. </code> 
     *
     *  @param  requestTransactionForm the form for this <code> 
     *          RequestTransaction </code> 
     *  @return the new <code> RequestTransaction </code> 
     *  @throws org.osid.IllegalStateException <code> requestTransactionForm 
     *          </code> already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> requestTransactionForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> requestForm </code> did 
     *          not originate from <code> getRequestTransactionFormForCreate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.RequestTransaction createRequestTransaction(org.osid.provisioning.RequestTransactionForm requestTransactionForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> RequestTransactions. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known updating a <code> 
     *  RequestTransaction </code> will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer update operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> RequestTransaction </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateRequestTransactions();


    /**
     *  Gets the request transaction form for updating an existing request. A 
     *  new request transaction form should be requested for each update 
     *  transaction. 
     *
     *  @param  requestTransactionId the <code> Id </code> of the <code> 
     *          RequestTransaction </code> 
     *  @return the request transaction form 
     *  @throws org.osid.NotFoundException <code> requestTransactionId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> requestTransactionId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.RequestTransactionForm getRequestTransactionFormForUpdate(org.osid.id.Id requestTransactionId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing request transaction. 
     *
     *  @param  requestTransactionForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> requestTransactionForm 
     *          </code> already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> requestTransactionForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> requestForm </code> did 
     *          not originate from <code> getRequestTransactionFormForUpdate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateRequestTransaction(org.osid.provisioning.RequestTransactionForm requestTransactionForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Submits a <code> RequestTransaction </code> and the related requests. 
     *
     *  @param  requestTransactionId the <code> Id </code> of the request 
     *          transaction to submit 
     *  @throws org.osid.NotFoundException <code> requestTransactionId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> requestTransactionId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void submitRequestTransaction(org.osid.id.Id requestTransactionId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can cancel <code> RequestTransactions. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known canceling a <code> 
     *  RequestTransaction </code> will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer cancel operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> RequestTransaction </code> 
     *          cancelation is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCancelRequestTransactions();


    /**
     *  Cancels a <code> RequestTransaction </code> and the related requests. 
     *
     *  @param  requestTransactionId the <code> Id </code> of the request 
     *          transaction to cancel 
     *  @throws org.osid.NotFoundException <code> requestTransactionId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> requestTransactionId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void cancelRequestTransaction(org.osid.id.Id requestTransactionId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> RequestTransactions. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known deleting a <code> 
     *  RequestTransaction </code> will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer delete operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> RequestTransaction </code> 
     *          deletion is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteRequestTransactions();


    /**
     *  Deletes a <code> RequestTransaction </code> and the related requests. 
     *
     *  @param  requestTransactionId the <code> Id </code> of the request 
     *          transaction to delete 
     *  @throws org.osid.NotFoundException <code> requestTransactionId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> requestTransactionId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteRequestTransaction(org.osid.id.Id requestTransactionId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  RequestTransactionss. </code> A return of true does not guarantee 
     *  successful authorization. A return of false indicates that it is known 
     *  changing an alias will result in a <code> PERMISSION_DENIED. </code> 
     *  This is intended as a hint to an application that may opt not to offer 
     *  alias operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> RequestTransaction </code> 
     *          aliasing is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageRequestTransactionAliases();


    /**
     *  Adds an <code> Id </code> to a <code> RequestTransaction </code> for 
     *  the purpose of creating compatibility. The primary <code> Id </code> 
     *  of the <code> RequestTransaction </code> is determined by the 
     *  provider. The new <code> Id </code> performs as an alias to the 
     *  primary <code> Id. </code> If the alias is a pointer to another 
     *  request, it is reassigned to the given request <code> Id. </code> 
     *
     *  @param  requestTransactionId the <code> Id </code> of a <code> 
     *          RequestTransaction </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> requestTransactionId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> requestTransactionId 
     *          </code> or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasRequestTransaction(org.osid.id.Id requestTransactionId, 
                                        org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
