//
// org.osid.provisioning.batch.BrokerBatchAdminSession
//
//     The OSID Java specification for org.osid.provisioning.batch.BrokerBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Brokers </code> in 
 *  bulk. The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Broker, </code> a <code> BrokerForm </code> is requested using <code> 
 *  getBrokerFormsForCreate() </code> specifying the desiredrecord <code> 
 *  Types </code> or none if no record <code> Types </code> are needed. Each 
 *  of the returned <code> BrokerForms </code> will indicate that it is to be 
 *  used with a create operation and can be used to examine metdata or 
 *  validate data prior to creation. Once a <code> BrokerForm </code> is 
 *  submiited to a create operation, it cannot be reused with another create 
 *  operation unless the first operation was unsuccessful. Each <code> 
 *  BrokerForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> BrokerForms </code> returned from <code> 
 *  getBrokerFormsForCreate() </code> may be linked to the originating request 
 *  through the peer <code> Ids </code> of the <code> BrokerForm. </code> In 
 *  the case where there may be duplicates, any <code> BrokerForm </code> of 
 *  the same peer <code> Ids </code> may be used for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> BrokerForms </code> are submitted for create, a 
 *  <code> CreateResponse </code> is returned for each <code> BrokerForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire create operation are returned from <code> createBrokers(), 
 *  </code> errors specific to an individual <code> BrokerForm </code> are 
 *  indicated in the corresponding <code> CreateResponse. </code> <code> 
 *  CreateResponses </code> may be linked to the originating <code> BrokerForm 
 *  </code> through the <code> BrokerForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> BrokerForms </code> are requested to the <code> 
 *  Broker </code> <code> Id </code> that is to be updated using <code> 
 *  getBrokerFormsForUpdate() </code> where the reference <code> Id </code> in 
 *  the <code> BrokerForm </code> may be used to link the request. Similarly, 
 *  the <code> BrokerForm </code> has metadata about the data that can be 
 *  updated and it can perform validation before submitting the update. The 
 *  <code> BrokerForm </code> can only be used once for a successful update 
 *  and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> BrokerForms </code> are submitted for update, 
 *  an <code> UpdateResponse </code> is returned for each <code> BrokerForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire update operation are returned from <code> updateBrokers(), 
 *  </code> errors specific to an individual <code> BrokerForm </code> are 
 *  indicated in the corresponding <code> UpdateResponse. </code> <code> 
 *  UpdateResponses </code> may be linked to the originating <code> BrokerForm 
 *  </code> through the <code> BrokerForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> Brokers </code> in bulk. To unmap 
 *  a <code> Broker </code> from the current <code> Distributor, </code> the 
 *  <code> BrokerDistributorAssignmentSession </code> should be used. These 
 *  delete operations attempt to remove the <code> Broker </code> itself thus 
 *  removing it from all known <code> Distributor </code> catalogs. Bulk 
 *  delete operations return the results in <code> DeleteResponses. </code> 
 *  </p>
 */

public interface BrokerBatchAdminSession
    extends org.osid.provisioning.BrokerAdminSession {


    /**
     *  Gets the broker forms for creating a bunch of new brokers. 
     *
     *  @param  number the number of forms to retrieve 
     *  @param  brokerRecordTypes array of broker record types to be included 
     *          in each create operation or an empty list if none 
     *  @return the broker forms 
     *  @throws org.osid.NullArgumentException <code> brokerRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.batch.BrokerBatchFormList getBrokerFormsForCreate(long number, 
                                                                                   org.osid.type.Type[] brokerRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Brokers. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  brokerForms the broker forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> brokerForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createBrokers(org.osid.provisioning.batch.BrokerBatchFormList brokerForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the broker forms for updating an existing set of brokers. A new 
     *  broker form should be requested for each update transaction. 
     *
     *  @param  brokerIds the <code> Ids </code> of the <code> Broker </code> 
     *  @return the broker form 
     *  @throws org.osid.NotFoundException a <code> brokerId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> brokerIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.batch.BrokerBatchFormList getBrokerFormsForUpdate(org.osid.id.IdList brokerIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing brokers. This method returns an error if the entire 
     *  operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  brokerForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> brokerForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateBrokers(org.osid.provisioning.batch.BrokerBatchFormList brokerForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Brokers </code> in this <code> Distributor </code> 
     *  . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllBrokers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes brokers for the given <code> Ids. </code> 
     *
     *  @param  brokerIds the <code> Ids </code> of the brokers to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> brokerIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteBrokers(org.osid.id.IdList brokerIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Broker </code> for the purpose 
     *  of creating compatibility. The primary <code> Id </code> of the <code> 
     *  Broker </code> is determined by the provider. The new <code> Id 
     *  </code> is an alias to the primary <code> Id. </code> If the alias is 
     *  a pointer to another broker, it is reassigned to the given broker 
     *  <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasBrokers(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
