//
// org.osid.provisioning.batch.RequestTransactionBatchAdminSession
//
//     The OSID Java specification for org.osid.provisioning.batch.RequestTransactionBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning.batch;


/**
 *  <p>This session creates, updates, and deletes <code> RequestTransactions 
 *  </code> in bulk. The data for create and update is provided by the 
 *  consumer via the form object. <code> OsidForms </code> are requested for 
 *  each create or update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  RequestTransaction </code> a <code> RequestTransactionForm </code> is 
 *  requested using <code> getRequestTransactionFormsForCreate() </code> 
 *  specifying the desired broker, resource, record <code> Types </code> or 
 *  none if no record <code> Types </code> are needed. Each of the returned 
 *  <code> RequestTransactionForms </code> will indicate that it is to be used 
 *  with a create operation and can be used to examine metdata or validate 
 *  data prior to creation. Once a <code> RequestTransactionForm </code> is 
 *  submiited to a create operation, it cannot be reused with another create 
 *  operation unless the first operation was unsuccessful. Each <code> 
 *  RequestTransactionForm </code> corresponds to an attempted transaction. 
 *  </p> 
 *  
 *  <p> The <code> RequestTransactionForms </code> returned from <code> 
 *  getRequestTransactionFormsForCreate() </code> may be linked to the 
 *  originating request transaction through the peer <code> Ids </code> of the 
 *  <code> RequestTransactionForm. </code> In the case where there may be 
 *  duplicates, any <code> RequestTransactionForm </code> of the same peer 
 *  <code> Ids </code> may be used for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> RequestTransactionForms </code> are submitted 
 *  for create, a <code> CreateResponse </code> is returned for each <code> 
 *  RequestTransactionForm, </code> although the ordering is not defined. Only 
 *  errors that pertain to the entire create operation are returned from 
 *  <code> createRequestTransactions(), </code> errors specific to an 
 *  individual <code> RequestTransactionForm </code> are indicated in the 
 *  corresponding <code> CreateResponse. </code> <code> CreateResponses 
 *  </code> may be linked to the originating <code> RequestTransactionForm 
 *  </code> through the <code> RequestTransactionForm </code> <code> Id 
 *  </code> . </p> 
 *  
 *  <p> For updates, <code> RequestTransactionForms </code> are requested to 
 *  the <code> RequestTransaction </code> <code> Id </code> that is to be 
 *  updated using <code> getRequestTransactionFormsForUpdate() </code> where 
 *  the reference <code> Id </code> in the <code> RequestTransactionForm 
 *  </code> may be used to link the request transaction. Similarly, the <code> 
 *  RequestTransactionForm </code> has metadata about the data that can be 
 *  updated and it can perform validation before submitting the update. The 
 *  <code> RequestTransactionForm </code> can only be used once for a 
 *  successful update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> RequestTransactionForms </code> are submitted 
 *  for update, a <code> UpdateResponse </code> is returned for each <code> 
 *  RequestTransactionForm, </code> although the ordering is not defined. Only 
 *  errors that pertain to the entire update operation are returned from 
 *  <code> updateRequestTransactions(), </code> errors specific to an 
 *  individual <code> RequestTransactionForm </code> are indicated in the 
 *  corresponding <code> UpdateResponse. </code> <code> UpdateResponses 
 *  </code> may be linked to the originating <code> RequestTransactionForm 
 *  </code> through the <code> RequestTransactionForm </code> <code> Id. 
 *  </code> </p> 
 *  
 *  <p> The delete operations delete <code> RequestTransactions </code> in 
 *  bulk. To unmap a <code> RequestTransaction </code> from the current <code> 
 *  Distributor, </code> the <code> RequestDistributorAssignmentSession 
 *  </code> should be used. These delete operations attempt to remove the 
 *  <code> Request </code> itself thus removing it from all known <code> 
 *  Distributor </code> catalogs. Bulk delete operations return the results in 
 *  <code> DeleteResponses. </code> </p>
 */

public interface RequestTransactionBatchAdminSession
    extends org.osid.provisioning.RequestTransactionAdminSession {


    /**
     *  Gets the request transaction forms for creating a bunch of new 
     *  requests. A form is returned for each broker and resource pair. 
     *
     *  @param  peers the relationship peers 
     *  @param  requestRecordTypes array of request transaction record types 
     *          to be included in each create operation or an empty list if 
     *          none 
     *  @return the request transaction forms 
     *  @throws org.osid.NotFoundException a <code> brokerId </code> or <code> 
     *          resourceId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> peers </code> or <code> 
     *          requestRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request transaction 
     *          forms with given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.batch.RequestTransactionBatchFormList getRequestTransactionFormsForCreate(org.osid.provisioning.batch.RequestTransactionPeerList peers, 
                                                                                                           org.osid.type.Type[] requestRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> RequestTransactions. </code> This method 
     *  returns an error if the entire operation fails. Otherwise, the status 
     *  of an individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  requestTransactionForms the request transaction forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> requestTransactionForms 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createRequestTransactions(org.osid.provisioning.batch.RequestTransactionBatchFormList requestTransactionForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the request transaction forms for updating an existing set of 
     *  requests. A new request transaction form should be requested for each 
     *  update transaction. 
     *
     *  @param  requestTransactionIds the <code> Ids </code> of the <code> 
     *          Request </code> 
     *  @return the request transaction form 
     *  @throws org.osid.NotFoundException a <code> requestTransactionId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> requestTransactionIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.batch.RequestTransactionBatchFormList getRequestTransactionFormsForUpdate(org.osid.id.IdList requestTransactionIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing requests. This method returns an error if the entire 
     *  operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  requestTransactionForms the form containing the elements to be 
     *          updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> requestTransactionForms 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateRequestTransactions(org.osid.provisioning.batch.RequestTransactionBatchFormList requestTransactionForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> RequestTransactions </code> in this <code> 
     *  Distributor </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllRequestTransactions()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes requests for the given <code> Ids. </code> 
     *
     *  @param  requestTransactionIds the <code> Ids </code> of the requests 
     *          to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> requestTransactionIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteRequestTransactions(org.osid.id.IdList requestTransactionIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes requests for the given resource. 
     *
     *  @param  resourceId an <code> Id </code> of a resource 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteRequestTransactionsForResource(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes requests for the given broker. 
     *
     *  @param  brokerId an <code> Id </code> of a broker 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> brokerId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteRequestTransactionsForBroker(org.osid.id.Id brokerId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes requests expired before the given date. 
     *
     *  @param  date a date 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteIneffectiveRequestTransactionsByDate(org.osid.calendaring.DateTime date)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> RequestTransaction </code> for 
     *  the purpose of creating compatibility. The primary <code> Id </code> 
     *  of the <code> Request </code> is determined by the provider. The new 
     *  <code> Id </code> is an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another request transaction, it is reassigned to 
     *  the given request transaction <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasRequestTransactionss(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
