//
// org.osid.provisioning.rules.BrokerConstrainerAdminSession
//
//     The OSID Java specification for org.osid.provisioning.rules.BrokerConstrainerAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning.rules;


/**
 *  <p>This session creates and removes broker constrainers. The data for 
 *  create and update is provided via the <code> BrokerConstrainerForm. 
 *  </code> </p>
 */

public interface BrokerConstrainerAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Distributor </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Distributor Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDistributorId();


    /**
     *  Gets the <code> Distributor </code> associated with this session. 
     *
     *  @return the distributor 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.Distributor getDistributor()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create broker constrainers. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> BrokerConstrainer </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer create operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> BrokerConstrainer </code> 
     *          creation is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateBrokerConstrainer();


    /**
     *  Tests if this user can create a single <code> BrokerConstrainer 
     *  </code> using the desired record types. While <code> 
     *  ProvisioningRulesManager.getBrokerConstrainerRecordTypes() </code> can 
     *  be used to examine which records are supported, this method tests 
     *  which record(s) are required for creating a specific <code> 
     *  BrokerConstrainer. </code> Providing an empty array tests if a <code> 
     *  BrokerConstrainer </code> can be created with no records. 
     *
     *  @param  brokerConstrainerRecordTypes array of broker constrainer 
     *          record types 
     *  @return <code> true </code> if <code> BrokerConstrainer </code> 
     *          creation using the specified record <code> Types </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          brokerConstrainerRecordTypes </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateBrokerConstrainerWithRecordTypes(org.osid.type.Type[] brokerConstrainerRecordTypes);


    /**
     *  Gets the broker constrainer form for creating new broker constrainers. 
     *  A new form should be requested for each create transaction. 
     *
     *  @param  brokerConstrainerRecordTypes array of broker constrainer 
     *          record types 
     *  @return the broker constrainer form 
     *  @throws org.osid.NullArgumentException <code> 
     *          brokerConstrainerRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.BrokerConstrainerForm getBrokerConstrainerFormForCreate(org.osid.type.Type[] brokerConstrainerRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> BrokerConstrainer. </code> 
     *
     *  @param  brokerConstrainerForm the form for this <code> 
     *          BrokerConstrainer </code> 
     *  @return the new <code> BrokerConstrainer </code> 
     *  @throws org.osid.IllegalStateException <code> brokerConstrainerForm 
     *          </code> already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> brokerConstrainerForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> brokerConstrainerForm 
     *          </code> did not originate from <code> 
     *          getBrokerConstrainerFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.BrokerConstrainer createBrokerConstrainer(org.osid.provisioning.rules.BrokerConstrainerForm brokerConstrainerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update broker constrainers. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> BrokerConstrainer </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer update operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> BrokerConstrainer </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateBrokerConstrainers();


    /**
     *  Gets the broker constrainer form for updating an existing broker 
     *  constrainer. A new broker constrainer form should be requested for 
     *  each update transaction. 
     *
     *  @param  brokerConstrainerId the <code> Id </code> of the <code> 
     *          BrokerConstrainer </code> 
     *  @return the broker constrainer form 
     *  @throws org.osid.NotFoundException <code> brokerConstrainerId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> brokerConstrainerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.BrokerConstrainerForm getBrokerConstrainerFormForUpdate(org.osid.id.Id brokerConstrainerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing broker constrainer. 
     *
     *  @param  brokerConstrainerForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> brokerConstrainerForm 
     *          </code> already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> brokerConstrainerForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> brokerConstrainerForm 
     *          </code> did not originate from <code> 
     *          getBrokerConstrainerFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateBrokerConstrainer(org.osid.provisioning.rules.BrokerConstrainerForm brokerConstrainerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete broker constrainers. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> BrokerConstrainer </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer delete operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> BrokerConstrainer </code> 
     *          deletion is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteBrokerConstrainers();


    /**
     *  Deletes a <code> BrokerConstrainer. </code> 
     *
     *  @param  brokerConstrainerId the <code> Id </code> of the <code> 
     *          BrokerConstrainer </code> to remove 
     *  @throws org.osid.NotFoundException <code> brokerConstrainerId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> brokerConstrainerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteBrokerConstrainer(org.osid.id.Id brokerConstrainerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for broker 
     *  constrainers. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> BrokerConstrainer </code> 
     *          aliasing is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageBrokerConstrainerAliases();


    /**
     *  Adds an <code> Id </code> to a <code> BrokerConstrainer </code> for 
     *  the purpose of creating compatibility. The primary <code> Id </code> 
     *  of the <code> BrokerConstrainer </code> is determined by the provider. 
     *  The new <code> Id </code> performs as an alias to the primary <code> 
     *  Id </code> . If the alias is a pointer to another broker constrainer. 
     *  it is reassigned to the given broker constrainer <code> Id. </code> 
     *
     *  @param  brokerConstrainerId the <code> Id </code> of a <code> 
     *          BrokerConstrainer </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> brokerConstrainerId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> brokerConstrainerId 
     *          </code> or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasBrokerConstrainer(org.osid.id.Id brokerConstrainerId, 
                                       org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
