//
// org.osid.provisioning.rules.BrokerConstrainerEnablerRuleApplicationSession
//
//     The OSID Java specification for org.osid.provisioning.rules.BrokerConstrainerEnablerRuleApplicationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning.rules;


/**
 *  <p>This session provides methods to apply <code> BrokerConstrainerEnablers 
 *  </code> to <code> BrokerConstrainers. </code> A <code> BrokerConstrainer 
 *  </code> with multiple <code> BrokerConstrainerEnablers </code> means any 
 *  positive rule evaluation across the enablers result in an effective <code> 
 *  BrokerConstrainer. </code> </p>
 */

public interface BrokerConstrainerEnablerRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Distributor </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Distributor Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDistributorId();


    /**
     *  Gets the <code> Distributor </code> associated with this session. 
     *
     *  @return the distributor 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.Distributor getDistributor()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter broker constrainer enabler/broker 
     *  constrainer mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known mapping 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignBrokerConstrainerEnablers();


    /**
     *  Adds an existing <code> BrokerConstrainerEnabler </code> to a <code> 
     *  BrokerConstrainer. </code> 
     *
     *  @param  brokerConstrainerEnablerId the <code> Id </code> of the <code> 
     *          BrokerConstrainerEnabler </code> 
     *  @param  brokerConstrainerId the <code> Id </code> of the <code> 
     *          BrokerConstrainer </code> 
     *  @throws org.osid.AlreadyExistsException <code> 
     *          brokerConstrainerEnablerId </code> is already applied to 
     *          <code> brokerConstrainerId </code> 
     *  @throws org.osid.NotFoundException <code> brokerConstrainerEnablerId 
     *          </code> or <code> brokerConstrainerId </code> not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          brokerConstrainerEnablerId </code> or <code> 
     *          brokerConstrainerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignBrokerConstrainerEnablerToBrokerConstrainer(org.osid.id.Id brokerConstrainerEnablerId, 
                                                                  org.osid.id.Id brokerConstrainerId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> BrokerConstrainerEnabler </code> from a <code> 
     *  BrokerConstrainer. </code> 
     *
     *  @param  brokerConstrainerEnablerId the <code> Id </code> of the <code> 
     *          BrokerConstrainerEnabler </code> 
     *  @param  brokerConstrainerId the <code> Id </code> of the <code> 
     *          BrokerConstrainer </code> 
     *  @throws org.osid.NotFoundException <code> brokerConstrainerEnablerId 
     *          </code> or <code> brokerConstrainerId </code> not found or 
     *          <code> brokerConstrainerEnablerId </code> not applied to 
     *          <code> brokerConstrainerId </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          brokerConstrainerEnablerId </code> or <code> 
     *          brokerConstrainerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignBrokerConstrainerEnablerFromBrokerConstrainer(org.osid.id.Id brokerConstrainerEnablerId, 
                                                                      org.osid.id.Id brokerConstrainerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> BrokerConstrainerEnablers. </code> 
     *  A return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known sequencing operations will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> BrokerConstrainerEnabler 
     *          </code> ordering is not authorized, <code> true </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceBrokerConstrainerEnablers();


    /**
     *  Reorders broker constrainer enablers for a broker constrainer by 
     *  moving the specified broker constrainer enabler in front of a 
     *  reference broker constrainer. 
     *
     *  @param  brokerConstrainerEnablerId the <code> Id </code> of a <code> 
     *          BrokerConstrainerEnabler </code> 
     *  @param  brokerConstrainerId the <code> Id </code> of a <code> 
     *          BrokerConstrainer </code> 
     *  @param  referenceId the reference broker constrainer enabler <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> brokerConstrainerEnablerId, 
     *          brokerConstrainerId, </code> or <code> referenceId </code> not 
     *          found or, <code> brokerConstrainerEnablerId </code> or <code> 
     *          referenceId </code> not related to <code> brokerConstrainerId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          brokerConstrainerEnablerId, brokerConstrainerId, </code> or 
     *          <code> referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveBrokerConstrainerEnablerAhead(org.osid.id.Id brokerConstrainerEnablerId, 
                                                  org.osid.id.Id brokerConstrainerId, 
                                                  org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders broker constrainer enablers for a broker constrainer by 
     *  moving the specified broker constrainer enabler behind a reference 
     *  broker constrainer. 
     *
     *  @param  brokerConstrainerEnablerId the <code> Id </code> of a <code> 
     *          BrokerConstrainerEnabler </code> 
     *  @param  brokerConstrainerId the <code> Id </code> of a <code> 
     *          BrokerConstrainer </code> 
     *  @param  referenceId the reference broker constrainer enabler <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> brokerConstrainerEnablerId, 
     *          brokerConstrainerId, </code> or <code> referenceId </code> not 
     *          found or, <code> brokerConstrainerEnablerId </code> or <code> 
     *          referenceId </code> not related to <code> brokerConstrainerId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          brokerConstrainerEnablerId, brokerConstrainerId, </code> or 
     *          <code> referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveBrokerConstrainerEnablerBehind(org.osid.id.Id brokerConstrainerEnablerId, 
                                                   org.osid.id.Id brokerConstrainerId, 
                                                   org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of broker constrainer enablers for a broker 
     *  constrainer. 
     *
     *  @param  brokerConstrainerEnablerIds the <code> Ids </code> for a set 
     *          of <code> BrokerConstrainerEnablers </code> 
     *  @param  brokerConstrainerId the <code> Id </code> of a <code> 
     *          BrokerConstrainer </code> 
     *  @throws org.osid.NotFoundException <code> brokerConstrainerId </code> 
     *          not found or, a <code> brokerConstrainerEnablerId </code> not 
     *          related to <code> brokerConstrainerId </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          brokerConstrainerEnablerIds </code> or <code> 
     *          brokerConstrainerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderBrokerConstrainerEnablers(org.osid.id.Id[] brokerConstrainerEnablerIds, 
                                               org.osid.id.Id brokerConstrainerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
