//
// org.osid.provisioning.rules.BrokerConstrainerLookupSession
//
//     The OSID Java specification for org.osid.provisioning.rules.BrokerConstrainerLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning.rules;


/**
 *  <p>This session provides methods for retrieving <code> BrokerConstrainers. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated distributor view: All broker constrainer methods in this 
 *      session operate, retrieve and pertain to broker constrainer defined 
 *      explicitly in the current distributor. Using an isolated view is 
 *      useful for managing <code> BrokerConstrainers </code> with the <code> 
 *      BrokerConstrainerAdminSession. </code> </li> 
 *      <li> federated distributor view: All broker constrainer methods in 
 *      this session operate, retrieve and pertain to all broker constrainer 
 *      defined in this distributor and any other broker constrainer 
 *      implicitly available in this distributor through distributor 
 *      inheritence. </li> 
 *      <li> active broker constrainer view: All broker constrainer lookup 
 *      methods return active broker constrainers. </li> 
 *      <li> any status broker constrainer view: Broker constrainers of any 
 *      active and inactive status are returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedDistributorView() </code> and <code> 
 *  useIsolatedDistributorView() </code> behave as a radio group and one 
 *  should be selected before invoking the methods in this session. </p>
 */

public interface BrokerConstrainerLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Distributor </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Distributor Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDistributorId();


    /**
     *  Gets the <code> Distributor </code> associated with this session. 
     *
     *  @return the distributor 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.Distributor getDistributor()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> BrokerConstrainers </code> 
     *  lookups. A return of true does not guarantee successful authorization. 
     *  A return of false indicates that it is known all methods in this 
     *  session will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer lookup 
     *  operations to unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupBrokerConstrainers();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeBrokerConstrainerView();


    /**
     *  A complete view of the <code> BrokerConstrainer </code> returns is 
     *  desired. Methods will return what is requested or result in an error. 
     *  This view is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryBrokerConstrainerView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include broker constrainer in distributors which are children of this 
     *  distributor in the distributor hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedDistributorView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this distributor only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedDistributorView();


    /**
     *  Only active broker constrainers are returned by methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveBrokerConstrainerView();


    /**
     *  All active and inactive broker constrainers are returned by methods in 
     *  this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusBrokerConstrainerView();


    /**
     *  Gets the <code> BrokerConstrainer </code> specified by its <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  BrokerConstrainer </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> BrokerConstrainer </code> and retained for 
     *  compatibility. 
     *  
     *  In active mode, offset broker constrainers are returned that are 
     *  currently active. In any status mode, active and inactive offset 
     *  broker constrainers are returned. 
     *
     *  @param  brokerConstrainerId <code> Id </code> of the <code> 
     *          BrokerConstrainer </code> 
     *  @return the broker constrainer 
     *  @throws org.osid.NotFoundException <code> brokerConstrainerId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> brokerConstrainerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.provisioning.rules.BrokerConstrainer getBrokerConstrainer(org.osid.id.Id brokerConstrainerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BrokerConstrainerList </code> corresponding to the given 
     *  <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  broker constrainer specified in the <code> Id </code> list, in the 
     *  order of the list, including duplicates, or an error results if an 
     *  <code> Id </code> in the supplied list is not found or inaccessible. 
     *  Otherwise, inaccessible <code> BrokerConstrainers </code> may be 
     *  omitted from the list and may present the elements in any order 
     *  including returning a unique set. 
     *  
     *  In active mode, offset broker constrainers are returned that are 
     *  currently active. In any status mode, active and inactive offset 
     *  broker constrainers are returned. 
     *
     *  @param  brokerConstrainerIds the list of <code> Ids </code> to 
     *          retrieve 
     *  @return the returned <code> BrokerConstrainer </code> list 
     *  @throws org.osid.NotFoundException an <code> Id </code> was not found 
     *  @throws org.osid.NullArgumentException <code> brokerConstrainerIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.BrokerConstrainerList getBrokerConstrainersByIds(org.osid.id.IdList brokerConstrainerIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BrokerConstrainerList </code> corresponding to the given 
     *  broker constrainer genus <code> Type </code> which does not include 
     *  broker constrainer of genus types derived from the specified <code> 
     *  Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  broker constrainer or an error results. Otherwise, the returned list 
     *  may contain only those broker constrainer that are accessible through 
     *  this session. 
     *  
     *  In active mode, offset broker constrainers are returned that are 
     *  currently active. In any status mode, active and inactive offset 
     *  broker constrainers are returned. 
     *
     *  @param  brokerConstrainerGenusType a broker constrainer genus type 
     *  @return the returned <code> BrokerConstrainer </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          brokerConstrainerGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.BrokerConstrainerList getBrokerConstrainersByGenusType(org.osid.type.Type brokerConstrainerGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BrokerConstrainerList </code> corresponding to the given 
     *  broker constrainer genus <code> Type </code> and include any 
     *  additional broker constrainer with genus types derived from the 
     *  specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  broker constrainer or an error results. Otherwise, the returned list 
     *  may contain only those broker constrainer that are accessible through 
     *  this session. 
     *  
     *  In active mode, offset broker constrainers are returned that are 
     *  currently active. In any status mode, active and inactive offset 
     *  broker constrainers are returned. 
     *
     *  @param  brokerConstrainerGenusType a broker constrainer genus type 
     *  @return the returned <code> BrokerConstrainer </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          brokerConstrainerGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.BrokerConstrainerList getBrokerConstrainersByParentGenusType(org.osid.type.Type brokerConstrainerGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BrokerConstrainerList </code> containing the given 
     *  broker constrainer record <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  broker constrainer or an error results. Otherwise, the returned list 
     *  may contain only those broker constrainer that are accessible through 
     *  this session. 
     *  
     *  In active mode, offset broker constrainers are returned that are 
     *  currently active. In any status mode, active and inactive offset 
     *  broker constrainers are returned. 
     *
     *  @param  brokerConstrainerRecordType a broker constrainer record type 
     *  @return the returned <code> BrokerConstrainer </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          brokerConstrainerRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.BrokerConstrainerList getBrokerConstrainersByRecordType(org.osid.type.Type brokerConstrainerRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> BrokerConstrainers. </code> 
     *  
     *  In plenary mode, the returned list contains all known broker 
     *  constrainer or an error results. Otherwise, the returned list may 
     *  contain only those broker constrainer that are accessible through this 
     *  session. 
     *  
     *  In active mode, offset broker constrainers are returned that are 
     *  currently active. In any status mode, active and inactive offset 
     *  broker constrainers are returned. 
     *
     *  @return the returned <code> BrokerConstrainer </code> list 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.BrokerConstrainerList getBrokerConstrainers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
