//
// org.osid.provisioning.rules.BrokerProcessorEnablerQuery
//
//     The OSID Java specification for org.osid.provisioning.rules.BrokerProcessorEnablerQuery.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning.rules;


/**
 *  <p>This is the query for searching broker processor enablers. Each method 
 *  match specifies an <code> AND </code> term while multiple invocations of 
 *  the same method produce a nested <code> OR. </code> </p>
 */

public interface BrokerProcessorEnablerQuery
    extends org.osid.OsidEnablerQuery {


    /**
     *  Matches enablers mapped to the broker processor. 
     *
     *  @param  brokerProcessorId the broker processor <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> brokerProcessorId 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRuledBrokerProcessorId(org.osid.id.Id brokerProcessorId, 
                                            boolean match);


    /**
     *  Clears the broker processor <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRuledBrokerProcessorIdTerms();


    /**
     *  Tests if a <code> BrokerProcessorQuery </code> is available. 
     *
     *  @return <code> true </code> if a broker processor query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRuledBrokerProcessorQuery();


    /**
     *  Gets the query for a broker processor. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the broker processor query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRuledBrokerProcessorQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRuledBrokerProcessorQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.rules.BrokerProcessorQuery getRuledBrokerProcessorQuery();


    /**
     *  Matches enablers mapped to any broker processor. 
     *
     *  @param  match <code> true </code> for enablers mapped to any broker 
     *          processor, <code> false </code> to match enablers mapped to no 
     *          broker processors 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRuledBrokerProcessor(boolean match);


    /**
     *  Clears the broker processor query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRuledBrokerProcessorTerms();


    /**
     *  Matches enablers mapped to the distributor. 
     *
     *  @param  distributorId the distributor <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDistributorId(org.osid.id.Id distributorId, boolean match);


    /**
     *  Clears the distributor <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDistributorIdTerms();


    /**
     *  Tests if a <code> DistributorQuery </code> is available. 
     *
     *  @return <code> true </code> if a distributor query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDistributorQuery();


    /**
     *  Gets the query for a distributor. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the distributor query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDistributorQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDistributorQuery() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.DistributorQuery getDistributorQuery();


    /**
     *  Clears the distributor query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDistributorTerms();


    /**
     *  Gets the broker processor enabler query record corresponding to the 
     *  given <code> BrokerProcessorEnabler </code> record <code> Type. 
     *  </code> Multiple record retrievals produce a nested <code> OR </code> 
     *  term. 
     *
     *  @param  brokerProcessorEnablerRecordType a broker processor enabler 
     *          record type 
     *  @return the broker processor enabler query record 
     *  @throws org.osid.NullArgumentException <code> 
     *          brokerProcessorEnablerRecordType </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(brokerProcessorEnablerRecordType) </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.records.BrokerProcessorEnablerQueryRecord getBrokerProcessorEnablerQueryRecord(org.osid.type.Type brokerProcessorEnablerRecordType)
        throws org.osid.OperationFailedException;
}
