//
// org.osid.provisioning.rules.BrokerProcessorEnablerRuleApplicationSession
//
//     The OSID Java specification for org.osid.provisioning.rules.BrokerProcessorEnablerRuleApplicationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning.rules;


/**
 *  <p>This session provides methods to apply <code> BrokerProcessorEnablers 
 *  </code> to <code> BrokerProcessors. </code> A <code> BrokerProcessor 
 *  </code> with multiple <code> BrokerProcessorEnablers </code> means any 
 *  positive rule evaluation across the enablers result in an effective <code> 
 *  BrokerProcessor. </code> </p>
 */

public interface BrokerProcessorEnablerRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Distributor </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Distributor Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDistributorId();


    /**
     *  Gets the <code> Distributor </code> associated with this session. 
     *
     *  @return the distributor 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.Distributor getDistributor()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter broker processor enabler/broker processor 
     *  mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known mapping 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignBrokerProcessorEnablers();


    /**
     *  Adds an existing <code> BrokerProcessorEnabler </code> to a <code> 
     *  BrokerProcessor. </code> 
     *
     *  @param  brokerProcessorEnablerId the <code> Id </code> of the <code> 
     *          BrokerProcessorEnabler </code> 
     *  @param  brokerProcessorId the <code> Id </code> of the <code> 
     *          BrokerProcessor </code> 
     *  @throws org.osid.AlreadyExistsException <code> 
     *          brokerProcessorEnablerId </code> is already applied to <code> 
     *          brokerProcessorId </code> 
     *  @throws org.osid.NotFoundException <code> brokerProcessorEnablerId 
     *          </code> or <code> brokerProcessorId </code> not found 
     *  @throws org.osid.NullArgumentException <code> brokerProcessorEnablerId 
     *          </code> or <code> brokerProcessorId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignBrokerProcessorEnablerToBrokerProcessor(org.osid.id.Id brokerProcessorEnablerId, 
                                                              org.osid.id.Id brokerProcessorId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> BrokerProcessorEnabler </code> from a <code> 
     *  BrokerProcessor. </code> 
     *
     *  @param  brokerProcessorEnablerId the <code> Id </code> of the <code> 
     *          BrokerProcessorEnabler </code> 
     *  @param  brokerProcessorId the <code> Id </code> of the <code> 
     *          BrokerProcessor </code> 
     *  @throws org.osid.NotFoundException <code> brokerProcessorEnablerId 
     *          </code> or <code> brokerProcessorId </code> not found or 
     *          <code> brokerProcessorEnablerId </code> not applied to <code> 
     *          brokerProcessorId </code> 
     *  @throws org.osid.NullArgumentException <code> brokerProcessorEnablerId 
     *          </code> or <code> brokerProcessorId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignBrokerProcessorEnablerFromBrokerProcessor(org.osid.id.Id brokerProcessorEnablerId, 
                                                                  org.osid.id.Id brokerProcessorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> BrokerProcessorEnablers. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known sequencing operations will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> BrokerProcessorEnabler </code> 
     *          ordering is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceBrokerProcessorEnablers();


    /**
     *  Reorders broker processor enablers for a broker processor by moving 
     *  the specified broker processor enabler in front of a reference broker 
     *  processor enabler. 
     *
     *  @param  brokerProcessorEnablerId the <code> Id </code> of a <code> 
     *          BrokerProcessorEnabler </code> 
     *  @param  brokerProcessorId the <code> Id </code> of a <code> 
     *          BrokerProcessor </code> 
     *  @param  referenceId the reference broker processor enabler <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> brokerProcessorEnablerId, 
     *          brokerProcessorId, </code> or <code> referenceId </code> not 
     *          found or, <code> brokerProcessorEnablerId </code> or <code> 
     *          referenceId </code> not related to <code> brokerProcessorId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          brokerProcessorEnablerId, brokerProcessorId, </code> or <code> 
     *          referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveBrokerProcessorEnablerAhead(org.osid.id.Id brokerProcessorEnablerId, 
                                                org.osid.id.Id brokerProcessorId, 
                                                org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders broker processor enablers for a broker processor by moving 
     *  the specified broker processor enabler behind a reference broker 
     *  processor enabler. 
     *
     *  @param  brokerProcessorEnablerId the <code> Id </code> of a <code> 
     *          BrokerProcessorEnabler </code> 
     *  @param  brokerProcessorId the <code> Id </code> of a <code> 
     *          BrokerProcessor </code> 
     *  @param  referenceId the reference broker processor enabler <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> brokerProcessorEnablerId, 
     *          brokerProcessorId, </code> or <code> referenceId </code> not 
     *          found or, <code> brokerProcessorEnablerId </code> or <code> 
     *          referenceId </code> not related to <code> brokerProcessorId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          brokerProcessorEnablerId, brokerProcessorId, </code> or <code> 
     *          referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveBrokerProcessorEnablerBehind(org.osid.id.Id brokerProcessorEnablerId, 
                                                 org.osid.id.Id brokerProcessorId, 
                                                 org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of broker processor enablers for a broker processor. 
     *
     *  @param  brokerProcessorEnablerIds the <code> Ids </code> for a set of 
     *          <code> BrokerProcessorEnablers </code> 
     *  @param  brokerProcessorId the <code> Id </code> of a <code> 
     *          BrokerProcessor </code> 
     *  @throws org.osid.NotFoundException <code> brokerProcessorId </code> 
     *          not found or, a <code> brokerProcessorEnablerId </code> not 
     *          related to <code> brokerProcessorId </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          brokerProcessorEnablerIds </code> or <code> brokerProcessorId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderBrokerProcessorEnablers(org.osid.id.Id[] brokerProcessorEnablerIds, 
                                             org.osid.id.Id brokerProcessorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
