//
// org.osid.provisioning.rules.BrokerProcessorNotificationSession
//
//     The OSID Java specification for org.osid.provisioning.rules.BrokerProcessorNotificationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning.rules;


/**
 *  <p>This session defines methods to receive notifications on adds/changes 
 *  to <code> BrokerProcessor </code> objects in this <code> Distributor. 
 *  </code> This also includes existing <code> BrokerProcessors </code> that 
 *  may appear or disappear due to changes in the <code> Distributor </code> 
 *  hierarchy, This session is intended for consumers needing to synchronize 
 *  their state with this service without the use of polling. Notifications 
 *  are cancelled when this session is closed. </p> 
 *  
 *  <p> The two views defined in this session correspond to the views in the 
 *  <code> BrokerProcessorLookupSession. </code> </p>
 */

public interface BrokerProcessorNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Distributor </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Distributor Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDistributorId();


    /**
     *  Gets the <code> Distributor </code> associated with this session. 
     *
     *  @return the distributor 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.Distributor getDistributor()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can register for <code> BrokerProcessor </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForBrokerProcessorNotifications();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include in distributors which are children of this distributor in the 
     *  distributor hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedDistributorView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts notifications to this distributor only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedDistributorView();


    /**
     *  Register for notifications of new broker processors. <code> 
     *  BrokerProcessorReceiver.newBrokerProcessors() </code> is invoked when 
     *  a new <code> BrokerProcessor </code> appears in this distributor. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewBrokerProcessors()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated distributors. <code> 
     *  BrokerProcessorReceiver.changedBrokerProcessors() </code> is invoked 
     *  when a broker processor in this distributor is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedBrokerProcessors()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated broker processor. <code> 
     *  ProvisionableReceiver.changedBrokerProcessors() </code> is invoked 
     *  when the specified broker processor in this distributor is changed. 
     *
     *  @param  brokerProcessorId the <code> Id </code> of the <code> 
     *          BrokerProcessor </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> brokerProcessorId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedBrokerProcessor(org.osid.id.Id brokerProcessorId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted broker processors. <code> 
     *  BrokerProcessorReceiver.deletedBrokerProcessors() </code> is invoked 
     *  when a broker processor is deleted or removed from this distributor. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedBrokerProcessors()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted broker processor. <code> 
     *  BrokerProcessorReceiver.deletedBrokerProcessors() </code> is invoked 
     *  when the specified broker processor is deleted or removed from this 
     *  distributor. 
     *
     *  @param  brokerProcessorId the <code> Id </code> of the <code> 
     *          BrokerProcessor </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> brokerProcessorId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedBrokerProcessor(org.osid.id.Id brokerProcessorId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
