//
// org.osid.provisioning.rules.BrokerProcessorQuery
//
//     The OSID Java specification for org.osid.provisioning.rules.BrokerProcessorQuery.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning.rules;


/**
 *  <p>This is the query for searching broker processors. Each method match 
 *  specifies an <code> AND </code> term while multiple invocations of the 
 *  same method produce a nested <code> OR. </code> </p>
 */

public interface BrokerProcessorQuery
    extends org.osid.OsidProcessorQuery {


    /**
     *  Matches brokers that issue leases. 
     *
     *  @param  match <code> true </code> to match brokers that issue leases, 
     *          <code> false </code> to match brokers that issue permanent 
     *          provisions 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchLeasing(boolean match);


    /**
     *  Clears the leasing query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLeasingTerms();


    /**
     *  Matches brokers that issue fixed duration leases between the given 
     *  durations inclusive. 
     *
     *  @param  from starting duration range 
     *  @param  to ending duration range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchFixedLeaseDuration(org.osid.calendaring.Duration from, 
                                        org.osid.calendaring.Duration to, 
                                        boolean match);


    /**
     *  Matches brokers with any fixed lease duration. 
     *
     *  @param  match <code> true </code> to match brokers with any fixed 
     *          lease duration, returns, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyFixedLeaseDuration(boolean match);


    /**
     *  Clears the fixed lease duration query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFixedLeaseDurationTerms();


    /**
     *  Matches brokers that require provisions to be returned. 
     *
     *  @param  match <code> true </code> to match brokers that require 
     *          provision returns,, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMustReturnProvisions(boolean match);


    /**
     *  Clears the must return provisions query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMustReturnProvisionsTerms();


    /**
     *  Matches brokers that allow provision exchange. 
     *
     *  @param  match <code> true </code> to match brokers that permit 
     *          provision exchange, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAllowsProvisionExchange(boolean match);


    /**
     *  Clears the allows provision exchange query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAllowsProvisionExchangeTerms();


    /**
     *  Matches brokers that allow comound requests. 
     *
     *  @param  match <code> true </code> to match brokers that permit 
     *          compound requests, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAllowsCompoundRequests(boolean match);


    /**
     *  Clears the allows compound requests query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAllowsCompoundRequestsTerms();


    /**
     *  Matches mapped to the broker. 
     *
     *  @param  distributorId the broker <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRuledBrokerId(org.osid.id.Id distributorId, boolean match);


    /**
     *  Clears the broker <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRuledBrokerIdTerms();


    /**
     *  Tests if a <code> BrokerQuery </code> is available. 
     *
     *  @return <code> true </code> if a broker query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRuledBrokerQuery();


    /**
     *  Gets the query for a broker. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the broker query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRuledBrokerQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRuledBrokerQuery() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.BrokerQuery getRuledBrokerQuery();


    /**
     *  Matches mapped to any broker. 
     *
     *  @param  match <code> true </code> for mapped to any broker, <code> 
     *          false </code> to match mapped to no broker 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRuledBroker(boolean match);


    /**
     *  Clears the broker query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRuledBrokerTerms();


    /**
     *  Matches mapped to the distributor. 
     *
     *  @param  distributorId the distributor <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDistributorId(org.osid.id.Id distributorId, boolean match);


    /**
     *  Clears the distributor <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDistributorIdTerms();


    /**
     *  Tests if a <code> DistributorQuery </code> is available. 
     *
     *  @return <code> true </code> if a distributor query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDistributorQuery();


    /**
     *  Gets the query for a distributor. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the distributor query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDistributorQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDistributorQuery() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.DistributorQuery getDistributorQuery();


    /**
     *  Clears the distributor query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDistributorTerms();


    /**
     *  Gets the broker processor query record corresponding to the given 
     *  <code> BrokerProcessor </code> record <code> Type. </code> Multiple 
     *  record retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  brokerProcessorRecordType a broker processor record type 
     *  @return the broker processor query record 
     *  @throws org.osid.NullArgumentException <code> 
     *          brokerProcessorRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(brokerProcessorRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.records.BrokerProcessorQueryRecord getBrokerProcessorQueryRecord(org.osid.type.Type brokerProcessorRecordType)
        throws org.osid.OperationFailedException;
}
