//
// org.osid.provisioning.rules.BrokerProcessorRuleApplicationSession
//
//     The OSID Java specification for org.osid.provisioning.rules.BrokerProcessorRuleApplicationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning.rules;


/**
 *  <p>This session provides methods to apply <code> BrokerProcessors </code> 
 *  to <code> Brokers. </code> </p>
 */

public interface BrokerProcessorRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Distributor </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Distributor Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDistributorId();


    /**
     *  Gets the <code> Distributor </code> associated with this session. 
     *
     *  @return the distributor 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.Distributor getDistributor()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter broker processor/broker mappings. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignBrokerProcessors();


    /**
     *  Adds an existing <code> BrokerProcessor </code> to a <code> Broker. 
     *  </code> 
     *
     *  @param  brokerProcessorId the <code> Id </code> of the <code> 
     *          BrokerProcessor </code> 
     *  @param  brokerId the <code> Id </code> of the <code> Broker </code> 
     *  @throws org.osid.AlreadyExistsException <code> brokerProcessorId 
     *          </code> is already applied to <code> brokerId </code> 
     *  @throws org.osid.NotFoundException <code> brokerProcessorId </code> or 
     *          <code> brokerId </code> not found 
     *  @throws org.osid.NullArgumentException <code> brokerProcessorId 
     *          </code> or <code> brokerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignBrokerProcessorToBroker(org.osid.id.Id brokerProcessorId, 
                                              org.osid.id.Id brokerId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> BrokerProcessor </code> from a <code> Broker. </code> 
     *
     *  @param  brokerProcessorId the <code> Id </code> of the <code> 
     *          BrokerProcessor </code> 
     *  @param  brokerId the <code> Id </code> of the <code> Broker </code> 
     *  @throws org.osid.NotFoundException <code> brokerProcessorId </code> or 
     *          <code> brokerId </code> not found or <code> brokerProcessorId 
     *          </code> not applied to <code> brokerId </code> 
     *  @throws org.osid.NullArgumentException <code> brokerProcessorId 
     *          </code> or <code> brokerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignBrokerProcessorFromBroker(org.osid.id.Id brokerProcessorId, 
                                                  org.osid.id.Id brokerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> BrokerProcessors. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known sequencing operations will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> BrokerProcessor </code> 
     *          ordering is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceBrokerProcessors();


    /**
     *  Reorders broker processors for a broker by moving the specified broker 
     *  processor in front of a reference broker processor. 
     *
     *  @param  brokerProcessorId the <code> Id </code> of a <code> 
     *          BrokerProcessor </code> 
     *  @param  brokerId the <code> Id </code> of a <code> Broker </code> 
     *  @param  referenceId the reference broker processor <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> brokerProcessorId, brokerId, 
     *          </code> or <code> referenceId </code> not found or, <code> 
     *          brokerProcessorId </code> or <code> referenceId </code> not 
     *          related to <code> brokerId </code> 
     *  @throws org.osid.NullArgumentException <code> brokerProcessorId, 
     *          brokerId, </code> or <code> referenceId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveBrokerProcessorAhead(org.osid.id.Id brokerProcessorId, 
                                         org.osid.id.Id brokerId, 
                                         org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders broker processors for a broker by moving the specified broker 
     *  processor behind a reference broker processor. 
     *
     *  @param  brokerProcessorEnablerId the <code> Id </code> of a <code> 
     *          BrokerProcessor </code> 
     *  @param  brokerProcessorId the <code> Id </code> of a <code> Broker 
     *          </code> 
     *  @param  brokerId the reference broker processor <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> brokerProcessorId, brokerId, 
     *          </code> or <code> referenceId </code> not found or, <code> 
     *          brokerProcessorId </code> or <code> referenceId </code> not 
     *          related to <code> brokerId </code> 
     *  @throws org.osid.NullArgumentException <code> brokerProcessorId, 
     *          brokerId, </code> or <code> referenceId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveBrokerProcessorBehind(org.osid.id.Id brokerProcessorEnablerId, 
                                          org.osid.id.Id brokerProcessorId, 
                                          org.osid.id.Id brokerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of broker processors for a broker. 
     *
     *  @param  brokerProcessorIds the <code> Ids </code> for a set of <code> 
     *          BrokerProcessors </code> 
     *  @param  brokerId the <code> Id </code> of a <code> Broker </code> 
     *  @throws org.osid.NotFoundException <code> brokerId </code> not found 
     *          or, a <code> brokerProcessorId </code> not related to <code> 
     *          brokerId </code> 
     *  @throws org.osid.NullArgumentException <code> brokerProcessorIds 
     *          </code> or <code> brokerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderBrokerProcessors(org.osid.id.Id[] brokerProcessorIds, 
                                      org.osid.id.Id brokerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
