//
// org.osid.provisioning.rules.PoolConstrainerEnablerDistributorAssignmentSession
//
//     The OSID Java specification for org.osid.provisioning.rules.PoolConstrainerEnablerDistributorAssignmentSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning.rules;


/**
 *  <p>This session provides methods to re-assign <code> 
 *  PoolConstrainerEnabler </code> to <code> Distributor </code> mappings. A 
 *  <code> PoolConstrainerEnabler </code> may appear in multiple <code> 
 *  Distributor </code> objects and removing the last reference to a <code> 
 *  PoolConstrainerEnabler </code> is the equivalent of deleting it. Each 
 *  <code> Distributor </code> may have its own authorizations governing who 
 *  is allowed to operate on it. </p> 
 *  
 *  <p> Adding a reference of a <code> PoolConstrainerEnabler </code> to 
 *  another <code> Distributor </code> is not a copy operation (eg: does not 
 *  change its <code> Id </code> ). </p>
 */

public interface PoolConstrainerEnablerDistributorAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter pool constrainer enabler/distributor 
     *  mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known mapping 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignPoolConstrainerEnablers();


    /**
     *  Tests if this user can alter pool constrainer enabler/distributor 
     *  mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known mapping 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignPoolConstrainerEnablersToDistributor(org.osid.id.Id distributorId);


    /**
     *  Gets a list of distributors including and under the given distributor 
     *  node in which any pool constrainer enabler can be assigned. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @return list of assignable distributor <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableDistributorIds(org.osid.id.Id distributorId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of distributors including and under the given distributor 
     *  node in which a specific pool constrainer enabler can be assigned. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  poolConstrainerEnablerId the <code> Id </code> of the <code> 
     *          PoolConstrainerEnabler </code> 
     *  @return list of assignable distributor <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> or 
     *          <code> poolConstrainerEnablerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableDistributorIdsForPoolConstrainerEnabler(org.osid.id.Id distributorId, 
                                                                                   org.osid.id.Id poolConstrainerEnablerId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> PoolConstrainerEnabler </code> to a <code> 
     *  Distributor. </code> 
     *
     *  @param  poolConstrainerEnablerId the <code> Id </code> of the <code> 
     *          PoolConstrainerEnabler </code> 
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @throws org.osid.AlreadyExistsException <code> 
     *          poolConstrainerEnablerId </code> is already assigned to <code> 
     *          distributorId </code> 
     *  @throws org.osid.NotFoundException <code> poolConstrainerEnablerId 
     *          </code> or <code> distributorId </code> not found 
     *  @throws org.osid.NullArgumentException <code> poolConstrainerEnablerId 
     *          </code> or <code> distributorId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignPoolConstrainerEnablerToDistributor(org.osid.id.Id poolConstrainerEnablerId, 
                                                          org.osid.id.Id distributorId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> PoolConstrainerEnabler </code> from a <code> 
     *  Distributor. </code> 
     *
     *  @param  poolConstrainerEnablerId the <code> Id </code> of the <code> 
     *          PoolConstrainerEnabler </code> 
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> poolConstrainerEnablerId 
     *          </code> or <code> distributorId </code> not found or <code> 
     *          poolConstrainerEnablerId </code> not assigned to <code> 
     *          distributorId </code> 
     *  @throws org.osid.NullArgumentException <code> poolConstrainerEnablerId 
     *          </code> or <code> distributorId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignPoolConstrainerEnablerFromDistributor(org.osid.id.Id poolConstrainerEnablerId, 
                                                              org.osid.id.Id distributorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
