//
// org.osid.provisioning.rules.PoolConstrainerEnablerRuleApplicationSession
//
//     The OSID Java specification for org.osid.provisioning.rules.PoolConstrainerEnablerRuleApplicationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning.rules;


/**
 *  <p>This session provides methods to apply <code> PoolConstrainerEnablers 
 *  </code> to <code> PoolConstrainers. </code> A <code> PoolConstrainer 
 *  </code> with multiple <code> PoolConstrainerEnablers </code> means any 
 *  positive rule evaluation across the enablers result in an effective <code> 
 *  PoolConstrainer. </code> </p>
 */

public interface PoolConstrainerEnablerRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Distributor </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Distributor Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDistributorId();


    /**
     *  Gets the <code> Distributor </code> associated with this session. 
     *
     *  @return the distributor 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.Distributor getDistributor()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter pool constrainer enabler/pool constrainer 
     *  mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known mapping 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignPoolConstrainerEnablers();


    /**
     *  Adds an existing <code> PoolConstrainerEnabler </code> to a <code> 
     *  PoolConstrainer. </code> 
     *
     *  @param  poolConstrainerEnablerId the <code> Id </code> of the <code> 
     *          PoolConstrainerEnabler </code> 
     *  @param  poolConstrainerId the <code> Id </code> of the <code> 
     *          PoolConstrainer </code> 
     *  @throws org.osid.AlreadyExistsException <code> 
     *          poolConstrainerEnablerId </code> is already applied to <code> 
     *          poolConstrainerId </code> 
     *  @throws org.osid.NotFoundException <code> poolConstrainerEnablerId 
     *          </code> or <code> poolConstrainerId </code> not found 
     *  @throws org.osid.NullArgumentException <code> poolConstrainerEnablerId 
     *          </code> or <code> poolConstrainerId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignPoolConstrainerEnablerToPoolConstrainer(org.osid.id.Id poolConstrainerEnablerId, 
                                                              org.osid.id.Id poolConstrainerId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> PoolConstrainerEnabler </code> from a <code> 
     *  PoolConstrainer. </code> 
     *
     *  @param  poolConstrainerEnablerId the <code> Id </code> of the <code> 
     *          PoolConstrainerEnabler </code> 
     *  @param  poolConstrainerId the <code> Id </code> of the <code> 
     *          PoolConstrainer </code> 
     *  @throws org.osid.NotFoundException <code> poolConstrainerEnablerId 
     *          </code> or <code> poolConstrainerId </code> not found or 
     *          <code> poolConstrainerEnablerId </code> not applied to <code> 
     *          poolConstrainerId </code> 
     *  @throws org.osid.NullArgumentException <code> poolConstrainerEnablerId 
     *          </code> or <code> poolConstrainerId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignPoolConstrainerEnablerFromPoolConstrainer(org.osid.id.Id poolConstrainerEnablerId, 
                                                                  org.osid.id.Id poolConstrainerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> PoolConstrainerEnablers. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known sequencing operations will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> PoolConstrainerEnabler </code> 
     *          ordering is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequencePoolConstrainerEnablers();


    /**
     *  Reorders pool constrainer enablers for a pool constrainer by moving 
     *  the specified pool constrainer enabler in front of a reference pool 
     *  constrainer enabler. 
     *
     *  @param  poolConstrainerEnablerId the <code> Id </code> of a <code> 
     *          PoolConstrainerEnabler </code> 
     *  @param  poolConstrainerId the <code> Id </code> of a <code> 
     *          PoolConstrainer </code> 
     *  @param  referenceId the reference pool constrainer enabler <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> poolConstrainerEnablerId, 
     *          poolConstrainerId, </code> or <code> referenceId </code> not 
     *          found or, <code> poolConstrainerEnablerId </code> or <code> 
     *          referenceId </code> not related to <code> poolConstrainerId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          poolConstrainerEnablerId, poolConstrainerId, </code> or <code> 
     *          referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void movePoolConstrainerEnablerAhead(org.osid.id.Id poolConstrainerEnablerId, 
                                                org.osid.id.Id poolConstrainerId, 
                                                org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders pool constrainer enablers for a pool constrainer by moving 
     *  the specified pool constrainer enabler behind a reference pool 
     *  constrainer enabler. 
     *
     *  @param  poolConstrainerEnablerId the <code> Id </code> of a <code> 
     *          PoolConstrainerEnabler </code> 
     *  @param  poolConstrainerId the <code> Id </code> of a <code> 
     *          PoolConstrainer </code> 
     *  @param  referenceId the reference pool constrainer enabler <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> poolConstrainerEnablerId, 
     *          poolConstrainerId, </code> or <code> referenceId </code> not 
     *          found or, <code> poolConstrainerEnablerId </code> or <code> 
     *          referenceId </code> not related to <code> poolConstrainerId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          poolConstrainerEnablerId, poolConstrainerId, </code> or <code> 
     *          referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void movePoolConstrainerEnablerBehind(org.osid.id.Id poolConstrainerEnablerId, 
                                                 org.osid.id.Id poolConstrainerId, 
                                                 org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of pool constrainer enablers for a pool constrainer. 
     *
     *  @param  poolConstrainerEnablerIds the <code> Ids </code> for a set of 
     *          <code> PoolConstrainerEnablers </code> 
     *  @param  poolConstrainerId the <code> Id </code> of a <code> 
     *          PoolConstrainer </code> 
     *  @throws org.osid.NotFoundException <code> poolConstrainerId </code> 
     *          not found or, a <code> poolConstrainerEnablerId </code> not 
     *          related to <code> poolConstrainerId </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          poolConstrainerEnablerIds </code> or <code> poolConstrainerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderPoolConstrainerEnablers(org.osid.id.Id[] poolConstrainerEnablerIds, 
                                             org.osid.id.Id poolConstrainerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
