//
// org.osid.provisioning.rules.PoolConstrainerEnablerRuleLookupSession
//
//     The OSID Java specification for org.osid.provisioning.rules.PoolConstrainerEnablerRuleLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning.rules;


/**
 *  <p>This session provides methods to retrieve <code> PoolConstrainerEnabler 
 *  </code> to <code> PoolConstrainer </code> mappings. A <code> 
 *  PoolConstrainer </code> with multiple <code> PoolConstrainerEnablers 
 *  </code> means any positive rule evaluation across the enablers result in 
 *  an effective <code> PoolConstrainer. </code> </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated distributor view: All methods in this session operate, 
 *      retrieve and pertain pool constrainer enablers defined explicitly in 
 *      the current distributor </li> 
 *      <li> federated distributor view: All methods in this session operate, 
 *      retrieve and pertain to all pool constrainer enablers defined in this 
 *      distributor and any other pool constrainer enablers implicitly 
 *      available in this distributor through distributor inheritence. </li> 
 *  </ul>
 *  
 */

public interface PoolConstrainerEnablerRuleLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Distributor </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Distributor Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDistributorId();


    /**
     *  Gets the <code> Distributor </code> associated with this session. 
     *
     *  @return the distributor 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.Distributor getDistributor()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform lookups of pool constrainer 
     *  enabler/pool constrainer mappings. A return of true does not guarantee 
     *  successful authorization. A return of false indicates that it is known 
     *  lookup methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if looking up mappings is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupPoolConstrainerEnablerRules();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativePoolConstrainerEnablerRuleView();


    /**
     *  A complete view of the <code> PoolConstrainerEnabler </code> and 
     *  <code> PoolConstrainer </code> returns is desired. Methods will return 
     *  what is requested or result in an error. This view is used when 
     *  greater precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryPoolConstrainerEnablerRuleView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include pool constrainer enablers in distributors which are children 
     *  of this distributor in the distributor hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedDistributorView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this distributor only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedDistributorView();


    /**
     *  Gets the <code> PoolConstrainerEnabler Id </code> associated with a 
     *  <code> PoolConstrainer. </code> 
     *
     *  @param   poolConstrainerId <code> Id </code> of the <code> 
     *          PoolConstrainer </code> 
     *  @return the pool constrainer enabler <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> poolConstrainerId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> poolConstrainerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getPoolConstrainerEnablerIdsForPoolConstrainer(org.osid.id.Id  poolConstrainerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> PoolConstrainerEnablers </code> associated with a 
     *  <code> PoolConstrainer. </code> 
     *
     *  @param  poolConstrainerId <code> Id </code> of the <code> 
     *          PoolConstrainer </code> 
     *  @return the pool constrainer enablers 
     *  @throws org.osid.NotFoundException <code> poolConstrainerId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> poolConstrainerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.PoolConstrainerEnablerList getPoolConstrainerEnablersForPoolConstrainer(org.osid.id.Id poolConstrainerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> PoolConstrainer </code> <code> Ids </code> mapped to a 
     *  <code> PoolConstrainerEnabler. </code> 
     *
     *  @param  poolConstrainerEnablerId <code> Id </code> of a <code> 
     *          PoolConstrainerEnabler </code> 
     *  @return list of pool constrainer <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> poolConstrainerEnablerId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> poolConstrainerEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getPoolConstrainerIdsForPoolConstrainerEnabler(org.osid.id.Id poolConstrainerEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> PoolConstrainers </code> mapped to a <code> 
     *  PoolConstrainerEnabler. </code> 
     *
     *  @param  poolConstrainerEnablerId <code> Id </code> of a <code> 
     *          PoolConstrainerEnabler </code> 
     *  @return list of pool constrainers 
     *  @throws org.osid.NotFoundException <code> poolConstrainerEnablerId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> poolConstrainerEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.PoolConstrainerList getPoolConstrainersForPoolConstrainerEnabler(org.osid.id.Id poolConstrainerEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
