//
// org.osid.provisioning.rules.PoolConstrainerEnablerSearchSession
//
//     The OSID Java specification for org.osid.provisioning.rules.PoolConstrainerEnablerSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning.rules;


/**
 *  <p>This session provides methods for searching among <code> 
 *  PoolConstrainerEnabler </code> objects. The search query is constructed 
 *  using the <code> PoolConstrainerEnableryQuery. </code> </p> 
 *  
 *  <p> <code> getPoolConstrainerEnablersByQuery() </code> is the basic search 
 *  method and returns a list of <code> PoolConstrainerEnablers. </code> A 
 *  more advanced search may be performed with <code> 
 *  getPoolConstrainerEnablersBySearch(). </code> It accepts a <code> 
 *  PoolConstrainerEnablerSearch </code> in addition to the query for the 
 *  purpose of specifying additional options affecting the entire search, such 
 *  as provisioning. <code> getPoolConstrainerEnablersBySearch() </code> 
 *  returns a <code> PoolConstrainerEnablerSearchResults </code> that can be 
 *  used to access the resulting <code> PoolConstrainerEnablerList </code> or 
 *  be used to perform a search within the result set through <code> 
 *  PoolConstrainerEnablerSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated distributor view: searches include pool constrainer 
 *      enablers in distributors of which this distributor is an ancestor in 
 *      the distributor hierarchy </li> 
 *      <li> isolated distributor view: searches are restricted to pool 
 *      constrainer enablers in this distributor </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> PoolConstrainerEnablers </code> may have a query record 
 *  indicated by their respective record types. The query record is accessed 
 *  via the <code> PoolConstrainerEnablerQuery. </code> </p>
 */

public interface PoolConstrainerEnablerSearchSession
    extends org.osid.provisioning.rules.PoolConstrainerEnablerQuerySession {


    /**
     *  Gets a pool constrainer enabler search. 
     *
     *  @return the pool constrainer enabler search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.PoolConstrainerEnablerSearch getPoolConstrainerEnablerSearch();


    /**
     *  Gets a pool constrainer enabler search order. The <code> 
     *  PoolConstrainerEnablerSearchOrder </code> is supplied to a <code> 
     *  PoolConstrainerEnablerSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the pool constrainer enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.PoolConstrainerEnablerSearchOrder getPoolConstrainerEnablerSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  poolConstrainerEnablerQuery the pool constrainer enabler query 
     *  @param  poolConstrainerEnablerSearch the pool constrainer enabler 
     *          search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> 
     *          poolConstrainerEnablerQuery </code> or <code> 
     *          poolConstrainerEnablerSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> 
     *          poolConstrainerEnablerQuery </code> or <code> 
     *          poolConstrainerEnablerSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.PoolConstrainerEnablerSearchResults getPoolConstrainerEnablersBySearch(org.osid.provisioning.rules.PoolConstrainerEnablerQuery poolConstrainerEnablerQuery, 
                                                                                                              org.osid.provisioning.rules.PoolConstrainerEnablerSearch poolConstrainerEnablerSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a pool constrainer enabler query from an inspector. The inspector 
     *  is available from a <code> PoolConstrainerEnablerSearchResults. 
     *  </code> 
     *
     *  @param  poolConstrainerEnablerQueryInspector a pool constrainer 
     *          enabler query inspector 
     *  @return the pool constrainer enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          poolConstrainerEnablerQueryInspector </code> is <code> null 
     *          </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          poolConstrainerEnablerQueryInspector </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.PoolConstrainerEnablerQuery getPoolConstrainerEnablerQueryFromInspector(org.osid.provisioning.rules.PoolConstrainerEnablerQueryInspector poolConstrainerEnablerQueryInspector);
}
