//
// org.osid.provisioning.rules.PoolProcessor
//
//     The OSID Java specification for org.osid.provisioning.rules.PoolProcessor.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning.rules;


/**
 *  <p>A <code> PoolProcessor </code> describes the rules for managing 
 *  resource allocations out of a pool. </p>
 */

public interface PoolProcessor
    extends org.osid.OsidProcessor {


    /**
     *  Tests if allocations balance the usage by preferring the least used 
     *  provisionables in the pool. 
     *
     *  @return <code> true </code> if the least used provisionables are 
     *          preferred, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean allocatesByLeastUse();


    /**
     *  Tests if allocations prefer the most used provisionables in the pool. 
     *
     *  @return <code> true </code> if the most used provisionables are 
     *          preferred, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean allocatesByMostUse();


    /**
     *  Tests if allocations prefer the cheapest provisionables. 
     *
     *  @return <code> true </code> if the cheapest provisionables are 
     *          preferred, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean allocatesByLeastCost();


    /**
     *  Tests if allocations prefer the most expensive provisionables. 
     *
     *  @return <code> true </code> if the most expensive provisionables are 
     *          prefsrred, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean allocatesByMostCost();


    /**
     *  Gets the pool processor record corresponding to the given <code> 
     *  PoolProcessor </code> record <code> Type. </code> This method is used 
     *  to retrieve an object implementing the requested record. The <code> 
     *  poolProcessorRecordType </code> may be the <code> Type </code> 
     *  returned in <code> getRecordTypes() </code> or any of its parents in a 
     *  <code> Type </code> hierarchy where <code> 
     *  hasRecordType(poolProcessorRecordType) </code> is <code> true </code> 
     *  . 
     *
     *  @param  poolProcessorRecordType the type of pool processor record to 
     *          retrieve 
     *  @return the pool processor record 
     *  @throws org.osid.NullArgumentException <code> poolProcessorRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(poolProcessorRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.records.PoolProcessorRecord getPoolProcessorRecord(org.osid.type.Type poolProcessorRecordType)
        throws org.osid.OperationFailedException;
}
