//
// org.osid.provisioning.rules.PoolProcessorSearchSession
//
//     The OSID Java specification for org.osid.provisioning.rules.PoolProcessorSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning.rules;


/**
 *  <p>This session provides methods for searching among <code> PoolProcessor 
 *  </code> objects. The search query is constructed using the <code> 
 *  PoolProcessoryQuery. </code> </p> 
 *  
 *  <p> <code> getPoolProcessorsByQuery() </code> is the basic search method 
 *  and returns a list of <code> PoolProcessors. </code> A more advanced 
 *  search may be performed with <code> getPoolProcessorsBySearch(). </code> 
 *  It accepts a <code> PoolProcessorSearch </code> in addition to the query 
 *  for the purpose of specifying additional options affecting the entire 
 *  search, such as provisioning. <code> getPoolProcessorsBySearch() </code> 
 *  returns a <code> PoolProcessorSearchResults </code> that can be used to 
 *  access the resulting <code> PoolProcessorList </code> or be used to 
 *  perform a search within the result set through <code> PoolProcessorSearch. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated distributor view: searches include pool processor in 
 *      distributors of which this distributor is an ancestor in the 
 *      distributor hierarchy </li> 
 *      <li> isolated distributor view: searches are restricted to pool 
 *      processor in this distributor </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> PoolProcessors </code> may have a query record indicated by 
 *  their respective record types. The query record is accessed via the <code> 
 *  PoolProcessorQuery. </code> </p>
 */

public interface PoolProcessorSearchSession
    extends org.osid.provisioning.rules.PoolProcessorQuerySession {


    /**
     *  Gets a pool processor search. 
     *
     *  @return the pool processor search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.PoolProcessorSearch getPoolProcessorSearch();


    /**
     *  Gets a pool processor search order. The <code> 
     *  PoolProcessorSearchOrder </code> is supplied to a <code> 
     *  PoolProcessorSearch </code> to specify the ordering of results. 
     *
     *  @return the pool processor search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.PoolProcessorSearchOrder getPoolProcessorSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  poolProcessorQuery the pool processor query 
     *  @param  poolProcessorSearch the pool processor search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> poolProcessorQuery 
     *          </code> or <code> poolProcessorSearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> poolProcessorQuery 
     *          </code> or <code> poolProcessorSearch </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.PoolProcessorSearchResults getPoolProcessorsBySearch(org.osid.provisioning.rules.PoolProcessorQuery poolProcessorQuery, 
                                                                                            org.osid.provisioning.rules.PoolProcessorSearch poolProcessorSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a pool processor query from an inspector. The inspector is 
     *  available from a <code> PoolProcessorSearchResults. </code> 
     *
     *  @param  poolProcessorQueryInspector a pool processor query inspector 
     *  @return the pool processor query 
     *  @throws org.osid.NullArgumentException <code> 
     *          poolProcessorQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          poolProcessorQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.PoolProcessorQuery getPoolProcessorQueryFromInspector(org.osid.provisioning.rules.PoolProcessorQueryInspector poolProcessorQueryInspector);
}
