//
// org.osid.provisioning.rules.QueueConstrainerEnablerSearchSession
//
//     The OSID Java specification for org.osid.provisioning.rules.QueueConstrainerEnablerSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning.rules;


/**
 *  <p>This session provides methods for searching among <code> 
 *  QueueConstrainerEnabler </code> objects. The search query is constructed 
 *  using the <code> QueueConstrainerEnableryQuery. </code> </p> 
 *  
 *  <p> <code> getQueueConstrainerEnablersByQuery() </code> is the basic 
 *  search method and returns a list of <code> QueueConstrainerEnablers. 
 *  </code> A more advanced search may be performed with <code> 
 *  getQueueConstrainerEnablersBySearch(). </code> It accepts a <code> 
 *  QueueConstrainerEnablerSearch </code> in addition to the query for the 
 *  purpose of specifying additional options affecting the entire search, such 
 *  as provisioning. <code> getQueueConstrainerEnablersBySearch() </code> 
 *  returns a <code> QueueConstrainerEnablerSearchResults </code> that can be 
 *  used to access the resulting <code> QueueConstrainerEnablerList </code> or 
 *  be used to perform a search within the result set through <code> 
 *  QueueConstrainerEnablerSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated distributor view: searches include queue constrainer 
 *      enablers in distributors of which this distributor is an ancestor in 
 *      the distributor hierarchy </li> 
 *      <li> isolated distributor view: searches are restricted to queue 
 *      constrainer enablers in this distributor </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> QueueConstrainerEnablers </code> may have a query record 
 *  indicated by their respective record types. The query record is accessed 
 *  via the <code> QueueConstrainerEnablerQuery. </code> </p>
 */

public interface QueueConstrainerEnablerSearchSession
    extends org.osid.provisioning.rules.QueueConstrainerEnablerQuerySession {


    /**
     *  Gets a queue constrainer enabler search. 
     *
     *  @return the queue constrainer enabler search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.QueueConstrainerEnablerSearch getQueueConstrainerEnablerSearch();


    /**
     *  Gets a queue constrainer enabler search order. The <code> 
     *  QueueConstrainerEnablerSearchOrder </code> is supplied to a <code> 
     *  QueueConstrainerEnablerSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the queue constrainer enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.QueueConstrainerEnablerSearchOrder getQueueConstrainerEnablerSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  queueConstrainerEnablerQuery the queue constrainer enabler 
     *          query 
     *  @param  queueConstrainerEnablerSearch the queue constrainer enabler 
     *          search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueConstrainerEnablerQuery </code> or <code> 
     *          queueConstrainerEnablerSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> 
     *          queueConstrainerEnablerQuery </code> or <code> 
     *          queueConstrainerEnablerSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.QueueConstrainerEnablerSearchResults getQueueConstrainerEnablersBySearch(org.osid.provisioning.rules.QueueConstrainerEnablerQuery queueConstrainerEnablerQuery, 
                                                                                                                org.osid.provisioning.rules.QueueConstrainerEnablerSearch queueConstrainerEnablerSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a queue constrainer enabler query from an inspector. The 
     *  inspector is available from a <code> 
     *  QueueConstrainerEnablerSearchResults. </code> 
     *
     *  @param  queueConstrainerEnablerQueryInspector a queue constrainer 
     *          enabler query inspector 
     *  @return the queue constrainer enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueConstrainerEnablerQueryInspector </code> is <code> null 
     *          </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          queueConstrainerEnablerQueryInspector </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.QueueConstrainerEnablerQuery getQueueConstrainerEnablerQueryFromInspector(org.osid.provisioning.rules.QueueConstrainerEnablerQueryInspector queueConstrainerEnablerQueryInspector);
}
