//
// org.osid.provisioning.rules.QueueProcessorAdminSession
//
//     The OSID Java specification for org.osid.provisioning.rules.QueueProcessorAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning.rules;


/**
 *  <p>This session creates and removes queue processors. The data for create 
 *  and update is provided via the <code> QueueProcessorForm. </code> </p>
 */

public interface QueueProcessorAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Distributor </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Distributor Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDistributorId();


    /**
     *  Gets the <code> Distributor </code> associated with this session. 
     *
     *  @return the distributor 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.Distributor getDistributor()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create queue processors. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known creating a <code> QueueProcessor </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer create operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> QueueProcessor </code> creation 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateQueueProcessor();


    /**
     *  Tests if this user can create a single <code> QueueProcessor </code> 
     *  using the desired record types. While <code> 
     *  ProvisioningRulesManager.getQueueProcessorRecordTypes() </code> can be 
     *  used to examine which records are supported, this method tests which 
     *  record(s) are required for creating a specific <code> QueueProcessor. 
     *  </code> Providing an empty array tests if a <code> QueueProcessor 
     *  </code> can be created with no records. 
     *
     *  @param  queueProcessorRecordTypes array of queue processor record 
     *          types 
     *  @return <code> true </code> if <code> QueueProcessor </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueProcessorRecordTypes </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateQueueProcessorWithRecordTypes(org.osid.type.Type[] queueProcessorRecordTypes);


    /**
     *  Gets the queue processor form for creating new queue processors. A new 
     *  form should be requested for each create transaction. 
     *
     *  @param  queueProcessorRecordTypes array of queue processor record 
     *          types 
     *  @return the queue processor form 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueProcessorRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.QueueProcessorForm getQueueProcessorFormForCreate(org.osid.type.Type[] queueProcessorRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> QueueProcessor. </code> 
     *
     *  @param  queueProcessorForm the form for this <code> QueueProcessor 
     *          </code> 
     *  @return the new <code> QueueProcessor </code> 
     *  @throws org.osid.IllegalStateException <code> queueProcessorForm 
     *          </code> already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> queueProcessorForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> queueProcessorForm 
     *          </code> did not originate from <code> 
     *          getQueueProcessorFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.QueueProcessor createQueueProcessor(org.osid.provisioning.rules.QueueProcessorForm queueProcessorForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update queue processors. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known updating a <code> QueueProcessor </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer update operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> QueueProcessor </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateQueueProcessors();


    /**
     *  Gets the queue processor form for updating an existing queue 
     *  processor. A new queue processor form should be requested for each 
     *  update transaction. 
     *
     *  @param  queueProcessorId the <code> Id </code> of the <code> 
     *          QueueProcessor </code> 
     *  @return the queue processor form 
     *  @throws org.osid.NotFoundException <code> queueProcessorId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> queueProcessorId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.QueueProcessorForm getQueueProcessorFormForUpdate(org.osid.id.Id queueProcessorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing queue processor. 
     *
     *  @param  queueProcessorForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> queueProcessorForm 
     *          </code> already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> queueProcessorForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> queueProcessorForm 
     *          </code> did not originate from <code> 
     *          getQueueProcessorFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateQueueProcessor(org.osid.provisioning.rules.QueueProcessorForm queueProcessorForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete queue processors. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known deleting a <code> QueueProcessor </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer delete operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> QueueProcessor </code> deletion 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteQueueProcessors();


    /**
     *  Deletes a <code> QueueProcessor. </code> 
     *
     *  @param  queueProcessorId the <code> Id </code> of the <code> 
     *          QueueProcessor </code> to remove 
     *  @throws org.osid.NotFoundException <code> queueProcessorId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> queueProcessorId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteQueueProcessor(org.osid.id.Id queueProcessorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for queue 
     *  processors. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> QueueProcessor </code> aliasing 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageQueueProcessorAliases();


    /**
     *  Adds a <code> Id </code> to a <code> QueueProcessor </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> QueueProcessor </code> is determined by the provider. The 
     *  new <code> Id </code> performs as an alias to the primary <code> Id 
     *  </code> . If the alias is a pointer to another queue processor. it is 
     *  reassigned to the given queue processor <code> Id. </code> 
     *
     *  @param  queueProcessorId the <code> Id </code> of a <code> 
     *          QueueProcessor </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> queueProcessorId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> queueProcessorId </code> 
     *          or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasQueueProcessor(org.osid.id.Id queueProcessorId, 
                                    org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
