//
// org.osid.provisioning.rules.QueueProcessorEnablerAdminSession
//
//     The OSID Java specification for org.osid.provisioning.rules.QueueProcessorEnablerAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning.rules;


/**
 *  <p>This session creates and removes queue processor enablers. The data for 
 *  create and update is provided via the <code> QueueProcessorEnablerForm. 
 *  </code> </p>
 */

public interface QueueProcessorEnablerAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Distributor </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Distributor Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDistributorId();


    /**
     *  Gets the <code> Distributor </code> associated with this session. 
     *
     *  @return the distributor 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.Distributor getDistributor()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create queue processor enablers. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> QueueProcessorEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer create 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> QueueProcessorEnabler </code> 
     *          creation is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateQueueProcessorEnabler();


    /**
     *  Tests if this user can create a single <code> QueueProcessorEnabler 
     *  </code> using the desired record types. While <code> 
     *  ProvisioningRulesManager.getQueueProcessorEnablerRecordTypes() </code> 
     *  can be used to examine which records are supported, this method tests 
     *  which record(s) are required for creating a specific <code> 
     *  QueueProcessorEnabler. </code> Providing an empty array tests if a 
     *  <code> QueueProcessorEnabler </code> can be created with no records. 
     *
     *  @param  queueProcessorEnablerRecordTypes array of types 
     *  @return <code> true </code> if <code> QueueProcessorEnabler </code> 
     *          creation using the specified record <code> Types </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueProcessorEnablerRecordTypes </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateQueueProcessorEnablerWithRecordTypes(org.osid.type.Type[] queueProcessorEnablerRecordTypes);


    /**
     *  Gets the queue processor enabler form for creating new queue processor 
     *  enablers. A new form should be requested for each create transaction. 
     *
     *  @return the queue processor enabler form 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.QueueProcessorEnablerForm getQueueProcessorEnablerFormForCreate()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> QueueProcessorEnabler. </code> 
     *
     *  @param  queueProcessorEnablerForm the form for this <code> 
     *          QueueProcessorEnabler </code> 
     *  @return the new <code> QueueProcessorEnabler </code> 
     *  @throws org.osid.IllegalStateException <code> 
     *          queueProcessorEnablerForm </code> already used in a create 
     *          transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueProcessorEnablerForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> queueProcessorEnablerForm 
     *          </code> did not originate from <code> 
     *          getQueueProcessorEnablerFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.QueueProcessorEnabler createQueueProcessorEnabler(org.osid.provisioning.rules.QueueProcessorEnablerForm queueProcessorEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update queue processor enablers. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> QueueProcessorEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer update 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> QueueProcessorEnabler </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateQueueProcessorEnablers();


    /**
     *  Gets the queue processor enabler form for updating an existing queue 
     *  processor enabler. A new queue processor enabler form should be 
     *  requested for each update transaction. 
     *
     *  @param  queueProcessorEnablerId the <code> Id </code> of the <code> 
     *          QueueProcessorEnabler </code> 
     *  @return the queue processor enabler form 
     *  @throws org.osid.NotFoundException <code> queueProcessorEnablerId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> queueProcessorEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.QueueProcessorEnablerForm getQueueProcessorEnablerFormForUpdate(org.osid.id.Id queueProcessorEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing queue processor enabler. 
     *
     *  @param  queueProcessorEnablerForm the form containing the elements to 
     *          be updated 
     *  @throws org.osid.IllegalStateException <code> 
     *          queueProcessorEnablerForm </code> already used in an update 
     *          transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueProcessorEnablerForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> queueProcessorEnablerForm 
     *          </code> did not originate from <code> 
     *          getQueueProcessorEnablerFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateQueueProcessorEnabler(org.osid.provisioning.rules.QueueProcessorEnablerForm queueProcessorEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete queue processor enablers. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> QueueProcessorEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer delete 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> QueueProcessorEnabler </code> 
     *          deletion is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteQueueProcessorEnablers();


    /**
     *  Deletes a <code> QueueProcessorEnabler. </code> 
     *
     *  @param  queueProcessorEnablerId the <code> Id </code> of the <code> 
     *          QueueProcessorEnabler </code> to remove 
     *  @throws org.osid.NotFoundException <code> queueProcessorEnablerId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> queueProcessorEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteQueueProcessorEnabler(org.osid.id.Id queueProcessorEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for queue 
     *  processor enablers. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> QueueProcessorEnabler </code> 
     *          aliasing is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageQueueProcessorEnablerAliases();


    /**
     *  Adds a <code> Id </code> to a <code> QueueProcessorEnabler </code> for 
     *  the purpose of creating compatibility. The primary <code> Id </code> 
     *  of the <code> QueueProcessorEnabler </code> is determined by the 
     *  provider. The new <code> Id </code> performs as an alias to the 
     *  primary <code> Id </code> . If the alias is a pointer to another queue 
     *  processor enabler. it is reassigned to the given queue processor 
     *  enabler <code> Id. </code> 
     *
     *  @param  queueProcessorEnablerId the <code> Id </code> of a <code> 
     *          QueueProcessorEnabler </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> queueProcessorEnablerId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> queueProcessorEnablerId 
     *          </code> or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasQueueProcessorEnabler(org.osid.id.Id queueProcessorEnablerId, 
                                           org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
