//
// org.osid.provisioning.rules.QueueProcessorEnablerRuleApplicationSession
//
//     The OSID Java specification for org.osid.provisioning.rules.QueueProcessorEnablerRuleApplicationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning.rules;


/**
 *  <p>This session provides methods to apply <code> QueueProcessorEnablers 
 *  </code> to <code> QueueProcessors. </code> a <code> QueueProcessor </code> 
 *  with multiple <code> QueueProcessorEnablers </code> means any positive 
 *  rule evaluation across the enablers result in an effective <code> 
 *  QueueProcessor. </code> </p>
 */

public interface QueueProcessorEnablerRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Distributor </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Distributor Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDistributorId();


    /**
     *  Gets the <code> Distributor </code> associated with this session. 
     *
     *  @return the distributor 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.Distributor getDistributor()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter queue processor enabler/queue processor 
     *  mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known mapping 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignQueueProcessorEnablers();


    /**
     *  Adds an existing <code> QueueProcessorEnabler </code> to a <code> 
     *  QueueProcessor. </code> 
     *
     *  @param  queueProcessorEnablerId the <code> Id </code> of the <code> 
     *          QueueProcessorEnabler </code> 
     *  @param  queueProcessorId the <code> Id </code> of the <code> 
     *          QueueProcessor </code> 
     *  @throws org.osid.AlreadyExistsException <code> queueProcessorEnablerId 
     *          </code> is already applied to <code> queueProcessorId </code> 
     *  @throws org.osid.NotFoundException <code> queueProcessorEnablerId 
     *          </code> or <code> queueProcessorId </code> not found 
     *  @throws org.osid.NullArgumentException <code> queueProcessorEnablerId 
     *          </code> or <code> queueProcessorId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignQueueProcessorEnablerToQueueProcessor(org.osid.id.Id queueProcessorEnablerId, 
                                                            org.osid.id.Id queueProcessorId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> QueueProcessorEnabler </code> from a <code> 
     *  QueueProcessor. </code> 
     *
     *  @param  queueProcessorEnablerId the <code> Id </code> of the <code> 
     *          QueueProcessorEnabler </code> 
     *  @param  queueProcessorId the <code> Id </code> of the <code> 
     *          QueueProcessor </code> 
     *  @throws org.osid.NotFoundException <code> queueProcessorEnablerId 
     *          </code> or <code> queueProcessorId </code> not found or <code> 
     *          queueProcessorEnablerId </code> not applied to <code> 
     *          queueProcessorId </code> 
     *  @throws org.osid.NullArgumentException <code> queueProcessorEnablerId 
     *          </code> or <code> queueProcessorId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignQueueProcessorEnablerFromQueueProcessor(org.osid.id.Id queueProcessorEnablerId, 
                                                                org.osid.id.Id queueProcessorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> QueueProcessorEnablers. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known sequencing operations will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> QueueProcessorEnabler </code> 
     *          ordering is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceQueueProcessorEnablers();


    /**
     *  Reorders queue processor enablers for a queue processor by moving the 
     *  specified queue processor enabler in front of a reference queue 
     *  processor enabler. 
     *
     *  @param  queueProcessorEnablerId the <code> Id </code> of a <code> 
     *          QueueProcessorEnabler </code> 
     *  @param  queueProcessorId the <code> Id </code> of a <code> 
     *          QueueProcessor </code> 
     *  @param  referenceId the reference queue processor enabler <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> queueProcessorEnablerId, 
     *          queueProcessorId, </code> or <code> referenceId </code> not 
     *          found or, <code> queueProcessorEnablerId </code> or <code> 
     *          referenceId </code> not related to <code> queueProcessorId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> queueProcessorEnablerId, 
     *          queueProcessorId, </code> or <code> referenceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveQueueProcessorEnablerAhead(org.osid.id.Id queueProcessorEnablerId, 
                                               org.osid.id.Id queueProcessorId, 
                                               org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders queue processor enablers for a queue processor by moving the 
     *  specified queue processor enabler behind a reference queue processor 
     *  enabler. 
     *
     *  @param  queueProcessorEnablerId the <code> Id </code> of a <code> 
     *          QueueProcessorEnabler </code> 
     *  @param  queueProcessorId the <code> Id </code> of a <code> 
     *          QueueProcessor </code> 
     *  @param  referenceId the reference queue processor enabler <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> queueProcessorEnablerId, 
     *          queueProcessorId, </code> or <code> referenceId </code> not 
     *          found or, <code> queueProcessorEnablerId </code> or <code> 
     *          referenceId </code> not related to <code> queueProcessorId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> queueProcessorEnablerId, 
     *          queueProcessorId, </code> or <code> referenceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveQueueProcessorEnablerBehind(org.osid.id.Id queueProcessorEnablerId, 
                                                org.osid.id.Id queueProcessorId, 
                                                org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of queue processor enablers for a queue processor. 
     *
     *  @param  queueProcessorEnablerIds the <code> Ids </code> for a set of 
     *          <code> QueueProcessorEnablers </code> 
     *  @param  queueProcessorId the <code> Id </code> of a <code> 
     *          QueueProcessor </code> 
     *  @throws org.osid.NotFoundException <code> queueProcessorId </code> not 
     *          found or, a <code> queueProcessorEnablerId </code> not related 
     *          to <code> queueProcessorId </code> 
     *  @throws org.osid.NullArgumentException <code> queueProcessorEnablerIds 
     *          </code> or <code> queueProcessorId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderQueueProcessorEnablers(org.osid.id.Id[] queueProcessorEnablerIds, 
                                            org.osid.id.Id queueProcessorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
