//
// org.osid.provisioning.rules.QueueProcessorEnablerRuleLookupSession
//
//     The OSID Java specification for org.osid.provisioning.rules.QueueProcessorEnablerRuleLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning.rules;


/**
 *  <p>This session provides methods to retrieve <code> QueueProcessorEnabler 
 *  </code> to <code> QueueProcessor </code> mappings. a <code> QueueProcessor 
 *  </code> with multiple <code> QueueProcessorEnablers </code> means any 
 *  positive rule evaluation across the enablers result in an effective <code> 
 *  QueueProcessor. </code> </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated distributor view: All methods in this session operate, 
 *      retrieve and pertain queue processor enablers defined explicitly in 
 *      the current distributor </li> 
 *      <li> federated distributor view: All methods in this session operate, 
 *      retrieve and pertain to all queue processor enablers defined in this 
 *      distributor and any other queue processor enablers implicitly 
 *      available in this distributor through distributor inheritence. </li> 
 *  </ul>
 *  
 */

public interface QueueProcessorEnablerRuleLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Distributor </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Distributor Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDistributorId();


    /**
     *  Gets the <code> Distributor </code> associated with this session. 
     *
     *  @return the distributor 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.Distributor getDistributor()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform lookups of queue processor 
     *  enabler/queue processor mappings. A return of true does not guarantee 
     *  successful authorization. A return of false indicates that it is known 
     *  lookup methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if looking up mappings is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupQueueProcessorEnablerRules();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeQueueProcessorEnablerRuleView();


    /**
     *  A complete view of the <code> QueueProcessorEnabler </code> and <code> 
     *  QueueProcessor </code> returns is desired. Methods will return what is 
     *  requested or result in an error. This view is used when greater 
     *  precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryQueueProcessorEnablerRuleView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include queue processor enablers in distributors which are children of 
     *  this distributor in the distributor hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedDistributorView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this distributor only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedDistributorView();


    /**
     *  Gets the <code> QueueProcessorEnabler Id </code> associated with a 
     *  <code> QueueProcessor. </code> 
     *
     *  @param  queueProcessorId <code> Id </code> of the <code> 
     *          QueueProcessor </code> 
     *  @return the queue processor enabler <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> queueProcessorId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> queueProcessorId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getQueueProcessorEnablerIdsForQueueProcessor(org.osid.id.Id queueProcessorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> QueueProcessorEnabler </code> associated with a <code> 
     *  QueueProcessor. </code> 
     *
     *  @param  queueProcessorId <code> Id </code> of the <code> 
     *          QueueProcessor </code> 
     *  @return the queue processor enablers 
     *  @throws org.osid.NotFoundException <code> queueProcessorId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> queueProcessorId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.QueueProcessorEnablerList getQueueProcessorEnablersForQueueProcessor(org.osid.id.Id queueProcessorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> QueueProcessor </code> <code> Ids </code> mapped to a 
     *  <code> QueueProcessorEnabler. </code> 
     *
     *  @param  queueProcessorEnablerId <code> Id </code> of a <code> 
     *          QueueProcessorEnabler </code> 
     *  @return list of queue processor <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> queueProcessorEnablerId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> queueProcessorEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getQueueProcessorIdsForQueueProcessorEnabler(org.osid.id.Id queueProcessorEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> QueueProcessors </code> mapped to a <code> 
     *  QueueProcessorEnabler. </code> 
     *
     *  @param  queueProcessorEnablerId <code> Id </code> of a <code> 
     *          QueueProcessorEnabler </code> 
     *  @return list of queue processors 
     *  @throws org.osid.NotFoundException <code> queueProcessorEnablerId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> queueProcessorEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.QueueProcessorList getQueueProcessorsForQueueProcessorEnabler(org.osid.id.Id queueProcessorEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
