//
// org.osid.provisioning.rules.QueueProcessorForm
//
//     The OSID Java specification for org.osid.provisioning.rules.QueueProcessorForm.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning.rules;


/**
 *  <p>This is the form for creating and updating <code> QueueProcessors. 
 *  </code> Like all <code> OsidForm </code> objects, various data elements 
 *  may be set here for use in the create and update methods in the <code> 
 *  QueueProcessorAdminSession. </code> For each data element that may be set, 
 *  metadata may be examined to provide display hints or data constraints. 
 *  </p>
 */

public interface QueueProcessorForm
    extends org.osid.OsidProcessorForm {


    /**
     *  Gets the metadata for automatic processing. 
     *
     *  @return metadata for automatic processing 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getAutomaticMetadata();


    /**
     *  Sets automatic processing. 
     *
     *  @param  auto <code> true </code> for automatic processing, <code> 
     *          false </code> for manual processing 
     *  @throws org.osid.InvalidArgumentException <code> auto </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setAutomatic(boolean auto);


    /**
     *  Removes the automatic processing flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAutomatic();


    /**
     *  Gets the metadata for first-in-first-out processing. 
     *
     *  @return metadata for fifo processing 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getFifoMetadata();


    /**
     *  Sets first-in-first-out processing 
     *
     *  @param  fifo <code> true </code> for fifo processing, <code> false 
     *          </code> otherwise 
     *  @throws org.osid.InvalidArgumentException <code> fifo </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setFifo(boolean fifo);


    /**
     *  Removes the fifo flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFifo();


    /**
     *  Gets the metadata for removal of procesed queue entries. 
     *
     *  @return metadata for removing processed queue entry processing 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getRemovesProcessedQueueEntriesMetadata();


    /**
     *  Sets removal of peocesse queue entry processing 
     *
     *  @param  remove <code> true </code> for removing processed queue 
     *          entries, <code> false </code> otherwise 
     *  @throws org.osid.InvalidArgumentException <code> remove </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setRemovesProcessedQueueEntries(boolean remove);


    /**
     *  Removes the remove processed queue entries flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRemovesProcessedQueueEntries();


    /**
     *  Gets the <code> QueueProcessorFormRecord </code> corresponding to the 
     *  given queue processor record <code> Type. </code> 
     *
     *  @param  queueProcessorRecordType a queue processor record type 
     *  @return the queue processor form record 
     *  @throws org.osid.NullArgumentException <code> queueProcessorRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(queueProcessorRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.records.QueueProcessorFormRecord getQueueProcessorFormRecord(org.osid.type.Type queueProcessorRecordType)
        throws org.osid.OperationFailedException;
}
