//
// org.osid.provisioning.rules.QueueProcessorRuleApplicationSession
//
//     The OSID Java specification for org.osid.provisioning.rules.QueueProcessorRuleApplicationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning.rules;


/**
 *  <p>This session provides methods to apply <code> QueueProcessors </code> 
 *  to <code> Queues. </code> </p>
 */

public interface QueueProcessorRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Distributor </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Distributor Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDistributorId();


    /**
     *  Gets the <code> Distributor </code> associated with this session. 
     *
     *  @return the distributor 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.Distributor getDistributor()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter queue processor/queue mappings. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignQueueProcessors();


    /**
     *  Adds an existing <code> QueueProcessor </code> to a <code> Queue. 
     *  </code> 
     *
     *  @param  queueProcessorId the <code> Id </code> of the <code> 
     *          QueueProcessor </code> 
     *  @param  queueId the <code> Id </code> of the <code> Queue </code> 
     *  @throws org.osid.AlreadyExistsException <code> queueProcessorId 
     *          </code> is already applied to <code> queueId </code> 
     *  @throws org.osid.NotFoundException <code> queueProcessorId </code> or 
     *          <code> queueId </code> not found 
     *  @throws org.osid.NullArgumentException <code> queueProcessorId </code> 
     *          or <code> queueId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignQueueProcessorToQueue(org.osid.id.Id queueProcessorId, 
                                            org.osid.id.Id queueId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> QueueProcessor </code> from a <code> Queue. </code> 
     *
     *  @param  queueProcessorId the <code> Id </code> of the <code> 
     *          QueueProcessor </code> 
     *  @param  queueId the <code> Id </code> of the <code> Queue </code> 
     *  @throws org.osid.NotFoundException <code> queueProcessorId </code> or 
     *          <code> queueId </code> not found or <code> queueProcessorId 
     *          </code> not applied to <code> queueId </code> 
     *  @throws org.osid.NullArgumentException <code> queueProcessorId </code> 
     *          or <code> queueId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignQueueProcessorFromQueue(org.osid.id.Id queueProcessorId, 
                                                org.osid.id.Id queueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> QueueProcessors. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known sequencing operations will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> QueueProcessor </code> ordering 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceQueueProcessors();


    /**
     *  Reorders queue processors for a queue by moving the specified queue 
     *  processor in front of a reference queue processor. 
     *
     *  @param  queueProcessorId the <code> Id </code> of a <code> 
     *          QueueProcessor </code> 
     *  @param  queueId the <code> Id </code> of a <code> Queue </code> 
     *  @param  referenceId the reference queue processor <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> queueProcessorId, queueId, 
     *          </code> or <code> referenceId </code> not found or, <code> 
     *          queueProcessorId </code> or <code> referenceId </code> not 
     *          related to <code> queueId </code> 
     *  @throws org.osid.NullArgumentException <code> queueProcessorId, 
     *          queueId, </code> or <code> referenceId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveQueueProcessorAhead(org.osid.id.Id queueProcessorId, 
                                        org.osid.id.Id queueId, 
                                        org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders queue processors for a queue by moving the specified queue 
     *  processor behind a reference queue processor. 
     *
     *  @param  queueProcessorId the <code> Id </code> of a <code> 
     *          QueueProcessor </code> 
     *  @param  queueId the <code> Id </code> of a <code> Queue </code> 
     *  @param  referenceId the reference queue processor <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> queueProcessorId, queueId, 
     *          </code> or <code> referenceId </code> not found or, <code> 
     *          queueProcessorId </code> or <code> referenceId </code> not 
     *          related to <code> queueId </code> 
     *  @throws org.osid.NullArgumentException <code> queueProcessorId, 
     *          queueId, </code> or <code> referenceId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveQueueProcessorBehind(org.osid.id.Id queueProcessorId, 
                                         org.osid.id.Id queueId, 
                                         org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of queue processors for a queue. 
     *
     *  @param  queueProcessorIds the <code> Ids </code> for a set of <code> 
     *          QueueProcessors </code> 
     *  @param  queueId the <code> Id </code> of a <code> QueueProcessor 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> queueId </code> not found 
     *          or, a <code> queueProcessorId </code> not related to <code> 
     *          queueId </code> 
     *  @throws org.osid.NullArgumentException <code> queueProcessorIds 
     *          </code> or <code> queueId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderQueueProcessors(org.osid.id.Id[] queueProcessorIds, 
                                     org.osid.id.Id queueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
