//
// org.osid.proxy.ProxyProfile
//
//     The OSID Java specification for org.osid.proxy.ProxyProfile.
//
// Copyright (C) 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.proxy;


/**
 *  <p>The <code> ProxyProfile </code> describes the interoperability among 
 *  proxy services. </p>
 */

public interface ProxyProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if a proxy session is supported. 
     *
     *  @return <code> true </code> if proxy is supported <code> , </code> 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProxy();


    /**
     *  Gets the supported <code> Proxy </code> record interface types. 
     *
     *  @return a list containing the supported <code> Proxy </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getProxyRecordTypes();


    /**
     *  Tests if the given <code> Proxy </code> record interface type is 
     *  supported. 
     *
     *  @param  proxyRecordType a <code> Type </code> indicating a <code> 
     *          Proxy </code> record type 
     *  @return <code> true </code> if the given type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> proxyRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProxyRecordType(org.osid.type.Type proxyRecordType);


    /**
     *  Gets the supported <code> ProxyCondition </code> record interface 
     *  types. 
     *
     *  @return a list containing the supported <code> ProxyCondition </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getProxyConditionRecordTypes();


    /**
     *  Tests if the given <code> ProxyCondition </code> record interface type 
     *  is supported. 
     *
     *  @param  proxyConditionRecordType a <code> Type </code> indicating a 
     *          <code> ProxyCondition </code> record type 
     *  @return <code> true </code> if the given type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> proxyConditionRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProxyConditionRecordType(org.osid.type.Type proxyConditionRecordType);
}
