//
// org.osid.recipe.CookbookNotificationSession
//
//     The OSID Java specification for org.osid.recipe.CookbookNotificationSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.recipe;


/**
 *  <p>This session defines methods to receive notifications on adds/changes 
 *  to <code> Cookbook </code> objects. This session is intended for consumers 
 *  needing to synchronize their state with this service without the use of 
 *  polling. Notifications are cancelled when this session is closed. </p> 
 *  
 *  <p> Notifications are triggered with changes to the <code> Cookbook 
 *  </code> object itself. Adding and removing procedures result in 
 *  notifications available from the notification session for procedures. </p>
 */

public interface CookbookNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can register for <code> Cookbook </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForCookbookNotifications();


    /**
     *  Register for notifications of new cook books. <code> 
     *  CookbookReceiver.newCookbooks() </code> is invoked when a new <code> 
     *  Cookbook </code> is created. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewCookbooks()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated hierarchy structure that 
     *  introduces a new ancestor of the specified cookbook. <code> 
     *  CookbookReceiver.newAncestorCookbook() </code> is invoked when the 
     *  specified cook book node gets a new ancestor. 
     *
     *  @param  cookbookId the <code> Id </code> of the <code> Cookbook 
     *          </code> node to monitor 
     *  @throws org.osid.NullArgumentException <code> cookbookId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewCookbookAncestors(org.osid.id.Id cookbookId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated hierarchy structure that 
     *  introduces a new descendant of the specified cookbook. <code> 
     *  CookbookReceiver.newDescendantCookbook() </code> is invoked when the 
     *  specified cook book node gets a new descendant. 
     *
     *  @param  cookbookId the <code> Id </code> of the <code> Cookbook 
     *          </code> node to monitor 
     *  @throws org.osid.NullArgumentException <code> cookbookId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewCookbookDescendants(org.osid.id.Id cookbookId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated cook books. <code> 
     *  CookbookReceiver.changedCookbook() </code> is invoked when a cook book 
     *  is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedCookbooks()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated cookbook. <code> 
     *  CookbookReceiver.changedCookbooks() </code> is invoked when the 
     *  specified cook book is changed. 
     *
     *  @param  cookbookId the <code> Id </code> of the <code> Cookbook 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> cookbookId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedCookbook(org.osid.id.Id cookbookId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted cook books. <code> 
     *  CookbookReceiver.deletedCookbooks() </code> is invoked when a cook 
     *  book is deleted. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedCookbooks()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted cookbook. <code> 
     *  CookbookReceiver.deletedCookbooks() </code> is invoked when the 
     *  specified cook book is deleted. 
     *
     *  @param  cookbookId the <code> Id </code> of the <code> Cookbook 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> cookbookId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedCookbook(org.osid.id.Id cookbookId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated hierarchy structure that 
     *  removes an ancestor of the specified cook book <code> 
     *  CookbookReceiver.deletedAncestor() </code> is invoked when the 
     *  specified cook book node loses an ancestor. 
     *
     *  @param  cookbookId the <code> Id </code> of the <code> Cookbook 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> cookbookId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedCookbookAncestors(org.osid.id.Id cookbookId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated hierarchy structure that 
     *  removes a descendant of the specified cookbook. <code> 
     *  CookbookReceiver.deletedDescendant() </code> is invoked when the 
     *  specified cook book node loses a descendant. 
     *
     *  @param  cookbookId the <code> Id </code> of the <code> Cookbook 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> cookbookId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedCookbookDescendants(org.osid.id.Id cookbookId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
