//
// org.osid.recipe.CookbookQuery
//
//     The OSID Java specification for org.osid.recipe.CookbookQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.recipe;


/**
 *  <p>This is the query for searching for cook books. Each method specifies 
 *  an <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface CookbookQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Sets the recipe <code> Id </code> for this query. 
     *
     *  @param  recipeId a recipe <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> recipeId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRecipeId(org.osid.id.Id recipeId, boolean match);


    /**
     *  Clears the recipe <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRecipeIdTerms();


    /**
     *  Tests if a recipe query is available. 
     *
     *  @return <code> true </code> if a recipe query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRecipeQuery();


    /**
     *  Gets the query for a recipe. 
     *
     *  @return the recipe query 
     *  @throws org.osid.UnimplementedException <code> supportsRecipeQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecipeQuery() </code> is <code> true. </code> 
     */

    public org.osid.recipe.RecipeQuery getRecipeQuery();


    /**
     *  Matches cook books with any recipe. 
     *
     *  @param  match <code> true </code> to match cook books with any recipe, 
     *          <code> false </code> to match cook books with no recipes 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRecipe(boolean match);


    /**
     *  Clears the procedure terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRecipeTerms();


    /**
     *  Sets the procedure <code> Id </code> for this query to match 
     *  procedures assigned to cook books. 
     *
     *  @param  procedureId a procedure <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> procedureId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchProcedureId(org.osid.id.Id procedureId, boolean match);


    /**
     *  Clears the procedure <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProcedureIdTerms();


    /**
     *  Tests if a procedure query is available. 
     *
     *  @return <code> true </code> if a procedure query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcedureQuery();


    /**
     *  Gets the query for an procedure. 
     *
     *  @return the procedure query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProcedureQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcedureQuery() </code> is <code> true. </code> 
     */

    public org.osid.recipe.ProcedureQuery getProcedureQuery();


    /**
     *  Matches cook books with any procedure. 
     *
     *  @param  match <code> true </code> to match cook books with any 
     *          procedure, <code> false </code> to match cook books with no 
     *          procedures 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyProcedure(boolean match);


    /**
     *  Clears the procedure terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProcedureTerms();


    /**
     *  Sets a direction <code> Id. </code> 
     *
     *  @param  directionId a direction <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> directionId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDirectionId(org.osid.id.Id directionId, boolean match);


    /**
     *  Clears the direction <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDirectionIdTerms();


    /**
     *  Tests if a <code> DirectionQuery </code> is available. 
     *
     *  @return <code> true </code> if a direction query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDirectionQuery();


    /**
     *  Gets the query for a direction query. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the direction query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDirectionQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDirectionQuery() </code> is <code> true. </code> 
     */

    public org.osid.recipe.DirectionQuery getDirectionQuery();


    /**
     *  Matches any direction. 
     *
     *  @param  match <code> true </code> to match cook books with any 
     *          direction, <code> false </code> to match cook books with no 
     *          directions 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDirection(boolean match);


    /**
     *  Clears the direction terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDirectionTerms();


    /**
     *  Sets the cook book <code> Id </code> for this query to match cook 
     *  books that have the specified cook book as an ancestor. 
     *
     *  @param  cookbookId a cook book <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> cookbookId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorCookbookId(org.osid.id.Id cookbookId, 
                                        boolean match);


    /**
     *  Clears the ancestor cook book <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorCookbookIdTerms();


    /**
     *  Tests if an <code> CookbookQuery </code> is available. 
     *
     *  @return <code> true </code> if a cook book query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorCookbookQuery();


    /**
     *  Gets the query for a cookbook. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the cook book query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorCookbookQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorCookbookQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.recipe.CookbookQuery getAncestorCookbookQuery();


    /**
     *  Matches cook books with any ancestor. 
     *
     *  @param  match <code> true </code> to match cook books with any 
     *          ancestor, <code> false </code> to match root cook books 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorCookbook(boolean match);


    /**
     *  Clears the ancestor cook book terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorCookbookTerms();


    /**
     *  Sets the cook book <code> Id </code> for this query to match cook 
     *  books that have the specified cook book as a descendant. 
     *
     *  @param  cookbookId a cook book <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> cookbookId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantCookbookId(org.osid.id.Id cookbookId, 
                                          boolean match);


    /**
     *  Clears the descendant cook book <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantCookbookIdTerms();


    /**
     *  Tests if an <code> CookbookQuery </code> is available. 
     *
     *  @return <code> true </code> if a cook book query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantCookbookQuery();


    /**
     *  Gets the query for a cookbook. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the cook book query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantCookbookQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantCookbookQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.recipe.CookbookQuery getDescendantCookbookQuery();


    /**
     *  Matches cook books with any descendant. 
     *
     *  @param  match <code> true </code> to match cook books with any 
     *          descendant, <code> false </code> to match leaf cook books 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantCookbook(boolean match);


    /**
     *  Clears the descendant cook book terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantCookbookTerms();


    /**
     *  Gets the query record corresponding to the given <code> Cookbook 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested boolean <code> OR </code> term. 
     *
     *  @param  cookbookRecordType a cook book record type 
     *  @return the cook book query record 
     *  @throws org.osid.NullArgumentException <code> cookbookRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(cookbookRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.records.CookbookQueryRecord getCookbookQueryRecord(org.osid.type.Type cookbookRecordType)
        throws org.osid.OperationFailedException;
}
