//
// org.osid.recipe.DirectionForm
//
//     The OSID Java specification for org.osid.recipe.DirectionForm.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.recipe;


/**
 *  <p>This is the form for creating and updating <code> Directions. </code> 
 *  Like all <code> OsidForm </code> objects, various data elements may be set 
 *  here for use in the create and update methods in the <code> 
 *  DirectionAdminSession. </code> For each data element that may be set, 
 *  metadata may be examined to provide display hints or data constraints. 
 *  </p>
 */

public interface DirectionForm
    extends org.osid.OsidObjectForm,
            org.osid.OsidSubjugateableForm {


    /**
     *  Gets the metadata for the procedures. 
     *
     *  @return metadata for the procedures 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getProceduresMetadata();


    /**
     *  Sets the procedures. 
     *
     *  @param  procedureIds the new procedures 
     *  @throws org.osid.InvalidArgumentException <code> procedureIds </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> procedureIds </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setProcedures(org.osid.id.Id[] procedureIds);


    /**
     *  Removes the procedures. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProcedures();


    /**
     *  Gets the metadata for the estimated duration. 
     *
     *  @return metadata for the estimated duration 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getEstimatedDurationMetadata();


    /**
     *  Sets the estimated duration. 
     *
     *  @param  duration the new estimated duration 
     *  @throws org.osid.InvalidArgumentException <code> duration </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> duration </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setEstimatedDuration(org.osid.calendaring.Duration duration);


    /**
     *  Removes the estimated duration. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEstimatedDuration();


    /**
     *  Gets the metadata for the assets. 
     *
     *  @return metadata for the assets 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getAssetsMetadata();


    /**
     *  Sets the assets. 
     *
     *  @param  assetIds the new assets 
     *  @throws org.osid.InvalidArgumentException <code> assetIds </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> assetIds </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setAssets(org.osid.id.Id[] assetIds);


    /**
     *  Removes the assets. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAssets();


    /**
     *  Gets the <code> DirectionFormRecord </code> corresponding to the given 
     *  direction record <code> Type. </code> 
     *
     *  @param  directionRecordType a direction record type 
     *  @return the direction form record 
     *  @throws org.osid.NullArgumentException <code> directionRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(directionRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.records.DirectionFormRecord getDirectionFormRecord(org.osid.type.Type directionRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
