//
// org.osid.recipe.DirectionNotificationSession
//
//     The OSID Java specification for org.osid.recipe.DirectionNotificationSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.recipe;


/**
 *  <p>This session defines methods to receive notifications on adds/changes 
 *  to <code> Direction </code> objects in this <code> Cookbook. </code> This 
 *  session is intended for consumers needing to synchronize their state with 
 *  this service without the use of polling. Notifications are cancelled when 
 *  this session is closed. </p> 
 *  
 *  <p> The two views defined in this session correspond to the views in the 
 *  <code> DirectionLookupSession. </code> </p>
 */

public interface DirectionNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Cookbook </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Cookbook Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCookbookId();


    /**
     *  Gets the <code> Cookbook </code> associated with this session. 
     *
     *  @return the cookbook 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.Cookbook getCookbook()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can register for <code> Direction </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForDirectionNotifications();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include directions in cook books which are children of this cook book 
     *  in the cook book hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCookbookView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts notifications to this cook book only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCookbookView();


    /**
     *  Register for notifications of new directions. <code> 
     *  DirectionReceiver.newDirections() </code> is invoked when a new <code> 
     *  Direction </code> appears in this cookbook. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewDirections()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new directions related to the given 
     *  recipe. <code> DirectionReceiver.newDirections() </code> is invoked 
     *  when a new <code> Direction </code> appears in this cookbook. 
     *
     *  @param  recipeId the <code> Id </code> of the <code> Recipe </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> recipeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewDirectionsForRecipe(org.osid.id.Id recipeId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated directions. <code> 
     *  DirectionReceiver.changedDirections() </code> is invoked when a 
     *  direction in this cook book is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedDirections()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated directions related to the given 
     *  recipe. <code> DirectionReceiver.changedDirections() </code> is 
     *  invoked when a direction related to the recipe in this cook book is 
     *  changed. 
     *
     *  @param  recipeId the <code> Id </code> of the <code> Recipe </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> recipeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedDirectionsForRecipe(org.osid.id.Id recipeId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated direction. <code> 
     *  DirectionReceiver.changedDirections() </code> is invoked when the 
     *  specified direction in this cook book is changed. 
     *
     *  @param  directionId the <code> Id </code> of the <code> Direction 
     *          </code> to monitor 
     *  @throws org.osid.NotFoundException a direction was not found in this 
     *          cook book identified by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> directionId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedDirection(org.osid.id.Id directionId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted directions. <code> 
     *  DirectionReceiver.deletedDirection() </code> is invoked when a 
     *  direction is deleted or removed from this cookbook. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedDirections()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted direction for a recipe. <code> 
     *  DirectionReceiver.deletedDirections() </code> is invoked when the 
     *  related direction is deleted or removed from this cookbook. 
     *
     *  @param  recipeId the <code> Id </code> of the <code> Recipe </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> recipeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedDirectionsForRecipe(org.osid.id.Id recipeId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted direction. <code> 
     *  DirectionReceiver.deletedDirections() </code> is invoked when the 
     *  specified direction is deleted or removed from this cookbook. 
     *
     *  @param  directionId the <code> Id </code> of the <code> Direction 
     *          </code> to monitor 
     *  @throws org.osid.NotFoundException a direction was not found 
     *          identified by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> directionId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedDirection(org.osid.id.Id directionId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
