//
// org.osid.recipe.ProcedureQuery
//
//     The OSID Java specification for org.osid.recipe.ProcedureQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.recipe;


/**
 *  <p>This is the query for searching procedures. Each method specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface ProcedureQuery
    extends org.osid.OsidObjectQuery {


    /**
     *  Sets the objective <code> Id </code> for this query. 
     *
     *  @param  objectiveId the asset <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> objectiveId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchLearningObjectiveId(org.osid.id.Id objectiveId, 
                                         boolean match);


    /**
     *  Clears the objective <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLearningObjectiveIdTerms();


    /**
     *  Tests if an <code> ObjectiveQuery </code> is available. 
     *
     *  @return <code> true </code> if an objective query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLearningObjectiveQuery();


    /**
     *  Gets the query for an objective. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the objective query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsLearningObjectiveQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLearningObjectiveQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.learning.ObjectiveQuery getLearningObjectiveQuery();


    /**
     *  Matches directions with any objective. 
     *
     *  @param  match <code> true </code> to match directions with any 
     *          objective, <code> false </code> to match directions with no 
     *          objectives 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyLearningObjective(boolean match);


    /**
     *  Clears the objective query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLearningObjectiveTerms();


    /**
     *  Sets the award <code> Id </code> for this query to match procedures 
     *  assigned to cook books. 
     *
     *  @param  cookbookId a cook book <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> cookbookId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCookbookId(org.osid.id.Id cookbookId, boolean match);


    /**
     *  Clears the cook book <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCookbookIdTerms();


    /**
     *  Tests if an <code> CookbookQuery </code> is available. 
     *
     *  @return <code> true </code> if a cook book query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCookbookQuery();


    /**
     *  Gets the query for a cook book query. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the cook book query 
     *  @throws org.osid.UnimplementedException <code> supportsCookbookQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCookbookQuery() </code> is <code> true. </code> 
     */

    public org.osid.recipe.CookbookQuery getCookbookQuery();


    /**
     *  Clears the cook book terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCookbookTerms();


    /**
     *  Gets the procedure query record corresponding to the given <code> 
     *  Procedure </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  procedureRecordType a procedure record type 
     *  @return the procedure query record 
     *  @throws org.osid.NullArgumentException <code> procedureRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(procedureRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.records.ProcedureQueryRecord getProcedureQueryRecord(org.osid.type.Type procedureRecordType)
        throws org.osid.OperationFailedException;
}
