//
// org.osid.recipe.RecipeLookupSession
//
//     The OSID Java specification for org.osid.recipe.RecipeLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.recipe;


/**
 *  <p>This session provides methods for retrieving <code> Recipe </code> 
 *  objects. </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated cook book view: All recipe methods in this session 
 *      operate, retrieve and pertain to recipes defined explicitly in the 
 *      current cookbook. Using an isolated view is useful for managing <code> 
 *      Recipes </code> with the <code> RecipeAdminSession. </code> </li> 
 *      <li> federated cook book view: All recipe methods in this session 
 *      operate, retrieve and pertain to all recipes defined in this cook book 
 *      and any other recipes implicitly available in this cook book through 
 *      cook book inheritence. </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedCookbookView() </code> and <code> 
 *  useIsolatedCookbookView() </code> behave as a radio group and one should 
 *  be selected before invoking any lookup methods. </p>
 */

public interface RecipeLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Cookbook </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Cookbook Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCookbookId();


    /**
     *  Gets the <code> Cookbook </code> associated with this session. 
     *
     *  @return the cookbook 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.Cookbook getCookbook()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Recipe </code> lookups. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupRecipes();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeRecipeView();


    /**
     *  A complete view of the <code> Recipe </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryRecipeView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include recipes in cook books which are children of this cook book in 
     *  the cook book hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCookbookView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this cook book only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCookbookView();


    /**
     *  Gets the <code> Recipe </code> specified by its <code> Id. </code> In 
     *  plenary mode, the exact <code> Id </code> is found or a <code> 
     *  NOT_FOUND </code> results. Otherwise, the returned <code> Recipe 
     *  </code> may have a different <code> Id </code> than requested, such as 
     *  the case where a duplicate <code> Id </code> was assigned to a <code> 
     *  Recipe </code> and retained for compatibility. 
     *
     *  @param  recipeId <code> Id </code> of the <code> Recipe </code> 
     *  @return the recipe 
     *  @throws org.osid.NotFoundException <code> recipeId </code> not found 
     *  @throws org.osid.NullArgumentException <code> recipeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.recipe.Recipe getRecipe(org.osid.id.Id recipeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RecipeList </code> corresponding to the given <code> 
     *  IdList. </code> In plenary mode, the returned list contains all of the 
     *  recipes specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Recipes </code> may be omitted from the list and 
     *  may present the elements in any order including returning a unique 
     *  set. 
     *
     *  @param  recipeIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Recipe </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> recipeIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.RecipeList getRecipesByIds(org.osid.id.IdList recipeIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RecipeList </code> corresponding to the given recipe 
     *  genus <code> Type </code> which does not include recipes of genus 
     *  types derived from the specified <code> Type </code> . In plenary 
     *  mode, the returned list contains all known recipes or an error 
     *  results. Otherwise, the returned list may contain only those recipes 
     *  that are accessible through this session. 
     *
     *  @param  recipeGenusType a recipe genus type 
     *  @return the returned <code> Recipe </code> list 
     *  @throws org.osid.NullArgumentException <code> recipeGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.RecipeList getRecipesByGenusType(org.osid.type.Type recipeGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RecipeList </code> corresponding to the given recipe 
     *  genus <code> Type </code> and include any additional recipes with 
     *  genus types derived from the specified <code> Type. </code> In plenary 
     *  mode, the returned list contains all known recipes or an error 
     *  results. Otherwise, the returned list may contain only those recipes 
     *  that are accessible through this session. 
     *
     *  @param  recipeGenusType a recipe genus type 
     *  @return the returned <code> Recipe </code> list 
     *  @throws org.osid.NullArgumentException <code> recipeGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.RecipeList getRecipesByParentGenusType(org.osid.type.Type recipeGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RecipeList </code> containing the given recipe record 
     *  <code> Type. </code> In plenary mode, the returned list contains all 
     *  known recipes or an error results. Otherwise, the returned list may 
     *  contain only those recipes that are accessible through this session. 
     *
     *  @param  recipeRecordType a recipe record type 
     *  @return the returned <code> Recipe </code> list 
     *  @throws org.osid.NullArgumentException <code> recipeRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.RecipeList getRecipesByRecordType(org.osid.type.Type recipeRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RecipeList </code> from the given provider <code> . 
     *  </code> In plenary mode, the returned list contains all known recipes 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those recipes that are accessible through this session. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @return the returned <code> Recipe </code> list 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.RecipeList getRecipesByProvider(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Recipes. </code> In plenary mode, the returned list 
     *  contains all known recipes or an error results. Otherwise, the 
     *  returned list may contain only those recipes that are accessible 
     *  through this session. 
     *
     *  @return a list of <code> Recipes </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.RecipeList getRecipes()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
