//
// org.osid.recipe.RecipeProfile
//
//     The OSID Java specification for org.osid.recipe.RecipeProfile.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.recipe;


/**
 *  <p>The recipe profile describes the interoperability among recipe 
 *  services. </p>
 */

public interface RecipeProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any cook book federation is exposed. Federation is exposed 
     *  when a specific cook book may be identified, selected and used to 
     *  create a lookup or admin session. Federation is not exposed when a set 
     *  of cook books appears as a single cookbook. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if looking up recipes is supported. 
     *
     *  @return <code> true </code> if recipe lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRecipeLookup();


    /**
     *  Tests if querying recipes is supported. 
     *
     *  @return <code> true </code> if recipe query is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRecipeQuery();


    /**
     *  Tests if searching recipes is supported. 
     *
     *  @return <code> true </code> if recipe search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRecipeSearch();


    /**
     *  Tests if recipe administrative service is supported. 
     *
     *  @return <code> true </code> if recipe administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRecipeAdmin();


    /**
     *  Tests if a recipe notification service is supported. 
     *
     *  @return <code> true </code> if recipe notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRecipeNotification();


    /**
     *  Tests if a recipe cook book lookup service is supported. 
     *
     *  @return <code> true </code> if a recipe cook book lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRecipeCookbook();


    /**
     *  Tests if a recipe cook book service is supported. 
     *
     *  @return <code> true </code> if recipe to cook book assignment service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRecipeCookbookAssignment();


    /**
     *  Tests if a recipe smart cook book lookup service is supported. 
     *
     *  @return <code> true </code> if a recipe smart cook book service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRecipeSmartCookbook();


    /**
     *  Tests if looking up directions is supported. 
     *
     *  @return <code> true </code> if direction lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDirectionLookup();


    /**
     *  Tests if querying directions is supported. 
     *
     *  @return <code> true </code> if direction query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDirectionQuery();


    /**
     *  Tests if searching directions is supported. 
     *
     *  @return <code> true </code> if direction search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDirectionSearch();


    /**
     *  Tests if direction <code> </code> administrative service is supported. 
     *
     *  @return <code> true </code> if direction administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDirectionAdmin();


    /**
     *  Tests if a direction <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if direction notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDirectionNotification();


    /**
     *  Tests if a direction cook book lookup service is supported. 
     *
     *  @return <code> true </code> if a direction cook book lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDirectionCookbook();


    /**
     *  Tests if a direction cook book assignment service is supported. 
     *
     *  @return <code> true </code> if a direction to cook book assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDirectionCookbookAssignment();


    /**
     *  Tests if a direction smart cook book service is supported. 
     *
     *  @return <code> true </code> if a direction smart cook book service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDirectionSmartCookbook();


    /**
     *  Tests for the availability of a procedure lookup service. 
     *
     *  @return <code> true </code> if procedure lookup is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcedureLookup();


    /**
     *  Tests if querying procedures is available. 
     *
     *  @return <code> true </code> if procedure query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcedureQuery();


    /**
     *  Tests if searching for procedures is available. 
     *
     *  @return <code> true </code> if procedure search is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcedureSearch();


    /**
     *  Tests if searching for procedures is available. 
     *
     *  @return <code> true </code> if procedure search is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcedureAdmin();


    /**
     *  Tests if procedure notification is available. 
     *
     *  @return <code> true </code> if procedure notification is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcedureNotification();


    /**
     *  Tests if a procedure to cook book lookup session is available. 
     *
     *  @return <code> true </code> if procedure cook book lookup session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcedureCookbook();


    /**
     *  Tests if a procedure to cook book assignment session is available. 
     *
     *  @return <code> true </code> if procedure cook book assignment is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcedureCookbookAssignment();


    /**
     *  Tests if a procedure smart cook book session is available. 
     *
     *  @return <code> true </code> if procedure smart cook book is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcedureSmartCookbook();


    /**
     *  Tests for the availability of a cook book lookup service. 
     *
     *  @return <code> true </code> if cook book lookup is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCookbookLookup();


    /**
     *  Tests if querying cook books is available. 
     *
     *  @return <code> true </code> if cook book query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCookbookQuery();


    /**
     *  Tests if searching for cook books is available. 
     *
     *  @return <code> true </code> if cook book search is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCookbookSearch();


    /**
     *  Tests for the availability of a cook book administrative service for 
     *  creating and deleting cook books. 
     *
     *  @return <code> true </code> if cook book administration is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCookbookAdmin();


    /**
     *  Tests for the availability of a cook book notification service. 
     *
     *  @return <code> true </code> if cook book notification is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsCookbookNotification();


    /**
     *  Tests for the availability of a cook book hierarchy traversal service. 
     *
     *  @return <code> true </code> if cook book hierarchy traversal is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCookbookHierarchy();


    /**
     *  Tests for the availability of a cook book hierarchy design service. 
     *
     *  @return <code> true </code> if cook book hierarchy design is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsCookbookHierarchyDesign();


    /**
     *  Tests for the availability of a batch recipie service. 
     *
     *  @return <code> true </code> if a batch recipie service is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsRecipieBatch();


    /**
     *  Gets the supported <code> Recipe </code> record types. 
     *
     *  @return a list containing the supported <code> Recipe </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getRecipeRecordTypes();


    /**
     *  Tests if the given <code> Recipe </code> record type is supported. 
     *
     *  @param  recipeRecordType a <code> Type </code> indicating an <code> 
     *          Recipe </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> recipeRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRecipeRecordType(org.osid.type.Type recipeRecordType);


    /**
     *  Gets the supported <code> Recipe </code> search record types. 
     *
     *  @return a list containing the supported <code> Recipe </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getRecipeSearchRecordTypes();


    /**
     *  Tests if the given <code> Recipe </code> search record type is 
     *  supported. 
     *
     *  @param  recipeSearchRecordType a <code> Type </code> indicating an 
     *          <code> Recipe </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> recipeSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRecipeSearchRecordType(org.osid.type.Type recipeSearchRecordType);


    /**
     *  Gets the supported <code> Direction </code> record types. 
     *
     *  @return a list containing the supported <code> Direction </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getDirectionRecordTypes();


    /**
     *  Tests if the given <code> Direction </code> record type is supported. 
     *
     *  @param  directionRecordType a <code> Type </code> indicating a <code> 
     *          Direction </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> directionRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDirectionRecordType(org.osid.type.Type directionRecordType);


    /**
     *  Gets the supported <code> Direction </code> search types. 
     *
     *  @return a list containing the supported <code> Direction </code> 
     *          search types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getDirectionSearchRecordTypes();


    /**
     *  Tests if the given <code> Direction </code> search type is supported. 
     *
     *  @param  directionSearchRecordType a <code> Type </code> indicating a 
     *          <code> Direction </code> search type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          directionSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDirectionSearchRecordType(org.osid.type.Type directionSearchRecordType);


    /**
     *  Gets the supported <code> Ingredient </code> record types. 
     *
     *  @return a list containing the supported <code> Ingredient </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getIngredientRecordTypes();


    /**
     *  Tests if the given <code> Ingredient </code> record type is supported. 
     *
     *  @param  ingredientRecordType a <code> Type </code> indicating an 
     *          <code> Ingredient </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> ingredientRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsIngredientRecordType(org.osid.type.Type ingredientRecordType);


    /**
     *  Gets the supported <code> Procedure </code> record types. 
     *
     *  @return a list containing the supported procedure record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getProcedureRecordTypes();


    /**
     *  Tests if the given <code> Procedure </code> record type is supported. 
     *
     *  @param  procedureRecordType a <code> Type </code> indicating a <code> 
     *          Procedure </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> procedureRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcedureRecordType(org.osid.type.Type procedureRecordType);


    /**
     *  Gets the supported procedure search record types. 
     *
     *  @return a list containing the supported procedure search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getProcedureSearchRecordTypes();


    /**
     *  Tests if the given procedure search record type is supported. 
     *
     *  @param  procedureSearchRecordType a <code> Type </code> indicating a 
     *          procedure record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          procedureSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcedureSearchRecordType(org.osid.type.Type procedureSearchRecordType);


    /**
     *  Gets the supported cook book record types. 
     *
     *  @return a list containing the supported cook book record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCookbookRecordTypes();


    /**
     *  Tests if the given cook book record type is supported. 
     *
     *  @param  cookbookRecordType a <code> Type </code> indicating a cook 
     *          book record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> cookbookRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCookbookRecordType(org.osid.type.Type cookbookRecordType);


    /**
     *  Gets the supported cook book search record types. 
     *
     *  @return a list containing the supported cook book search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCookbookSearchRecordTypes();


    /**
     *  Tests if the given cook book search record type is supported. 
     *
     *  @param  cookbookSearchRecordType a <code> Type </code> indicating a 
     *          cook book record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> cookbookSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCookbookSearchRecordType(org.osid.type.Type cookbookSearchRecordType);
}
