//
// org.osid.recipe.RecipeProxyManager
//
//     The OSID Java specification for org.osid.recipe.RecipeProxyManager.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.recipe;


/**
 *  <p>The recipe manager provides access to procedure sessions and provides 
 *  interoperability tests for various aspects of this service. Methods in 
 *  this manager accept a <code> Proxy </code> for passing information from a 
 *  server environment. The sessions included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> RecipeLookupSession: </code> a session to retrieve recipes 
 *      </li> 
 *      <li> <code> RecipeQuerySession: </code> a session to query for recipes 
 *      </li> 
 *      <li> <code> RecipeSearchSession: </code> a session to search for 
 *      recipes </li> 
 *      <li> <code> RecipeAdminSession: </code> a session to create and delete 
 *      recipes </li> 
 *      <li> <code> RecipeNotificationSession: </code> a session to receive 
 *      notifications pertaining to recipe changes </li> 
 *      <li> <code> RecipeCookbookSession: </code> a session to looking 
 *      mappings of recipes to cook books </li> 
 *      <li> <code> RecipeCookbookAssignmentSession: </code> a session to 
 *      manage recipe to cook book mappings </li> 
 *      <li> <code> RecipeCookbookAssignmentSession: </code> a session to 
 *      manage dynamic cook books of recipes </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> DirectionLookupSession: </code> a session to retrieve 
 *      directions </li> 
 *      <li> <code> DirectionQuerySession: </code> a session to query for 
 *      directions </li> 
 *      <li> <code> DirectionSearchSession: </code> a session to search for 
 *      directions </li> 
 *      <li> <code> DirectionAdminSession: </code> a session to create and 
 *      delete directions </li> 
 *      <li> <code> DirectionNotificationSession: </code> a session to receive 
 *      notifications pertaining to direction changes </li> 
 *      <li> <code> DirectionCookbookSession: </code> a session to look up 
 *      direction cook book mappings </li> 
 *      <li> <code> DirectionCookbookAssignmentSession: </code> a session to 
 *      manage direction to cook book mappings </li> 
 *      <li> <code> DirectionSmartCookbookSession: </code> a session to manage 
 *      dynamic cook books of directions </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> ProcedureLookupSession: </code> a session to lookup 
 *      procedures </li> 
 *      <li> <code> ProcedureQuerySession: </code> a session to query 
 *      procedures </li> 
 *      <li> <code> ProcedureSearchSession: </code> a session to search 
 *      procedures </li> 
 *      <li> <code> ProcedureAdminSession: </code> a session to manage 
 *      procedures </li> 
 *      <li> <code> ProcedureNotificationSession: </code> a session to 
 *      subscribe to notifications of procedure changes </li> 
 *      <li> <code> ProcedureCookbookSession: </code> a session to lookup 
 *      procedure cook book mappings </li> 
 *      <li> <code> ProcedureCookbookAssignmentSession: </code> a session to 
 *      manage procedure cook book mappings </li> 
 *      <li> <code> ProcedureSmartCookbookSession: </code> a session to manage 
 *      smart cook books of procedures </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> CookbookLookupSession: </code> a session to retrieve cook 
 *      books </li> 
 *      <li> <code> CookbookQuerySession: </code> a session to query cook 
 *      books </li> 
 *      <li> <code> CookbookSearchSession: </code> a session to search for 
 *      cook books </li> 
 *      <li> <code> CookbookAdminSession: </code> a session to create, update 
 *      and delete cook books </li> 
 *      <li> <code> CookbookNotificationSession: </code> a session to receive 
 *      notifications for changes in cook books </li> 
 *      <li> <code> CookbookHierarchyTraversalSession: </code> a session to 
 *      traverse hierarchies of cook books </li> 
 *      <li> <code> CookbookHierarchyDesignSession: </code> a session to 
 *      manage hierarchies of cook books </li> 
 *  </ul>
 *  
 */

public interface RecipeProxyManager
    extends org.osid.OsidProxyManager,
            org.osid.recipe.RecipeProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the recipe lookup 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RecipeLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRecipeLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecipeLookup() </code> is <code> true. </code> 
     */

    public org.osid.recipe.RecipeLookupSession getRecipeLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the recipe lookup 
     *  service for the given cookbook. 
     *
     *  @param  cookbookId the <code> Id </code> of the <code> Cookbook 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RecipeLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Cookbook </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> cookbookId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRecipeLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecipeLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.recipe.RecipeLookupSession getRecipeLookupSessionForCookbook(org.osid.id.Id cookbookId, 
                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the recipe query 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RecipeQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRecipeQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecipeQuery() </code> is <code> true. </code> 
     */

    public org.osid.recipe.RecipeQuerySession getRecipeQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the recipe query 
     *  service for the given cookbook. 
     *
     *  @param  cookbookId the <code> Id </code> of the <code> Cookbook 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RecipeQuerySession </code> 
     *  @throws org.osid.NotFoundException no cook book found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> cookbookId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRecipeQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecipeQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.recipe.RecipeQuerySession getRecipeQuerySessionForCookbook(org.osid.id.Id cookbookId, 
                                                                               org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the recipe search 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RecipeSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRecipeSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecipeSearch() </code> is <code> true. </code> 
     */

    public org.osid.recipe.RecipeSearchSession getRecipeSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the recipe search 
     *  service for the given cookbook. 
     *
     *  @param  cookbookId the <code> Id </code> of the <code> Cookbook 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RecipeSearchSession </code> 
     *  @throws org.osid.NotFoundException no cook book found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> cookbookId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRecipeSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecipeSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.recipe.RecipeSearchSession getRecipeSearchSessionForCookbook(org.osid.id.Id cookbookId, 
                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the recipe 
     *  administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RecipeAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRecipeAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecipeAdmin() </code> is <code> true. </code> 
     */

    public org.osid.recipe.RecipeAdminSession getRecipeAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the recipe 
     *  administration service for the given cookbook. 
     *
     *  @param  cookbookId the <code> Id </code> of the <code> Cookbook 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RecipeAdminSession </code> 
     *  @throws org.osid.NotFoundException no cook book found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> cookbookId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRecipeAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecipeAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.recipe.RecipeAdminSession getRecipeAdminSessionForCookbook(org.osid.id.Id cookbookId, 
                                                                               org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the recipe 
     *  notification service. 
     *
     *  @param  recipeReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> RecipeNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> recipeReceiver </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRecipeNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecipeNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.recipe.RecipeNotificationSession getRecipeNotificationSession(org.osid.recipe.RecipeReceiver recipeReceiver, 
                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the recipe 
     *  notification service for the given cookbook. 
     *
     *  @param  recipeReceiver the notification callback 
     *  @param  cookbookId the <code> Id </code> of the <code> Cookbook 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RecipeNotificationSession </code> 
     *  @throws org.osid.NotFoundException no cook book found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> recipeReceiver, 
     *          cookbookId </code> or <code> proxy </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRecipeNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecipeNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.recipe.RecipeNotificationSession getRecipeNotificationSessionForCookbook(org.osid.recipe.RecipeReceiver recipeReceiver, 
                                                                                             org.osid.id.Id cookbookId, 
                                                                                             org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup recipe/cook book 
     *  mappings. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RecipeCookbookSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRecipeCookbook() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecipeCookbook() </code> is <code> true. </code> 
     */

    public org.osid.recipe.RecipeCookbookSession getRecipeCookbookSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning recipes 
     *  to cook books. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RecipeCookbookAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRecipeCookbookAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecipeCookbookAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.recipe.RecipeCookbookAssignmentSession getRecipeCookbookAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage recipe smart cook books. 
     *
     *  @param  cookbookId the <code> Id </code> of the <code> Cookbook 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RecipeSmartCookbookSession </code> 
     *  @throws org.osid.NotFoundException no cook book found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> cookbookId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRecipeSmartCookbook() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecipeSmartCookbook() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.recipe.RecipeSmartCookbookSession getRecipeSmartCookbookSession(org.osid.id.Id cookbookId, 
                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the direction 
     *  lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> DirectionLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDirectionLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDirectionLookup() </code> is <code> true. </code> 
     */

    public org.osid.recipe.DirectionLookupSession getDirectionLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the direction 
     *  lookup service for the given cookbook. 
     *
     *  @param  cookbookId the <code> Id </code> of the cook book 
     *  @param  proxy a proxy 
     *  @return a <code> DirectionLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Cookbook </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> cookbookId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDirectionLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDirectionLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.recipe.DirectionLookupSession getDirectionLookupSessionForCookbook(org.osid.id.Id cookbookId, 
                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the direction 
     *  query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> DirectionQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDirectionQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDirectionQuery() </code> is <code> true. </code> 
     */

    public org.osid.recipe.DirectionQuerySession getDirectionQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the direction 
     *  query service for the given cookbook. 
     *
     *  @param  cookbookId the <code> Id </code> of the <code> Cookbook 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> DirectionQuerySession </code> 
     *  @throws org.osid.NotFoundException no cook book found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> cookbookId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDirectionQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDirectionQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.recipe.DirectionQuerySession getDirectionQuerySessionForCookbook(org.osid.id.Id cookbookId, 
                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the direction 
     *  search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> DirectionSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDirectionSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDirectionSearch() </code> is <code> true. </code> 
     */

    public org.osid.recipe.DirectionSearchSession getDirectionSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the direction 
     *  search service for the given cookbook. 
     *
     *  @param  cookbookId the <code> Id </code> of the <code> Cookbook 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> DirectionSearchSession </code> 
     *  @throws org.osid.NotFoundException no cook book found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> cookbookId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDirectionSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDirectionSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.recipe.DirectionSearchSession getDirectionSearchSessionForCookbook(org.osid.id.Id cookbookId, 
                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the direction 
     *  administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> DirectionAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDirectionAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDirectionAdmin() </code> is <code> true. </code> 
     */

    public org.osid.recipe.DirectionAdminSession getDirectionAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the direction 
     *  administration service for the given cookbook. 
     *
     *  @param  cookbookId the <code> Id </code> of the <code> Cookbook 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> DirectionAdminSession </code> 
     *  @throws org.osid.NotFoundException no cook book found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> cookbookId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDirectionAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDirectionAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.recipe.DirectionAdminSession getDirectionAdminSessionForCookbook(org.osid.id.Id cookbookId, 
                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the direction 
     *  notification service. 
     *
     *  @param  directionReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> DirectionNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> directionReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDirectionNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDirectionNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.recipe.DirectionNotificationSession getDirectionNotificationSession(org.osid.recipe.DirectionReceiver directionReceiver, 
                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the direction 
     *  notification service for the given cookbook. 
     *
     *  @param  directionReceiver the notification callback 
     *  @param  cookbookId the <code> Id </code> of the <code> Cookbook 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> DirectionNotificationSession </code> 
     *  @throws org.osid.NotFoundException no cook book found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> directionReceiver, 
     *          </code> <code> cookbookId </code> or <code> proxy </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDirectionNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDirectionNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.recipe.DirectionNotificationSession getDirectionNotificationSessionForCookbook(org.osid.recipe.DirectionReceiver directionReceiver, 
                                                                                                   org.osid.id.Id cookbookId, 
                                                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup direction/cook book 
     *  ingredients. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> DirectionCookbookSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDirectionCookbook() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDirectionCookbook() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.recipe.DirectionCookbookSession getDirectionCookbookSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning mappings 
     *  to cook books. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> DirectionCookbookAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDirectionCookbookAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDirectionCookbookAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.recipe.DirectionCookbookAssignmentSession getDirectionCookbookAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage locatin smart cook 
     *  books. 
     *
     *  @param  cookbookId the <code> Id </code> of the <code> Cookbook 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> DirectionSmartCookbookSession </code> 
     *  @throws org.osid.NotFoundException no cook book found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> cookbookId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDirectionSmartCookbook() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDirectionSmartCookbook() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.recipe.DirectionSmartCookbookSession getDirectionSmartCookbookSession(org.osid.id.Id cookbookId, 
                                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the procedure 
     *  lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ProcedureLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProcedureLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcedureLookup() </code> is <code> true. </code> 
     */

    public org.osid.recipe.ProcedureLookupSession getProcedureLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the procedure 
     *  lookup service for the given cookbook. 
     *
     *  @param  cookbookId the <code> Id </code> of the <code> Cookbook 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ProcedureLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Cookbook </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> cookbookId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProcedureLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcedureLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.recipe.ProcedureLookupSession getProcedureLookupSessionForCookbook(org.osid.id.Id cookbookId, 
                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the procedure 
     *  query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ProcedureQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProcedureQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcedureQuery() </code> is <code> true. </code> 
     */

    public org.osid.recipe.ProcedureQuerySession getProcedureQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the procedure 
     *  query service for the given cookbook. 
     *
     *  @param  cookbookId the <code> Id </code> of the <code> Cookbook 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ProcedureQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Cookbook </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> cookbookId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProcedureQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcedureQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.recipe.ProcedureQuerySession getProcedureQuerySessionForCookbook(org.osid.id.Id cookbookId, 
                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the procedure 
     *  search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ProcedureSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProcedureSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcedureSearch() </code> is <code> true. </code> 
     */

    public org.osid.recipe.ProcedureSearchSession getProcedureSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the procedure 
     *  search service for the given cookbook. 
     *
     *  @param  cookbookId the <code> Id </code> of the <code> Cookbook 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ProcedureSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Cookbook </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> cookbookId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProcedureSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcedureSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.recipe.ProcedureSearchSession getProcedureSearchSessionForCookbook(org.osid.id.Id cookbookId, 
                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the procedure 
     *  administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ProcedureAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProcedureAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcedureAdmin() </code> is <code> true. </code> 
     */

    public org.osid.recipe.ProcedureAdminSession getProcedureAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the procedure 
     *  administration service for the given cookbook. 
     *
     *  @param  cookbookId the <code> Id </code> of the <code> Cookbook 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ProcedureAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Cookbook </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> cookbookId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProcedureAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcedureAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.recipe.ProcedureAdminSession getProcedureAdminSessionForCookbook(org.osid.id.Id cookbookId, 
                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the procedure 
     *  notification service. 
     *
     *  @param  procedureReceiver the receiver 
     *  @param  proxy a proxy 
     *  @return a <code> ProcedureNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> procedureReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProcedureNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcedureNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.recipe.ProcedureNotificationSession getProcedureNotificationSession(org.osid.recipe.ProcedureReceiver procedureReceiver, 
                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the procedure 
     *  notification service for the given cookbook. 
     *
     *  @param  procedureReceiver the receiver 
     *  @param  cookbookId the <code> Id </code> of the <code> Cookbook 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ProcedureNotificationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Cookbook </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> procedureReceiver, 
     *          cookbookId, </code> or <code> proxy </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProcedureNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcedureNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.recipe.ProcedureNotificationSession getProcedureNotificationSessionForCookbook(org.osid.recipe.ProcedureReceiver procedureReceiver, 
                                                                                                   org.osid.id.Id cookbookId, 
                                                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving procedure to cook book mappings. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ProcedureCookbookSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProcedureCookbook() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcedureCookbook() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.recipe.ProcedureCookbookSession getProcedureCookbookSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning procedure to cook book mappings. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ProcedureCookbookAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProcedureCookbookAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcedureCookbookAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.recipe.ProcedureCookbookAssignmentSession getProcedureCookbookAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session associated with the procedure smart cook book for the 
     *  given cookbook. 
     *
     *  @param  cookbookId the <code> Id </code> of the procedure book 
     *  @param  proxy a proxy 
     *  @return a <code> ProcedureSmartCookbookSession </code> 
     *  @throws org.osid.NotFoundException <code> procedureBookId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> procedureBookId </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProcedureSmartCookbook() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcedureSmartCookbook() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.recipe.ProcedureSmartCookbookSession getProcedureSmartCookbookSession(org.osid.id.Id cookbookId, 
                                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the cook book 
     *  lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> CookbookLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCookbookLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCookbookLookup() </code> is <code> true. </code> 
     */

    public org.osid.recipe.CookbookLookupSession getCookbookLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the cook book 
     *  query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> CookbookQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsCookbookQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCookbookQuery() </code> is <code> true. </code> 
     */

    public org.osid.recipe.CookbookQuerySession getCookbookQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the cook book 
     *  search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> CookbookSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCookbookSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCookbookSearch() </code> is <code> true. </code> 
     */

    public org.osid.recipe.CookbookSearchSession getCookbookSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the cook book 
     *  administrative service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> CookbookAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsCookbookAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCookbookAdmin() </code> is <code> true. </code> 
     */

    public org.osid.recipe.CookbookAdminSession getCookbookAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the cook book 
     *  notification service. 
     *
     *  @param  cookbookReceiver the receiver 
     *  @param  proxy a proxy 
     *  @return a <code> CookbookNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> cookbookReceiver </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCookbookNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCookbookNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.recipe.CookbookNotificationSession getCookbookNotificationSession(org.osid.recipe.CookbookReceiver cookbookReceiver, 
                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the cook book 
     *  hierarchy service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> CookbookHierarchySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCookbookHierarchy() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCookbookHierarchy() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.recipe.CookbookHierarchySession getCookbookHierarchySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the cook book 
     *  hierarchy design service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> CookbookHierarchyDesignSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCookbookHierarchyDesign() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCookbookHierarchyDesign() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.recipe.CookbookHierarchyDesignSession getCookbookHierarchyDesignSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> RecipieBatchProxyManager </code> . 
     *
     *  @return a <code> RecipeBatchProxyManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRecipeBatch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecipeBatch() </code> is <code> true. </code> 
     */

    public org.osid.recipe.batch.RecipeBatchProxyManager getRecipeBatchProxyManager()
        throws org.osid.OperationFailedException;
}
