//
// org.osid.recipe.RecipeSearchSession
//
//     The OSID Java specification for org.osid.recipe.RecipeSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.recipe;


/**
 *  <p>This session provides methods for searching among <code> Recipe </code> 
 *  objects. The search query is constructed using the <code> RecipeQuery. 
 *  </code> </p> 
 *  
 *  <p> <code> getRecipesByQuery() </code> is the basic search method and 
 *  returns a list of <code> Recipes. </code> A more advanced search may be 
 *  performed with <code> getRecipesBySearch(). </code> It accepts a <code> 
 *  RecipeSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getRecipesBySearch() </code> returns a <code> 
 *  RecipeSearchResults </code> that can be used to access the resulting 
 *  <code> RecipeList </code> or be used to perform a search within the result 
 *  set through <code> RecipeSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated cook book view: searches include recipes in cook books 
 *      of which this cook book is an ancestor in the cook book hierarchy 
 *      </li> 
 *      <li> isolated cook book view: searches are restricted to recipes in 
 *      this cook books </li> 
 *  </ul>
 *  
 *  
 *  <p> Recipes may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> RecipeQuery. </code> 
 *  </p>
 */

public interface RecipeSearchSession
    extends org.osid.recipe.RecipeQuerySession {


    /**
     *  Gets a recipe search. 
     *
     *  @return the recipe search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.RecipeSearch getRecipeSearch();


    /**
     *  Gets a recipe search order. The <code> RecipeSearchOrder </code> is 
     *  supplied to a <code> RecipeSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the recipe search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.RecipeSearchOrder getRecipeSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  recipeQuery the recipe query 
     *  @param  recipeSearch the recipe search 
     *  @return the recipe search results 
     *  @throws org.osid.NullArgumentException <code> recipeQuery </code> or 
     *          <code> recipeSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> recipeQuery </code> or 
     *          <code> recipeSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.RecipeSearchResults getRecipesBySearch(org.osid.recipe.RecipeQuery recipeQuery, 
                                                                  org.osid.recipe.RecipeSearch recipeSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a recipe query from an inspector. The inspector is available from 
     *  a <code> RecipeSearchResults. </code> 
     *
     *  @param  recipeQueryInspector a recipe query inspector 
     *  @return the recipe query 
     *  @throws org.osid.NullArgumentException <code> recipeQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> recipeQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.RecipeQuery getRecipeQueryFromInspector(org.osid.recipe.RecipeQueryInspector recipeQueryInspector);
}
