//
// org.osid.recipe.RecipeSmartCookbookSession
//
//     The OSID Java specification for org.osid.recipe.RecipeSmartCookbookSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.recipe;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. A <code> RecipeQuery </code> can be retrieved from this session 
 *  and mapped to this <code> Cookbook </code> to create a virtual collection 
 *  of <code> Recipes. </code> The recipes may be sequenced using the <code> 
 *  RecipeSearchOrder </code> from this session. </p> 
 *  
 *  <p> This <code> Cookbook </code> has a default query that matches any 
 *  recipe and a default search order that specifies no sequencing. The 
 *  queries may be examined using a <code> RecipeQueryInspector. </code> The 
 *  query may be modified by converting the inspector back to a <code> 
 *  RecipeQuery. </code> </p>
 */

public interface RecipeSmartCookbookSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Cookbook </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Cookbook Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCookbookId();


    /**
     *  Gets the <code> Cookbook </code> associated with this session. 
     *
     *  @return the cookbook 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.Cookbook getCookbook()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart cook books. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart cook book management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartCookbooks();


    /**
     *  Gets a recipe query. 
     *
     *  @return the recipe query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.RecipeQuery getRecipeQuery();


    /**
     *  Gets a recipe search order. 
     *
     *  @return the recipe search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.RecipeSearchOrder getRecipeSearchOrder();


    /**
     *  Applies a recipe query to this cookbook. 
     *
     *  @param  recipeQuery the recipe query 
     *  @throws org.osid.NullArgumentException <code> recipeQuery </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> recipeQuery </code> not 
     *          of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyRecipeQuery(org.osid.recipe.RecipeQuery recipeQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a recipe query inspector for this cookbook. 
     *
     *  @return the recipe query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.RecipeQueryInspector inspectRecipeQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a recipe search order to this cookbook. 
     *
     *  @param  recipeSearchOrder the recipe search order 
     *  @throws org.osid.NullArgumentException <code> recipeSearchOrder 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> recipeSearchOrder </code> 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyRecipeSequencing(org.osid.recipe.RecipeSearchOrder recipeSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a recipe query from an inspector. 
     *
     *  @param  recipeQueryInspector a recipe query inspector 
     *  @return the recipe query 
     *  @throws org.osid.NullArgumentException <code> recipeQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> recipeQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.RecipeQuery getRecipeQueryFromInspector(org.osid.recipe.RecipeQueryInspector recipeQueryInspector);
}
