//
// org.osid.recipe.batch.RecipeBatchAdminSession
//
//     The OSID Java specification for org.osid.recipe.batch.RecipeBatchAdminSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.recipe.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Recipes </code> in 
 *  bulk. The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Recipe, </code> a <code> RecipeForm </code> is requested using <code> 
 *  getRecipeFormsForCreate() </code> specifying the desired record <code> 
 *  Types </code> or none if no record <code> Types </code> are needed. Each 
 *  of the returned <code> RecipeForms </code> will indicate that it is to be 
 *  used with a create operation and can be used to examine metdata or 
 *  validate data prior to creation. Once a <code> RecipeForm </code> is 
 *  submiited to a create operation, it cannot be reused with another create 
 *  operation unless the first operation was unsuccessful. Each <code> 
 *  RecipeForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> RecipeForms </code> returned from <code> 
 *  getRecipeFormsForCreate() </code> may be linked to the originating request 
 *  through the peer <code> Ids </code> of the <code> RecipeForm. </code> In 
 *  the case where there may be duplicates, any <code> RecipeForm </code> of 
 *  the same peer <code> Ids </code> may be used for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> RecipeForms </code> are submitted for create, a 
 *  <code> CreateResponse </code> is returned for each <code> RecipeForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire create operation are returned from <code> createRecipes(), 
 *  </code> errors specific to an individual <code> RecipeForm </code> are 
 *  indicated in the corresponding <code> CreateResponse. </code> <code> 
 *  CreateResponses </code> may be linked to the originating <code> RecipeForm 
 *  </code> through the <code> RecipeForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> RecipeForms </code> are requested to the <code> 
 *  Recipe </code> <code> Id </code> that is to be updated using <code> 
 *  getRecipeFormsForUpdate() </code> where the reference <code> Id </code> in 
 *  the <code> RecipeForm </code> may be used to link the request. Similarly, 
 *  the <code> RecipeForm </code> has metadata about the data that can be 
 *  updated and it can perform validation before submitting the update. The 
 *  <code> RecipeForm </code> can only be used once for a successful update 
 *  and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> RecipeForms </code> are submitted for update, 
 *  an <code> UpdateResponse </code> is returned for each <code> RecipeForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire update operation are returned from <code> updateRecipes(), 
 *  </code> errors specific to an individual <code> RecipeForm </code> are 
 *  indicated in the corresponding <code> UpdateResponse. </code> <code> 
 *  UpdateResponses </code> may be linked to the originating <code> RecipeForm 
 *  </code> through the <code> RecipeForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> Recipes </code> in bulk. To unmap 
 *  a <code> Recipe </code> from the current <code> Cookbook, </code> the 
 *  <code> RecipeCookbookAssignmentSession </code> should be used. These 
 *  delete operations attempt to remove the <code> Recipe </code> itself thus 
 *  removing it from all known <code> Cookbook </code> catalogs. Bulk delete 
 *  operations return the results in <code> DeleteResponses. </code> </p>
 */

public interface RecipeBatchAdminSession
    extends org.osid.recipe.RecipeAdminSession {


    /**
     *  Gets the recipe forms for creating a bunch of new recipes. 
     *
     *  @param  number the number of forms to retrieve 
     *  @param  recipeRecordTypes array of recipe record types to be included 
     *          in each create operation or an empty list if none 
     *  @return the recipe forms 
     *  @throws org.osid.NullArgumentException <code> recipeRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.batch.RecipeBatchFormList getRecipeFormsForCreate(long number, 
                                                                             org.osid.type.Type[] recipeRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Recipes. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  recipeForms the recipe forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> recipeForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createRecipes(org.osid.recipe.batch.RecipeBatchFormList recipeForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the recipe forms for updating an existing set of recipes. A new 
     *  recipe form should be requested for each update transaction. 
     *
     *  @param  recipeIds the <code> Ids </code> of the <code> Recipe </code> 
     *  @return the recipe form 
     *  @throws org.osid.NotFoundException a <code> recipeId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> recipeIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.batch.RecipeBatchFormList getRecipeFormsForUpdate(org.osid.id.IdList recipeIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing recipes. This method returns an error if the entire 
     *  operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  recipeForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> recipeForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateRecipes(org.osid.recipe.batch.RecipeBatchFormList recipeForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Recipes </code> in this <code> Cookbook </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllRecipes()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes recipes for the given <code> Ids. </code> 
     *
     *  @param  recipeIds the <code> Ids </code> of the recipes to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> recipeIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteRecipes(org.osid.id.IdList recipeIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Recipe </code> for the purpose 
     *  of creating compatibility. The primary <code> Id </code> of the <code> 
     *  Recipe </code> is determined by the provider. The new <code> Id 
     *  </code> is an alias to the primary <code> Id. </code> If the alias is 
     *  a pointer to another recipe, it is reassigned to the given recipe 
     *  <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasRecipes(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
