//
// org.osid.recognition.AcademyQuery
//
//     The OSID Java specification for org.osid.recognition.AcademyQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.recognition;


/**
 *  <p>This is the query for searching for academies. Each method specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface AcademyQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Sets the conferral <code> Id </code> for this query to match 
     *  conferrals assigned to academies. 
     *
     *  @param  conferralId a conferral <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> conferralId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchConferralId(org.osid.id.Id conferralId, boolean match);


    /**
     *  Clears the conferral <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearConferralIdTerms();


    /**
     *  Tests if a conferral query is available. 
     *
     *  @return <code> true </code> if a conferral query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsConferralQuery();


    /**
     *  Gets the query for an conferral. 
     *
     *  @return the conferral query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsConferralQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsConferralQuery() </code> is <code> true. </code> 
     */

    public org.osid.recognition.ConferralQuery getConferralQuery();


    /**
     *  Matches academies with any conferral. 
     *
     *  @param  match <code> true </code> to match academies with any 
     *          conferral, <code> false </code> to match academies with no 
     *          conferrals 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyConferral(boolean match);


    /**
     *  Clears the conferral terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearConferralTerms();


    /**
     *  Sets the award <code> Id </code> for this query to match conferrals 
     *  assigned to awards. 
     *
     *  @param  awardId an award <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> awardId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAwardId(org.osid.id.Id awardId, boolean match);


    /**
     *  Clears the award <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAwardIdTerms();


    /**
     *  Tests if an <code> AwardQuery </code> is available. 
     *
     *  @return <code> true </code> if an award query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAwardQuery();


    /**
     *  Gets the query for an award query. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the award query 
     *  @throws org.osid.UnimplementedException <code> supportsAwardQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAwardQuery() </code> is <code> true. </code> 
     */

    public org.osid.recognition.AwardQuery getAwardQuery();


    /**
     *  Matches academies with any award. 
     *
     *  @param  match <code> true </code> to match academies with any award, 
     *          <code> false </code> to match academies with no awards 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAward(boolean match);


    /**
     *  Clears the award terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAwardTerms();


    /**
     *  Sets a convocaton <code> Id. </code> 
     *
     *  @param  convocationId a convocaton <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> convocationId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchConvocationId(org.osid.id.Id convocationId, boolean match);


    /**
     *  Clears the convocaton <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearConvocationIdTerms();


    /**
     *  Tests if a <code> ConvocationQuery </code> is available. 
     *
     *  @return <code> true </code> if a convocaton query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsConvocationQuery();


    /**
     *  Gets the query for a convocaton query. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the convocaton query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsConvocationQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsConvocationQuery() </code> is <code> true. </code> 
     */

    public org.osid.recognition.ConvocationQuery getConvocationQuery();


    /**
     *  Matches any convocaton. 
     *
     *  @param  match <code> true </code> to match academies with any 
     *          convocation, <code> false </code> to match academies with no 
     *          convocations 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyConvocation(boolean match);


    /**
     *  Clears the convocaton terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearConvocationTerms();


    /**
     *  Sets the academy <code> Id </code> for this query to match academies 
     *  that have the specified academy as an ancestor. 
     *
     *  @param  academyId an academy <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> academyId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorAcademyId(org.osid.id.Id academyId, boolean match);


    /**
     *  Clears the ancestor academy <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorAcademyIdTerms();


    /**
     *  Tests if an <code> AcademyQuery </code> is available. 
     *
     *  @return <code> true </code> if an academy query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorAcademyQuery();


    /**
     *  Gets the query for an academy. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the academy query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorAcademyQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorAcademyQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.recognition.AcademyQuery getAncestorAcademyQuery();


    /**
     *  Matches academies with any ancestor. 
     *
     *  @param  match <code> true </code> to match academies with any 
     *          ancestor, <code> false </code> to match root academies 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorAcademy(boolean match);


    /**
     *  Clears the ancestor academy terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorAcademyTerms();


    /**
     *  Sets the academy <code> Id </code> for this query to match academies 
     *  that have the specified academy as a descendant. 
     *
     *  @param  academyId an academy <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> academyId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantAcademyId(org.osid.id.Id academyId, 
                                         boolean match);


    /**
     *  Clears the descendant academy <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantAcademyIdTerms();


    /**
     *  Tests if an <code> AcademyQuery </code> is available. 
     *
     *  @return <code> true </code> if an academy query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantAcademyQuery();


    /**
     *  Gets the query for an academy. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the academy query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantAcademyQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantAcademyQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.recognition.AcademyQuery getDescendantAcademyQuery();


    /**
     *  Matches academies with any descendant. 
     *
     *  @param  match <code> true </code> to match academies with any 
     *          descendant, <code> false </code> to match leaf academies 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantAcademy(boolean match);


    /**
     *  Clears the descendant academy terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantAcademyTerms();


    /**
     *  Gets the query record corresponding to the given <code> Academy 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested boolean <code> OR </code> term. 
     *
     *  @param  academyRecordType an academy record type 
     *  @return the academy query record 
     *  @throws org.osid.NullArgumentException <code> academyRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(academyRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.records.AcademyQueryRecord getAcademyQueryRecord(org.osid.type.Type academyRecordType)
        throws org.osid.OperationFailedException;
}
