//
// org.osid.recognition.AcademyQueryInspector
//
//     The OSID Java specification for org.osid.recognition.AcademyQueryInspector.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.recognition;


/**
 *  <p>This is the query inspector for searching for academies. Each method 
 *  specifies an <code> AND </code> term while multiple invocations of the 
 *  same method produce a nested <code> OR. </code> </p>
 */

public interface AcademyQueryInspector
    extends org.osid.OsidCatalogQueryInspector {


    /**
     *  Gets the conferral <code> Id </code> terms. 
     *
     *  @return the conferral <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getConferralIdTerms();


    /**
     *  Gets the conferral terms. 
     *
     *  @return the conferral terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.ConferralQueryInspector[] getConferralTerms();


    /**
     *  Gets the award <code> Id </code> terms. 
     *
     *  @return the award <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getAwardIdTerms();


    /**
     *  Gets the award terms. 
     *
     *  @return the award terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.AwardQueryInspector[] getAwardTerms();


    /**
     *  Gets the convocation <code> Id </code> terms. 
     *
     *  @return the convocation <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getConvocationIdTerms();


    /**
     *  Gets the convocation terms. 
     *
     *  @return the convocation terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.ConvocationQueryInspector[] getConvocationTerms();


    /**
     *  Gets the ancestor academy <code> Id </code> terms. 
     *
     *  @return the ancestor academy <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getAncestorAcademyIdTerms();


    /**
     *  Gets the ancestor academy terms. 
     *
     *  @return the ancestor academy terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.AcademyQueryInspector[] getAncestorAcademyTerms();


    /**
     *  Gets the descendant academy <code> Id </code> terms. 
     *
     *  @return the descendant academy <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getDescendantAcademyIdTerms();


    /**
     *  Gets the descendant academy terms. 
     *
     *  @return the descendant academy terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.AcademyQueryInspector[] getDescendantAcademyTerms();


    /**
     *  Gets the query inspector record corresponding to the given <code> 
     *  Academy </code> record <code> Type. </code> 
     *
     *  @param  academyRecordType an academy record type 
     *  @return the academy query inspector record 
     *  @throws org.osid.NullArgumentException <code> academyRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(academyRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.records.AcademyQueryInspectorRecord getAcademyQueryInspectorRecord(org.osid.type.Type academyRecordType)
        throws org.osid.OperationFailedException;
}
