//
// org.osid.recognition.AcademySearchSession
//
//     The OSID Java specification for org.osid.recognition.AcademySearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.recognition;


/**
 *  <p>This session provides methods for searching <code> Academy </code> 
 *  objects. The search query is constructed using the <code> AcademyQuery. 
 *  </code> The academy record <code> Type </code> also specifies the record 
 *  for the academy query. </p> 
 *  
 *  <p> <code> getAcademiesByQuery() </code> is the basic search method and 
 *  returns a list of <code> Academy </code> elements. A more advanced search 
 *  may be performed with <code> getAcademiesBySearch(). </code> It accepts an 
 *  <code> AcademySearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getAcademiesBySearch() </code> returns an <code> 
 *  AcademySearchResults </code> that can be used to access the resulting 
 *  <code> AcademyList </code> or be used to perform a search within the 
 *  result set through <code> AcademySearch. </code> </p> 
 *  
 *  <p> Academies may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> AcademyQuery. </code> 
 *  The returns in this session may not be cast directly to these interfaces. 
 *  </p>
 */

public interface AcademySearchSession
    extends org.osid.recognition.AcademyQuerySession {


    /**
     *  Gets an academy search. 
     *
     *  @return the academy search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.AcademySearch getAcademySearch();


    /**
     *  Gets an academy search order. The <code> AcademySearchOrder </code> is 
     *  supplied to an <code> AcademySearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the academy search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.AcademySearchOrder getAcademySearchOrder();


    /**
     *  Gets the search results matching the given search. 
     *
     *  @param  academyQuery the academy query 
     *  @param  academySearch the academy search 
     *  @return the academy search results 
     *  @throws org.osid.NullArgumentException <code> academyQuery </code> or 
     *          <code> academies earch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> academyQuery </code> or 
     *          <code> academies earch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.AcademySearchResults getAcademiesBySearch(org.osid.recognition.AcademyQuery academyQuery, 
                                                                          org.osid.recognition.AcademySearch academySearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an academy query from an inspector. The inspector is available 
     *  from an <code> AcademySearchResults. </code> 
     *
     *  @param  academyQueryInspector an academy query inspector 
     *  @return the academy query 
     *  @throws org.osid.NullArgumentException <code> academyQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> academyQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.AcademyQuery getAcademyQueryFromInspector(org.osid.recognition.AcademyQueryInspector academyQueryInspector);
}
