//
// org.osid.recognition.AwardAcademyAssignmentSession
//
//     The OSID Java specification for org.osid.recognition.AwardAcademyAssignmentSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.recognition;


/**
 *  <p>This session provides methods to re-assign <code> Awards </code> to 
 *  <code> Academies. </code> An <code> Award </code> may map to multiple 
 *  <code> Academies </code> and removing the last reference to an <code> 
 *  Award </code> is the equivalent of deleting it. Each <code> Academy 
 *  </code> may have its own authorizations governing who is allowed to 
 *  operate on it. </p> 
 *  
 *  <p> Adding a reference of an <code> Award </code> to another <code> 
 *  Academy </code> is not a copy operation (eg: does not change its <code> Id 
 *  </code> ). </p>
 */

public interface AwardAcademyAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter award/academy mappings. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignAwards();


    /**
     *  Tests if this user can alter award/academy mappings. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @param  academyId the <code> Id </code> of the <code> Academy </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> academyId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignAwardsToAcademy(org.osid.id.Id academyId);


    /**
     *  Gets a list of academies including and under the given academy node in 
     *  which any award can be assigned. 
     *
     *  @param  academyId the <code> Id </code> of the <code> Academy </code> 
     *  @return list of assignable academy <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> academyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableAcademyIds(org.osid.id.Id academyId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of academies including and under the given academy node in 
     *  which a specific award can be assigned. 
     *
     *  @param  academyId the <code> Id </code> of the <code> Academy </code> 
     *  @param  awardId the <code> Id </code> of the <code> Award </code> 
     *  @return list of assignable academy <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> academyId </code> or 
     *          <code> awardId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableAcademyIdsForAward(org.osid.id.Id academyId, 
                                                              org.osid.id.Id awardId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> Award </code> to an <code> Academy. </code> 
     *
     *  @param  awardId the <code> Id </code> of the <code> Award </code> 
     *  @param  academyId the <code> Id </code> of the <code> Academy </code> 
     *  @throws org.osid.AlreadyExistsException <code> awardId </code> is 
     *          already assigned to <code> academyId </code> 
     *  @throws org.osid.NotFoundException <code> awardId </code> or <code> 
     *          academyId </code> not found 
     *  @throws org.osid.NullArgumentException <code> awardId </code> or 
     *          <code> academyId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignAwardToAcademy(org.osid.id.Id awardId, 
                                     org.osid.id.Id academyId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes an <code> Award </code> from an <code> Academy. </code> 
     *
     *  @param  awardId the <code> Id </code> of the <code> Award </code> 
     *  @param  academyId the <code> Id </code> of the <code> Academy </code> 
     *  @throws org.osid.NotFoundException <code> awardId </code> or <code> 
     *          academyId </code> not found or <code> awardId </code> not 
     *          asigned to <code> academyId </code> 
     *  @throws org.osid.NullArgumentException <code> awardId </code> or 
     *          <code> academyId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignAwardFromAcademy(org.osid.id.Id awardId, 
                                         org.osid.id.Id academyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
