//
// org.osid.recognition.Conferral
//
//     The OSID Java specification for org.osid.recognition.Conferral.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.recognition;


/**
 *  <p>A <code> Conferral </code> represents an <code> Award </code> conferred 
 *  to a <code> Recipient </code> for something (reference). Often, an award 
 *  is conferred for a body of work. The body of work may be represented by 
 *  another <code> OsidObject, </code> such as an <code> Asset </code> or an 
 *  <code> Assessment </code> may be related using an <code> Id. </code> The 
 *  recipiens is the <code> Resource </code> to whom the award is addressed is 
 *  often the producer or creator of the work. In some instances, the <code> 
 *  Resource </code> and the reference may be one in the same. </p>
 */

public interface Conferral
    extends org.osid.OsidRelationship {


    /**
     *  Gets the <code> Id </code> of the subscriber's award. 
     *
     *  @return the subscriber <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAwardId();


    /**
     *  Gets the subscriber's award. 
     *
     *  @return the subscriber's award. 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.Award getAward()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of the recipient. 
     *
     *  @return the resource <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getRecipientId();


    /**
     *  Gets the recipient (e.g. Samuel Goldwyn). 
     *
     *  @return the resource 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getRecipient()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if the was conferred for a reference object. 
     *
     *  @return <code> true </code> if a reference exists, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasReference();


    /**
     *  Gets the <code> Id </code> of the reference (e.g. "Best Years of Our 
     *  Lives"). 
     *
     *  @return the reference <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> hasReference() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getReferenceId();


    /**
     *  Tests if the award was conferred as part of a convocation. 
     *
     *  @return <code> true </code> if a convocation exists, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasConvocation();


    /**
     *  Gets the <code> Id </code> of the convocation. 
     *
     *  @return the convocation <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> hasConvocation() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getConvocationId();


    /**
     *  Gets the convocation (e.g. 19th Academy Awards for the time period 
     *  1946). 
     *
     *  @return the convocation 
     *  @throws org.osid.IllegalStateException <code> hasConvocation() </code> 
     *          is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.Convocation getConvocation()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the conferral record corresponding to the given <code> Conferral 
     *  </code> record <code> Type. </code> This method is used to retrieve an 
     *  object implementing the requested record. The <code> 
     *  conferralRecordType </code> may be the <code> Type </code> returned in 
     *  <code> getRecordTypes() </code> or any of its parents in a <code> Type 
     *  </code> hierarchy where <code> hasRecordType(conferralRecordType) 
     *  </code> is <code> true </code> . 
     *
     *  @param  conferralRecordType the type of conferral record to retrieve 
     *  @return the conferral record 
     *  @throws org.osid.NullArgumentException <code> conferralRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(conferralRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.records.ConferralRecord getConferralRecord(org.osid.type.Type conferralRecordType)
        throws org.osid.OperationFailedException;
}
