//
// org.osid.recognition.ConferralLookupSession
//
//     The OSID Java specification for org.osid.recognition.ConferralLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.recognition;


/**
 *  <p>This session defines methods for retrieving conferrals. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated academy view: All conferral methods in this session 
 *      operate, retrieve and pertain to conferrals defined explicitly in the 
 *      current academy. Using an isolated view is useful for managing 
 *      conferrals with the <code> ConferralAdminSession. </code> </li> 
 *      <li> federated academy view: All conferral lookup methods in this 
 *      session operate, retrieve and pertain to all conferrals defined in 
 *      this academy and any other academies implicitly available in this 
 *      academy through academy inheritence. </li> 
 *      <li> effective conferral view: All conferral lookup methods return 
 *      conferrals where the current dates falls in between the effective 
 *      dates inclusive. </li> 
 *      <li> any effective conferral view: Conferrals of any effective date 
 *      are returned. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedAcademyView() </code> and <code> 
 *  useIsolatedAcademyView() </code> behave as a radio group and one should be 
 *  selected before invoking any lookup methods. </p>
 */

public interface ConferralLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Academy </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Academy Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAcademyId();


    /**
     *  Gets the <code> Academy </code> associated with this session. 
     *
     *  @return the academy 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.Academy getAcademy()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can lookup conferrals. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer these operations. 
     *
     *  @return <code> false </code> if conferral lookup methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupConferrals();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeConferralView();


    /**
     *  A complete view of the <code> Conferral </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryConferralView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include conferrals in academies which are children of this academy in 
     *  the academy hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedAcademyView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this academy only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedAcademyView();


    /**
     *  Only conferrals whose effective dates are current are returned by 
     *  methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useEffectiveConferralView();


    /**
     *  All conferrals of any effective dates are returned by all methods in 
     *  this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyEffectiveConferralView();


    /**
     *  Gets the <code> Conferral </code> specified by its <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Conferral </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> Conferral </code> and retained for compatibility. 
     *  
     *  In effective mode, conferrals are returned that are currently 
     *  effective. In any effective mode, effective conferrals and those 
     *  currently expired are returned. 
     *
     *  @param  conferralId the <code> Id </code> of the <code> Conferral 
     *          </code> to retrieve 
     *  @return the returned <code> Conferral </code> 
     *  @throws org.osid.NotFoundException no <code> Conferral </code> found 
     *          with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> conferralId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.Conferral getConferral(org.osid.id.Id conferralId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ConferralList </code> corresponding to the given <code> 
     *  IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  conferrals specified in the <code> Id </code> list, in the order of 
     *  the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible conferrals may be omitted from the list and may present 
     *  the elements in any order including returning a unique set. 
     *  
     *  In effective mode, conferrals are returned that are currently 
     *  effective. In any effective mode, effective conferrals and those 
     *  currently expired are returned. 
     *
     *  @param  conferralIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Conferral list </code> 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> conferralIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.ConferralList getConferralsByIds(org.osid.id.IdList conferralIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ConferralList </code> corresponding to the given 
     *  conferral genus <code> Type </code> which does not include conferrals 
     *  of genus types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  conferrals or an error results. Otherwise, the returned list may 
     *  contain only those conferrals that are accessible through this 
     *  session. 
     *  
     *  In effective mode, conferrals are returned that are currently 
     *  effective. In any effective mode, effective conferrals and those 
     *  currently expired are returned. 
     *
     *  @param  conferralGenusType a conferral genus type 
     *  @return the returned <code> Conferral </code> list 
     *  @throws org.osid.NullArgumentException <code> conferralGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.ConferralList getConferralsByGenusType(org.osid.type.Type conferralGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ConferralList </code> corresponding to the given 
     *  conferral genus <code> Type </code> and include any additional 
     *  conferrals with genus types derived from the specified <code> Type. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  conferrals or an error results. Otherwise, the returned list may 
     *  contain only those conferrals that are accessible through this 
     *  session. 
     *  
     *  In effective mode, conferrals are returned that are currently 
     *  effective. In any effective mode, effective conferrals and those 
     *  currently expired are returned. 
     *
     *  @param  conferralGenusType a conferral genus type 
     *  @return the returned <code> Conferral </code> list 
     *  @throws org.osid.NullArgumentException <code> conferralGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.ConferralList getConferralsByParentGenusType(org.osid.type.Type conferralGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ConferralList </code> containing the given conferral 
     *  record <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  conferrals or an error results. Otherwise, the returned list may 
     *  contain only those conferrals that are accessible through this 
     *  session. 
     *  
     *  In effective mode, conferrals are returned that are currently 
     *  effective. In any effective mode, effective conferrals and those 
     *  currently expired are returned. 
     *
     *  @param  conferralRecordType a conferral record type 
     *  @return the returned <code> Conferral </code> list 
     *  @throws org.osid.NullArgumentException <code> conferralRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.ConferralList getConferralsByRecordType(org.osid.type.Type conferralRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of conferrals effective during the entire given date range 
     *  inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known conferrals or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  conferrals that are accessible through this session. 
     *  
     *  In effective mode, conferrals are returned that are currently 
     *  effective. In any effective mode, effective conferrals and those 
     *  currently expired are returned. 
     *
     *  @param  from the starting date 
     *  @param  to the ending date 
     *  @return the returned <code> ConferralList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.ConferralList getConferralsOnDate(org.osid.calendaring.DateTime from, 
                                                                  org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of conferrals corresponding to a resource <code> Id. 
     *  </code> 
     *  
     *  In plenary mode, the returned list contains all known conferrals or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  conferrals that are accessible through this session. 
     *  
     *  In effective mode, conferrals are returned that are currently 
     *  effective. In any effective mode, effective conferrals and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId the <code> Id </code> of the resource 
     *  @return the returned <code> ConferralList </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.ConferralList getConferralsForRecipient(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all conferrals corresponding to a resource <code> Id 
     *  </code> and effective during the entire given date range inclusive but 
     *  not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known conferrals or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  conferrals that are accessible through this session. 
     *  
     *  In effective mode, conferrals are returned that are currently 
     *  effective. In any effective mode, effective conferrals and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  from from date 
     *  @param  to to date 
     *  @return the returned <code> ConferralList </code> 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, from, 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.ConferralList getConferralsForRecipientOnDate(org.osid.id.Id resourceId, 
                                                                              org.osid.calendaring.DateTime from, 
                                                                              org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all conferrals corresponding to an award <code> Id. 
     *  </code> 
     *  
     *  In plenary mode, the returned list contains all known conferrals or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  conferrals that are accessible through this session. 
     *  
     *  In effective mode, conferrals are returned that are currently 
     *  effective. In any effective mode, effective conferrals and those 
     *  currently expired are returned. 
     *
     *  @param  awardId the <code> Id </code> of the award 
     *  @return the returned <code> ConferralList </code> 
     *  @throws org.osid.NullArgumentException <code> awardId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.ConferralList getConferralsForAward(org.osid.id.Id awardId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all conferrals corresponding to an award <code> Id 
     *  </code> and effective during the entire given date range inclusive but 
     *  not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known conferrals or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  conferrals that are accessible through this session. 
     *  
     *  In effective mode, conferrals are returned that are currently 
     *  effective. In any effective mode, effective conferrals and those 
     *  currently expired are returned. 
     *
     *  @param  awardId an award <code> Id </code> 
     *  @param  from from date 
     *  @param  to to date 
     *  @return the returned <code> ConferralList </code> 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> awardId, from, </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.ConferralList getConferralsForAwardOnDate(org.osid.id.Id awardId, 
                                                                          org.osid.calendaring.DateTime from, 
                                                                          org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of conferralsfor the given resource and award. 
     *  
     *  In plenary mode, the returned list contains all known conferrals or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  conferrals that are accessible through this session. 
     *  
     *  In effective mode, conferrals are returned that are currently 
     *  effective. In any effective mode, effective conferrals and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId the <code> Id </code> of the resource 
     *  @param  awardid the Id of the award 
     *  @return the returned <code> ConferralList </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> or 
     *          <code> awardId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.ConferralList getConferralsForRecipientAndAward(org.osid.id.Id resourceId, 
                                                                                org.osid.id.Id awardid)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all conferrals for the given resource, award, <code> 
     *  </code> and effective during the entire given date range inclusive but 
     *  not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known conferrals or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  conferrals that are accessible through this session. 
     *  
     *  In effective mode, conferrals are returned that are currently 
     *  effective. In any effective mode, effective conferrals and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  awardid an award <code> Id </code> 
     *  @param  from from date 
     *  @param  to to date 
     *  @return the returned <code> ConferralList </code> 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, awardid, 
     *          from, </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.ConferralList getConferralsForRecipientAndAwardOnDate(org.osid.id.Id resourceId, 
                                                                                      org.osid.id.Id awardid, 
                                                                                      org.osid.calendaring.DateTime from, 
                                                                                      org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of conferrals corresponding to a reference <code> Id. 
     *  </code> 
     *  
     *  In plenary mode, the returned list contains all known conferrals or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  conferrals that are accessible through this session. 
     *  
     *  In effective mode, conferrals are returned that are currently 
     *  effective. In any effective mode, effective conferrals and those 
     *  currently expired are returned. 
     *
     *  @param  referenceId the <code> Id </code> of the reference 
     *  @return the returned <code> ConferralList </code> 
     *  @throws org.osid.NullArgumentException <code> referenceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.ConferralList getConferralsByReference(org.osid.id.Id referenceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all conferrals corresponding to a reference <code> Id 
     *  </code> and effective during the entire given date range inclusive but 
     *  not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known conferrals or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  conferrals that are accessible through this session. 
     *  
     *  In effective mode, conferrals are returned that are currently 
     *  effective. In any effective mode, effective conferrals and those 
     *  currently expired are returned. 
     *
     *  @param  referenceId a reference <code> Id </code> 
     *  @param  from from date 
     *  @param  to to date 
     *  @return the returned <code> ConferralList </code> 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> referenceId, from 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.ConferralList getConferralsByReferenceOnDate(org.osid.id.Id referenceId, 
                                                                             org.osid.calendaring.DateTime from, 
                                                                             org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all conferrals corresponding to a convocation <code> 
     *  Id. </code> 
     *  
     *  In plenary mode, the returned list contains all known conferrals or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  conferrals that are accessible through this session. 
     *  
     *  In effective mode, conferrals are returned that are currently 
     *  effective. In any effective mode, effective conferrals and those 
     *  currently expired are returned. 
     *
     *  @param  convocationId the <code> Id </code> of the convocation 
     *  @return the returned <code> ConferralList </code> 
     *  @throws org.osid.NullArgumentException <code> convocationId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.ConferralList getConferralsByConvocation(org.osid.id.Id convocationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all conferrals corresponding to a convocation <code> Id 
     *  </code> and effective during the entire given date range inclusive but 
     *  not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known conferrals or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  conferrals that are accessible through this session. 
     *  
     *  In effective mode, conferrals are returned that are currently 
     *  effective. In any effective mode, effective conferrals and those 
     *  currently expired are returned. 
     *
     *  @param  convocationId a convocation <code> Id </code> 
     *  @param  from from date 
     *  @param  to to date 
     *  @return the returned <code> ConferralList </code> 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> convocationId, from, 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.ConferralList getConferralsByConvocationOnDate(org.osid.id.Id convocationId, 
                                                                               org.osid.calendaring.DateTime from, 
                                                                               org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all conferrals. 
     *  
     *  In plenary mode, the returned list contains all known conferrals or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  conferrals that are accessible through this session. 
     *  
     *  In effective mode, conferrals are returned that are currently 
     *  effective. In any effective mode, effective conferrals and those 
     *  currently expired are returned. 
     *
     *  @return a list of conferrals 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.ConferralList getConferrals()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
