//
// org.osid.recognition.ConvocationAdminSession
//
//     The OSID Java specification for org.osid.recognition.ConvocationAdminSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.recognition;


/**
 *  <p>This session creates, updates, and deletes <code> Convocations. </code> 
 *  The data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Convocation, </code> a <code> ConvocationForm </code> is requested using 
 *  <code> getConvocationFormForCreate() </code> specifying the desired record 
 *  <code> Types </code> or none if no record <code> Types </code> are needed. 
 *  The returned <code> ConvocationForm </code> will indicate that it is to be 
 *  used with a create operation and can be used to examine metdata or 
 *  validate data prior to creation. Once the <code> ConvocationForm </code> 
 *  is submiited to a create operation, it cannot be reused with another 
 *  create operation unless the first operation was unsuccessful. Each <code> 
 *  ConvocationForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> ConvocationForms </code> are requested to the 
 *  <code> Convocation </code> <code> Id </code> that is to be updated using 
 *  <code> getConvocationFormForUpdate(). </code> Similarly, the <code> 
 *  ConvocationForm </code> has metadata about the data that can be updated 
 *  and it can perform validation before submitting the update. The <code> 
 *  ConvocationForm </code> can only be used once for a successful update and 
 *  cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Convocations. </code> To unmap a 
 *  <code> Convocation </code> from the current <code> Academy, </code> the 
 *  <code> ConvocationAcademyAssignmentSession </code> should be used. These 
 *  delete operations attempt to remove the <code> Convocation </code> itself 
 *  thus removing it from all known <code> Academy </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface ConvocationAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Academy </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Academy Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAcademyId();


    /**
     *  Gets the <code> Academy </code> associated with this session. 
     *
     *  @return the academy 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.Academy getAcademy()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create convocations. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known creating a <code> Convocation </code> will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer create operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Convocation </code> creation is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateConvocations();


    /**
     *  Tests if this user can create a single <code> Convocation </code> 
     *  using the desired record types. While <code> 
     *  RecognitionManager.getConvocationRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> Convocation. </code> 
     *  Providing an empty array tests if a <code> Convocation </code> can be 
     *  created with no records. 
     *
     *  @param  convocationRecordTypes array of convocation record types 
     *  @return <code> true </code> if <code> Convocation </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> convocationRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateConvocationWithRecordTypes(org.osid.type.Type[] convocationRecordTypes);


    /**
     *  Gets the convocation form for creating new convocations. A new form 
     *  should be requested for each create transaction. 
     *
     *  @param  convocationRecordTypes array of convocation record types 
     *  @return the convocation form 
     *  @throws org.osid.NullArgumentException <code> convocationRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.ConvocationForm getConvocationFormForCreate(org.osid.type.Type[] convocationRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Convocation. </code> 
     *
     *  @param  convocationForm the form for this <code> Convocation </code> 
     *  @return the new <code> Convocation </code> 
     *  @throws org.osid.IllegalStateException <code> convocationForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> convocationForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> convocationForm </code> 
     *          did not originate from <code> getConvocationFormForCreate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.Convocation createConvocation(org.osid.recognition.ConvocationForm convocationForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update convocations. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known updating a <code> Convocation </code> will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer update operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Convocation </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateConvocations();


    /**
     *  Gets the convocation form for updating an existing convocation. A new 
     *  convocation form should be requested for each update transaction. 
     *
     *  @param  convocationId the <code> Id </code> of the <code> Convocation 
     *          </code> 
     *  @return the convocation form 
     *  @throws org.osid.NotFoundException <code> convocationId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> convocationId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.ConvocationForm getConvocationFormForUpdate(org.osid.id.Id convocationId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing convocation. 
     *
     *  @param  convocationForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException the form contains an invalid 
     *          value 
     *  @throws org.osid.InvalidArgumentException <code> convocationForm 
     *          </code> already used in an update transaction 
     *  @throws org.osid.NullArgumentException <code> convocationForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> convocationForm </code> 
     *          did not originate from <code> getConvocationFormForUpdate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateConvocation(org.osid.recognition.ConvocationForm convocationForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete convocations. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known deleting an <code> Convocation </code> will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer delete operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Convocation </code> deletion is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteConvocations();


    /**
     *  Deletes a <code> Convocation. </code> 
     *
     *  @param  convocationId the <code> Id </code> of the <code> Convocation 
     *          </code> to remove 
     *  @throws org.osid.NotFoundException <code> convocationId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> convocationId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteConvocation(org.osid.id.Id convocationId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Convocations. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Convocation </code> aliasing is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageConvocationAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Convocation </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Convocation </code> is determined by the provider. The new 
     *  <code> Id </code> performs as an alias to the primary <code> Id. 
     *  </code> If the alias is a pointer to another convocation, it is 
     *  reassigned to the given convocation <code> Id. </code> 
     *
     *  @param  convocationId the <code> Id </code> of a <code> Convocation 
     *          </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> convocationId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> convocationId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasConvocation(org.osid.id.Id convocationId, 
                                 org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage convocations. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known changing an alias will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer alias operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Convocation </code> management 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageConvocations();


    /**
     *  Adds an award to a convocation. 
     *
     *  @param  awardId the <code> Id </code> of an <code> Award </code> 
     *  @param  convocationId the <code> Id </code> of a <code> Convocation 
     *          </code> 
     *  @throws org.osid.AlreadyExistsException <code> awardId </code> is 
     *          already part of <code> convocationId </code> 
     *  @throws org.osid.NotFoundException <code> awardId </code> or <code> 
     *          convocationId </code> not found 
     *  @throws org.osid.NullArgumentException <code> awardid </code> or 
     *          <code> convocationId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void addAward(org.osid.id.Id awardId, org.osid.id.Id convocationId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  removes an award from a convocation. 
     *
     *  @param  awardId the <code> Id </code> of an <code> Award </code> 
     *  @param  convocationId the <code> Id </code> of a <code> Convocation 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> awardId </code> or <code> 
     *          convocationId </code> not found or <code> awardid </code> not 
     *          part of <code> convocationId </code> 
     *  @throws org.osid.NullArgumentException <code> awardid </code> or 
     *          <code> convocationId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeAward(org.osid.id.Id awardId, 
                            org.osid.id.Id convocationId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
