//
// org.osid.recognition.RecognitionManager
//
//     The OSID Java specification for org.osid.recognition.RecognitionManager.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.recognition;


/**
 *  <p>The recognition manager provides access to conferral sessions and 
 *  provides interoperability tests for various aspects of this service. The 
 *  sessions included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> ConferralLookupSession: </code> a session to lookup 
 *      conferrals </li> 
 *      <li> <code> ConferralQuerySession: </code> a session to query 
 *      conferrals </li> 
 *      <li> <code> ConferralSearchSession: </code> a session to search 
 *      conferrals </li> 
 *      <li> <code> ConferralAdminSession: </code> a session to manage 
 *      conferrals </li> 
 *      <li> <code> ConferralNotificationSession: </code> a session to 
 *      subscribe to notifications of conferral changes </li> 
 *      <li> <code> ConferralAcademySession: </code> a session to lookup 
 *      conferral academy mappings </li> 
 *      <li> <code> ConferralAcademyAssignmentSession: </code> a session to 
 *      manage conferral academy mappings </li> 
 *      <li> <code> ConferralSmartAcademySession: </code> a session to manage 
 *      smart academies of conferrals </li> 
 *      <li> <code> AwardLookupSession: </code> a session to retrieve awards 
 *      </li> 
 *      <li> <code> AwardQuerySession: </code> a session to query awards </li> 
 *      <li> <code> AwardSearchSession: </code> a session to search for awards 
 *      </li> 
 *      <li> <code> AwardAdminSession: </code> a session to create, update and 
 *      delete awards </li> 
 *      <li> <code> AwardNotificationSession: </code> a session to receive 
 *      notifications for changes in awards </li> 
 *      <li> <code> AwardAcademySession: </code> a session to lookup award 
 *      academy mappings </li> 
 *      <li> <code> AwardAcademyAssignmentSession: </code> a session to manage 
 *      award academy mappings </li> 
 *      <li> <code> AwardSmartAcademySession: </code> a session to manage 
 *      smart academies of awards </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> ConvocationSession </code> : a session to get available 
 *      convocations for a resource </li> 
 *      <li> <code> ConvocationLookupSession: </code> a session to lookup 
 *      convocations </li> 
 *      <li> <code> ConvocationQuerySession: </code> a session to query 
 *      convocations </li> 
 *      <li> <code> ConvocationSearchSession: </code> a session to search 
 *      convocations </li> 
 *      <li> <code> ConvocationAdminSession: </code> a session to manage 
 *      convocations </li> 
 *      <li> <code> ConvocationNotificationSession: </code> a session to 
 *      subscribe to notifications of convocation changes </li> 
 *      <li> <code> ConvocationAcademySession: </code> a session to lookup 
 *      convocation academy mappings </li> 
 *      <li> <code> ConvocationAcademyAssignmentSession: </code> a session to 
 *      manage convocation academy mappings </li> 
 *      <li> <code> ConvocationSmartAcademySession: </code> a session to 
 *      manage smart academies of convocations </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> AcademyLookupSession: </code> a session to retrieve 
 *      academies </li> 
 *      <li> <code> AcademyQuerySession: </code> a session to query academies 
 *      </li> 
 *      <li> <code> AcademySearchSession: </code> a session to search for 
 *      academies </li> 
 *      <li> <code> AcademyAdminSession: </code> a session to create, update 
 *      and delete academies </li> 
 *      <li> <code> AcademyNotificationSession: </code> a session to receive 
 *      notifications for changes in academies </li> 
 *      <li> <code> AcademyHierarchyTraversalSession: </code> a session to 
 *      traverse hierarchies of academies </li> 
 *      <li> <code> AcademyHierarchyDesignSession: </code> a session to manage 
 *      hierarchies of academies </li> 
 *  </ul>
 *  
 *  
 *  <p> The recognition manager also provides a profile for determing the 
 *  supported search types supported by this service. </p>
 */

public interface RecognitionManager
    extends org.osid.OsidManager,
            org.osid.recognition.RecognitionProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the conferral 
     *  lookup service. 
     *
     *  @return a <code> ConferralLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsConferralLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsConferralLookup() </code> is <code> true. </code> 
     */

    public org.osid.recognition.ConferralLookupSession getConferralLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the conferral 
     *  lookup service for the given academy. 
     *
     *  @param  academyId the <code> Id </code> of the <code> Academy </code> 
     *  @return a <code> ConferralLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Academy </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> academyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsConferralLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsConferralLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.recognition.ConferralLookupSession getConferralLookupSessionForAcademy(org.osid.id.Id academyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the conferral 
     *  query service. 
     *
     *  @return a <code> ConferralQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsConferralQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsConferralQuery() </code> is <code> true. </code> 
     */

    public org.osid.recognition.ConferralQuerySession getConferralQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the conferral 
     *  query service for the given academy. 
     *
     *  @param  academyId the <code> Id </code> of the <code> Academy </code> 
     *  @return a <code> ConferralQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Academy </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> academyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsConferralQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsConferralQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.recognition.ConferralQuerySession getConferralQuerySessionForAcademy(org.osid.id.Id academyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the conferral 
     *  search service. 
     *
     *  @return a <code> ConferralSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsConferralSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsConferralSearch() </code> is <code> true. </code> 
     */

    public org.osid.recognition.ConferralSearchSession getConferralSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the conferral 
     *  search service for the given academy. 
     *
     *  @param  academyId the <code> Id </code> of the <code> Academy </code> 
     *  @return a <code> ConferralSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Academy </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> academyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsConferralSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsConferralSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.recognition.ConferralSearchSession getConferralSearchSessionForAcademy(org.osid.id.Id academyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the conferral 
     *  administration service. 
     *
     *  @return a <code> ConferralAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsConferralAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsConferralAdmin() </code> is <code> true. </code> 
     */

    public org.osid.recognition.ConferralAdminSession getConferralAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the conferral 
     *  administration service for the given academy. 
     *
     *  @param  academyId the <code> Id </code> of the <code> Academy </code> 
     *  @return a <code> ConferralAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Academy </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> academyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsConferralAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsConferralAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.recognition.ConferralAdminSession getConferralAdminSessionForAcademy(org.osid.id.Id academyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the conferral 
     *  notification service. 
     *
     *  @param  conferralReceiver the receiver 
     *  @return a <code> ConferralNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> conferralReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsConferralNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsConferralNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.recognition.ConferralNotificationSession getConferralNotificationSession(org.osid.recognition.ConferralReceiver conferralReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the conferral 
     *  notification service for the given academy. 
     *
     *  @param  conferralReceiver the receiver 
     *  @param  academyId the <code> Id </code> of the <code> Academy </code> 
     *  @return a <code> ConferralNotificationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Academy </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> conferralReceiver 
     *          </code> or <code> academyId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsConferralNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsConferralNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.recognition.ConferralNotificationSession getConferralNotificationSessionForAcademy(org.osid.recognition.ConferralReceiver conferralReceiver, 
                                                                                                       org.osid.id.Id academyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving conferral to academy mappings. 
     *
     *  @return a <code> ConferralAcademySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsConferralAcademy() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsConferralAcademy() </code> is <code> true. </code> 
     */

    public org.osid.recognition.ConferralAcademySession getConferralAcademySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning conferral to academy mappings. 
     *
     *  @return a <code> ConferralAcademyAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsConferralAcademyAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsConferralAcademyAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.recognition.ConferralAcademyAssignmentSession getConferralAcademyAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session associated with the conferral smart academy for the 
     *  given academy. 
     *
     *  @param  academyId the <code> Id </code> of the academy 
     *  @return a <code> ConferralSmartAcademySession </code> 
     *  @throws org.osid.NotFoundException <code> conferralBookId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> conferralBookId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsConferralSmartAcademy() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsConferralSmartAcademy() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.recognition.ConferralSmartAcademySession getConferralSmartAcademySession(org.osid.id.Id academyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the award lookup 
     *  service. 
     *
     *  @return an <code> AwardLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAwardLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAwardLookup() </code> is <code> true. </code> 
     */

    public org.osid.recognition.AwardLookupSession getAwardLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the award lookup 
     *  service for the given academy. 
     *
     *  @param  academyId the <code> Id </code> of the <code> Academy </code> 
     *  @return an <code> AwardLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Academy </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> academyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAwardLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAwardLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.recognition.AwardLookupSession getAwardLookupSessionForAcademy(org.osid.id.Id academyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the award query 
     *  service. 
     *
     *  @return an <code> AwardQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAwardQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAwardQuery() </code> is <code> true. </code> 
     */

    public org.osid.recognition.AwardQuerySession getAwardQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the award query 
     *  service for the given academy. 
     *
     *  @param  academyId the <code> Id </code> of the <code> Academy </code> 
     *  @return an <code> AwardQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Academy </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> academyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAwardQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAwardQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.recognition.AwardQuerySession getAwardQuerySessionForAcademy(org.osid.id.Id academyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the award search 
     *  service. 
     *
     *  @return an <code> AwardSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAwardSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAwardSearch() </code> is <code> true. </code> 
     */

    public org.osid.recognition.AwardSearchSession getAwardSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the award search 
     *  service for the given academy. 
     *
     *  @param  academyId the <code> Id </code> of the <code> Academy </code> 
     *  @return an <code> AwardSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Academy </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> academyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAwardSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAwardSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.recognition.AwardSearchSession getAwardSearchSessionForAcademy(org.osid.id.Id academyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the award 
     *  administrative service. 
     *
     *  @return an <code> AwardAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAwardAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAwardAdmin() </code> is <code> true. </code> 
     */

    public org.osid.recognition.AwardAdminSession getAwardAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the award 
     *  administrative service for the given academy. 
     *
     *  @param  academyId the <code> Id </code> of the <code> Academy </code> 
     *  @return an <code> AwardAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Academy </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> academyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAwardAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAwardAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.recognition.AwardAdminSession getAwardAdminSessionForAcademy(org.osid.id.Id academyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the award 
     *  notification service. 
     *
     *  @param  awardReceiver the receiver 
     *  @return an <code> AwardNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> awardReceiver </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAwardNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAwardNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.recognition.AwardNotificationSession getAwardNotificationSession(org.osid.recognition.AwardReceiver awardReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the award 
     *  notification service for the given academy. 
     *
     *  @param  awardReceiver the receiver 
     *  @param  academyId the <code> Id </code> of the <code> Academy </code> 
     *  @return an <code> AwardNotificationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Academy </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> awardReceiver </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAwardNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAwardNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.recognition.AwardNotificationSession getAwardNotificationSessionForAcademy(org.osid.recognition.AwardReceiver awardReceiver, 
                                                                                               org.osid.id.Id academyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving award to academy mappings. 
     *
     *  @return an <code> AwardAcademySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAwardAcademy() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAwardAcademy() </code> is <code> true. </code> 
     */

    public org.osid.recognition.AwardAcademySession getAwardAcademySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning award to academy mappings. 
     *
     *  @return an <code> AwardAcademyAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAwardAcademyAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAwardAcademyAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.recognition.AwardAcademyAssignmentSession getAwardAcademyAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session associated with the award smart academy for the given 
     *  academy. 
     *
     *  @param  academyId the <code> Id </code> of the academy 
     *  @return an <code> AwardSmartAcademySession </code> 
     *  @throws org.osid.NotFoundException <code> academyId </code> not found 
     *  @throws org.osid.NullArgumentException <code> academyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAwardSmartAcademy() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAwardSmartAcademy() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.recognition.AwardSmartAcademySession getAwardSmartAcademySession(org.osid.id.Id academyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the convocation 
     *  lookup service. 
     *
     *  @return a <code> ConvocationLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsConvocationLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsConvocationLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.recognition.ConvocationLookupSession getConvocationLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the convocation 
     *  lookup service for the given academy. 
     *
     *  @param  academyId the <code> Id </code> of the <code> Academy </code> 
     *  @return a <code> ConvocationLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Academy </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> academyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsConvocationLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsConvocationLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.recognition.ConvocationLookupSession getConvocationLookupSessionForAcademy(org.osid.id.Id academyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the convocation 
     *  query service. 
     *
     *  @return a <code> ConvocationQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsConvocationQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsConvocationQuery() </code> is <code> true. </code> 
     */

    public org.osid.recognition.ConvocationQuerySession getConvocationQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the convocation 
     *  query service for the given academy. 
     *
     *  @param  academyId the <code> Id </code> of the <code> Academy </code> 
     *  @return a <code> ConvocationQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Academy </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> academyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsConvocationQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsConvocationQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.recognition.ConvocationQuerySession getConvocationQuerySessionForAcademy(org.osid.id.Id academyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the convocation 
     *  search service. 
     *
     *  @return a <code> ConvocationSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsConvocationSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsConvocationSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.recognition.ConvocationSearchSession getConvocationSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the convocation 
     *  search service for the given academy. 
     *
     *  @param  academyId the <code> Id </code> of the <code> Academy </code> 
     *  @return a <code> ConvocationSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Academy </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> academyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsConvocationSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsConvocationSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.recognition.ConvocationSearchSession getConvocationSearchSessionForAcademy(org.osid.id.Id academyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the convocation 
     *  administration service. 
     *
     *  @return a <code> ConvocationAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsConvocationAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsConvocationAdmin() </code> is <code> true. </code> 
     */

    public org.osid.recognition.ConvocationAdminSession getConvocationAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the convocation 
     *  administration service for the given academy. 
     *
     *  @param  academyId the <code> Id </code> of the <code> Academy </code> 
     *  @return a <code> ConvocationAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Academy </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> academyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsConvocationAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsConvocationAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.recognition.ConvocationAdminSession getConvocationAdminSessionForAcademy(org.osid.id.Id academyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the convocation 
     *  notification service. 
     *
     *  @param  convocationReceiver the receiver 
     *  @return a <code> ConvocationNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> convocationReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsConvocationNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsConvocationNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.recognition.ConvocationNotificationSession getConvocationNotificationSession(org.osid.recognition.ConvocationReceiver convocationReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the convocation 
     *  notification service for the given academy. 
     *
     *  @param  convocationReceiver the receiver 
     *  @param  academyId the <code> Id </code> of the <code> Academy </code> 
     *  @return a <code> ConvocationNotificationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Academy </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> convocationReceiver 
     *          </code> or <code> academyId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsConvocationNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsConvocationNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.recognition.ConvocationNotificationSession getConvocationNotificationSessionForAcademy(org.osid.recognition.ConvocationReceiver convocationReceiver, 
                                                                                                           org.osid.id.Id academyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving convocation to academy mappings. 
     *
     *  @return a <code> ConvocationAcademySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsConvocationAcademy() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsConvocationAcademy() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.recognition.ConvocationAcademySession getConvocationAcademySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning convocation to academy mappings. 
     *
     *  @return a <code> ConvocationAcademyAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsConvocationAcademyAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsConvocationAcademyAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.recognition.ConvocationAcademyAssignmentSession getConvocationAcademyAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session associated with the convocation smart academy for the 
     *  given academy. 
     *
     *  @param  academyId the <code> Id </code> of the convocation book 
     *  @return a <code> ConvocationSmartAcademySession </code> 
     *  @throws org.osid.NotFoundException <code> convocationBookId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> convocationBookId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsConvocationSmartAcademy() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsConvocationSmartAcademy() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.recognition.ConvocationSmartAcademySession getConvocationSmartAcademySession(org.osid.id.Id academyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the academy lookup 
     *  service. 
     *
     *  @return an <code> AcademyLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAcademyLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAcademyLookup() </code> is <code> true. </code> 
     */

    public org.osid.recognition.AcademyLookupSession getAcademyLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the academy query 
     *  service. 
     *
     *  @return an <code> AcademyQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAcademyQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAcademyQuery() </code> is <code> true. </code> 
     */

    public org.osid.recognition.AcademyQuerySession getAcademyQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the academy search 
     *  service. 
     *
     *  @return an <code> AcademySearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAcademySearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAcademySearch() </code> is <code> true. </code> 
     */

    public org.osid.recognition.AcademySearchSession getAcademySearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the academy 
     *  administrative service. 
     *
     *  @return an <code> AcademyAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAcademyAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAcademyAdmin() </code> is <code> true. </code> 
     */

    public org.osid.recognition.AcademyAdminSession getAcademyAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the academy 
     *  notification service. 
     *
     *  @param  academyReceiver the receiver 
     *  @return an <code> AcademyNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> academyReceiver </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAcademyNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAcademyNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.recognition.AcademyNotificationSession getAcademyNotificationSession(org.osid.recognition.AcademyReceiver academyReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the academy 
     *  hierarchy service. 
     *
     *  @return an <code> AcademyHierarchySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAcademyHierarchy() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAcademyHierarchy() </code> is <code> true. </code> 
     */

    public org.osid.recognition.AcademyHierarchySession getAcademyHierarchySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the academy 
     *  hierarchy design service. 
     *
     *  @return an <code> AcademyHierarchyDesignSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAcademyHierarchyDesign() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAcademyHierarchyDesign() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.recognition.AcademyHierarchyDesignSession getAcademyHierarchyDesignSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a <code> RecognitionBatchManager. </code> 
     *
     *  @return a <code> RecognitionBatchManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRecognitionBatch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecognitionBatch() </code> is <code> true. </code> 
     */

    public org.osid.recognition.batch.RecognitionBatchManager getRecognitionBatchManager()
        throws org.osid.OperationFailedException;
}
