//
// org.osid.recognition.batch.ConferralBatchAdminSession
//
//     The OSID Java specification for org.osid.recognition.batch.ConferralBatchAdminSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.recognition.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Conferrals </code> in 
 *  bulk. The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Conferral, </code> a <code> ConferralForm </code> is requested using 
 *  <code> getConferralFormsForCreate() </code> specifying the desired award, 
 *  recipient, and record <code> Types </code> or none if no record <code> 
 *  Types </code> are needed. Each of the returned <code> ConferralForms 
 *  </code> will indicate that it is to be used with a create operation and 
 *  can be used to examine metdata or validate data prior to creation. Once a 
 *  <code> ConferralForm </code> is submiited to a create operation, it cannot 
 *  be reused with another create operation unless the first operation was 
 *  unsuccessful. Each <code> ConferralForm </code> corresponds to an 
 *  attempted transaction. </p> 
 *  
 *  <p> The <code> ConferralForms </code> returned from <code> 
 *  getConferralFormsForCreate() </code> may be linked to the originating 
 *  request through the peer <code> Ids </code> of the <code> ConferralForm. 
 *  </code> In the case where there may be duplicates, any <code> 
 *  ConferralForm </code> of the same peer <code> Ids </code> may be used for 
 *  a create operation. </p> 
 *  
 *  <p> Once a batch of <code> ConferralForms </code> are submitted for 
 *  create, a <code> CreateResponse </code> is returned for each <code> 
 *  ConferralForm, </code> although the ordering is not defined. Only errors 
 *  that pertain to the entire create operation are returned from <code> 
 *  createConferrals(), </code> errors specific to an individual <code> 
 *  ConferralForm </code> are indicated in the corresponding <code> 
 *  CreateResponse. </code> <code> CreateResponses </code> may be linked to 
 *  the originating <code> ConferralForm </code> through the <code> 
 *  ConferralForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> ConferralForms </code> are requested to the <code> 
 *  Conferral </code> <code> Id </code> that is to be updated using <code> 
 *  getConferralFormsForUpdate() </code> where the reference <code> Id </code> 
 *  in the <code> ConferralForm </code> may be used to link the request. 
 *  Similarly, the <code> ConferralForm </code> has metadata about the data 
 *  that can be updated and it can perform validation before submitting the 
 *  update. The <code> ConferralForm </code> can only be used once for a 
 *  successful update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> ConferralForms </code> are submitted for 
 *  update, an <code> UpdateResponse </code> is returned for each <code> 
 *  ConferralForm, </code> although the ordering is not defined. Only errors 
 *  that pertain to the entire update operation are returned from <code> 
 *  updateConferrals(), </code> errors specific to an individual <code> 
 *  ConferralForm </code> are indicated in the corresponding <code> 
 *  UpdateResponse. </code> <code> UpdateResponses </code> may be linked to 
 *  the originating <code> ConferralForm </code> through the <code> 
 *  ConferralForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> Conferrals </code> in bulk. To 
 *  unmap a <code> Conferral </code> from the current <code> Academy, </code> 
 *  the <code> ConferralAcademyAssignmentSession </code> should be used. These 
 *  delete operations attempt to remove the <code> Conferral </code> itself 
 *  thus removing it from all known <code> Academy </code> catalogs. Bulk 
 *  delete operations return the results in <code> DeleteResponses. </code> 
 *  </p>
 */

public interface ConferralBatchAdminSession
    extends org.osid.recognition.ConferralAdminSession {


    /**
     *  Gets the conferral forms for creating a bunch of new conferrals. A new 
     *  form is retuned for each supplied award and recipient. 
     *
     *  @param  peers a list of conferral peers 
     *  @param  conferralRecordTypes array of conferral record types to be 
     *          included in each create operation or an empty list if none 
     *  @return the conferral forms 
     *  @throws org.osid.NotFoundException an <code> awardId </code> or <code> 
     *          resourceId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> peers </code> or <code> 
     *          conferralRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.batch.ConferralBatchFormList getConferralFormsForCreate(org.osid.recognition.batch.ConferralPeerList peers, 
                                                                                        org.osid.type.Type[] conferralRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Conferrals. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  conferralForms the conferral forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> conferralForms </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createConferrals(org.osid.recognition.batch.ConferralBatchFormList conferralForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the conferral forms for updating an existing set of conferrals. A 
     *  new conferral form should be requested for each update transaction. 
     *
     *  @param  conferralIds the <code> Ids </code> of the <code> Conferral 
     *          </code> 
     *  @return the conferral form 
     *  @throws org.osid.NotFoundException a <code> conferralId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> conferralIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.batch.ConferralBatchFormList getConferralFormsForUpdate(org.osid.id.IdList conferralIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing conferrals. This method returns an error if the 
     *  entire operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  conferralForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> conferralForms </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateConferrals(org.osid.recognition.batch.ConferralBatchFormList conferralForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Conferrals </code> in this <code> Academy </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllConferrals()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes conferrals for the given <code> Ids. </code> 
     *
     *  @param  conferralIds the <code> Ids </code> of the conferrals to 
     *          delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> conferralIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteConferrals(org.osid.id.IdList conferralIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes conferrals for the given award. 
     *
     *  @param  awardId the <code> Id </code> of the award 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> awardId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteConferralsForAward(org.osid.id.Id awardId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes conferrals for the given recipient. 
     *
     *  @param  resourceId the <code> Id </code> of the resource 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteConferralsForRecipient(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes conferrals expired before the given date. 
     *
     *  @param  date a date 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteIneffectiveConferralsByDate(org.osid.calendaring.DateTime date)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Conferral </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Conferral </code> is determined by the provider. The new 
     *  <code> Id </code> is an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another conferral, it is reassigned to the given 
     *  conferral <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasConferrals(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
