//
// org.osid.relationship.RelationshipFamilyAssignmentSession
//
//     The OSID Java specification for org.osid.relationship.RelationshipFamilyAssignmentSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.relationship;


/**
 *  <p>This session provides methods to re-assign <code> Relationships </code> 
 *  to <code> Family </code> objects A <code> Relationship </code> may appear 
 *  in multiple <code> Family </code> objects and removing the last reference 
 *  to a <code> Relationship </code> is the equivalent of deleting it. Each 
 *  <code> Family </code> may have its own authorizations governing who is 
 *  allowed to operate on it. </p> 
 *  
 *  <p> Moving or adding a reference of a <code> Relationship </code> to 
 *  another <code> Family </code> is not a copy operation (eg: does not change 
 *  its <code> Id </code> ). </p>
 */

public interface RelationshipFamilyAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter relationship/family mappings. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignRelationships();


    /**
     *  Tests if this user can alter relationship/family mappings. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @param  familyId the <code> Id </code> of the <code> Family </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> familyId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignRelationshipsToFamily(org.osid.id.Id familyId);


    /**
     *  Gets a list of families including and under the given family node in 
     *  which any relationship can be assigned. 
     *
     *  @param  familyId the <code> Id </code> of the <code> Family </code> 
     *  @return list of assignable family <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> familyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableFamilyIds(org.osid.id.Id familyId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of families including and under the given family node in 
     *  which a specific relationship can be assigned. 
     *
     *  @param  familyId the <code> Id </code> of the <code> Family </code> 
     *  @param  relationshipId the <code> Id </code> of the <code> 
     *          Relationship </code> 
     *  @return list of assignable family <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> familyId </code> or 
     *          <code> relationshipId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableFamilyIdsForRelationship(org.osid.id.Id familyId, 
                                                                    org.osid.id.Id relationshipId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> Relationship </code> to a <code> Family. 
     *  </code> 
     *
     *  @param  relationshipId the <code> Id </code> of the <code> 
     *          Relationship </code> 
     *  @param  familyId the <code> Id </code> of the <code> Family </code> 
     *  @throws org.osid.AlreadyExistsException <code> relationshipId </code> 
     *          is already assigned to <code> familyId </code> 
     *  @throws org.osid.NotFoundException <code> relationshipId </code> or 
     *          <code> familyId </code> not found 
     *  @throws org.osid.NullArgumentException <code> relationshipId </code> 
     *          or <code> familyId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignRelationshipToFamily(org.osid.id.Id relationshipId, 
                                           org.osid.id.Id familyId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> Relationship </code> from a <code> Family. </code> 
     *
     *  @param  relationshipId the <code> Id </code> of the <code> 
     *          Relationship </code> 
     *  @param  familyId the <code> Id </code> of the <code> Family </code> 
     *  @throws org.osid.NotFoundException <code> relationshipId </code> or 
     *          <code> familyId </code> not found or <code> relationshipId 
     *          </code> not assigned to <code> familyId </code> 
     *  @throws org.osid.NullArgumentException <code> relationshipId </code> 
     *          or <code> familyId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignRelationshipFromFamily(org.osid.id.Id relationshipId, 
                                               org.osid.id.Id familyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Moves a <code> Relationship </code> from one <code> Family </code> to 
     *  another. Mappings to other <code> Families </code> are unaffected. 
     *
     *  @param  relationshipId the <code> Id </code> of the <code> 
     *          Relationship </code> 
     *  @param  fromFamilyId the <code> Id </code> of the current <code> 
     *          Family </code> 
     *  @param  toFamilyId the <code> Id </code> of the destination <code> 
     *          Family </code> 
     *  @throws org.osid.NotFoundException <code> relationshipId, 
     *          fromFamilyId, </code> or <code> toFamilyId </code> not found 
     *          or <code> relationshipId </code> not mapped to <code> 
     *          fromFamilyId </code> 
     *  @throws org.osid.NullArgumentException <code> relationshipId, 
     *          fromFamilyId, </code> or <code> toFamilyId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void reassignRelationshipToFamily(org.osid.id.Id relationshipId, 
                                             org.osid.id.Id fromFamilyId, 
                                             org.osid.id.Id toFamilyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
