//
// org.osid.relationship.RelationshipLookupSession
//
//     The OSID Java specification for org.osid.relationship.RelationshipLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.relationship;


/**
 *  <p>This session defines methods for retrieving relationships. A <code> 
 *  Relationship </code> is mapped to two OSID <code> Ids. </code> </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> federated family view: includes relationships in families which 
 *      are children of this family in the family hierarchy </li> 
 *      <li> isolated family view: restricts lookups to this family only </li> 
 *      <li> effective relationship view: Relationship methods return only 
 *      relationships currently in effect. </li> 
 *      <li> any effective relationship view: Relationship methods return both 
 *      effective and ineffective relationships. </li> 
 *  </ul>
 *  
 *  
 *  <p> Relationships may have an additional records indicated by their 
 *  respective record types. The record may not be accessed through a cast of 
 *  the <code> Relationship. </code> </p>
 */

public interface RelationshipLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Family </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Family Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFamilyId();


    /**
     *  Gets the <code> Family </code> associated with this session. 
     *
     *  @return the family 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.Family getFamily()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Relationship </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupRelationships();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeRelationshipView();


    /**
     *  A complete view of the <code> Relationship </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryRelationshipView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include relationships in families which are children of this family in 
     *  the family hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedFamilyView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this family only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedFamilyView();


    /**
     *  Only relationships whose effective dates are current are returned by 
     *  methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useEffectiveRelationshipView();


    /**
     *  All relationships of any effective dates are returned by all methods 
     *  in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyEffectiveRelationshipView();


    /**
     *  Gets the <code> Relationship </code> specified by its <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Relationship </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> Relationship </code> and retained for 
     *  compatibility. 
     *  
     *  In effective mode, relationships are returned that are currently 
     *  effective. In any effective mode, effective relationships and those 
     *  currently expired are returned. 
     *
     *  @param  relationshipId the <code> Id </code> of the <code> 
     *          Relationship </code> to retrieve 
     *  @return the returned <code> Relationship </code> 
     *  @throws org.osid.NotFoundException no <code> Relationship </code> 
     *          found with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> relationshipId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.Relationship getRelationship(org.osid.id.Id relationshipId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RelationshipList </code> corresponding to the given 
     *  <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  relationships specified in the <code> Id </code> list, in the order of 
     *  the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Relationships </code> may be omitted from the list 
     *  and may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In effective mode, relationships are returned that are currently 
     *  effective. In any effective mode, effective relationships and those 
     *  currently expired are returned. 
     *
     *  @param  relationshipIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Relationship list </code> 
     *  @throws org.osid.NotFoundException an <code> Id </code> was not found 
     *  @throws org.osid.NullArgumentException <code> relationshipIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.RelationshipList getRelationshipsByIds(org.osid.id.IdList relationshipIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RelationshipList </code> corresponding to the given 
     *  relationship genus <code> Type </code> which does not include 
     *  relationships of types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  relationships or an error results. Otherwise, the returned list may 
     *  contain only those relationships that are accessible through this 
     *  session. 
     *  
     *  In effective mode, relationships are returned that are currently 
     *  effective. In any effective mode, effective relationships and those 
     *  currently expired are returned. 
     *
     *  @param  relationshipGenusType a relationship genus type 
     *  @return the returned <code> Relationship list </code> 
     *  @throws org.osid.NullArgumentException <code> relationshipGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.RelationshipList getRelationshipsByGenusType(org.osid.type.Type relationshipGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RelationshipList </code> corresponding to the given 
     *  relationship genus <code> Type </code> and include any additional 
     *  relationships with genus types derived from the specified <code> Type. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  relationships or an error results. Otherwise, the returned list may 
     *  contain only those relationships that are accessible through this 
     *  session. 
     *  
     *  In effective mode, relationships are returned that are currently 
     *  effective. In any effective mode, effective relationships and those 
     *  currently expired are returned. 
     *
     *  @param  relationshipGenusType a relationship genus type 
     *  @return the returned <code> Relationship list </code> 
     *  @throws org.osid.NullArgumentException <code> relationshipGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.RelationshipList getRelationshipsByParentGenusType(org.osid.type.Type relationshipGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RelationshipList </code> containing the given 
     *  relationship record <code> Type. </code> 
     *  
     *  In plenary mode, the returned list contains all known relationships or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  relationships that are accessible through this session. 
     *  
     *  In effective mode, relationships are returned that are currently 
     *  effective. In any effective mode, effective relationships and those 
     *  currently expired are returned. 
     *
     *  @param  relationshipRecordType a relationship record type 
     *  @return the returned <code> RelationshipList </code> 
     *  @throws org.osid.NullArgumentException <code> relationshipRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.RelationshipList getRelationshipsByRecordType(org.osid.type.Type relationshipRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RelationshipList </code> effective during the entire 
     *  given date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all of the relationships 
     *  corresponding to date or an error results if a relationship is 
     *  inaccessible. Otherwise, inaccessible <code> Relationships </code> may 
     *  be omitted from the list. 
     *  
     *  In effective mode, relationships are returned that are currently 
     *  effective in addition to being effective during the given dates. In 
     *  any effective mode, effective relationships and those currently 
     *  expired are returned. 
     *
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the relationships 
     *  @throws org.osid.InvalidArgumentException <code> from is greater than 
     *          to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.RelationshipList getRelationshipsOnDate(org.osid.calendaring.DateTime from, 
                                                                         org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RelationshipList </code> corresponding to the given peer 
     *  <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  relationships corresponding to the given peer or an error results if a 
     *  relationship is inaccessible. Otherwise, inaccessible <code> 
     *  Relationships </code> may be omitted from the list and may present the 
     *  elements in any order including returning a unique set. 
     *  
     *  In effective mode, relationships are returned that are currently 
     *  effective. In any effective mode, effective relationships and those 
     *  currently expired are returned. 
     *
     *  @param  sourceId a peer <code> Id </code> 
     *  @return the relationships 
     *  @throws org.osid.NullArgumentException <code> sourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.RelationshipList getRelationshipsForSource(org.osid.id.Id sourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RelationshipList </code> corresponding to the given peer 
     *  <code> Id </code> and effective during the entire given date range 
     *  inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all of the relationships 
     *  corresponding to the given peer or an error results if a relationship 
     *  is inaccessible. Otherwise, inaccessible <code> Relationships </code> 
     *  may be omitted from the list. 
     *  
     *  In effective mode, relationships are returned that are currently 
     *  effective in addition to being effective during the given dates. In 
     *  any effective mode, effective relationships and those currently 
     *  expired are returned. 
     *
     *  @param  sourceId a peer <code> Id </code> 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the relationships 
     *  @throws org.osid.InvalidArgumentException <code> from is greater than 
     *          to </code> 
     *  @throws org.osid.NullArgumentException <code> sourceId, from </code> 
     *          ,or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.RelationshipList getRelationshipsForSourceOnDate(org.osid.id.Id sourceId, 
                                                                                  org.osid.calendaring.DateTime from, 
                                                                                  org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RelationshipList </code> corresponding to the given peer 
     *  <code> Id </code> and relationship genus <code> Type. Relationships 
     *  </code> of any genus derived from the given genus are returned. 
     *  
     *  In plenary mode, the returned list contains all of the relationships 
     *  corresponding to the given peer, including duplicates, or an error 
     *  results if a relationship is inaccessible. Otherwise, inaccessible 
     *  <code> Relationships </code> may be omitted from the list and may 
     *  present the elements in any order including returning a unique set. 
     *  
     *  In effective mode, relationships are returned that are currently 
     *  effective. In any effective mode, effective relationships and those 
     *  currently expired are returned. 
     *
     *  @param  sourceId a peer <code> Id </code> 
     *  @param  relationshipGenusType a relationship genus type 
     *  @return the relationships 
     *  @throws org.osid.NullArgumentException <code> sourceId </code> or 
     *          <code> relationshipGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.RelationshipList getRelationshipsByGenusTypeForSource(org.osid.id.Id sourceId, 
                                                                                       org.osid.type.Type relationshipGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RelationshipList </code> corresponding to the given peer 
     *  <code> Id </code> and relationship genus <code> Type </code> and 
     *  effective during the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all of the relationships 
     *  corresponding to the given peer or an error results if a relationship 
     *  is inaccessible. Otherwise, inaccessible <code> Relationships </code> 
     *  may be omitted from the list. 
     *  
     *  In effective mode, relationships are returned that are currently 
     *  effective in addition to being effective during the given dates. In 
     *  any effective mode, effective relationships and those currently 
     *  expired are returned. 
     *
     *  @param  sourceId a peer <code> Id </code> 
     *  @param  relationshipGenusType a relationship genus type 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the relationships 
     *  @throws org.osid.InvalidArgumentException <code> from is greater than 
     *          to </code> 
     *  @throws org.osid.NullArgumentException <code> sourceId, 
     *          relationshipGenusType, from </code> or <code> to </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.RelationshipList getRelationshipsByGenusTypeForSourceOnDate(org.osid.id.Id sourceId, 
                                                                                             org.osid.type.Type relationshipGenusType, 
                                                                                             org.osid.calendaring.DateTime from, 
                                                                                             org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RelationshipList </code> corresponding to the given peer 
     *  <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  relationships corresponding to the given peer or an error results if a 
     *  relationship is inaccessible. Otherwise, inaccessible <code> 
     *  Relationships </code> may be omitted from the list and may present the 
     *  elements in any order including returning a unique set. 
     *  
     *  In effective mode, relationships are returned that are currently 
     *  effective. In any effective mode, effective relationships and those 
     *  currently expired are returned. 
     *
     *  @param  destinationId a peer <code> Id </code> 
     *  @return the relationships 
     *  @throws org.osid.NullArgumentException <code> destinationId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.RelationshipList getRelationshipsForDestination(org.osid.id.Id destinationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RelationshipList </code> corresponding to the given peer 
     *  <code> Id </code> with a starting effective date in the given range 
     *  inclusive. 
     *  
     *  In plenary mode, the returned list contains all of the relationships 
     *  corresponding to the given peer or an error results if a relationship 
     *  is inaccessible. Otherwise, inaccessible <code> Relationships </code> 
     *  may be omitted from the list. 
     *  
     *  In effective mode, relationships are returned that are currently 
     *  effective. In any effective mode, effective relationships and those 
     *  currently expired are returned. 
     *
     *  @param  destinationId a peer <code> Id </code> 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the relationships 
     *  @throws org.osid.InvalidArgumentException <code> from is greater than 
     *          to </code> 
     *  @throws org.osid.NullArgumentException <code> destinationId, from 
     *          </code> ,or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.RelationshipList getRelationshipsForDestinationOnDate(org.osid.id.Id destinationId, 
                                                                                       org.osid.calendaring.DateTime from, 
                                                                                       org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RelationshipList </code> corresponding to the given peer 
     *  <code> Id </code> and relationship genus <code> Type. Relationships 
     *  </code> of any genus derived from the given genus are returned. 
     *  
     *  In plenary mode, the returned list contains all of the relationships 
     *  corresponding to the given peer, including duplicates, or an error 
     *  results if a relationship is inaccessible. Otherwise, inaccessible 
     *  <code> Relationships </code> may be omitted from the list and may 
     *  present the elements in any order including returning a unique set. 
     *  
     *  In effective mode, relationships are returned that are currently 
     *  effective. In any effective mode, effective relationships and those 
     *  currently expired are returned. 
     *
     *  @param  destinationId a peer <code> Id </code> 
     *  @param  relationshipGenusType a relationship genus type 
     *  @return the relationships 
     *  @throws org.osid.NullArgumentException <code> destinationId </code> or 
     *          <code> relationshipGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.RelationshipList getRelationshipsByGenusTypeForDestination(org.osid.id.Id destinationId, 
                                                                                            org.osid.type.Type relationshipGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RelationshipList </code> corresponding to the given peer 
     *  <code> Id </code> and relationship genus <code> Type </code> and 
     *  effective during the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all of the relationships 
     *  corresponding to the given peer or an error results if a relationship 
     *  is inaccessible. Otherwise, inaccessible <code> Relationships </code> 
     *  may be omitted from the list. 
     *  
     *  In effective mode, relationships are returned that are currently 
     *  effective in addition to being effective during the given dates. In 
     *  any effective mode, effective relationships and those currently 
     *  expired are returned. 
     *
     *  @param  destinationId a peer <code> Id </code> 
     *  @param  relationshipGenusType a relationship genus type 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the relationships 
     *  @throws org.osid.InvalidArgumentException <code> from is greater than 
     *          to </code> 
     *  @throws org.osid.NullArgumentException <code> destinationId, 
     *          relationshipGenusType, from </code> or <code> to </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.RelationshipList getRelationshipsByGenusTypeForDestinationOnDate(org.osid.id.Id destinationId, 
                                                                                                  org.osid.type.Type relationshipGenusType, 
                                                                                                  org.osid.calendaring.DateTime from, 
                                                                                                  org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RelationshipList </code> corresponding to the given peer 
     *  <code> Ids. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  relationships corresponding to the given peer or an error results if a 
     *  relationship is inaccessible. Otherwise, inaccessible <code> 
     *  Relationships </code> may be omitted from the list. 
     *  
     *  In effective mode, relationships are returned that are currently 
     *  effective. In any effective mode, effective relationships and those 
     *  currently expired are returned. 
     *
     *  @param  sourceId a peer <code> Id </code> 
     *  @param  destinationId a related peer <code> Id </code> 
     *  @return the relationships 
     *  @throws org.osid.NullArgumentException <code> sourceId </code> or 
     *          <code> destinationId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.RelationshipList getRelationshipsForPeers(org.osid.id.Id sourceId, 
                                                                           org.osid.id.Id destinationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RelationshipList </code> corresponding to the given peer 
     *  <code> Ids </code> and effective during the entire given date range 
     *  inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all of the relationships 
     *  corresponding to the given peer set or an error results if a 
     *  relationship is inaccessible. Otherwise, inaccessible <code> 
     *  Relationships </code> may be omitted from the list. 
     *  
     *  In effective mode, relationships are returned that are currently 
     *  effective in addition to being effective during the given dates. In 
     *  any effective mode, effective relationships and those currently 
     *  expired are returned. 
     *
     *  @param  sourceId a peer <code> Id </code> 
     *  @param  destinationId a related peer <code> Id </code> 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the relationships 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> sourceId, destinationId, 
     *          from </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.RelationshipList getRelationshipsForPeersOnDate(org.osid.id.Id sourceId, 
                                                                                 org.osid.id.Id destinationId, 
                                                                                 org.osid.calendaring.DateTime from, 
                                                                                 org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RelationshipList </code> corresponding between the given 
     *  peer <code> Ids </code> and relationship genus <code> Type. 
     *  Relationships </code> of any genus derived from the given genus are 
     *  returned. 
     *  
     *  In plenary mode, the returned list contains all of the relationships 
     *  corresponding to the given peer or an error results if a relationship 
     *  is inaccessible. Otherwise, inaccessible <code> Relationships </code> 
     *  may be omitted from the list. 
     *  
     *  In effective mode, relationships are returned that are currently 
     *  effective. In any effective mode, effective relationships and those 
     *  currently expired are returned. 
     *
     *  @param  sourceId a peer <code> Id </code> 
     *  @param  destinationId a related peer <code> Id </code> 
     *  @param  relationshipGenusType a relationship genus type 
     *  @return the relationships 
     *  @throws org.osid.NullArgumentException <code> sourceId, destinationId, 
     *          </code> or <code> relationshipGenusType </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.RelationshipList getRelationshipsByGenusTypeForPeers(org.osid.id.Id sourceId, 
                                                                                      org.osid.id.Id destinationId, 
                                                                                      org.osid.type.Type relationshipGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RelationshipList </code> effective during the entire 
     *  given date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all of the relationships 
     *  corresponding to the given peer set or an error results if a 
     *  relationship is inaccessible. Otherwise, inaccessible <code> 
     *  Relationships </code> may be omitted from the list. 
     *  
     *  In effective mode, relationships are returned that are currently 
     *  effective in addition to being effective during the given dates. In 
     *  any effective mode, effective relationships and those currently 
     *  expired are returned. 
     *
     *  @param  sourceId a peer <code> Id </code> 
     *  @param  destinationId a related peer <code> Id </code> 
     *  @param  relationshipGenusType a relationship genus type 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the relationships 
     *  @throws org.osid.InvalidArgumentException <code> from is greater than 
     *          to </code> 
     *  @throws org.osid.NullArgumentException <code> sourceId, destinationId, 
     *          relationshipGenusType, from </code> or <code> to </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.RelationshipList getRelationshipsByGenusTypeForPeersOnDate(org.osid.id.Id sourceId, 
                                                                                            org.osid.id.Id destinationId, 
                                                                                            org.osid.type.Type relationshipGenusType, 
                                                                                            org.osid.calendaring.DateTime from, 
                                                                                            org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Relationships. </code> 
     *  
     *  In plenary mode, the returned list contains all known relationships or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  relationships that are accessible through this session. 
     *  
     *  In effective mode, relationships are returned that are currently 
     *  effective. In any effective mode, effective relationships and those 
     *  currently expired are returned. 
     *
     *  @return a list of <code> Relationships </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.RelationshipList getRelationships()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
