//
// org.osid.relationship.RelationshipManager
//
//     The OSID Java specification for org.osid.relationship.RelationshipManager.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.relationship;


/**
 *  <p>The relationship manager provides access to relationship sessions and 
 *  provides interoperability tests for various aspects of this service. The 
 *  sessions included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> RelationshipLookupSession: </code> a session to retrieve 
 *      and examine relationships </li> 
 *      <li> <code> RelationshipQuerySession: </code> a session to query 
 *      relationships </li> 
 *      <li> <code> RelationshipSearchSession: </code> a session to search for 
 *      relationships </li> 
 *      <li> <code> RelationshipAdminSession: </code> a session to manage 
 *      relationships </li> 
 *      <li> <code> RelationshipNotificationSession: </code> a session to 
 *      receive notifications pertaining to relationship changes </li> 
 *      <li> <code> RelationshipFamilySession: </code> a session to look up 
 *      relationship to family mappings </li> 
 *      <li> <code> RelationshipFamilyAssignmentSession: </code> a session to 
 *      manage relationship to family catalog mappings </li> 
 *      <li> <code> RelationshipSmartFamilySession: </code> a session to 
 *      manage dynamic relationship families </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> FamilyLookupSession: </code> a session to retrieve 
 *      families </li> 
 *      <li> <code> FamilyQuerySession: </code> a session to query families 
 *      </li> 
 *      <li> <code> FamilySearchSession: </code> a session to search for 
 *      families </li> 
 *      <li> <code> FamilyAdminSession: </code> a session to create and delete 
 *      families </li> 
 *      <li> <code> FamilyNotificationSession: </code> a session to receive 
 *      notifications pertaining to family changes </li> 
 *      <li> <code> FamilyHierarchySession: </code> a session to traverse a 
 *      hierarchy of families </li> 
 *      <li> <code> FamilyHierarchyDesignSession: </code> a session to manage 
 *      a family hierarchy </li> 
 *  </ul>
 *  
 */

public interface RelationshipManager
    extends org.osid.OsidManager,
            org.osid.relationship.RelationshipProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the relationship 
     *  lookup service. 
     *
     *  @return a <code> RelationshipLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelationshipLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelationshipLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.relationship.RelationshipLookupSession getRelationshipLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the relationship 
     *  lookup service for the given family. 
     *
     *  @param  familyId the <code> Id </code> of the family 
     *  @return a <code> RelationshipLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Family </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> familyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelationshipLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelationshipLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.relationship.RelationshipLookupSession getRelationshipLookupSessionForFamily(org.osid.id.Id familyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the relationship 
     *  query service. 
     *
     *  @return a <code> RelationshipQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelationshipQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelationshipQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.relationship.RelationshipQuerySession getRelationshipQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the relationship 
     *  query service for the given family. 
     *
     *  @param  familyId the <code> Id </code> of the family 
     *  @return a <code> RelationshipQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Family </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> familyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelationshipQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelationshipQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.relationship.RelationshipQuerySession getRelationshipQuerySessionForFamily(org.osid.id.Id familyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the relationship 
     *  search service. 
     *
     *  @return a <code> RelationshipSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelationshipSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelationshipSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.relationship.RelationshipSearchSession getRelationshipSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the relationship 
     *  search service for the given family. 
     *
     *  @param  familyId the <code> Id </code> of the <code> Family </code> 
     *  @return a <code> RelationshipSearchSession </code> 
     *  @throws org.osid.NotFoundException no family found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> familyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelationshipSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelationshipSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.relationship.RelationshipSearchSession getRelationshipSearchSessionForFamily(org.osid.id.Id familyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the relationship 
     *  administration service. 
     *
     *  @return a <code> RelationshipAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelationshipAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelationshipAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.relationship.RelationshipAdminSession getRelationshipAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the relationship 
     *  administration service for the given family. 
     *
     *  @param  familyId the <code> Id </code> of the <code> Family </code> 
     *  @return a <code> RelationshipAdminSession </code> 
     *  @throws org.osid.NotFoundException no family found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> familyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelationshipAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelationshipAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.relationship.RelationshipAdminSession getRelationshipAdminSessionForFamily(org.osid.id.Id familyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the relationship 
     *  notification service. 
     *
     *  @param  relationshipReceiver the receiver 
     *  @return a <code> RelationshipNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> relationshipReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelationshipNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelationshipNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.relationship.RelationshipNotificationSession getRelationshipNotificationSession(org.osid.relationship.RelationshipReceiver relationshipReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the relationship 
     *  notification service for the given family. 
     *
     *  @param  relationshipReceiver the receiver 
     *  @param  familyId the <code> Id </code> of the <code> Family </code> 
     *  @return a <code> RelationshipNotificationSession </code> 
     *  @throws org.osid.NotFoundException no family found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> relationshipReceiver 
     *          </code> or <code> familyId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelationshipNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelationshipNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.relationship.RelationshipNotificationSession getRelationshipNotificationSessionForFamily(org.osid.relationship.RelationshipReceiver relationshipReceiver, 
                                                                                                             org.osid.id.Id familyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup relationship/family 
     *  mappings. 
     *
     *  @return a <code> RelationshipFamilySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelationshipFamily() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelationshipFamily() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.relationship.RelationshipFamilySession getRelationshipFamilySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning 
     *  relationships to families. 
     *
     *  @return a <code> RelationshipFamilyAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelationshipFamilyAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelationshipFamilyAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.relationship.RelationshipFamilyAssignmentSession getRelationshipFamilyAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage dynamic families of 
     *  retlationships. 
     *
     *  @param  familyId the <code> Id </code> of the <code> Family </code> 
     *  @return a <code> RelationshipSmartFamilySession </code> 
     *  @throws org.osid.NotFoundException no family found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> familyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelationshipSmartFamily() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelationshipSmartFamily() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.relationship.RelationshipSmartFamilySession getRelationshipSmartFamilySession(org.osid.id.Id familyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the family lookup 
     *  service. 
     *
     *  @return a <code> FamilyLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsFamilyLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFamilyLookup() </code> is <code> true. </code> 
     */

    public org.osid.relationship.FamilyLookupSession getFamilyLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the family query 
     *  service. 
     *
     *  @return a <code> FamilyQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsFamilyQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFamilyQuery() </code> is <code> true. </code> 
     */

    public org.osid.relationship.FamilyQuerySession getFamilyQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the family search 
     *  service. 
     *
     *  @return a <code> FamilySearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsFamilySearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFamilySearch() </code> is <code> true. </code> 
     */

    public org.osid.relationship.FamilySearchSession getFamilySearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the family 
     *  administrative service. 
     *
     *  @return a <code> FamilyAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsFamilyAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFamilyAdmin() </code> is <code> true. </code> 
     */

    public org.osid.relationship.FamilyAdminSession getFamilyAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the family 
     *  notification service. 
     *
     *  @param  familyReceiver the receiver 
     *  @return a <code> FamilyNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> familyReceiver </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsFamilyNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFamilyNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.relationship.FamilyNotificationSession getFamilyNotificationSession(org.osid.relationship.FamilyReceiver familyReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the family 
     *  hierarchy service. 
     *
     *  @return a <code> FamilyHierarchySession </code> for families 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsFamilyHierarchy() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFamilyHierarchy() </code> is <code> true. </code> 
     */

    public org.osid.relationship.FamilyHierarchySession getFamilyHierarchySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the family 
     *  hierarchy design service. 
     *
     *  @return a <code> HierarchyDesignSession </code> for families 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsFamilyHierarchyDesign() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFamilyHierarchyDesign() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.relationship.FamilyHierarchyDesignSession getFamilyHierarchyDesignSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the relationship batch manager. 
     *
     *  @return a <code> RelationshipBatchManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelationshipBatch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelationshipBatch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.relationship.batch.RelationshipBatchManager getRelationshipBatchManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the relationship rules manager. 
     *
     *  @return a <code> RelationshipRulesManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelationshipRules() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelationshipRules() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.relationship.rules.RelationshipRulesManager getRelationshipRulesManager()
        throws org.osid.OperationFailedException;
}
