//
// org.osid.relationship.RelationshipNotificationSession
//
//     The OSID Java specification for org.osid.relationship.RelationshipNotificationSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.relationship;


/**
 *  <p>This session defines methods to receive notifications on adds/changes 
 *  to <code> Relationship </code> objects in this <code> Family. </code> This 
 *  also includes existing relationships that may appear or disappear due to 
 *  changes in the <code> Family </code> hierarchy, This session is intended 
 *  for consumers needing to synchronize their state with this service without 
 *  the use of polling. Notifications are cancelled when this session is 
 *  closed. </p> 
 *  
 *  <p> The two views defined in this session correspond to the views in the 
 *  <code> RelationshipLookupSession. </code> </p>
 */

public interface RelationshipNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Family </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Family Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFamilyId();


    /**
     *  Gets the <code> Family </code> associated with this session. 
     *
     *  @return the family 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.Family getFamily()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can register for <code> Relationship </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForRelationshipNotifications();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include relationships in families which are children of this family in 
     *  the family hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedFamilyView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts notifications to this family only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedFamilyView();


    /**
     *  Reliable notifications are desired. In reliable mode, notifications 
     *  are to be acknowledged using <code> 
     *  acknowledgeRelationshipNotification() </code> . 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void reliableRelationshipNotifications();


    /**
     *  Unreliable notifications are desired. In unreliable mode, 
     *  notifications do not need to be acknowledged. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void unreliableRelationshipNotifications();


    /**
     *  Acknowledge a relationship notification. 
     *
     *  @param  notificationId the <code> Id </code> of the notification 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void acknowledgeRelationshipNotification(org.osid.id.Id notificationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new relationships. <code> 
     *  RelationshipReceiver.newRelationships() </code> is invoked when a new 
     *  <code> Relationship </code> appears in this family. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewRelationships()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new relationships from the given source. 
     *  <code> RelationshipReceiver.newRelationships() </code> is invoked when 
     *  a new <code> Relationship </code> appears for the given peer. 
     *
     *  @param  sourceId the <code> Id </code> of the source to monitor 
     *  @throws org.osid.NullArgumentException <code> sourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewRelationshipsForSource(org.osid.id.Id sourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new relationships to the given 
     *  destination. <code> RelationshipReceiver.newRelationships() </code> is 
     *  invoked when a new <code> Relationship </code> appears for the given 
     *  peer. 
     *
     *  @param  destinationId the <code> Id </code> of the destination node to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> destinationId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewRelationshipsForDestination(org.osid.id.Id destinationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new relationships. <code> 
     *  RelationshipReceiver.newRelationships() </code> is invoked when a new 
     *  <code> Relationship </code> appears for the given peer. 
     *
     *  @param  relationshipGenusType the genus type of the <code> 
     *          Relationship </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> relationshipGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewRelationshipsByGenusType(org.osid.type.Type relationshipGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated relationships. <code> 
     *  RelationshipReceiver.changedRelationships() </code> is invoked when a 
     *  relationship in this family is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedRelationships()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of updated relationships from the given 
     *  source node. <code> RelationshipReceiver.changedRelationships() 
     *  </code> is invoked when a <code> Relationship </code> if changed for 
     *  the given peer. 
     *
     *  @param  sourceId the <code> Id </code> of the source node to monitor 
     *  @throws org.osid.NullArgumentException <code> sourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedRelationshipsForSource(org.osid.id.Id sourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of updated relationships to the given 
     *  destination node. <code> RelationshipReceiver.changedRelationships() 
     *  </code> is invoked when a <code> Relationship </code> if changed for 
     *  the given peer. 
     *
     *  @param  destinationId the <code> Id </code> of the destination node to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> destinationId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedRelationshipsForDestination(org.osid.id.Id destinationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of updated relationships. <code> 
     *  RelationshipReceiver.changedRelationships() </code> is invoked when a 
     *  <code> Relationship </code> if changed for the given peer. 
     *
     *  @param  relationshipGenusType the genus type of the <code> 
     *          Relationship </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> relationshipGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedRelationshipsByGenusType(org.osid.type.Type relationshipGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated relationship. <code> 
     *  RelationshipReceiver.changedRelationships() </code> is invoked when 
     *  the specified relationship in this family is changed. 
     *
     *  @param  relationshipId the <code> Id </code> of the <code> 
     *          Relationship </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> relationshipId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedRelationship(org.osid.id.Id relationshipId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted relationships. <code> 
     *  RelationshipReceiver.deletedRelationships() </code> is invoked when a 
     *  relationship is deleted or removed from this family. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedRelationships()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of deleted relationships from the given 
     *  source node. <code> RelationshipReceiver.deletedRelationships() 
     *  </code> is invoked when a <code> Relationship </code> if removed for 
     *  the given peer. 
     *
     *  @param  sourceId the <code> Id </code> of the source node to monitor 
     *  @throws org.osid.NullArgumentException <code> sourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedRelationshipsForSource(org.osid.id.Id sourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of deleted relationships to the given 
     *  destination node. <code> RelationshipReceiver.deletedRelationships() 
     *  </code> is invoked when a <code> Relationship </code> if removed for 
     *  the given peer. 
     *
     *  @param  destinationId the <code> Id </code> of the destination node to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> destinationId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedRelationshipsForDestination(org.osid.id.Id destinationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of deleted relationships. <code> 
     *  RelationshipReceiver.deletedRelationships() </code> is invoked when a 
     *  <code> Relationship </code> if removed for the given peer. 
     *
     *  @param  relationshipGenusType the genus type of the <code> 
     *          Relationship </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> relationshipGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedRelationshipsByGenusType(org.osid.type.Type relationshipGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted relationship. <code> 
     *  RelationshipReceiver.deletedRelationships() </code> is invoked when 
     *  the specified relationship is deleted or removed from this family. 
     *
     *  @param  relationshipId the <code> Id </code> of the <code> 
     *          Relationship </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> relationshipId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedRelationship(org.osid.id.Id relationshipId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
