//
// org.osid.relationship.RelationshipSmartFamilySession
//
//     The OSID Java specification for org.osid.relationship.RelationshipSmartFamilySession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.relationship;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. A <code> RelationshipQuery </code> can be retrieved from this 
 *  session and mapped to this <code> Family </code> to create a virtual 
 *  collection of <code> Relationships. </code> The entries may be sequenced 
 *  using the <code> RelationshipSearchOrder </code> from this session. </p> 
 *  
 *  <p> This <code> Family </code> has a default query that matches any 
 *  relationship and a default search order that specifies no sequencing. The 
 *  queries may be examined using a <code> RelationshipQueryInspector. </code> 
 *  The query may be modified by converting the inspector back to a <code> 
 *  RelationshipQuery. </code> </p>
 */

public interface RelationshipSmartFamilySession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Family </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Family Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFamilyId();


    /**
     *  Gets the <code> Family </code> associated with this session. 
     *
     *  @return the family 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.Family getFamily()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart families. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer smart operations. 
     *
     *  @return <code> false </code> if smart family methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartFamilies();


    /**
     *  Gets a relationship query. 
     *
     *  @return the relationship query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.RelationshipQuery getRelationshipQuery();


    /**
     *  Gets a relationship search order. 
     *
     *  @return the relationship search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.RelationshipSearchOrder getRelationshipSearchOrder();


    /**
     *  Applies a relationship query to this family. 
     *
     *  @param  relationshipQuery the relationship query 
     *  @throws org.osid.NullArgumentException <code> relationshipQuery 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> relationshipQuery </code> 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyRelationshipQuery(org.osid.relationship.RelationshipQuery relationshipQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a relationship query inspector for this family. 
     *
     *  @return the relationship query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.RelationshipQueryInspector inspectRelationshipQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a relationship search order to this family. 
     *
     *  @param  relationshipSearchOrder the relationship search order 
     *  @throws org.osid.NullArgumentException <code> relationshipSearchOrder 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> relationshipSearchOrder 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyRelationshipSequencing(org.osid.relationship.RelationshipSearchOrder relationshipSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a relationship query from an inspector. 
     *
     *  @param  relationshipQueryInspector a relationship query inspector 
     *  @return the relationship query 
     *  @throws org.osid.NullArgumentException <code> 
     *          relatinshipQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          relationshipQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.RelationshipQuery getRelationshipQueryFromInspector(org.osid.relationship.RelationshipQueryInspector relationshipQueryInspector);
}
