//
// org.osid.relationship.rules.RelationshipEnablerSmartFamilySession
//
//     The OSID Java specification for org.osid.relationship.rules.RelationshipEnablerSmartFamilySession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.relationship.rules;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  families. A <code> RelationshipEnablerQuery </code> can be retrieved from 
 *  this session and mapped to this <code> Family </code> to create a virtual 
 *  collection of relationship enablers. The relationship enablers may be 
 *  sequenced using the <code> RelationshipEnablerSearchOrder </code> from 
 *  this session. </p> 
 *  
 *  <p> This <code> Family </code> has a default query that matches any 
 *  relationship enabler and a default search order that specifies no 
 *  sequencing. The queries may be examined using a <code> 
 *  RelationshipEnablerQueryInspector. </code> The query may be modified by 
 *  converting the inspector back to a <code> RelationshipEnablerQuery. 
 *  </code> </p>
 */

public interface RelationshipEnablerSmartFamilySession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Family </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Family Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFamilyId();


    /**
     *  Gets the <code> Family </code> associated with this session. 
     *
     *  @return the family 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.Family getFamily()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart families. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart family management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartFamilies();


    /**
     *  Gets a relationship enabler query. 
     *
     *  @return the relationship enabler query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.rules.RelationshipEnablerQuery getRelationshipEnablerQuery();


    /**
     *  Gets a relationship enabler search order. 
     *
     *  @return the relationship enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.rules.RelationshipEnablerSearchOrder getRelationshipEnablerSearchOrder();


    /**
     *  Applies a relationship enabler query to this family. 
     *
     *  @param  relationshipEnablerQuery the relationship enabler query 
     *  @throws org.osid.NullArgumentException <code> relationshipEnablerQuery 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> relationshipEnablerQuery 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyRelationshipEnablerQuery(org.osid.relationship.rules.RelationshipEnablerQuery relationshipEnablerQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a relationship enabler query inspector for this family. 
     *
     *  @return the relationship enabler query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.rules.RelationshipEnablerQueryInspector inspectRelationshipEnablerQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a relationship enabler search order to this family. 
     *
     *  @param  relationshipEnablerSearchOrder the relationship enabler search 
     *          order 
     *  @throws org.osid.NullArgumentException <code> 
     *          relationshipEnablerSearchOrder </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> 
     *          relationshipEnablerSearchOrder </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyRelationshipEnablerSequencing(org.osid.relationship.rules.RelationshipEnablerSearchOrder relationshipEnablerSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a relationship enabler query from an inspector. 
     *
     *  @param  relationshipEnablerQueryInspector a relationship enabler query 
     *          inspector 
     *  @return the relationship enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          relationshipEnablerQueryInspector </code> is <code> null 
     *          </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          relationshipEnablerQueryInspector </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.rules.RelationshipEnablerQuery getRelationshipEnablerQueryFromInspector(org.osid.relationship.rules.RelationshipEnablerQueryInspector relationshipEnablerQueryInspector);
}
