//
// org.osid.relationship.rules.RelationshipRulesProfile
//
//     The OSID Java specification for org.osid.relationship.rules.RelationshipRulesProfile.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.relationship.rules;


/**
 *  <p>The relationship rules profile describes the interoperability among 
 *  relationship rules services. </p>
 */

public interface RelationshipRulesProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any broker federation is exposed. Federation is exposed when 
     *  a specific broker may be identified, selected and used to create a 
     *  lookup or admin session. Federation is not exposed when a set of 
     *  brokers appears as a single broker. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if looking up relationship enablers is supported. 
     *
     *  @return <code> true </code> if relationship enabler lookup is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelationshipEnablerLookup();


    /**
     *  Tests if querying relationship enablers is supported. 
     *
     *  @return <code> true </code> if relationship enabler query is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelationshipEnablerQuery();


    /**
     *  Tests if searching relationship enablers is supported. 
     *
     *  @return <code> true </code> if relationship enabler search is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelationshipEnablerSearch();


    /**
     *  Tests if a relationship enabler administrative service is supported. 
     *
     *  @return <code> true </code> if relationship enabler administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelationshipEnablerAdmin();


    /**
     *  Tests if a relationship enabler notification service is supported. 
     *
     *  @return <code> true </code> if relationship enabler notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelationshipEnablerNotification();


    /**
     *  Tests if a relationship enabler family lookup service is supported. 
     *
     *  @return <code> true </code> if a family enabler family lookup service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelationshipEnablerFamily();


    /**
     *  Tests if a relationship enabler family service is supported. 
     *
     *  @return <code> true </code> if relationship enabler family assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelationshipEnablerFamilyAssignment();


    /**
     *  Tests if a relationship enabler smart family service is supported. 
     *
     *  @return <code> true </code> if a relationship enabler smart family 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelationshipEnablerSmartFamily();


    /**
     *  Tests if a relationship enabler rule lookup service is supported. 
     *
     *  @return <code> true </code> if a enabler relationship rule lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelationshipEnablerRuleLookup();


    /**
     *  Tests if a relationship enabler rule application service is supported. 
     *
     *  @return <code> true </code> if enabler relationship rule application 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelationshipEnablerRuleApplication();


    /**
     *  Gets the supported <code> RelationshipEnabler </code> record types. 
     *
     *  @return a list containing the supported <code> RelationshipEnabler 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getRelationshipEnablerRecordTypes();


    /**
     *  Tests if the given <code> RelationshipEnabler </code> record type is 
     *  supported. 
     *
     *  @param  relationshipEnablerRecordType a <code> Type </code> indicating 
     *          a <code> RelationshipEnabler </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          relationshipEnablerRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelationshipEnablerRecordType(org.osid.type.Type relationshipEnablerRecordType);


    /**
     *  Gets the supported <code> RelationshipEnabler </code> search record 
     *  types. 
     *
     *  @return a list containing the supported <code> RelationshipEnabler 
     *          </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getRelationshipEnablerSearchRecordTypes();


    /**
     *  Tests if the given <code> RelationshipEnabler </code> search record 
     *  type is supported. 
     *
     *  @param  relationshipEnablerSearchRecordType a <code> Type </code> 
     *          indicating a <code> RelationshipEnabler </code> search record 
     *          type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          relationshipEnablerSearchRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelationshipEnablerSearchRecordType(org.osid.type.Type relationshipEnablerSearchRecordType);
}
