//
// org.osid.repository.AssetAdminSession
//
//     The OSID Java specification for org.osid.repository.AssetAdminSession.
//
// Copyright (C) 2002-2004, 2007-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.repository;


/**
 *  <p>This session creates, updates, and deletes <code> Assets. </code> The 
 *  data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create an 
 *  <code> Asset, </code> an <code> AssetForm </code> is requested using 
 *  <code> getAssetFormForCreate() </code> specifying the desired record 
 *  <code> Types </code> or none if no record <code> Types </code> are needed. 
 *  The returned <code> AssetyForm </code> will indicate that it is to be used 
 *  with a create operation and can be used to examine metdata or validate 
 *  data prior to creation. Once the <code> AssetForm </code> is submiited to 
 *  a create operation, it cannot be reused with another create operation 
 *  unless the first operation was unsuccessful. Each <code> AssetForm </code> 
 *  corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> AssetForms </code> are requested to the <code> 
 *  Asset </code> <code> Id </code> that is to be updated using <code> 
 *  getAssetFormForUpdate(). </code> Similarly, the <code> AssetForm </code> 
 *  has metadata about the data that can be updated and it can perform 
 *  validation before submitting the update. The <code> AssetForm </code> can 
 *  only be used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Assets. </code> To unmap an <code> 
 *  Asset </code> from the current <code> Repository, </code> the <code> 
 *  AssetRepositoryAssignmentSession </code> should be used. These delete 
 *  operations attempt to remove the <code> Bid </code> itself thus removing 
 *  it from all known <code> Repository </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p> 
 *  
 *  <p> The view of the administrative methods defined in this session is 
 *  determined by the provider. For an instance of this session where no 
 *  repository has been specified, it may not be parallel to the <code> 
 *  AssetLookupSession. </code> For example, a default <code> 
 *  AssetLookupSession </code> may view the entire repository hierarchy while 
 *  the default <code> AssetAdminSession </code> uses an isolated <code> 
 *  Repository </code> to create new <code> Assets </code> or <code> </code> a 
 *  specific repository to operate on a predetermined set of <code> Assets. 
 *  </code> Another scenario is a federated provider who does not wish to 
 *  permit administrative operations for the federation unaware. </p> 
 *  
 *  <p> Example create: </p> 
 *  
 *  <pre>
 *       
 *       
 *       if (!session.canCreateAssets()) {
 *           return "asset creation not permitted";
 *       }
 *       
 *       Type types[1];
 *       types[0] = assetPhotographType; 
 *       if (!session.canCreateAssetWithRecordTypes(types)) {
 *           return "creating an asset with a photograph type is not supported";
 *       }
 *       
 *       AssetForm form = session.getAssetFormForCreate();
 *       Metadata metadata = form.getDisplayNameMetadata();
 *       if (metadata.isReadOnly()) {
 *           return "cannot set display name";
 *       }
 *       
 *       form.setDisplayName("my photo");
 *       
 *       PhotographRecordForm photoForm = (PhotographRecordForn) form.getRecordForm(assetPhotogaphType);
 *       Metadata metadata = form.getApertureMetadata();
 *       if (metadata.isReadOnly()) {
 *           return ("cannot set aperture");
 *       }
 *       
 *       photoForm.setAperture("5.6");
 *       if (!form.isValid()) {
 *           return form.getValidationMessage();
 *       }
 *       
 *       Asset newAsset = session.createAsset(form);
 *       
 *                   
 *       
 *  </pre>
 *  
 */

public interface AssetAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Repository </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Repository Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getRepositoryId();


    /**
     *  Gets the <code> Repository </code> associated with this session. 
     *
     *  @return the <code> Repository </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.Repository getRepository()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> Assets. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating an <code> Asset </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer create operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Asset </code> creation is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAssets();


    /**
     *  Tests if this user can create a single <code> Asset </code> using the 
     *  desired record types. While <code> 
     *  RepositoryManager.getAssetRecordTypes() </code> can be used to examine 
     *  which records are supported, this method tests which record(s) are 
     *  required for creating a specific <code> Asset. </code> Providing an 
     *  empty array tests if an <code> Asset </code> can be created with no 
     *  records. 
     *
     *  @param  assetRecordTypes array of asset record types 
     *  @return <code> true </code> if <code> Asset </code> creation using the 
     *          specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> assetRecordTypes </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAssetWithRecordTypes(org.osid.type.Type[] assetRecordTypes);


    /**
     *  Gets the asset form for creating new assets. A new form should be 
     *  requested for each create transaction. 
     *
     *  @param  assetRecordTypes array of asset record types 
     *  @return the asset form 
     *  @throws org.osid.NullArgumentException <code> assetRecordTypes </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.AssetForm getAssetFormForCreate(org.osid.type.Type[] assetRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Asset. </code> 
     *
     *  @param  assetForm the form for this <code> Asset </code> 
     *  @return the new <code> Asset </code> 
     *  @throws org.osid.IllegalStateException <code> assetForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> assetForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> assetForm </code> did not 
     *          originate from <code> getAssetFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.Asset createAsset(org.osid.repository.AssetForm assetForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Assets. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating an <code> Asset </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer update operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Asset </code> modification is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateAssets();


    /**
     *  Gets the asset form for updating an existing asset. A new asset form 
     *  should be requested for each update transaction. 
     *
     *  @param  assetId the <code> Id </code> of the <code> Asset </code> 
     *  @return the asset form 
     *  @throws org.osid.NotFoundException <code> assetId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> assetId </code> is null 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.AssetForm getAssetFormForUpdate(org.osid.id.Id assetId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing asset. 
     *
     *  @param  assetForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> assetForm </code> 
     *          already used in anupdate transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> assetForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> assetForm </code> did not 
     *          originate from <code> getAssetFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateAsset(org.osid.repository.AssetForm assetForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> Assets. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting an <code> Asset </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer delete operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Asset </code> deletion is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteAssets();


    /**
     *  Deletes an <code> Asset. </code> 
     *
     *  @param  assetId the <code> Id </code> of the <code> Asset </code> to 
     *          remove 
     *  @throws org.osid.NotFoundException <code> assetId </code> not found 
     *  @throws org.osid.NullArgumentException <code> assetId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteAsset(org.osid.id.Id assetId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Assets. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Asset </code> aliasing is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageAssetAliases();


    /**
     *  Adds an <code> Id </code> to an <code> Asset </code> for the purpose 
     *  of creating compatibility. The primary <code> Id </code> of the <code> 
     *  Asset </code> is determined by the provider. The new <code> Id </code> 
     *  performs as an alias to the primary <code> Id. </code> If the alias is 
     *  a pointer to another asset, it is reassigned to the given asset <code> 
     *  Id. </code> 
     *
     *  @param  assetId the <code> Id </code> of an <code> Asset </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> assetId </code> not found 
     *  @throws org.osid.NullArgumentException <code> assetId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasAsset(org.osid.id.Id assetId, org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create content for <code> Assets. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known creating an <code> AssetContent 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer create 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Asset </code> content creation 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAssetContent();


    /**
     *  Tests if this user can create an <code> AssetContent </code> using the 
     *  desired record types. While <code> 
     *  RepositoryManager.getAssetContentRecordTypes() </code> can be used to 
     *  test which records are supported, this method tests which records are 
     *  required for creating a specific <code> AssetContent. </code> 
     *  Providing an empty array tests if an <code> AssetContent </code> can 
     *  be created with no records. 
     *
     *  @param  assetContentRecordTypes array of asset content record types 
     *  @return <code> true </code> if <code> AssetContent </code> creation 
     *          using the specified <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> assetContentRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAssetContentWithRecordTypes(org.osid.type.Type[] assetContentRecordTypes);


    /**
     *  Gets an asset content form for creating new assets. 
     *
     *  @param  assetId the <code> Id </code> of an <code> Asset </code> 
     *  @param  assetContentRecordTypes array of asset content record types 
     *  @return the asset content form 
     *  @throws org.osid.NotFoundException <code> assetId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> assetId </code> or 
     *          <code> assetContentRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.AssetContentForm getAssetContentFormForCreate(org.osid.id.Id assetId, 
                                                                             org.osid.type.Type[] assetContentRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates new <code> AssetContent </code> for a given asset. 
     *
     *  @param  assetContentForm the form for this <code> AssetContent </code> 
     *  @return the new <code> AssetContent </code> 
     *  @throws org.osid.IllegalStateException <code> assetContentForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> assetContentForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> assetContentForm </code> 
     *          did not originate from <code> getAssetContentFormForCreate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.AssetContent createAssetContent(org.osid.repository.AssetContentForm assetContentForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> AssetContent. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating an <code> AssetContent </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer update operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> AssetContent </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateAssetContents();


    /**
     *  Gets the asset content form for updating an existing asset content. A 
     *  new asset content form should be requested for each update 
     *  transaction. 
     *
     *  @param  assetContentId the <code> Id </code> of the <code> 
     *          AssetContent </code> 
     *  @return the asset content form 
     *  @throws org.osid.NotFoundException <code> assetContentId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> assetContentId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.AssetContentForm getAssetContentFormForUpdate(org.osid.id.Id assetContentId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Updates an existing asset content. 
     *
     *  @param  assetContentForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> assetContentForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> assetForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> assetContentForm </code> 
     *          did not originate from <code> getAssetContentFormForUpdate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateAssetContent(org.osid.repository.AssetContentForm assetContentForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> AssetsContents. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting an <code> AssetContent </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer delete operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> AssetContent </code> deletion 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteAssetContents();


    /**
     *  Deletes content from an <code> Asset. </code> 
     *
     *  @param  assetContentId the <code> Id </code> of the <code> 
     *          AssetContent </code> 
     *  @throws org.osid.NotFoundException <code> assetContentId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> assetContentId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteAssetContent(org.osid.id.Id assetContentId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
