//
// org.osid.repository.AssetContentForm
//
//     The OSID Java specification for org.osid.repository.AssetContentForm.
//
// Copyright (C) 2002-2004, 2007-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.repository;


/**
 *  <p>This is the form for creating and updating content for <code> 
 *  AssetContent. </code> Like all <code> OsidForm </code> objects, various 
 *  data elements may be set here for use in the create and update methods in 
 *  the <code> AssetAdminSession. </code> For each data element that may be 
 *  set, metadata may be examined to provide display hints or data 
 *  constraints. </p>
 */

public interface AssetContentForm
    extends org.osid.OsidObjectForm,
            org.osid.OsidSubjugateableForm {


    /**
     *  Gets the metadata for an accessibility type. 
     *
     *  @return metadata for the accessibility types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getAccessibilityTypeMetadata();


    /**
     *  Adds an accessibility type. Multiple types can be added. 
     *
     *  @param  accessibilityType a new accessibility type 
     *  @throws org.osid.InvalidArgumentException <code> accessibilityType 
     *          </code> is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> accessibilityTYpe 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void addAccessibilityType(org.osid.type.Type accessibilityType);


    /**
     *  Removes an accessibility type. 
     *
     *  @param  accessibilityType accessibility type to remove 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NotFoundException acessibility type not found 
     *  @throws org.osid.NullArgumentException <code> accessibilityType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeAccessibilityType(org.osid.type.Type accessibilityType)
        throws org.osid.NotFoundException;


    /**
     *  Removes all accessibility types. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAccessibilityTypes();


    /**
     *  Gets the metadata for the content data. 
     *
     *  @return metadata for the content data 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getDataMetadata();


    /**
     *  Sets the content data. 
     *
     *  @param  data the content data 
     *  @throws org.osid.InvalidArgumentException <code> data </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> data </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setData(org.osid.transport.DataInputStream data);


    /**
     *  Removes the content data. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearData();


    /**
     *  Gets the metadata for the url. 
     *
     *  @return metadata for the url 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getURLMetadata();


    /**
     *  Sets the url. 
     *
     *  @param  url the new copyright 
     *  @throws org.osid.InvalidArgumentException <code> url </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> url </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setURL(String url);


    /**
     *  Removes the url. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearURL();


    /**
     *  Gets the <code> AssetContentFormRecord </code> corresponding to the 
     *  given asset content record <code> Type. </code> 
     *
     *  @param  assetContentRecordType an asset content record type 
     *  @return the asset content form record 
     *  @throws org.osid.NullArgumentException <code> assetContentRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(assetContentRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.records.AssetContentFormRecord getAssetContentFormRecord(org.osid.type.Type assetContentRecordType)
        throws org.osid.OperationFailedException;
}
