//
// org.osid.repository.AssetForm
//
//     The OSID Java specification for org.osid.repository.AssetForm.
//
// Copyright (C) 2002-2004, 2007-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.repository;


/**
 *  <p>This is the form for creating and updating <code> Assets. </code> Like 
 *  all <code> OsidForm </code> objects, various data elements may be set here 
 *  for use in the create and update methods in the <code> AssetAdminSession. 
 *  </code> For each data element that may be set, metadata may be examined to 
 *  provide display hints or data constraints. </p>
 */

public interface AssetForm
    extends org.osid.OsidObjectForm,
            org.osid.OsidAggregateableForm,
            org.osid.OsidSourceableForm {


    /**
     *  Gets the metadata for an asset title. 
     *
     *  @return metadata for the title 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getTitleMetadata();


    /**
     *  Sets the title. 
     *
     *  @param  title the new title 
     *  @throws org.osid.InvalidArgumentException <code> title </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> title </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setTitle(String title);


    /**
     *  Removes the title. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTitle();


    /**
     *  Gets the metadata for the public domain flag. 
     *
     *  @return metadata for the public domain 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getPublicDomainMetadata();


    /**
     *  Sets the public domain flag. 
     *
     *  @param  publicDomain the public domain status 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setPublicDomain(boolean publicDomain);


    /**
     *  Removes the public domain status. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPublicDomain();


    /**
     *  Gets the metadata for the copyright. 
     *
     *  @return metadata for the copyright 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getCopyrightMetadata();


    /**
     *  Sets the copyright. 
     *
     *  @param  copyright the new copyright 
     *  @throws org.osid.InvalidArgumentException <code> copyright </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> copyright </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setCopyright(String copyright);


    /**
     *  Removes the copyright. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCopyright();


    /**
     *  Gets the metadata for the copyright registration. 
     *
     *  @return metadata for the copyright registration 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getCopyrightRegistrationMetadata();


    /**
     *  Sets the copyright registration. 
     *
     *  @param  registration the new copyright registration 
     *  @throws org.osid.InvalidArgumentException <code> copyright </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> copyright </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setCopyrightRegistration(String registration);


    /**
     *  Removes the copyright registration. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCopyrightRegistration();


    /**
     *  Gets the metadata for the distribute verbatim rights flag. 
     *
     *  @return metadata for the distribution rights fields 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getDistributeVerbatimMetadata();


    /**
     *  Sets the distribution rights. 
     *
     *  @param  distributeVerbatim right to distribute verbatim copies 
     *  @throws org.osid.InvalidArgumentException <code> distributeVerbatim 
     *          </code> is invalid 
     *  @throws org.osid.NoAccessException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setDistributeVerbatim(boolean distributeVerbatim);


    /**
     *  Removes the distribution rights. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDistributeVerbatim();


    /**
     *  Gets the metadata for the distribute alterations rights flag. 
     *
     *  @return metadata for the distribution rights fields 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getDistributeAlterationsMetadata();


    /**
     *  Sets the distribute alterations flag. This also sets distribute 
     *  verbatim to <code> true. </code> 
     *
     *  @param  distributeMods right to distribute modifications 
     *  @throws org.osid.InvalidArgumentException <code> distributeMods 
     *          </code> is invalid 
     *  @throws org.osid.NoAccessException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setDistributeAlterations(boolean distributeMods);


    /**
     *  Removes the distribution rights. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDistributeAlterations();


    /**
     *  Gets the metadata for the distribute compositions rights flag. 
     *
     *  @return metadata for the distribution rights fields 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getDistributeCompositionsMetadata();


    /**
     *  Sets the distribution rights. This sets distribute verbatim to <code> 
     *  true. </code> 
     *
     *  @param  distributeComps right to distribute modifications 
     *  @throws org.osid.InvalidArgumentException <code> distributeComps 
     *          </code> is invalid 
     *  @throws org.osid.NoAccessException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setDistributeCompositions(boolean distributeComps);


    /**
     *  Removes the distribution rights. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDistributeCompositions();


    /**
     *  Gets the metadata for the source. 
     *
     *  @return metadata for the source 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getSourceMetadata();


    /**
     *  Sets the source. 
     *
     *  @param  sourceId the new publisher 
     *  @throws org.osid.InvalidArgumentException <code> sourceId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> sourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setSource(org.osid.id.Id sourceId);


    /**
     *  Removes the source. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSource();


    /**
     *  Gets the metadata for the provider chain. 
     *
     *  @return metadata for the provider chain 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getProviderLinksMetadata();


    /**
     *  Sets a provider chain in order from the most recent source to the 
     *  originating source. 
     *
     *  @param  resourceIds the new source 
     *  @throws org.osid.InvalidArgumentException <code> resourceIds </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> resourceIds </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setProviderLinks(org.osid.id.Id[] resourceIds);


    /**
     *  Removes the provider chain. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProviderLinks();


    /**
     *  Gets the metadata for the asset creation date. 
     *
     *  @return metadata for the created date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getCreatedDateMetadata();


    /**
     *  Sets the created date. 
     *
     *  @param  createdDate the new created date 
     *  @throws org.osid.InvalidArgumentException <code> createdDate </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> createdDate </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setCreatedDate(org.osid.calendaring.DateTime createdDate);


    /**
     *  Removes the created date. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCreatedDate();


    /**
     *  Gets the metadata for the published status. 
     *
     *  @return metadata for the published field 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getPublishedMetadata();


    /**
     *  Sets the published status. 
     *
     *  @param  published the published status 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setPublished(boolean published);


    /**
     *  Removes the published status. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPublished();


    /**
     *  Gets the metadata for the published date. 
     *
     *  @return metadata for the published date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getPublishedDateMetadata();


    /**
     *  Sets the published date. 
     *
     *  @param  publishedDate the new published date 
     *  @throws org.osid.InvalidArgumentException <code> publishedDate </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> publishedDate </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setPublishedDate(org.osid.calendaring.DateTime publishedDate);


    /**
     *  Removes the puiblished date. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPublishedDate();


    /**
     *  Gets the metadata for the principal credit string. 
     *
     *  @return metadata for the credit string 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getPrincipalCreditStringMetadata();


    /**
     *  Sets the principal credit string. 
     *
     *  @param  creditString the new credit string 
     *  @throws org.osid.InvalidArgumentException <code> creditString </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> creditString </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setPrincipalCreditString(String creditString);


    /**
     *  Removes the principal credit string. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPrincipalCreditString();


    /**
     *  Gets the metadata for linking this asset to a composition. 
     *
     *  @return metadata for the composition 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getCompositionMetadata();


    /**
     *  Sets the composition. 
     *
     *  @param  compositionId a composition 
     *  @throws org.osid.InvalidArgumentException <code> compositionId </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> compositionId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setComposition(org.osid.id.Id compositionId);


    /**
     *  Removes the composition link. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearComposition();


    /**
     *  Gets the <code> AssetFormRecord </code> corresponding to the given 
     *  <code> Asset </code> record <code> Type. </code> 
     *
     *  @param  assetRecordType an asset record type 
     *  @return the asset form record 
     *  @throws org.osid.NullArgumentException <code> assetRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(assetRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.records.AssetFormRecord getAssetFormRecord(org.osid.type.Type assetRecordType)
        throws org.osid.OperationFailedException;
}
