//
// org.osid.repository.AssetSearchSession
//
//     The OSID Java specification for org.osid.repository.AssetSearchSession.
//
// Copyright (C) 2002-2004, 2007-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.repository;


/**
 *  <p>This session provides methods for searching among <code> Asset </code> 
 *  objects. The search query is constructed using the <code> AssetQuery. 
 *  </code> </p> 
 *  
 *  <p> <code> getAssetsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Assets. </code> A more advanced search may be 
 *  performed with <code> getAssetsBySearch(). </code> It accepts an <code> 
 *  AssetSearch </code> in addition to the query for the purpose of specifying 
 *  additional options affecting the entire search, such as ordering. <code> 
 *  getAssetsBySearch() </code> returns an <code> AssetSearchResults </code> 
 *  that can be used to access the resulting <code> AssetList </code> or be 
 *  used to perform a search within the result set through <code> AssetList. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated repository view: searches include assets in 
 *      repositories of which this repository is a ancestor in the repository 
 *      hierarchy </li> 
 *      <li> isolated repository view: searches are restricted to assets in 
 *      this repository </li> 
 *  </ul>
 *  
 *  
 *  <p> Assets may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> AssetQuery. </code> 
 *  </p>
 */

public interface AssetSearchSession
    extends org.osid.repository.AssetQuerySession {


    /**
     *  Gets an asset search. 
     *
     *  @return the asset search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.AssetSearch getAssetSearch();


    /**
     *  Gets an asset search order. The <code> AssetSearchOrder </code> is 
     *  supplied to an <code> AssetSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the asset search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.AssetSearchOrder getAssetSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  assetQuery the asset query 
     *  @param  assetSearch the asset search 
     *  @return the asset search results 
     *  @throws org.osid.NullArgumentException <code> assetQuery </code> or 
     *          <code> assetSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> assetQuery </code> or 
     *          <code> assetSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.AssetSearchResults getAssetsBySearch(org.osid.repository.AssetQuery assetQuery, 
                                                                    org.osid.repository.AssetSearch assetSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an asset query from an inspector. The inspector is available from 
     *  a <code> AssetSearchResults. </code> 
     *
     *  @param  assetQueryInspector an asset query inspector 
     *  @return the asset query 
     *  @throws org.osid.NullArgumentException <code> assetQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> assetQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.AssetQuery getAssetQueryFromInspector(org.osid.repository.AssetQueryInspector assetQueryInspector);
}
