//
// org.osid.repository.AssetSpatialAssignmentSession
//
//     The OSID Java specification for org.osid.repository.AssetSpatialAssignmentSession.
//
// Copyright (C) 2002-2004, 2007-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.repository;


/**
 *  <p>This session defines methods to manage the spatial coverage of an 
 *  asset. </p>
 */

public interface AssetSpatialAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Repository </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Repository Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getRepositoryId();


    /**
     *  Gets the <code> Repository </code> associated with this session. 
     *
     *  @return the <code> Repository </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.Repository getRepository()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage spatial lookups. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer assignment operations. 
     *
     *  @return <code> false </code> if spatial management is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignSpatialCoverage();


    /**
     *  Adds a location to an asset. 
     *
     *  @param  assetId <code> Id </code> of the <code> Asset </code> 
     *  @param  locationId a location <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException asset already contains this 
     *          spatial coverage 
     *  @throws org.osid.NotFoundException <code> assetId </code> or <code> 
     *          locationId </code> not <code> found </code> 
     *  @throws org.osid.NullArgumentException <code> assetId </code> or 
     *          <code> locationId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization fauilure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void addAssetLocation(org.osid.id.Id assetId, 
                                 org.osid.id.Id locationId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds a spatial coverage to an asset. 
     *
     *  @param  assetId <code> Id </code> of the <code> Asset </code> 
     *  @param  spatialUnit spatial coverage 
     *  @throws org.osid.AlreadyExistsException asset already contains this 
     *          spatial coverage 
     *  @throws org.osid.NotFoundException <code> assetId </code> not <code> 
     *          found </code> 
     *  @throws org.osid.NullArgumentException <code> assetId </code> or 
     *          <code> spatialUnit </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization fauilure 
     *  @throws org.osid.UnsupportedException <code> spatialUnit </code> not 
     *          supported 
     *  @compliance mandatory This method must be implemented. 
     */

    public void addAssetSpatialCoverage(org.osid.id.Id assetId, 
                                        org.osid.mapping.SpatialUnit spatialUnit)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a location from an asset. 
     *
     *  @param  assetId <code> Id </code> of the <code> Asset </code> 
     *  @param  locationId spatial coverage 
     *  @throws org.osid.NotFoundException <code> assetId </code> with <code> 
     *          locationId </code> not <code> found </code> 
     *  @throws org.osid.NullArgumentException <code> assetId </code> or 
     *          <code> locationId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization fauilure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeAssetLocation(org.osid.id.Id assetId, 
                                    org.osid.id.Id locationId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a spatial coverage from an asset. 
     *
     *  @param  assetId <code> Id </code> of the <code> Asset </code> 
     *  @param  spatialUnit spatial coverage 
     *  @throws org.osid.NotFoundException <code> assetId </code> with <code> 
     *          spatialUnit </code> not <code> found </code> 
     *  @throws org.osid.NullArgumentException <code> assetId </code> or 
     *          <code> spatialUnit </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization fauilure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeAssetSpatialCoverage(org.osid.id.Id assetId, 
                                           org.osid.mapping.SpatialUnit spatialUnit)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
