//
// org.osid.repository.CompositionLookupSession
//
//     The OSID Java specification for org.osid.repository.CompositionLookupSession.
//
// Copyright (C) 2002-2004, 2007-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.repository;


/**
 *  <p>This session provides methods for retrieving <code> Composition </code> 
 *  objects. The <code> Composition </code> represents a collection of <code> 
 *  Assets. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete and ordered result set or is an 
 *      error condition </li> 
 *      <li> isolated repository view: All lookup methods in this session 
 *      operate, retrieve and pertain to compositions defined explicitly in 
 *      the current repository. Using an isolated view is useful for managing 
 *      compositions with the <code> CompositionAdminSession. </code> </li> 
 *      <li> federated repository view: All composition methods in this 
 *      session operate, retrieve and pertain to all compositions defined in 
 *      this repository and any other compositions implicitly available in 
 *      this repository through repository inheritence. </li> 
 *      <li> active composition view: All composition lookup methods return 
 *      active compositions. </li> 
 *      <li> any status composition view: Compositions of any active or 
 *      inactive status are returned from methods. </li> 
 *      <li> sequestered composition viiew: All composition methods suppress 
 *      sequestered compositions. </li> 
 *      <li> unsequestered composition view: All composition methods return 
 *      all compositions. </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. For 
 *  example, a browsing application may only need to examine the <code> 
 *  Composition </code> it can access, without breaking execution. However, an 
 *  administrative application may require a complete set of <code> 
 *  Composition </code> objects to be returned. </p> 
 *  
 *  <p> Compositions may have an additional records indicated by their 
 *  respective record types. The record may not be accessed through a cast of 
 *  the <code> Composition. </code> </p>
 */

public interface CompositionLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Repository </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Repository Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getRepositoryId();


    /**
     *  Gets the <code> Repository </code> associated with this session. 
     *
     *  @return the <code> Repository </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.Repository getRepository()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Composition </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupCompositions();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeCompositionView();


    /**
     *  A complete view of the <code> Composition </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryCompositionView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include compositions in repositories which are children of this 
     *  repository in the repository hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedRepositoryView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this repository only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedRepositoryView();


    /**
     *  Only active compositions are returned by methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveCompositionView();


    /**
     *  All active and inactive compositions are returned by methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusCompositionView();


    /**
     *  The methods in this session omit sequestered compositions. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useSequesteredCompositionView();


    /**
     *  The methods in this session return all compositions, including 
     *  sequestered compositions. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useUnsequesteredCompositionView();


    /**
     *  Gets the <code> Composition </code> specified by its <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Composition </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> Composition </code> and retained for compatility. 
     *  
     *  In active mode, compositions are returned that are currently active. 
     *  In any effective mode, active and inactive compositions are returned. 
     *  
     *  In sequestered mode, no sequestered compositions are returned. In 
     *  unsequestered mode, all compositions are returned. 
     *
     *  @param  compositionId <code> Id </code> of the <code> Composiiton 
     *          </code> 
     *  @return the composition 
     *  @throws org.osid.NotFoundException <code> compositionId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> compositionId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.repository.Composition getComposition(org.osid.id.Id compositionId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CompositionList </code> corresponding to the given 
     *  <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  compositions specified in the <code> Id </code> list, in the order of 
     *  the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Compositions </code> may be omitted from the list 
     *  and may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In active mode, compositions are returned that are currently active. 
     *  In any effective mode, active and inactive compositions are returned. 
     *  
     *  In sequestered mode, no sequestered compositions are returned. In 
     *  unsequestered mode, all compositions are returned. 
     *
     *  @param  compositionIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Composition list </code> 
     *  @throws org.osid.NotFoundException an <code> Id </code> was not found 
     *  @throws org.osid.NullArgumentException <code> compositionIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.CompositionList getCompositionsByIds(org.osid.id.IdList compositionIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CompositionList </code> corresponding to the given 
     *  composition genus <code> Type </code> which does not include 
     *  compositions of types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  compositions or an error results. Otherwise, the returned list may 
     *  contain only those compositions that are accessible through this 
     *  session. 
     *  
     *  In active mode, compositions are returned that are currently active. 
     *  In any effective mode, active and inactive compositions are returned. 
     *  
     *  In sequestered mode, no sequestered compositions are returned. In 
     *  unsequestered mode, all compositions are returned. 
     *
     *  @param  compositionGenusType a composition genus type 
     *  @return the returned <code> Composition list </code> 
     *  @throws org.osid.NullArgumentException <code> compositionGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.CompositionList getCompositionsByGenusType(org.osid.type.Type compositionGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CompositionList </code> corresponding to the given 
     *  composition genus <code> Type </code> and include any additional 
     *  compositions with genus types derived from the specified <code> Type. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  compositions or an error results. Otherwise, the returned list may 
     *  contain only those compositions that are accessible through this 
     *  session. 
     *  
     *  In active mode, compositions are returned that are currently active. 
     *  In any effective mode, active and inactive compositions are returned. 
     *  
     *  In sequestered mode, no sequestered compositions are returned. In 
     *  unsequestered mode, all compositions are returned. 
     *
     *  @param  compositionGenusType a composition genus type 
     *  @return the returned <code> Composition list </code> 
     *  @throws org.osid.NullArgumentException <code> compositionGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.CompositionList getCompositionsByParentGenusType(org.osid.type.Type compositionGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CompositionList </code> containing the given composition 
     *  record <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  compositions or an error results. Otherwise, the returned list may 
     *  contain only those compositions that are accessible through this 
     *  session. 
     *  
     *  In active mode, compositions are returned that are currently active. 
     *  In any effective mode, active and inactive compositions are returned. 
     *  
     *  In sequestered mode, no sequestered compositions are returned. In 
     *  unsequestered mode, all compositions are returned. 
     *
     *  @param  compositionRecordType a composition record type 
     *  @return the returned <code> Composition list </code> 
     *  @throws org.osid.NullArgumentException <code> compositionRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.CompositionList getCompositionsByRecordType(org.osid.type.Type compositionRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CompositionList </code> from the given provider <code> . 
     *  </code> In plenary mode, the returned list contains all known 
     *  compositions or an error results. Otherwise, the returned list may 
     *  contain only those compositions that are accessible through this 
     *  session. 
     *  
     *  In sequestered mode, no sequestered compositions are returned. In 
     *  unsequestered mode, all compositions are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @return the returned <code> Composition list </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.CompositionList getCompositionsByProvider(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Compositions. </code> 
     *  
     *  In plenary mode, the returned list contains all known compositions or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  compositions that are accessible through this session. 
     *  
     *  In active mode, compositions are returned that are currently active. 
     *  In any effective mode, active and inactive compositions are returned. 
     *  
     *  In sequestered mode, no sequestered compositions are returned. In 
     *  unsequestered mode, all compositions are returned. 
     *
     *  @return a list of <code> Compositions </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.CompositionList getCompositions()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
