//
// org.osid.repository.CompositionQuerySession
//
//     The OSID Java specification for org.osid.repository.CompositionQuerySession.
//
// Copyright (C) 2002-2004, 2007-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.repository;


/**
 *  <p>This session provides methods for searching among <code> Composition 
 *  </code> objects. The search query is constructed using the <code> 
 *  CompositionQuery. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated repository view: searches include compositions in 
 *      repositories of which this repository is an ancestor in the repository 
 *      hierarchy </li> 
 *      <li> isolated repository view: searches are restricted to subjects in 
 *      this repository </li> 
 *      <li> sequestered composition viiew: All composition methods suppress 
 *      sequestered compositions. </li> 
 *      <li> unsequestered composition view: All composition methods return 
 *      all compositions. </li> 
 *  </ul>
 *  
 *  
 *  <p> Compositions may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> 
 *  CompositionQuery. </code> </p>
 */

public interface CompositionQuerySession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Repository </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Repository Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getRepositoryId();


    /**
     *  Gets the <code> Repository </code> associated with this session. 
     *
     *  @return the <code> Repository </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.Repository getRepository()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Composition </code> searches. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer search operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if search methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSearchCompositions();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include compositions in repositories which are children of this 
     *  repository in the repository hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedRepositoryView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this repository only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedRepositoryView();


    /**
     *  The methods in this session omit sequestered compositions. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useSequesteredCompositionView();


    /**
     *  The methods in this session return all compositions, including 
     *  sequestered compositions. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useUnsequesteredCompositionView();


    /**
     *  Gets a composition query. 
     *
     *  @return the composition query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.CompositionQuery getCompositionQuery();


    /**
     *  Gets a list of <code> Compositions </code> matching the given 
     *  composition query. 
     *
     *  @param  compositionQuery the composition query 
     *  @return the returned <code> CompositionList </code> 
     *  @throws org.osid.NullArgumentException <code> compositionQuery </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> compositionQuery </code> 
     *          is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.CompositionList getCompositionsByQuery(org.osid.repository.CompositionQuery compositionQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
