//
// org.osid.repository.CompositionRepositoryAssignmentSession
//
//     The OSID Java specification for org.osid.repository.CompositionRepositoryAssignmentSession.
//
// Copyright (C) 2002-2004, 2007-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.repository;


/**
 *  <p>This session provides methods to re-assign <code> Compositions </code> 
 *  to <code> Repository </code> objects. A <code> Composition </code> may be 
 *  associated with multiple <code> Repository </code> objects. Removing the 
 *  last reference to a <code> Composition </code> is the equivalent of 
 *  deleting it. Each <code> Repository </code> may have its own 
 *  authorizations governing who is allowed to operate on it. </p> 
 *  
 *  <p> Moving or adding a reference of a <code> Composition </code> to 
 *  another <code> Repository </code> is not a copy operation (eg: does not 
 *  change its <code> Id </code> ). </p>
 */

public interface CompositionRepositoryAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter composition/repository mappings. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignCompositions();


    /**
     *  Tests if this user can alter composition/repository mappings. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @param  repositoryId the <code> Id </code> of the <code> Repository 
     *          </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> repositoryId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignCompositionsToRepository(org.osid.id.Id repositoryId);


    /**
     *  Gets a list of repositories including and under the given repository 
     *  node in which any composition can be assigned. 
     *
     *  @param  repositoryId the <code> Id </code> of the <code> Repository 
     *          </code> 
     *  @return list of assignable repository <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> repositoryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableRepositoryIds(org.osid.id.Id repositoryId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of repositories including and under the given repository 
     *  node in which a specific composition can be assigned. 
     *
     *  @param  repositoryId the <code> Id </code> of the <code> Repository 
     *          </code> 
     *  @param  compositionId the <code> Id </code> of the <code> Composition 
     *          </code> 
     *  @return list of assignable repository <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> repositoryId </code> or 
     *          <code> compositionId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableRepositoryIdsForComposition(org.osid.id.Id repositoryId, 
                                                                       org.osid.id.Id compositionId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> Composition </code> to a <code> Repository. 
     *  </code> 
     *
     *  @param  compositionId the <code> Id </code> of the <code> Composition 
     *          </code> 
     *  @param  repositoryId the <code> Id </code> of the <code> Repository 
     *          </code> 
     *  @throws org.osid.AlreadyExistsException <code> compositionId </code> 
     *          already assigned to <code> repositoryId </code> 
     *  @throws org.osid.NotFoundException <code> compositionId </code> or 
     *          <code> repositoryId </code> not found 
     *  @throws org.osid.NullArgumentException <code> compositionId </code> or 
     *          <code> repositoryId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignCompositionToRepository(org.osid.id.Id compositionId, 
                                              org.osid.id.Id repositoryId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes <code> Composition </code> from a <code> Repository. </code> 
     *
     *  @param  compositionId the <code> Id </code> of the <code> Composition 
     *          </code> 
     *  @param  repositoryId the <code> Id </code> of the <code> Repository 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> compositionId </code> or 
     *          <code> repositoryId </code> not found or <code> compositionId 
     *          </code> not assigned to <code> repositoryId </code> 
     *  @throws org.osid.NullArgumentException <code> compositionId </code> or 
     *          <code> repositoryId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignCompositionFromRepository(org.osid.id.Id compositionId, 
                                                  org.osid.id.Id repositoryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
