//
// org.osid.repository.RepositoryProfile
//
//     The OSID Java specification for org.osid.repository.RepositoryProfile.
//
// Copyright (C) 2002-2004, 2007-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.repository;


/**
 *  <p>The repository profile describes interoperability among repository 
 *  services. </p>
 */

public interface RepositoryProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if federation is visible. 
     *
     *  @return <code> true </code> if visible federation is supported <code> 
     *          , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if asset lookup is supported. 
     *
     *  @return <code> true </code> if asset lookup is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssetLookup();


    /**
     *  Tests if asset query is supported. 
     *
     *  @return <code> true </code> if asset query is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssetQuery();


    /**
     *  Tests if asset search is supported. 
     *
     *  @return <code> true </code> if asset search is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssetSearch();


    /**
     *  Tests if asset administration is supported. 
     *
     *  @return <code> true </code> if asset administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssetAdmin();


    /**
     *  Tests if asset notification is supported. A repository may send 
     *  messages when assets are created, modified, or deleted. 
     *
     *  @return <code> true </code> if asset notification is supported <code> 
     *          , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssetNotification();


    /**
     *  Tests if retrieving mappings of assets and repositories is supported. 
     *
     *  @return <code> true </code> if asset repository mapping retrieval is 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssetRepository();


    /**
     *  Tests if managing mappings of assets and repositories is supported. 
     *
     *  @return <code> true </code> if asset repository assignment is 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssetRepositoryAssignment();


    /**
     *  Tests if asset smart repository is supported. 
     *
     *  @return <code> true </code> if asset smart repository is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssetSmartRepository();


    /**
     *  Tests if retrieving mappings of assets and time coverage is supported. 
     *
     *  @return <code> true </code> if asset temporal mapping retrieval is 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssetTemporal();


    /**
     *  Tests if managing mappings of assets and time ocverage is supported. 
     *
     *  @return <code> true </code> if asset temporal assignment is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssetTemporalAssignment();


    /**
     *  Tests if retrieving mappings of assets and spatial coverage is 
     *  supported. 
     *
     *  @return <code> true </code> if asset spatial mapping retrieval is 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssetSpatial();


    /**
     *  Tests if managing mappings of assets and spatial ocverage is 
     *  supported. 
     *
     *  @return <code> true </code> if asset spatial assignment is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssetSpatialAssignment();


    /**
     *  Tests if assets are included in compositions. 
     *
     *  @return <code> true </code> if asset composition supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssetComposition();


    /**
     *  Tests if mapping assets to compositions is supported. 
     *
     *  @return <code> true </code> if designing asset compositions is 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssetCompositionDesign();


    /**
     *  Tests if composition lookup is supported. 
     *
     *  @return <code> true </code> if composition lookup is supported <code> 
     *          , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCompositionLookup();


    /**
     *  Tests if composition query is supported. 
     *
     *  @return <code> true </code> if composition query is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCompositionQuery();


    /**
     *  Tests if composition search is supported. 
     *
     *  @return <code> true </code> if composition search is supported <code> 
     *          , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCompositionSearch();


    /**
     *  Tests if composition administration is supported. 
     *
     *  @return <code> true </code> if composition administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCompositionAdmin();


    /**
     *  Tests if composition notification is supported. 
     *
     *  @return <code> true </code> if composition notification is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCompositionNotification();


    /**
     *  Tests if retrieval of composition to repository mappings is supported. 
     *
     *  @return <code> true </code> if composition to repository mapping is 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCompositionRepository();


    /**
     *  Tests if assigning composition to repository mappings is supported. 
     *
     *  @return <code> true </code> if composition to repository assignment is 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCompositionRepositoryAssignment();


    /**
     *  Tests if composition smart repository is supported. 
     *
     *  @return <code> true </code> if composition smart repository is 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCompositionSmartRepository();


    /**
     *  Tests if repository lookup is supported. 
     *
     *  @return <code> true </code> if repository lookup is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRepositoryLookup();


    /**
     *  Tests if repository query is supported. 
     *
     *  @return <code> true </code> if repository query is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRepositoryQuery();


    /**
     *  Tests if repository search is supported. 
     *
     *  @return <code> true </code> if repository search is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRepositorySearch();


    /**
     *  Tests if repository administration is supported. 
     *
     *  @return <code> true </code> if repository administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRepositoryAdmin();


    /**
     *  Tests if repository notification is supported. Messages may be sent 
     *  when <code> Repository </code> objects are created, deleted or 
     *  updated. Notifications for assets within repositories are sent via the 
     *  asset notification session. 
     *
     *  @return <code> true </code> if repository notification is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRepositoryNotification();


    /**
     *  Tests if a repository hierarchy traversal is supported. 
     *
     *  @return <code> true </code> if a repository hierarchy traversal is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRepositoryHierarchy();


    /**
     *  Tests if a repository hierarchy design is supported. 
     *
     *  @return <code> true </code> if a repository hierarchy design is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRepositoryHierarchyDesign();


    /**
     *  Tests if a repository batch service is supported. 
     *
     *  @return <code> true </code> if a repository batch service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRepositoryBatch();


    /**
     *  Tests if a repository rules service is supported. 
     *
     *  @return <code> true </code> if a repository rules service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRepositoryRules();


    /**
     *  Gets all the asset record types supported. 
     *
     *  @return the list of supported asset record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAssetRecordTypes();


    /**
     *  Tests if a given asset type is supported. 
     *
     *  @param  assetRecordType the asset record type 
     *  @return <code> true </code> if the asset record type is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> assetRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssetRecordType(org.osid.type.Type assetRecordType);


    /**
     *  Gets all the asset search record types supported. 
     *
     *  @return the list of supported asset search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAssetSearchRecordTypes();


    /**
     *  Tests if a given asset search record type is supported. 
     *
     *  @param  assetSearchRecordType the asset search record type 
     *  @return <code> true </code> if the asset search record type is 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> assetSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssetSearchRecordType(org.osid.type.Type assetSearchRecordType);


    /**
     *  Gets all the asset content record types supported. 
     *
     *  @return the list of supported asset content record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAssetContentRecordTypes();


    /**
     *  Tests if a given asset content record type is supported. 
     *
     *  @param  assetContentRecordType the asset content record type 
     *  @return <code> true </code> if the asset content record type is 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> assetContentRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssetContentRecordType(org.osid.type.Type assetContentRecordType);


    /**
     *  Gets all the composition record types supported. 
     *
     *  @return the list of supported composition record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCompositionRecordTypes();


    /**
     *  Tests if a given composition record type is supported. 
     *
     *  @param  compositionRecordType the composition record type 
     *  @return <code> true </code> if the composition record type is 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> compositionRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCompositionRecordType(org.osid.type.Type compositionRecordType);


    /**
     *  Gets all the composition search record types supported. 
     *
     *  @return the list of supported composition search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCompositionSearchRecordTypes();


    /**
     *  Tests if a given composition search record type is supported. 
     *
     *  @param  compositionSearchRecordType the composition serach type 
     *  @return <code> true </code> if the composition search record type is 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          compositionSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCompositionSearchRecordType(org.osid.type.Type compositionSearchRecordType);


    /**
     *  Gets all the repository record types supported. 
     *
     *  @return the list of supported repository record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getRepositoryRecordTypes();


    /**
     *  Tests if a given repository record type is supported. 
     *
     *  @param  repositoryRecordType the repository record type 
     *  @return <code> true </code> if the repository record type is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> repositoryRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRepositoryRecordType(org.osid.type.Type repositoryRecordType);


    /**
     *  Gets all the repository search record types supported. 
     *
     *  @return the list of supported repository search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getRepositorySearchRecordTypes();


    /**
     *  Tests if a given repository search record type is supported. 
     *
     *  @param  repositorySearchRecordType the repository search type 
     *  @return <code> true </code> if the repository search record type is 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          repositorySearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRepositorySearchRecordType(org.osid.type.Type repositorySearchRecordType);


    /**
     *  Gets all the spatial unit record types supported. 
     *
     *  @return the list of supported spatial unit record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSpatialUnitRecordTypes();


    /**
     *  Tests if a given spatial unit record type is supported. 
     *
     *  @param  spatialUnitRecordType the spatial unit record type 
     *  @return <code> true </code> if the spatial unit record type is 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> spatialUnitRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSpatialUnitRecordType(org.osid.type.Type spatialUnitRecordType);


    /**
     *  Gets all the coordinate types supported. 
     *
     *  @return the list of supported coordinate types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCoordinateTypes();


    /**
     *  Tests if a given coordinate type is supported. 
     *
     *  @param  coordinateType the coordinate type 
     *  @return <code> true </code> if the coordinate type is supported <code> 
     *          , </code> <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> coordinateType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCoordinateType(org.osid.type.Type coordinateType);
}
