//
// org.osid.repository.RepositoryQuery
//
//     The OSID Java specification for org.osid.repository.RepositoryQuery.
//
// Copyright (C) 2002-2004, 2007-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.repository;


/**
 *  <p>This is the query for searching repositories. Each method specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface RepositoryQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Sets the asset <code> Id </code> for this query. 
     *
     *  @param  assetId an asset <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> assetId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAssetId(org.osid.id.Id assetId, boolean match);


    /**
     *  Clears the asset <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAssetIdTerms();


    /**
     *  Tests if an <code> AssetQuery </code> is available. 
     *
     *  @return <code> true </code> if an asset query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssetQuery();


    /**
     *  Gets the query for an asset. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the asset query 
     *  @throws org.osid.UnimplementedException <code> supportsAssetQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssetQuery() </code> is <code> true. </code> 
     */

    public org.osid.repository.AssetQuery getAssetQuery();


    /**
     *  Matches repositories that has any asset mapping. 
     *
     *  @param  match <code> true </code> to match repositories with any 
     *          asset, <code> false </code> to match repositories with no 
     *          asset 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAsset(boolean match);


    /**
     *  Clears the asset terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAssetTerms();


    /**
     *  Sets the composition <code> Id </code> for this query. 
     *
     *  @param  compositionId a composition <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> compositionId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCompositionId(org.osid.id.Id compositionId, boolean match);


    /**
     *  Clears the composition <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCompositionIdTerms();


    /**
     *  Tests if a <code> CompositionQuery </code> is available. 
     *
     *  @return <code> true </code> if a composition query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCompositionQuery();


    /**
     *  Gets the query for a composition. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the composition query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCompositionQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCompositionQuery() </code> is <code> true. </code> 
     */

    public org.osid.repository.CompositionQuery getCompositionQuery();


    /**
     *  Matches repositories that has any composition mapping. 
     *
     *  @param  match <code> true </code> to match repositories with any 
     *          composition, <code> false </code> to match repositories with 
     *          no composition 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyComposition(boolean match);


    /**
     *  Clears the composition terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCompositionTerms();


    /**
     *  Sets the repository <code> Id </code> for this query to match 
     *  repositories that have the specified repository as an ancestor. 
     *
     *  @param  repositoryId a repository <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> repositoryId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorRepositoryId(org.osid.id.Id repositoryId, 
                                          boolean match);


    /**
     *  Clears the ancestor repository <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorRepositoryIdTerms();


    /**
     *  Tests if a <code> RepositoryQuery </code> is available. 
     *
     *  @return <code> true </code> if a repository query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorRepositoryQuery();


    /**
     *  Gets the query for a repository. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the repository query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorRepositoryQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorRepositoryQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.repository.RepositoryQuery getAncestorRepositoryQuery();


    /**
     *  Matches repositories with any ancestor. 
     *
     *  @param  match <code> true </code> to match repositories with any 
     *          ancestor, <code> false </code> to match root repositories 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorRepository(boolean match);


    /**
     *  Clears the ancestor repository terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorRepositoryTerms();


    /**
     *  Sets the repository <code> Id </code> for this query to match 
     *  repositories that have the specified repository as a descendant. 
     *
     *  @param  repositoryId a repository <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> repositoryId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantRepositoryId(org.osid.id.Id repositoryId, 
                                            boolean match);


    /**
     *  Clears the descendant repository <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantRepositoryIdTerms();


    /**
     *  Tests if a <code> RepositoryQuery </code> is available. 
     *
     *  @return <code> true </code> if a repository query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantRepositoryQuery();


    /**
     *  Gets the query for a repository. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the repository query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantRepositoryQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantRepositoryQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.repository.RepositoryQuery getDescendantRepositoryQuery();


    /**
     *  Matches repositories with any descendant. 
     *
     *  @param  match <code> true </code> to match repositories with any 
     *          descendant, <code> false </code> to match leaf repositories 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantRepository(boolean match);


    /**
     *  Clears the descendant repository terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantRepositoryTerms();


    /**
     *  Gets the repository query record corresponding to the given <code> 
     *  Repository </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  repositoryRecordType a repository record type 
     *  @return the repository query record 
     *  @throws org.osid.NullArgumentException <code> repositoryRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(repositoryRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.records.RepositoryQueryRecord getRepositoryQueryRecord(org.osid.type.Type repositoryRecordType)
        throws org.osid.OperationFailedException;
}
