//
// org.osid.repository.RepositorySearchSession
//
//     The OSID Java specification for org.osid.repository.RepositorySearchSession.
//
// Copyright (C) 2002-2004, 2007-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.repository;


/**
 *  <p>This session provides methods for searching among <code> Repository 
 *  </code> objects. The search query is constructed using the <code> 
 *  RepositoryQuery. </code> </p> 
 *  
 *  <p> <code> getRepositoriesByQuery() </code> is the basic search method and 
 *  returns a list of <code> Repository </code> objects.A more advanced search 
 *  may be performed with <code> getRepositoriesBySearch(). </code> It accepts 
 *  a <code> RepositorySearch </code> in addition to the query for the purpose 
 *  of specifying additional options affecting the entire search, such as 
 *  ordering. <code> getRepositoriesBySearch() </code> returns a <code> 
 *  RepositorySearchResults </code> that can be used to access the resulting 
 *  <code> RepositoryList </code> or be used to perform a search within the 
 *  result set through <code> RepositorySearch. </code> </p> 
 *  
 *  <p> Repositories may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> RepositoryQuery. 
 *  </code> </p>
 */

public interface RepositorySearchSession
    extends org.osid.repository.RepositoryQuerySession {


    /**
     *  Gets a repository search. 
     *
     *  @return the repository search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.RepositorySearch getRepositorySearch();


    /**
     *  Gets a repository search order. The <code> RepositorySearchOrder 
     *  </code> is supplied to a <code> RepositorySearch </code> to specify 
     *  the ordering of results. 
     *
     *  @return the repository search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.RepositorySearchOrder getRepositorySearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  repositoryQuery the repository query 
     *  @param  repositorySearch the repository search 
     *  @return the repository search results 
     *  @throws org.osid.NullArgumentException <code> repositoryQuery </code> 
     *          or <code> repositorySearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> repositoryQuery </code> 
     *          or <code> repositorySearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.RepositorySearchResults getRepositoriesBySearch(org.osid.repository.RepositoryQuery repositoryQuery, 
                                                                               org.osid.repository.RepositorySearch repositorySearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a repository query from an inspector. The inspector is available 
     *  from a <code> RepositorySearchResults. </code> 
     *
     *  @param  repositoryQueryInspector a repository query inspector 
     *  @return the repository query 
     *  @throws org.osid.NullArgumentException <code> repositoryQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> repositoryQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.RepositoryQuery getRepositoryQueryFromInspector(org.osid.repository.RepositoryQueryInspector repositoryQueryInspector);
}
