//
// org.osid.repository.rules.CompositionEnablerLookupSession
//
//     The OSID Java specification for org.osid.repository.rules.CompositionEnablerLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.repository.rules;


/**
 *  <p>This session provides methods for retrieving <code> 
 *  CompositionEnablers. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated repository view: All composition enabler methods in this 
 *      session operate, retrieve and pertain to composition enablers defined 
 *      explicitly in the current repository. Using an isolated view is useful 
 *      for managing <code> CompositionEnablers </code> with the <code> 
 *      CompositionEnablerAdminSession. </code> </li> 
 *      <li> federated repository view: All composition enabler methods in 
 *      this session operate, retrieve and pertain to all composition enablers 
 *      defined in this repository and any other composition enablers 
 *      implicitly available in this repository through repository 
 *      inheritence. </li> 
 *      <li> active composition enabler view: All composition enabler lookup 
 *      methods return active composition enablers. </li> 
 *      <li> any status composition enabler view: Composition enablers of any 
 *      active or inactive status are returned from methods. </li> 
 *  </ul>
 *  
 */

public interface CompositionEnablerLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Repository </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Repository Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getRepositoryId();


    /**
     *  Gets the <code> Repository </code> associated with this session. 
     *
     *  @return the repository 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.Repository getRepository()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> CompositionEnablers </code> 
     *  lookups. A return of true does not guarantee successful authorization. 
     *  A return of false indicates that it is known all methods in this 
     *  session will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer lookup 
     *  operations to unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupCompositionEnablers();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeCompositionEnablerView();


    /**
     *  A complete view of the <code> CompositionEnabler </code> returns is 
     *  desired. Methods will return what is requested or result in an error. 
     *  This view is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryCompositionEnablerView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include composition enablers in repositories which are children of 
     *  this repository in the repository hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedRepositoryView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this repository only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedRepositoryView();


    /**
     *  Only active composition enablers are returned by methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveCompositionEnablerView();


    /**
     *  All active and inactive composition enablers are returned by methods 
     *  in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusCompositionEnablerView();


    /**
     *  Gets the <code> CompositionEnabler </code> specified by its <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  CompositionEnabler </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> CompositionEnabler </code> and retained for 
     *  compatibility. 
     *  
     *  In active mode, composition enablers are returned that are currently 
     *  active in addition to being effective during the given date range. In 
     *  any status mode, active and inactive composition enablers are 
     *  returned. 
     *
     *  @param  compositionEnablerId <code> Id </code> of the <code> 
     *          CompositionEnabler </code> 
     *  @return the composition enabler 
     *  @throws org.osid.NotFoundException <code> compositionEnablerId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> compositionEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.repository.rules.CompositionEnabler getCompositionEnabler(org.osid.id.Id compositionEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CompositionEnablerList </code> corresponding to the 
     *  given <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  composition enablers specified in the <code> Id </code> list, in the 
     *  order of the list, including duplicates, or an error results if an 
     *  <code> Id </code> in the supplied list is not found or inaccessible. 
     *  Otherwise, inaccessible <code> CompositionEnablers </code> may be 
     *  omitted from the list and may present the elements in any order 
     *  including returning a unique set. 
     *  
     *  In active mode, composition enablers are returned that are currently 
     *  active in addition to being effective during the given date range. In 
     *  any status mode, active and inactive composition enablers are 
     *  returned. 
     *
     *  @param  compositionEnablerIds the list of <code> Ids </code> to 
     *          retrieve 
     *  @return the returned <code> CompositionEnabler </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> compositionEnablerIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.rules.CompositionEnablerList getCompositionEnablersByIds(org.osid.id.IdList compositionEnablerIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CompositionEnablerList </code> corresponding to the 
     *  given composition enabler genus <code> Type </code> which does not 
     *  include composition enablers of genus types derived from the specified 
     *  <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  composition enablers or an error results. Otherwise, the returned list 
     *  may contain only those composition enablers that are accessible 
     *  through this session. 
     *  
     *  In active mode, composition enablers are returned that are currently 
     *  active in addition to being effective during the given date range. In 
     *  any status mode, active and inactive composition enablers are 
     *  returned. 
     *
     *  @param  compositionEnablerGenusType a composition enabler genus type 
     *  @return the returned <code> CompositionEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          compositionEnablerGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.rules.CompositionEnablerList getCompositionEnablersByGenusType(org.osid.type.Type compositionEnablerGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CompositionEnablerList </code> corresponding to the 
     *  given composition enabler genus <code> Type </code> and include any 
     *  additional composition enablers with genus types derived from the 
     *  specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  composition enablers or an error results. Otherwise, the returned list 
     *  may contain only those composition enablers that are accessible 
     *  through this session. 
     *  
     *  In active mode, composition enablers are returned that are currently 
     *  active in addition to being effective during the given date range. In 
     *  any status mode, active and inactive composition enablers are 
     *  returned. 
     *
     *  @param  compositionEnablerGenusType a composition enabler genus type 
     *  @return the returned <code> CompositionEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          compositionEnablerGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.rules.CompositionEnablerList getCompositionEnablersByParentGenusType(org.osid.type.Type compositionEnablerGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CompositionEnablerList </code> containing the given 
     *  composition enabler record <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  composition enablers or an error results. Otherwise, the returned list 
     *  may contain only those composition enablers that are accessible 
     *  through this session. 
     *  
     *  In active mode, composition enablers are returned that are currently 
     *  active in addition to being effective during the given date range. In 
     *  any status mode, active and inactive composition enablers are 
     *  returned. 
     *
     *  @param  compositionEnablerRecordType a composition enabler record type 
     *  @return the returned <code> CompositionEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          compositionEnablerRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.rules.CompositionEnablerList getCompositionEnablersByRecordType(org.osid.type.Type compositionEnablerRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CompositionEnablerList </code> that are effective for 
     *  the entire given date range inclusive but not confined to the date 
     *  range for any agent. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  composition enablers or an error results. Otherwise, the returned list 
     *  may contain only those composition enablers that are accessible 
     *  through this session. 
     *  
     *  In active mode, composition enablers are returned that are currently 
     *  active in addition to being effective during the given date range. In 
     *  any status mode, active and inactive composition enablers are 
     *  returned. 
     *
     *  @param  from a start date 
     *  @param  to an end date 
     *  @return the returned <code> CompositionEnabler </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.rules.CompositionEnablerList getCompositionEnablersOnDate(org.osid.calendaring.DateTime from, 
                                                                                         org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CompositionEnablerList </code> that are effective for 
     *  the entire given date range inclusive but not confined to the date 
     *  range evaluated against the given agent. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  composition enablers or an error results. Otherwise, the returned list 
     *  may contain only those composition enablers that are accessible 
     *  through this session. 
     *  
     *  In active mode, composition enablers are returned that are currently 
     *  active in addition to being effective during the given date range. In 
     *  any status mode, active and inactive composition enablers are 
     *  returned. 
     *
     *  @param  agentId an agent <code> Id </code> 
     *  @param  from a start date 
     *  @param  to an end date 
     *  @return the returned <code> CompositionEnabler </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> agentId, from, </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.rules.CompositionEnablerList getCompositionEnablersOnDateWithAgent(org.osid.id.Id agentId, 
                                                                                                  org.osid.calendaring.DateTime from, 
                                                                                                  org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> CompositionEnablers. </code> 
     *  
     *  In plenary mode, the returned list contains all known composition 
     *  enablers or an error results. Otherwise, the returned list may contain 
     *  only those composition enablers that are accessible through this 
     *  session. 
     *  
     *  In active mode, composition enablers are returned that are currently 
     *  active in addition to being effective during the given date range. In 
     *  any status mode, active and inactive composition enablers are 
     *  returned. 
     *
     *  @return the returned <code> CompositionEnabler </code> list 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.rules.CompositionEnablerList getCompositionEnablers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
