//
// org.osid.repository.rules.CompositionEnablerRuleApplicationSession
//
//     The OSID Java specification for org.osid.repository.rules.CompositionEnablerRuleApplicationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.repository.rules;


/**
 *  <p>This session provides methods to apply <code> CompositionEnablers 
 *  </code> to <code> Compositions. </code> A <code> Composition </code> with 
 *  multiple <code> CompositionEnablers </code> means any positive rule 
 *  evaluation across the enablers result in a visible <code> Composition. 
 *  </code> </p>
 */

public interface CompositionEnablerRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Repository </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Repository Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getRepositoryId();


    /**
     *  Gets the <code> Repository </code> associated with this session. 
     *
     *  @return the repository 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.Repository getRepository()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter composition enabler/composition mappings. 
     *  A return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignCompositionEnablers();


    /**
     *  Adds an existing <code> CompositionEnabler </code> to a <code> 
     *  Composition. </code> 
     *
     *  @param  compositionEnablerId the <code> Id </code> of the <code> 
     *          CompositionEnabler </code> 
     *  @param  compositionId the <code> Id </code> of the <code> Composition 
     *          </code> 
     *  @throws org.osid.AlreadyExistsException <code> compositionEnablerId 
     *          </code> is already applied to <code> compositionId </code> 
     *  @throws org.osid.NotFoundException <code> compositionEnablerId </code> 
     *          or <code> compositionId </code> not found 
     *  @throws org.osid.NullArgumentException <code> compositionEnablerId 
     *          </code> or <code> compositionId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignCompositionEnablerToComposition(org.osid.id.Id compositionEnablerId, 
                                                      org.osid.id.Id compositionId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> CompositionEnabler </code> from a <code> Composition. 
     *  </code> 
     *
     *  @param  compositionEnablerId the <code> Id </code> of the <code> 
     *          CompositionEnabler </code> 
     *  @param  compositionId the <code> Id </code> of the <code> Composition 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> compositionEnablerId </code> 
     *          or <code> compositionId </code> not found or <code> 
     *          compositionEnablerId </code> not applied to <code> 
     *          compositionId </code> 
     *  @throws org.osid.NullArgumentException <code> compositionEnablerId 
     *          </code> or <code> compositionId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignCompositionEnablerFromComposition(org.osid.id.Id compositionEnablerId, 
                                                          org.osid.id.Id compositionId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> CompositionEnablers. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known sequencing operations will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> CompositionEnabler </code> 
     *          ordering is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceCompositionEnablers();


    /**
     *  Reorders composiiton enablers for a composiiton by moving the 
     *  specified composiiton enabler in front of a reference composiiton 
     *  enabler. 
     *
     *  @param  composiitonEnablerId the <code> Id </code> of a <code> 
     *          CompositionEnabler </code> 
     *  @param  composiitonId the <code> Id </code> of a <code> Composition 
     *          </code> 
     *  @param  referenceId the reference composiiton enabler <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> composiitonEnablerId, 
     *          composiitonId, </code> or <code> referenceId </code> not found 
     *          or, <code> composiitonEnablerId </code> or <code> referenceId 
     *          </code> not related to <code> composiitonId </code> 
     *  @throws org.osid.NullArgumentException <code> composiitonEnablerId, 
     *          composiitonId, </code> or <code> referenceId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveCompositionEnablerAhead(org.osid.id.Id composiitonEnablerId, 
                                            org.osid.id.Id composiitonId, 
                                            org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders composiiton enablers for a composiiton by moving the 
     *  specified composiiton enabler behind a reference composiiton enabler. 
     *
     *  @param  composiitonEnablerId the <code> Id </code> of a <code> 
     *          CompositionEnabler </code> 
     *  @param  composiitonId the <code> Id </code> of a <code> Composition 
     *          </code> 
     *  @param  referenceId the reference composiiton enabler <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> composiitonEnablerId, 
     *          composiitonId, </code> or <code> referenceId </code> not found 
     *          or, <code> composiitonEnablerId </code> or <code> referenceId 
     *          </code> not related to <code> composiitonId </code> 
     *  @throws org.osid.NullArgumentException <code> composiitonEnablerId, 
     *          composiitonId, </code> or <code> referenceId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveCompositionEnablerBehind(org.osid.id.Id composiitonEnablerId, 
                                             org.osid.id.Id composiitonId, 
                                             org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of composiiton enablers for a composiiton. 
     *
     *  @param  composiitonEnablerIds the <code> Ids </code> for a set of 
     *          <code> CompositionEnablers </code> 
     *  @param  composiitonId the <code> Id </code> of a <code> Composition 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> composiitonId </code> not 
     *          found or, an <code> composiitonEnablerId </code> not related 
     *          to <code> composiitonId </code> 
     *  @throws org.osid.NullArgumentException <code> composiitonEnablerIds 
     *          </code> or <code> composiitonId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderCompositionEnablers(org.osid.id.Id[] composiitonEnablerIds, 
                                         org.osid.id.Id composiitonId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
