//
// org.osid.repository.rules.RepositoryRulesProxyManager
//
//     The OSID Java specification for org.osid.repository.rules.RepositoryRulesProxyManager.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.repository.rules;


/**
 *  <p>The repository rules proxy manager provides access to repository rules 
 *  sessions and provides interoperability tests for various aspects of this 
 *  service. Methods in this manager pass a <code> Proxy </code> for passing 
 *  information from server environments. The sessions included in this 
 *  manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> CompositionEnablerLookupSession: </code> a session to 
 *      retrieve composition enablers </li> 
 *      <li> <code> CompositionEnablerQuerySession: </code> a session to query 
 *      for composition enablers </li> 
 *      <li> <code> CompositionEnablerSearchSession: </code> a session to 
 *      search for composition enablers </li> 
 *      <li> <code> CompositionEnablerAdminSession: </code> a session to 
 *      create and delete composition enablers </li> 
 *      <li> <code> CompositionEnablerNotificationSession: </code> a session 
 *      to receive notifications pertaining to composition enabler changes 
 *      </li> 
 *      <li> <code> CompositionEnablerRepositorySession: </code> a session to 
 *      look up composition enabler repository mappings </li> 
 *      <li> <code> CompositionEnablerRepositoryAssignmentSession: </code> a 
 *      session to manage composition enabler to repository mappings </li> 
 *      <li> <code> CompositionEnablerSmartRepositorySession: </code> a 
 *      session to manage dynamic repositories of composition enablers </li> 
 *      <li> <code> CompositionEnablerRuleLookupSession: </code> a session to 
 *      look up composition enabler to composition mappings </li> 
 *      <li> <code> CompositionEnablerRuleApplicationSession: </code> a 
 *      session to apply composition enablers to compositions </li> 
 *  </ul>
 *  
 */

public interface RepositoryRulesProxyManager
    extends org.osid.OsidProxyManager,
            org.osid.repository.rules.RepositoryRulesProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the composition 
     *  enabler lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> CompositionEnablerLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCompositionEnablerLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCompositionEnablerLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.repository.rules.CompositionEnablerLookupSession getCompositionEnablerLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the composition 
     *  enabler lookup service for the given repository. 
     *
     *  @param  repositoryId the <code> Id </code> of the <code> Repository 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> CompositionEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Repository </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> repositoryId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCompositionEnablerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCompositionEnablerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.repository.rules.CompositionEnablerLookupSession getCompositionEnablerLookupSessionForRepository(org.osid.id.Id repositoryId, 
                                                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the composition 
     *  enabler query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> CompositionEnablerQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCompositionEnablerQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCompositionEnablerQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.repository.rules.CompositionEnablerQuerySession getCompositionEnablerQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the composition 
     *  enabler query service for the given repository. 
     *
     *  @param  repositoryId the <code> Id </code> of the <code> Repository 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> CompositionEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Repository </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> repositoryId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCompositionEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCompositionEnablerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.repository.rules.CompositionEnablerQuerySession getCompositionEnablerQuerySessionForRepository(org.osid.id.Id repositoryId, 
                                                                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the composition 
     *  enabler search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> CompositionEnablerSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCompositionEnablerSearch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCompositionEnablerSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.repository.rules.CompositionEnablerSearchSession getCompositionEnablerSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the composition 
     *  enablers earch service for the given repository. 
     *
     *  @param  repositoryId the <code> Id </code> of the <code> Repository 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> CompositionEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Repository </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> repositoryId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCompositionEnablerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCompositionEnablerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.repository.rules.CompositionEnablerSearchSession getCompositionEnablerSearchSessionForRepository(org.osid.id.Id repositoryId, 
                                                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the composition 
     *  enabler administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> CompositionEnablerAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCompositionEnablerAdmin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCompositionEnablerAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.repository.rules.CompositionEnablerAdminSession getCompositionEnablerAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the composition 
     *  enabler administration service for the given repository. 
     *
     *  @param  repositoryId the <code> Id </code> of the <code> Repository 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> CompositionEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Repository </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> repositoryId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCompositionEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCompositionEnablerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.repository.rules.CompositionEnablerAdminSession getCompositionEnablerAdminSessionForRepository(org.osid.id.Id repositoryId, 
                                                                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the composition 
     *  enabler notification service. 
     *
     *  @param  compositionEnablerReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> CompositionEnablerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          compositionEnablerReceiver </code> or <code> proxy </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCompositionEnablerNotification() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCompositionEnablerNotification() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.repository.rules.CompositionEnablerNotificationSession getCompositionEnablerNotificationSession(org.osid.repository.rules.CompositionEnablerReceiver compositionEnablerReceiver, 
                                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the composition 
     *  enabler notification service for the given repository. 
     *
     *  @param  compositionEnablerReceiver the notification callback 
     *  @param  repositoryId the <code> Id </code> of the <code> Repository 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> CompositionEnablerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no repository found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          compositionEnablerReceiver, repositoryId, </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCompositionEnablerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCompositionEnablerNotification() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.repository.rules.CompositionEnablerNotificationSession getCompositionEnablerNotificationSessionForRepository(org.osid.repository.rules.CompositionEnablerReceiver compositionEnablerReceiver, 
                                                                                                                                 org.osid.id.Id repositoryId, 
                                                                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup composition 
     *  enabler/composition mappings for composition enablers. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> CompositionEnablerRepositorySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCompositionEnablerRepository() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCompositionEnablerRepository() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.repository.rules.CompositionEnablerRepositorySession getCompositionEnablerRepositorySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning 
     *  composition enablers to repositories. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> CompositionEnablerRepositoryAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCompositionEnablerCompositionAssignment() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCompositionEnablerRepositoryAssignment() </code> 
     *              is <code> true. </code> 
     */

    public org.osid.repository.rules.CompositionEnablerRepositoryAssignmentSession getCompositionEnablerRepositoryAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage composition enabler 
     *  smart repositories. 
     *
     *  @param  repositoryId the <code> Id </code> of the <code> Repository 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> CompositionEnablerSmartRepositorySession </code> 
     *  @throws org.osid.NotFoundException no <code> Repository </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> repositoryId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCompositionEnablerSmartRepository() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCompositionEnablerSmartRepository() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.repository.rules.CompositionEnablerSmartRepositorySession getCompositionEnablerSmartRepositorySession(org.osid.id.Id repositoryId, 
                                                                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the composition 
     *  enabler mapping lookup service for looking up the rules applied to the 
     *  composition. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> CompositionEnablerRuleLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCompositionEnablerRuleLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCompositionEnablerRuleLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.repository.rules.CompositionEnablerRuleLookupSession getCompositionEnablerRuleLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the composition 
     *  enabler mapping lookup service for the given composition for looking 
     *  up rules applied to a composition. 
     *
     *  @param  repositoryId the <code> Id </code> of the <code> Repository 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> CompositionEnablerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Repository </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> repositoryId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCompositionEnablerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCompositionEnablerRuleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.repository.rules.CompositionEnablerRuleLookupSession getCompositionEnablerRuleLookupSessionForRepository(org.osid.id.Id repositoryId, 
                                                                                                                             org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the composition 
     *  enabler assignment service to apply enablers to compositions. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> CompositionEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCompositionEnablerRuleApplication() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCompositionEnablerRuleApplication() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.repository.rules.CompositionEnablerRuleApplicationSession getCompositionEnablerRuleApplicationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the composition 
     *  enabler assignment service for the given composition to apply enablers 
     *  to compositions. 
     *
     *  @param  repositoryId the <code> Id </code> of the <code> Repository 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> CompositionEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Repository </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> repositoryId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCompositionEnablerRuleApplication() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCompositionEnablerRuleApplication() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.repository.rules.CompositionEnablerRuleApplicationSession getCompositionEnablerRuleApplicationSessionForRepository(org.osid.id.Id repositoryId, 
                                                                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;
}
