//
// org.osid.resource.Resource
//
//     The OSID Java specification for org.osid.resource.Resource.
//
// Copyright (C) 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resource;


/**
 *  <p>A <code> Resource </code> represents an arbitrary entity. Resources are 
 *  used to define an object to accompany an OSID <code> Id </code> used in 
 *  other OSIDs. A resource may be used to represent a meeting room in the 
 *  Scheduling OSID, or a student in the Course OSID. </p> 
 *  
 *  <p> A <code> Resource </code> may also represent a group or organization. 
 *  A provider may present such a group in an opaque manner through a single 
 *  resource definition, or the provider may expose the resource collection 
 *  for examination or manipulation. If such a resource collection is visible, 
 *  <code> isGroup() </code> is <code> true </code> and can be used in one of 
 *  the group sessions available in this OSID. </p>
 */

public interface Resource
    extends org.osid.OsidObject {


    /**
     *  Tests if this resource is a group. A resource that is a group can be 
     *  used in the group sessions. 
     *
     *  @return <code> true </code> if this resource is a group, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isGroup();


    /**
     *  Tests if this resource is a demographic. A resource that is a 
     *  demographic can be used in the demographic service and the group 
     *  sessions. 
     *
     *  @return <code> true </code> if this resource is a demographic, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isDemographic();


    /**
     *  Tests if this resource has an avatar. 
     *
     *  @return <code> true </code> if this resource has an avatar, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasAvatar();


    /**
     *  Gets the asset <code> Id. </code> 
     *
     *  @return the asset <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> hasAvatar() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAvatarId();


    /**
     *  Gets the asset. 
     *
     *  @return the asset 
     *  @throws org.osid.IllegalStateException <code> hasAvatar() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.Asset getAvatar()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the resource record corresponding to the given <code> Resource 
     *  </code> record <code> Type. </code> This method is used to retrieve an 
     *  object implementing the requested record. The <code> 
     *  resourceRecordType </code> may be the <code> Type </code> returned in 
     *  <code> getRecordTypes() </code> or any of its parents in a <code> Type 
     *  </code> hierarchy where <code> hasRecordType(resourceRecordType) 
     *  </code> is <code> true </code> . 
     *
     *  @param  resourceRecordType the resource record type 
     *  @return the resource record 
     *  @throws org.osid.NullArgumentException <code> resourceRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(resourceRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.records.ResourceRecord getResourceRecord(org.osid.type.Type resourceRecordType)
        throws org.osid.OperationFailedException;
}
