//
// org.osid.resource.ResourceQuery
//
//     The OSID Java specification for org.osid.resource.ResourceQuery.
//
// Copyright (C) 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resource;


/**
 *  <p>This is the query for searching resources. Each method specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface ResourceQuery
    extends org.osid.OsidObjectQuery {


    /**
     *  Matches resources that are also groups. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchGroup(boolean match);


    /**
     *  Clears the group terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGroupTerms();


    /**
     *  Matches resources that are also demographics. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDemographic(boolean match);


    /**
     *  Clears the demographic terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDemographicTerms();


    /**
     *  Sets the group <code> Id </code> for this query to match resources 
     *  within the given group. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchContainingGroupId(org.osid.id.Id resourceId, 
                                       boolean match);


    /**
     *  Clears the group <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearContainingGroupIdTerms();


    /**
     *  Tests if a <code> ResourceQuery </code> is available for querying 
     *  containing groups. 
     *
     *  @return <code> true </code> if a group resource query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsContainingGroupQuery();


    /**
     *  Gets the query for a a containing group. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the resource query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsContainingGroupQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAgentQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceQuery getContainingGroupQuery();


    /**
     *  Matches resources inside any group. 
     *
     *  @param  match <code> true </code> to match any containing group, 
     *          <code> false </code> to match resources part of no groups 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyContainingGroup(boolean match);


    /**
     *  Clears the containing group terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearContainingGroupTerms();


    /**
     *  Sets the asset <code> Id </code> for this query. 
     *
     *  @param  assetId the asset <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> assetId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAvatarId(org.osid.id.Id assetId, boolean match);


    /**
     *  Clears the asset <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAvatarIdTerms();


    /**
     *  Tests if an <code> AssetQuery </code> is available. 
     *
     *  @return <code> true </code> if an asset query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAvatarQuery();


    /**
     *  Gets the query for an asset. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the asset query 
     *  @throws org.osid.UnimplementedException <code> supportsAvatarQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAvatarQuery() </code> is <code> true. </code> 
     */

    public org.osid.repository.AssetQuery getAvatarQuery();


    /**
     *  Matches resources with any asset. 
     *
     *  @param  match <code> true </code> to match any asset, <code> false 
     *          </code> to match resources with no asset 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAvatar(boolean match);


    /**
     *  Clears the asset terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAvatarTerms();


    /**
     *  Sets the agent <code> Id </code> for this query. 
     *
     *  @param  agentId the agent <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> agentId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAgentId(org.osid.id.Id agentId, boolean match);


    /**
     *  Clears the agent <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAgentIdTerms();


    /**
     *  Tests if an <code> AgentQuery </code> is available. 
     *
     *  @return <code> true </code> if an agent query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAgentQuery();


    /**
     *  Gets the query for an agent. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the agent query 
     *  @throws org.osid.UnimplementedException <code> supportsAgentQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAgentQuery() </code> is <code> true. </code> 
     */

    public org.osid.authentication.AgentQuery getAgentQuery();


    /**
     *  Matches resources with any agent. 
     *
     *  @param  match <code> true </code> to match any agent, <code> false 
     *          </code> to match resources with no agent 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAgent(boolean match);


    /**
     *  Clears the agent terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAgentTerms();


    /**
     *  Sets the resource relationship <code> Id </code> for this query. 
     *
     *  @param  resourceRelationshipId the resource relationship <code> Id 
     *          </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> resourceRelationshipId 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchResourceRelationshipId(org.osid.id.Id resourceRelationshipId, 
                                            boolean match);


    /**
     *  Clears the resource relationship <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearResourceRelationshipIdTerms();


    /**
     *  Tests if a <code> ResourceRelationshipQuery </code> is available. 
     *
     *  @return <code> true </code> if a resource relationship query is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceRelationshipQuery();


    /**
     *  Gets the query for aa resource relationship. Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @return the resource relationship query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResourceRelationshipQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceRelationshipQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.resource.ResourceRelationshipQuery getResourceRelationshipQuery();


    /**
     *  Matches resources with any resource relationship. 
     *
     *  @param  match <code> true </code> to match any resource relationship, 
     *          <code> false </code> to match resources with no relationship 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyResourceRelationship(boolean match);


    /**
     *  Clears the resource relationship terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearResourceRelationshipTerms();


    /**
     *  Sets the bin <code> Id </code> for this query. 
     *
     *  @param  binId the bin <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> binId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBinId(org.osid.id.Id binId, boolean match);


    /**
     *  Clears the bin <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBinIdTerms();


    /**
     *  Tests if a <code> BinQuery </code> is available. 
     *
     *  @return <code> true </code> if a bin query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBinQuery();


    /**
     *  Gets the query for a bin. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the bin query 
     *  @throws org.osid.UnimplementedException <code> supportsBinQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBinQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.BinQuery getBinQuery();


    /**
     *  Clears the bin terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBinTerms();


    /**
     *  Gets the resource query record corresponding to the given <code> 
     *  Resource </code> record <code> Type. </code> Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @param  resourceRecordType a resource record type 
     *  @return the resource query record 
     *  @throws org.osid.NullArgumentException <code> resourceRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(resourceRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.records.ResourceQueryRecord getResourceQueryRecord(org.osid.type.Type resourceRecordType)
        throws org.osid.OperationFailedException;
}
