//
// org.osid.resource.ResourceRelationship
//
//     The OSID Java specification for org.osid.resource.ResourceRelationship.
//
// Copyright (C) 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resource;


/**
 *  <p><code> ResourceRelationship </code> relates two resources. </p>
 */

public interface ResourceRelationship
    extends org.osid.OsidRelationship {


    /**
     *  Gets the source resource <code> Id. </code> 
     *
     *  @return a resource <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getSourceResourceId();


    /**
     *  Gets the <code> Resource. </code> 
     *
     *  @return the source resource 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getSourceResource()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the destination resource <code> Id. </code> 
     *
     *  @return a resource <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDestinationResourceId();


    /**
     *  Gets the <code> Resource. </code> 
     *
     *  @return the destination resource 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getDestinationResource()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the resource relationship record corresponding to the given 
     *  <code> ResourceRelationship </code> record <code> Type. </code> This 
     *  method is used to retrieve an object implementing the requested 
     *  record. The <code> resourceRelationshipRecordType </code> may be the 
     *  <code> Type </code> returned in <code> getRecordTypes() </code> or any 
     *  of its parents in a <code> Type </code> hierarchy where <code> 
     *  hasRecordType(resourceRelationshipRecordType) </code> is <code> true 
     *  </code> . 
     *
     *  @param  resourceRelationshipRecordType the type of the record to 
     *          retrieve 
     *  @return the resource relationship record 
     *  @throws org.osid.NullArgumentException <code> 
     *          resourceRelationshipRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(resourceRelationshipRecordType) </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.records.ResourceRelationshipRecord getResourceRelationshipRecord(org.osid.type.Type resourceRelationshipRecordType)
        throws org.osid.OperationFailedException;
}
