//
// org.osid.resource.batch.BinBatchAdminSession
//
//     The OSID Java specification for org.osid.resource.batch.BinBatchAdminSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resource.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Bins </code> in bulk. 
 *  The data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create an 
 *  <code> Bin, </code> an <code> BinForm </code> is requested using <code> 
 *  getBinFormsForCreate() </code> specifying the desired record <code> Types 
 *  </code> or none if no record <code> Types </code> are needed. Each of the 
 *  returned <code> BinForms </code> will indicate that it is to be used with 
 *  a create operation and can be used to examine metdata or validate data 
 *  prior to creation. Once an <code> BinForm </code> is submiited to a create 
 *  operation, it cannot be reused with another create operation unless the 
 *  first operation was unsuccessful. Each <code> BinForm </code> corresponds 
 *  to an attempted transaction. </p> 
 *  
 *  <p> The <code> BinForms </code> returned from <code> 
 *  getBinFormsForCreate() </code> may be linked to the originating request 
 *  through the peer <code> Ids </code> of the <code> BinForm. </code> In the 
 *  case where there may be duplicates, any <code> BinForm </code> of the same 
 *  peer <code> Ids </code> may be used for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> BinForms </code> are submitted for create, a 
 *  <code> CreateResponse </code> is returned for each <code> BinForm, </code> 
 *  although the ordering is not defined. Only errors that pertain to the 
 *  entire create operation are returned from <code> createBins(), </code> 
 *  errors specific to an individual <code> BinForm </code> are indicated in 
 *  the corresponding <code> CreateResponse. </code> <code> CreateResponses 
 *  </code> may be linked to the originating <code> BinForm </code> through 
 *  the <code> BinForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> BinForms </code> are requested to the <code> Bin 
 *  </code> <code> Id </code> that is to be updated using <code> 
 *  getBinFormsForUpdate() </code> where the reference <code> Id </code> in 
 *  the <code> BinForm </code> may be used to link the request. Similarly, the 
 *  <code> BinForm </code> has metadata about the data that can be updated and 
 *  it can perform validation before submitting the update. The <code> BinForm 
 *  </code> can only be used once for a successful update and cannot be 
 *  reused. </p> 
 *  
 *  <p> Once a batch of <code> BinForms </code> are submitted for update, an 
 *  <code> UpdateResponse </code> is returned for each <code> BinForm, </code> 
 *  although the ordering is not defined. Only errors that pertain to the 
 *  entire update operation are returned from <code> updateBins(), </code> 
 *  errors specific to an individual <code> BinForm </code> are indicated in 
 *  the corresponding <code> UpdateResponse. </code> <code> UpdateResponses 
 *  </code> may be linked to the originating <code> BinForm </code> through 
 *  the <code> BinForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> Bins </code> in bulk. Bulk delete 
 *  operations return the results in <code> DeleteResponses. </code> </p>
 */

public interface BinBatchAdminSession
    extends org.osid.resource.BinAdminSession {


    /**
     *  Gets the bin forms for creating a bunch of new bins. 
     *
     *  @param  number the number of forms to retrieve 
     *  @param  binRecordTypes array of bin record types to be included in 
     *          each create operation or an empty list if none 
     *  @return the bin forms 
     *  @throws org.osid.NullArgumentException <code> binRecordTypes </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.batch.BinBatchFormList getBinFormsForCreate(long number, 
                                                                         org.osid.type.Type[] binRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Bins. </code> This method returns an error 
     *  if the entire operation fails. Otherwise, the status of an individual 
     *  create operation is indicated in the <code> BatchCreateResponse 
     *  </code> . 
     *
     *  @param  binForms the bin forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> binForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createBins(org.osid.resource.batch.BinBatchFormList binForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the bin forms for updating an existing set of bins. A new bin 
     *  form should be requested for each update transaction. 
     *
     *  @param  binIds the <code> Ids </code> of the <code> Bin </code> 
     *  @return the bin form 
     *  @throws org.osid.NotFoundException an <code> binId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> binIds </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.batch.BinBatchFormList getBinFormsForUpdate(org.osid.id.IdList binIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing bins. This method returns an error if the entire 
     *  operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  binForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> binForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateBins(org.osid.resource.batch.BinBatchFormList binForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Bins. </code> 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllBins()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes bins for the given <code> Ids. </code> 
     *
     *  @param  binIds the <code> Ids </code> of the bins to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> binIds </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteBins(org.osid.id.IdList binIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to an <code> Bin </code> for the purpose of 
     *  creating compatibility. The primary <code> Id </code> of the <code> 
     *  Bin </code> is determined by the provider. The new <code> Id </code> 
     *  is an alias to the primary <code> Id. </code> If the alias is a 
     *  pointer to another bin, it is reassigned to the given entry <code> Id. 
     *  </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasBins(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
