//
// org.osid.resource.demographic.DemographicEnablerSearchSession
//
//     The OSID Java specification for org.osid.resource.demographic.DemographicEnablerSearchSession.
//
// Copyright (C) 2010 Ingenescus All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resource.demographic;


/**
 *  <p>This session provides methods for searching among <code> 
 *  DemographicEnabler </code> objects. The search query is constructed using 
 *  the <code> DemographicEnableryQuery. </code> </p> 
 *  
 *  <p> <code> getDemographicEnablersByQuery() </code> is the basic search 
 *  method and returns a list of <code> DemographicEnablers. </code> A more 
 *  advanced search may be performed with <code> 
 *  getDemographicEnablersBySearch(). </code> It accepts a <code> 
 *  DemographicEnablerSearch </code> in addition to the query for the purpose 
 *  of specifying additional options affecting the entire search, such as bin. 
 *  <code> getDemographicEnablersBySearch() </code> returns a <code> 
 *  DemographicEnablerSearchResults </code> that can be used to access the 
 *  resulting <code> DemographicEnablerList </code> or be used to perform a 
 *  search within the result set through <code> DemographicEnablerSearch. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated bin view: searches include demographic enablers in bins 
 *      of which this bin is an ancestor in the bin hierarchy </li> 
 *      <li> isolated bin view: searches are restricted to demographic 
 *      enablers in this bin </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> DemographicEnablers </code> may have a query record indicated 
 *  by their respective record types. The query record is accessed via the 
 *  <code> DemographicEnablerQuery. </code> </p>
 */

public interface DemographicEnablerSearchSession
    extends org.osid.resource.demographic.DemographicEnablerQuerySession {


    /**
     *  Gets a demographic enabler search. 
     *
     *  @return the demographic enabler search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.demographic.DemographicEnablerSearch getDemographicEnablerSearch();


    /**
     *  Gets a demographic enabler search order. The <code> 
     *  DemographicEnablerSearchOrder </code> is supplied to a <code> 
     *  DemographicEnablerSearch </code> to specify the ordering of results. 
     *
     *  @return the demographic enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.demographic.DemographicEnablerSearchOrder getDemographicEnablerSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  demographicEnablerQuery the demographic enabler query 
     *  @param  demographicEnablerSearch the demographic enabler search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> demographicEnablerQuery 
     *          </code> or <code> demographicEnablerSearch </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> demographicEnablerQuery 
     *          </code> or <code> demographicEnablerSearch </code> is not of 
     *          this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.demographic.DemographicEnablerSearchResults getDemographicEnablersBySearch(org.osid.resource.demographic.DemographicEnablerQuery demographicEnablerQuery, 
                                                                                                        org.osid.resource.demographic.DemographicEnablerSearch demographicEnablerSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a demographic enabler query from an inspector. The inspector is 
     *  available from a <code> DemographicEnablerSearchResults. </code> 
     *
     *  @param  demographicEnablerQueryInspector a demographic enabler query 
     *          inspector 
     *  @return the demographic enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          demographicEnablerQueryInspector </code> is <code> null 
     *          </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          demographicEnablerQueryInspector </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.demographic.DemographicEnablerQuery getDemographicEnablerQueryFromInspector(org.osid.resource.demographic.DemographicEnablerQueryInspector demographicEnablerQueryInspector);
}
