//
// org.osid.resource.demographic.ResourceDemographicManager
//
//     The OSID Java specification for org.osid.resource.demographic.ResourceDemographicManager.
//
// Copyright (C) 2010 Ingenescus All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resource.demographic;


/**
 *  <p>The resource demographic manager provides access to resource 
 *  demographic sessions and provides interoperability tests for various 
 *  aspects of this service. The sessions included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> DemographicLookupSession: </code> a session to retrieve 
 *      demographic </li> 
 *      <li> <code> DemographicQuerySession: </code> a session to query for 
 *      demographic </li> 
 *      <li> <code> DemographicSearchSession: </code> a session to search for 
 *      demographic </li> 
 *      <li> <code> DemographicAdminSession: </code> a session to create and 
 *      delete demographic </li> 
 *      <li> <code> DemographicBuilderSession: </code> a session to build 
 *      demographics from searches </li> 
 *      <li> <code> DemographicNotificationSession: </code> a session to 
 *      receive notifications pertaining to demographic changes </li> 
 *      <li> <code> DemographicBinSession: </code> a session to look up 
 *      demographic bin mappings </li> 
 *      <li> <code> DemographicBinAssignmentSession: </code> a session to 
 *      manage demographic to bin mappings </li> 
 *      <li> <code> DemographicSmartBinSession: </code> a session to manage 
 *      dynamic bins of demographic </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> DemographicEnablerLookupSession: </code> a session to 
 *      retrieve demographic enablers </li> 
 *      <li> <code> DemographicEnablerQuerySession: </code> a session to query 
 *      for demographic enablers </li> 
 *      <li> <code> DemographicEnablerSearchSession: </code> a session to 
 *      search for demographic enablers </li> 
 *      <li> <code> DemographicEnablerAdminSession: </code> a session to 
 *      create and delete demographic enablers </li> 
 *      <li> <code> DemographicEnablerNotificationSession: </code> a session 
 *      to receive notifications pertaining to demographic enabler changes 
 *      </li> 
 *      <li> <code> DemographicEnablerBinSession: </code> a session to look up 
 *      demographic enabler bin mappings </li> 
 *      <li> <code> DemographicEnablerBinAssignmentSession: </code> a session 
 *      to manage demographic enabler to bin mappings </li> 
 *      <li> <code> DemographicEnablerSmartBinSession: </code> a session to 
 *      manage dynamic bins of demographic enablers </li> 
 *      <li> <code> DemographicEnablerRuleLookupSession: </code> a session to 
 *      look up demographic enabler mappings </li> 
 *      <li> <code> DemographicEnablerRuleApplicationSession: </code> a 
 *      session to apply demographic enablers </li> 
 *  </ul>
 *  
 */

public interface ResourceDemographicManager
    extends org.osid.OsidManager,
            org.osid.resource.demographic.ResourceDemographicProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the demographic 
     *  lookup service. 
     *
     *  @return a <code> DemographicLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDemographicLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDemographicLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resource.demographic.DemographicLookupSession getDemographicLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the demographic 
     *  lookup service for the given bin. 
     *
     *  @param  binId the <code> Id </code> of the <code> Bin </code> 
     *  @return a <code> DemographicLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Bin </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> binId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDemographicLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDemographicLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resource.demographic.DemographicLookupSession getDemographicLookupSessionForBin(org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the demographic 
     *  query service. 
     *
     *  @return a <code> DemographicQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDemographicQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDemographicQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.demographic.DemographicQuerySession getDemographicQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the demographic 
     *  query service for the given bin. 
     *
     *  @param  binId the <code> Id </code> of the <code> Bin </code> 
     *  @return a <code> DemographicQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Bin </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> binId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDemographicQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDemographicQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resource.demographic.DemographicQuerySession getDemographicQuerySessionForBin(org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the demographic 
     *  search service. 
     *
     *  @return a <code> DemographicSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDemographicSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDemographicSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resource.demographic.DemographicSearchSession getDemographicSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the demographic 
     *  earch service for the given bin. 
     *
     *  @param  binId the <code> Id </code> of the <code> Bin </code> 
     *  @return a <code> DemographicSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Bin </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> binId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDemographicSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDemographicSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resource.demographic.DemographicSearchSession getDemographicSearchSessionForBin(org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the demographic 
     *  administration service. 
     *
     *  @return a <code> DemographicAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDemographicAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDemographicAdmin() </code> is <code> true. </code> 
     */

    public org.osid.resource.demographic.DemographicAdminSession getDemographicAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the demographic 
     *  administration service for the given bin. 
     *
     *  @param  binId the <code> Id </code> of the <code> Bin </code> 
     *  @return a <code> DemographicAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Bin </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> binId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDemographicAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDemographicAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resource.demographic.DemographicAdminSession getDemographicAdminSessionForBin(org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the demographic 
     *  builder service. 
     *
     *  @return a <code> DemographicBuilderSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDemographicBuilder() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDemographicBuilder() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resource.demographic.DemographicBuilderSession getDemographicBuilderSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the demographic 
     *  builder service for the given bin. 
     *
     *  @param  binId the <code> Id </code> of the <code> Bin </code> 
     *  @return a <code> DemographicBuilderSession </code> 
     *  @throws org.osid.NotFoundException no <code> Bin </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> binId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDemographicBuilder() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDemographicBuilder() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resource.demographic.DemographicBuilderSession getDemographicBuilderSessionForBin(org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the demographic 
     *  notification service. 
     *
     *  @param  demographicReceiver the notification callback 
     *  @return a <code> DemographicNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> demographicReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDemographicNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDemographicNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resource.demographic.DemographicNotificationSession getDemographicNotificationSession(org.osid.resource.demographic.DemographicReceiver demographicReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the demographic 
     *  notification service for the given bin. 
     *
     *  @param  demographicReceiver the notification callback 
     *  @param  binId the <code> Id </code> of the <code> Bin </code> 
     *  @return a <code> DemographicNotificationSession </code> 
     *  @throws org.osid.NotFoundException no bin found by the given <code> Id 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> demographicReceiver 
     *          </code> or <code> binId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDemographicNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDemographicNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resource.demographic.DemographicNotificationSession getDemographicNotificationSessionForBin(org.osid.resource.demographic.DemographicReceiver demographicReceiver, 
                                                                                                                org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup demographic/bin mappings 
     *  for demographics. 
     *
     *  @return a <code> DemographicBinSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDemographicBin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDemographicBin() </code> is <code> true. </code> 
     */

    public org.osid.resource.demographic.DemographicBinSession getDemographicBinSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning 
     *  demographic to bins. 
     *
     *  @return a <code> DemographicBinAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDemographicBinAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDemographicBinAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resource.demographic.DemographicBinAssignmentSession getDemographicBinAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage demographic smart bins. 
     *
     *  @param  binId the <code> Id </code> of the <code> Bin </code> 
     *  @return a <code> DemographicSmartBinSession </code> 
     *  @throws org.osid.NotFoundException no <code> Bin </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> binId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDemographicSmartBin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDemographicSmartBin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resource.demographic.DemographicSmartBinSession getDemographicSmartBinSession(org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the demographic 
     *  enabler lookup service. 
     *
     *  @return a <code> DemographicEnablerLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDemographicEnablerLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDemographicEnablerLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resource.demographic.DemographicEnablerLookupSession getDemographicEnablerLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the demographic 
     *  enabler lookup service for the given bin. 
     *
     *  @param  binId the <code> Id </code> of the <code> Bin </code> 
     *  @return a <code> DemographicEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Bin </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> binId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDemographicEnablerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDemographicEnablerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resource.demographic.DemographicEnablerLookupSession getDemographicEnablerLookupSessionForBin(org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the demographic 
     *  enabler query service. 
     *
     *  @return a <code> DemographicEnablerQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDemographicEnablerQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDemographicEnablerQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resource.demographic.DemographicEnablerQuerySession getDemographicEnablerQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the demographic 
     *  enabler query service for the given bin. 
     *
     *  @param  binId the <code> Id </code> of the <code> Bin </code> 
     *  @return a <code> DemographicEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Bin </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> binId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDemographicEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDemographicEnablerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resource.demographic.DemographicEnablerQuerySession getDemographicEnablerQuerySessionForBin(org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the demographic 
     *  enabler search service. 
     *
     *  @return a <code> DemographicEnablerSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDemographicEnablerSearch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDemographicEnablerSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resource.demographic.DemographicEnablerSearchSession getDemographicEnablerSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the demographic 
     *  enablers earch service for the given bin. 
     *
     *  @param  binId the <code> Id </code> of the <code> Bin </code> 
     *  @return a <code> DemographicEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Bin </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> binId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDemographicEnablerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDemographicEnablerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resource.demographic.DemographicEnablerSearchSession getDemographicEnablerSearchSessionForBin(org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the demographic 
     *  enabler administration service. 
     *
     *  @return a <code> DemographicEnablerAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDemographicEnablerAdmin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDemographicEnablerAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resource.demographic.DemographicEnablerAdminSession getDemographicEnablerAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the demographic 
     *  enabler administration service for the given bin. 
     *
     *  @param  binId the <code> Id </code> of the <code> Bin </code> 
     *  @return a <code> DemographicEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Bin </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> binId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDemographicEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDemographicEnablerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resource.demographic.DemographicEnablerAdminSession getDemographicEnablerAdminSessionForBin(org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the demographic 
     *  enabler notification service. 
     *
     *  @param  demographicEnablerReceiver the notification callback 
     *  @return a <code> DemographicEnablerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          demographicEnablerReceiver </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDemographicEnablerNotification() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDemographicEnablerNotification() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.resource.demographic.DemographicEnablerNotificationSession getDemographicEnablerNotificationSession(org.osid.resource.demographic.DemographicEnablerReceiver demographicEnablerReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the demographic 
     *  enabler notification service for the given bin. 
     *
     *  @param  demographicEnablerReceiver the notification callback 
     *  @param  binId the <code> Id </code> of the <code> Bin </code> 
     *  @return a <code> DemographicEnablerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no bin found by the given <code> Id 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          demographicEnablerReceiver </code> or <code> binId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDemographicEnablerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDemographicEnablerNotification() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.resource.demographic.DemographicEnablerNotificationSession getDemographicEnablerNotificationSessionForBin(org.osid.resource.demographic.DemographicEnablerReceiver demographicEnablerReceiver, 
                                                                                                                              org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup demographic enabler/bin 
     *  mappings for demographic enablers. 
     *
     *  @return a <code> DemographicEnablerBinSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDemographicEnablerBin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDemographicEnablerBin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resource.demographic.DemographicEnablerBinSession getDemographicEnablerBinSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning 
     *  demographic enablers to bins. 
     *
     *  @return a <code> DemographicEnablerBinAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDemographicEnablerBinAssignment() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDemographicEnablerBinAssignment() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.resource.demographic.DemographicEnablerBinAssignmentSession getDemographicEnablerBinAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage demographic enabler 
     *  smart bins. 
     *
     *  @param  binId the <code> Id </code> of the <code> Bin </code> 
     *  @return a <code> DemographicEnablerSmartBinSession </code> 
     *  @throws org.osid.NotFoundException no <code> Bin </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> binId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDemographicEnablerSmartBin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDemographicEnablerSmartBin() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.resource.demographic.DemographicEnablerSmartBinSession getDemographicEnablerSmartBinSession(org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the demographic 
     *  enabler mapping lookup service. 
     *
     *  @return a <code> DemographicEnablerRuleLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDemographicEnablerRuleLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDemographicEnablerRuleLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.resource.demographic.DemographicEnablerRuleLookupSession getDemographicEnablerRuleLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the demographic 
     *  enabler mapping lookup service. 
     *
     *  @param  binId the <code> Id </code> of the <code> Bin </code> 
     *  @return a <code> DemographicEnablerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Bin </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> binId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDemographicEnablerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDemographicEnablerRuleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resource.demographic.DemographicEnablerRuleLookupSession getDemographicEnablerRuleLookupSessionForBin(org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the demographic 
     *  enabler assignment service. 
     *
     *  @return a <code> DemographicEnablerRuleApplicationSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDemographicEnablerRuleApplication() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDemographicEnablerRuleApplication() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.resource.demographic.DemographicEnablerRuleApplicationSession getDemographicEnablerRuleApplicationSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the demographic 
     *  enabler assignment service for the given bin. 
     *
     *  @param  binId the <code> Id </code> of the <code> Bin </code> 
     *  @return a <code> DemographicEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Bin </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> binId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDemographicEnablerRuleApplication() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDemographicEnablerRuleApplication() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.resource.demographic.DemographicEnablerRuleApplicationSession getDemographicEnablerRuleApplicationSessionForBin(org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;
}
