//
// org.osid.resourcing.AvailabilitySearchSession
//
//     The OSID Java specification for org.osid.resourcing.AvailabilitySearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing;


/**
 *  <p>This session provides methods for searching among <code> Availability 
 *  </code> objects. The search query is constructed using the <code> 
 *  AvailabilityQuery. </code> </p> 
 *  
 *  <p> <code> getAvailabilitiesByQuery() </code> is the basic search method 
 *  and returns a list of <code> Availabilities. </code> A more advanced 
 *  search may be performed with <code> getAvailabilitiesBySearch(). </code> 
 *  It accepts an <code> AvailabilitySearch </code> in addition to the query 
 *  for the purpose of specifying additional options affecting the entire 
 *  search, such as ordering. <code> getAvailabilitiesBySearch() </code> 
 *  returns an <code> AvailabilitySearchResults </code> that can be used to 
 *  access the resulting <code> AvailabilityList </code> or be used to perform 
 *  a search within the result set through <code> AvailabilitySearch. </code> 
 *  </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated foundry view: searches include availabilities in 
 *      foundries of which this foundry is an ancestor in the foundry 
 *      hierarchy </li> 
 *      <li> isolated foundry view: searches are restricted to availabilities 
 *      in this foundry </li> 
 *  </ul>
 *  
 *  
 *  <p> Availabilitys may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> 
 *  AvailabilityQuery. </code> </p>
 */

public interface AvailabilitySearchSession
    extends org.osid.resourcing.AvailabilityQuerySession {


    /**
     *  Gets an availability search. 
     *
     *  @return the availability search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.AvailabilitySearch getAvailabilitySearch();


    /**
     *  Gets an availability search order. The <code> AvailabilitySearchOrder 
     *  </code> is supplied to an <code> AvailabilitySearch </code> to specify 
     *  the ordering of results. 
     *
     *  @return the availability search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.AvailabilitySearchOrder getAvailabilitySearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  availabilityQuery the availability query 
     *  @param  availabilitySearch the availability search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> availabilityQuery 
     *          </code> or <code> availabilitySearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> availabilityQuery </code> 
     *          or <code> availabilitySearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.AvailabilitySearchResults getAvailabilitiesBySearch(org.osid.resourcing.AvailabilityQuery availabilityQuery, 
                                                                                   org.osid.resourcing.AvailabilitySearch availabilitySearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an availability query from an inspector. The inspector is 
     *  available from an <code> AvailabilitySearchResults. </code> 
     *
     *  @param  availabilityQueryInspector an availability query inspector 
     *  @return the availability query 
     *  @throws org.osid.NullArgumentException <code> 
     *          availabilityQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          availabilityQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.AvailabilityQuery getAvailabilityQueryFromInspector(org.osid.resourcing.AvailabilityQueryInspector availabilityQueryInspector);
}
