//
// org.osid.resourcing.Commission
//
//     The OSID Java specification for org.osid.resourcing.Commission.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing;


/**
 *  <p>A <code> Commission </code> represents a commitment of a resource for 
 *  work. A commission may also specify a competency to qualify the work 
 *  performed. The effective dates of the relationship specify the duration of 
 *  the commission. </p>
 */

public interface Commission
    extends org.osid.OsidRelationship {


    /**
     *  Gets the <code> Id </code> of the commissioned resource. 
     *
     *  @return the resource <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getResourceId();


    /**
     *  Gets the commissioned resource. 
     *
     *  @return the resource 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getResource()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of the work. 
     *
     *  @return the work <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getWorkId();


    /**
     *  Gets the work. 
     *
     *  @return the work 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.Work getWork()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if a competency is specified for this commission. 
     *
     *  @return <code> true </code> if a competency is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isCompetent();


    /**
     *  Gets the competency <code> Id. </code> 
     *
     *  @return the competency <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> isCompetent() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCompetencyId();


    /**
     *  Gets the competency. 
     *
     *  @return the competency 
     *  @throws org.osid.IllegalStateException <code> isCompetent() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.Competency getCompetency()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the percentage commitment. 
     *
     *  @return the percentage commitment 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getPercentage();


    /**
     *  Gets the commission record corresponding to the given <code> 
     *  Commission </code> record <code> Type. </code> This method is used to 
     *  retrieve an object implementing the requested record. The <code> 
     *  commissionRecordType </code> may be the <code> Type </code> returned 
     *  in <code> getRecordTypes() </code> or any of its parents in a <code> 
     *  Type </code> hierarchy where <code> 
     *  hasRecordType(commissionRecordType) </code> is <code> true </code> . 
     *
     *  @param  commissionRecordType the type of commission record to retrieve 
     *  @return the commission record 
     *  @throws org.osid.NullArgumentException <code> commissionRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(commissionRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.records.CommissionRecord getCommissionRecord(org.osid.type.Type commissionRecordType)
        throws org.osid.OperationFailedException;
}
