//
// org.osid.resourcing.CommissionLookupSession
//
//     The OSID Java specification for org.osid.resourcing.CommissionLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing;


/**
 *  <p>This session provides methods for retrieving <code> Commission </code> 
 *  relationships. </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated foundry view: All commission methods in this session 
 *      operate, retrieve and pertain to commissions defined explicitly in the 
 *      current foundry. Using an isolated view is useful for managing <code> 
 *      Commissions </code> with the <code> CommissionAdminSession. </code> 
 *      </li> 
 *      <li> federated foundry view: All commission methods in this session 
 *      operate, retrieve and pertain to all commissions defined in this 
 *      foundry and any other commissions implicitly available in this foundry 
 *      through foundry inheritence. </li> 
 *      <li> effective commission view: All commission lookup methods return 
 *      commissions where the current date falls in between the effective 
 *      dates inclusive. </li> 
 *      <li> any effective commission view: Commissions of any effective date 
 *      are returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedFoundryView() </code> and <code> 
 *  useIsolatedFoundryView() </code> behave as a radio group and one should be 
 *  selected before invoking any lookup methods. </p>
 */

public interface CommissionLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Foundry </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Foundry Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFoundryId();


    /**
     *  Gets the <code> Foundry </code> associated with this session. 
     *
     *  @return the foundry 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.Foundry getFoundry()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Commission </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupCommissions();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeCommissionView();


    /**
     *  A complete view of the <code> Commission </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryCommissionView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include commissions in foundries which are children of this foundry in 
     *  the foundry hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedFoundryView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this foundry only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedFoundryView();


    /**
     *  Only commissions whose effective dates are current are returned by 
     *  methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useEffectiveCommissionView();


    /**
     *  All commissions of any effective dates are returned by methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyEffectiveCommissionView();


    /**
     *  Gets the <code> Commission </code> specified by its <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Commission </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> Commission </code> and retained for 
     *  compatibility. 
     *  
     *  In effective mode, commissions are returned that are currently 
     *  effective. In any effective mode, effective commissions and those 
     *  currently expired are returned. 
     *
     *  @param  commissionId <code> Id </code> of the <code> Commission 
     *          </code> 
     *  @return the commission 
     *  @throws org.osid.NotFoundException <code> commissionId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> commissionId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.resourcing.Commission getCommission(org.osid.id.Id commissionId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CommissionList </code> corresponding to the given <code> 
     *  IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  commissions specified in the <code> Id </code> list, in the order of 
     *  the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Commissions </code> may be omitted from the list 
     *  and may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In effective mode, commissions are returned that are currently 
     *  effective. In any effective mode, effective commissions and those 
     *  currently expired are returned. 
     *
     *  @param  commissionIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Commission </code> list 
     *  @throws org.osid.NotFoundException an <code> Id </code> was not found 
     *  @throws org.osid.NullArgumentException <code> commissionIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.CommissionList getCommissionsByIds(org.osid.id.IdList commissionIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CommissionList </code> corresponding to the given 
     *  commission genus <code> Type </code> which does not include 
     *  commissions of genus types derived from the specified <code> Type. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  commissions or an error results. Otherwise, the returned list may 
     *  contain only those commissions that are accessible through this 
     *  session. 
     *  
     *  In effective mode, commissions are returned that are currently 
     *  effective. In any effective mode, effective commissions and those 
     *  currently expired are returned. 
     *
     *  @param  commissionGenusType a commission genus type 
     *  @return the returned <code> Commission </code> list 
     *  @throws org.osid.NullArgumentException <code> commissionGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.CommissionList getCommissionsByGenusType(org.osid.type.Type commissionGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CommissionList </code> corresponding to the given 
     *  commission genus <code> Type </code> and include any additional 
     *  commissions with genus types derived from the specified <code> Type. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  commissions or an error results. Otherwise, the returned list may 
     *  contain only those commissions that are accessible through this 
     *  session. In both cases, the order of the set is by the start effective 
     *  date. 
     *  
     *  In effective mode, commissions are returned that are currently 
     *  effective. In any effective mode, effective commissions and those 
     *  currently expired are returned. 
     *
     *  @param  commissionGenusType a commission genus type 
     *  @return the returned <code> Commission </code> list 
     *  @throws org.osid.NullArgumentException <code> commissionGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.CommissionList getCommissionsByParentGenusType(org.osid.type.Type commissionGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CommissionList </code> containing the given commission 
     *  record <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  commissions or an error results. Otherwise, the returned list may 
     *  contain only those commissions that are accessible through this 
     *  session. 
     *  
     *  In effective mode, commissions are returned that are currently 
     *  effective. In any effective mode, effective commissions and those 
     *  currently expired are returned. 
     *
     *  @param  commissionRecordType a commission record type 
     *  @return the returned <code> Commission </code> list 
     *  @throws org.osid.NullArgumentException <code> commissionRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.CommissionList getCommissionsByRecordType(org.osid.type.Type commissionRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of commissions effective during the entire given date 
     *  range inclusive but not confined to the date range. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  commissions or an error results. Otherwise, the returned list may 
     *  contain only those commissions that are accessible through this 
     *  session. 
     *  
     *  In effective mode, commissions are returned that are currently 
     *  effective. In any effective mode, effective commissions and those 
     *  currently expired are returned. 
     *
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Commission </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.CommissionList getCommissionsOnDate(org.osid.calendaring.DateTime from, 
                                                                   org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of commissions for a resource. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  commissions or an error results. Otherwise, the returned list may 
     *  contain only those commissions that are accessible through this 
     *  session. 
     *  
     *  In effective mode, commissions are returned that are currently 
     *  effective. In any effective mode, effective commissions and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @return the returned <code> Commission </code> list 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.CommissionList getCommissionsForResource(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of commissions for a resource and effective during the 
     *  entire given date range inclusive but not confined to the date range. 
     *  <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  commissions or an error results. Otherwise, the returned list may 
     *  contain only those commissions that are accessible through this 
     *  session. 
     *  
     *  In effective mode, commissions are returned that are currently 
     *  effective. In any effective mode, effective commissions and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Commission </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, from </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.CommissionList getCommissionsForResourceOnDate(org.osid.id.Id resourceId, 
                                                                              org.osid.calendaring.DateTime from, 
                                                                              org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of commissions for a work. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  commissions or an error results. Otherwise, the returned list may 
     *  contain only those commissions that are accessible through this 
     *  session. 
     *  
     *  In effective mode, commissions are returned that are currently 
     *  effective. In any effective mode, effective commissions and those 
     *  currently expired are returned. 
     *
     *  @param  workId a work <code> Id </code> 
     *  @return the returned C <code> ommission </code> list 
     *  @throws org.osid.NullArgumentException <code> workId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.CommissionList getCommissionsForWork(org.osid.id.Id workId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of commissions for a work and effective during the entire 
     *  given date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known commissions or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  commissions that are accessible through this session. 
     *  
     *  In effective mode, commissions are returned that are currently 
     *  effective. In any effective mode, effective commissions and those 
     *  currently expired are returned. 
     *
     *  @param  workId a work <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned C <code> ommission </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> workId, from </code> or 
     *          <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.CommissionList getCommissionsForWorkOnDate(org.osid.id.Id workId, 
                                                                          org.osid.calendaring.DateTime from, 
                                                                          org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of commissions for a resource and work. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  commissions or an error results. Otherwise, the returned list may 
     *  contain only those commissions that are accessible through this 
     *  session. 
     *  
     *  In effective mode, commissions are returned that are currently 
     *  effective. In any effective mode, effective commissions and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  workId a work <code> Id </code> 
     *  @return the returned C <code> ommission </code> list 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> or 
     *          <code> workId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.CommissionList getCommissionsForResourceAndWork(org.osid.id.Id resourceId, 
                                                                               org.osid.id.Id workId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of commissions for a resource and work and effective 
     *  during the entire given date range inclusive but not confined to the 
     *  date range. 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  commissions or an error results. Otherwise, the returned list may 
     *  contain only those commissions that are accessible through this 
     *  session. 
     *  
     *  In effective mode, commissions are returned that are currently 
     *  effective. In any effective mode, effective commissions and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  workId a work <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned C <code> ommission </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, workId, from 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.CommissionList getCommissionsForResourceAndWorkOnDate(org.osid.id.Id resourceId, 
                                                                                     org.osid.id.Id workId, 
                                                                                     org.osid.calendaring.DateTime from, 
                                                                                     org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Commissions. </code> 
     *  
     *  In plenary mode, the returned list contains all known commissions or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  commissions that are accessible through this session. 
     *  
     *  In effective mode, commissions are returned that are currently 
     *  effective. In any effective mode, effective commissions and those 
     *  currently expired are returned. 
     *
     *  @return a list of <code> Commissions </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.CommissionList getCommissions()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
