//
// org.osid.resourcing.CommissionSearchSession
//
//     The OSID Java specification for org.osid.resourcing.CommissionSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing;


/**
 *  <p>This session provides methods for searching among <code> Commission 
 *  </code> objects. The search query is constructed using the <code> 
 *  CommissionQuery. </code> </p> 
 *  
 *  <p> <code> getCommissionsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Commissions. </code> A more advanced search may 
 *  be performed with <code> getCommissionsBySearch(). </code> It accepts a 
 *  <code> CommissionSearch </code> in addition to the query for the purpose 
 *  of specifying additional options affecting the entire search, such as 
 *  ordering. <code> getCommissionsBySearch() </code> returns a <code> 
 *  CommissionSearchResults </code> that can be used to access the resulting 
 *  <code> CommissionList </code> or be used to perform a search within the 
 *  result set through <code> CommissionSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated foundry view: searches include commissions in foundries 
 *      of which this foundry is an ancestor in the foundry hierarchy </li> 
 *      <li> isolated foundry view: searches are restricted to commissions in 
 *      this foundry </li> 
 *  </ul>
 *  
 *  
 *  <p> Commissions may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> CommissionQuery. 
 *  </code> </p>
 */

public interface CommissionSearchSession
    extends org.osid.resourcing.CommissionQuerySession {


    /**
     *  Gets a commission search. 
     *
     *  @return the commission search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.CommissionSearch getCommissionSearch();


    /**
     *  Gets a commission search order. The <code> CommissionSearchOrder 
     *  </code> is supplied to a <code> CommissionSearch </code> to specify 
     *  the ordering of results. 
     *
     *  @return the commission search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.CommissionSearchOrder getCommissionSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  commissionQuery the commission query 
     *  @param  commissionSearch the commission search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> commissionQuery </code> 
     *          or <code> commissionSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> commissionQuery </code> 
     *          or <code> commissionSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.CommissionSearchResults getCommissionsBySearch(org.osid.resourcing.CommissionQuery commissionQuery, 
                                                                              org.osid.resourcing.CommissionSearch commissionSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a commission query from an inspector. The inspector is available 
     *  from a <code> CommissionSearchResults. </code> 
     *
     *  @param  commissionQueryInspector a commission query inspector 
     *  @return the commission query 
     *  @throws org.osid.NullArgumentException <code> commissionQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> commissionQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.CommissionQuery getCommissionQueryFromInspector(org.osid.resourcing.CommissionQueryInspector commissionQueryInspector);
}
