//
// org.osid.resourcing.CompetencySearch
//
//     The OSID Java specification for org.osid.resourcing.CompetencySearch.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing;


/**
 *  <p>The search interface for governing competency searches. </p>
 */

public interface CompetencySearch
    extends org.osid.OsidSearch {


    /**
     *  Execute this search among the given list of competencies. 
     *
     *  @param  competencyIds list of competencies 
     *  @throws org.osid.NullArgumentException <code> competencyIds </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void searchAmongCompetencies(org.osid.id.IdList competencyIds);


    /**
     *  Specify an ordering to the search results. 
     *
     *  @param  competencySearchOrder competency search order 
     *  @throws org.osid.NullArgumentException <code> competencySearchOrder 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> competencySearchOrder 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderCompetencyResults(org.osid.resourcing.CompetencySearchOrder competencySearchOrder);


    /**
     *  Gets the competency search record corresponding to the given 
     *  competency search record <code> Type. </code> This method is used to 
     *  retrieve an object implementing the requested record. 
     *
     *  @param  competencySearchRecordType a competency search record type 
     *  @return the competency search record 
     *  @throws org.osid.NullArgumentException <code> 
     *          competencySearchRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(competencySearchRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.records.CompetencySearchRecord getCompetencySearchRecord(org.osid.type.Type competencySearchRecordType)
        throws org.osid.OperationFailedException;
}
