//
// org.osid.resourcing.EffortFoundryAssignmentSession
//
//     The OSID Java specification for org.osid.resourcing.EffortFoundryAssignmentSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing;


/**
 *  <p>This session provides methods to re-assign <code> Efforts </code> to 
 *  <code> Foundry </code> mappings. An <code> Effort </code> may appear in 
 *  multiple <code> Foundry </code> objects and removing the last reference to 
 *  an <code> Effort </code> is the equivalent of deleting it. Each <code> 
 *  Foundry </code> may have its own authorizations governing who is allowed 
 *  to operate on it. </p> 
 *  
 *  <p> Adding a reference of an <code> Effort </code> to another <code> 
 *  Foundry </code> is not a copy operation (eg: does not change its <code> Id 
 *  </code> ). </p>
 */

public interface EffortFoundryAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter effort/foundry mappings. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if resourcing is not authorized, <code> 
     *          true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignEfforts();


    /**
     *  Tests if this user can alter effort/foundry mappings. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @return <code> false </code> if resourcing is not authorized, <code> 
     *          true </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> foundryId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignEffortsToFoundry(org.osid.id.Id foundryId);


    /**
     *  Gets a list of foundries including and under the given foundry node in 
     *  which any effort can be assigned. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @return list of assignable foundry <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableFoundryIds(org.osid.id.Id foundryId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of foundries including and under the given foundry node in 
     *  which a specific effort can be assigned. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  effortId the <code> Id </code> of the <code> Effort </code> 
     *  @return list of assignable foundry <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId </code> or 
     *          <code> effortId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableFoundryIdsForEffort(org.osid.id.Id foundryId, 
                                                               org.osid.id.Id effortId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> Effort </code> to a <code> Foundry. </code> 
     *
     *  @param  effortId the <code> Id </code> of the <code> Effort </code> 
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @throws org.osid.NotFoundException <code> effortId </code> or <code> 
     *          foundryId </code> not found 
     *  @throws org.osid.NullArgumentException <code> effortId </code> or 
     *          <code> foundryId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignEffortToFoundry(org.osid.id.Id effortId, 
                                      org.osid.id.Id foundryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes an <code> Effort </code> from a <code> Foundry. </code> 
     *
     *  @param  effortId the <code> Id </code> of the <code> Effort </code> 
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @throws org.osid.NotFoundException <code> effortId </code> or <code> 
     *          foundryId </code> not found 
     *  @throws org.osid.NullArgumentException <code> effortId </code> or 
     *          <code> foundryId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignEffortFromFoundry(org.osid.id.Id effortId, 
                                          org.osid.id.Id foundryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
