//
// org.osid.resourcing.FoundryReceiver
//
//     The OSID Java specification for org.osid.resourcing.FoundryReceiver.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing;


/**
 *  <p>The foundry receiver is the consumer supplied interface for receiving 
 *  notifications pertaining to new, updated or deleted <code> Foundry </code> 
 *  objects. </p>
 */

public interface FoundryReceiver
    extends org.osid.OsidReceiver {


    /**
     *  The callback for notifications of new foundries. 
     *
     *  @param  foundryIds the <code> Ids </code> of the new <code> Foundries 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newFoundries(org.osid.id.IdList foundryIds);


    /**
     *  The callback for notifications of new foundry ancestors. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  ancestorId the <code> Id </code> of the new <code> Foundry 
     *          </code> ancestor 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newAncestorFoundry(org.osid.id.Id foundryId, 
                                   org.osid.id.Id ancestorId);


    /**
     *  The callback for notifications of new foundry descendants. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  descendantId the <code> Id </code> of the new <code> Foundry 
     *          </code> descendant 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newDescendantFoundry(org.osid.id.Id foundryId, 
                                     org.osid.id.Id descendantId);


    /**
     *  The callback for notification of updated foundry. 
     *
     *  @param  foundryIds the <code> Ids </code> of the updated <code> 
     *          Foundries </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void changedFoundries(org.osid.id.IdList foundryIds);


    /**
     *  The callback for notification of deleted foundries. 
     *
     *  @param  foundryIds the <code> Ids </code> of the deleted <code> 
     *          Foundries </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedFoundries(org.osid.id.IdList foundryIds);


    /**
     *  The callback for notifications of deleted foundry ancestors. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  ancestorId the <code> Id </code> of the removed <code> Foundry 
     *          </code> ancestor 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedAncestorFoundry(org.osid.id.Id foundryId, 
                                       org.osid.id.Id ancestorId);


    /**
     *  The callback for notifications of deleted foundry descendants. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  descendantId the <code> Id </code> of the removed <code> 
     *          Foundry </code> descendant 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedDescendantFoundry(org.osid.id.Id foundryId, 
                                         org.osid.id.Id descendantId);


    /**
     *  The callback for notifications of changes to a foundry hierarchy where 
     *  the hierarchy needs to refreshed. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void restructuredFoundrtyHierarchy();
}
