//
// org.osid.resourcing.FoundrySearchSession
//
//     The OSID Java specification for org.osid.resourcing.FoundrySearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing;


/**
 *  <p>This session provides methods for searching among <code> Foundry 
 *  </code> objects. The search query is constructed using the <code> 
 *  FoundryQuery. </code> </p> 
 *  
 *  <p> <code> getFoundriesByQuery() </code> is the basic search method and 
 *  returns a list of <code> Foundries. </code> A more advanced search may be 
 *  performed with <code> getFoundriesBySearch(). </code> It accepts a <code> 
 *  FoundrySearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getFoundriesBySearch() </code> returns a <code> 
 *  FoundrySearchResults </code> that can be used to access the resulting 
 *  <code> FoundryList </code> or be used to perform a search within the 
 *  result set through <code> FoundrySearch. </code> </p> 
 *  
 *  <p> Foundries may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> FoundryQuery. </code> 
 *  </p>
 */

public interface FoundrySearchSession
    extends org.osid.resourcing.FoundryQuerySession {


    /**
     *  Gets a foundry search. 
     *
     *  @return the foundry search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.FoundrySearch getFoundrySearch();


    /**
     *  Gets a foundry search order. The <code> FoundrySearchOrder </code> is 
     *  supplied to a <code> FoundrySearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the foundry search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.FoundrySearchOrder getFoundrySearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  foundryQuery the foundry query 
     *  @param  foundrySearch the foundry search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> foundryQuery </code> or 
     *          <code> foundrySearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> foundryQuery </code> or 
     *          <code> foundrySearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.FoundrySearchResults getFoundriesBySearch(org.osid.resourcing.FoundryQuery foundryQuery, 
                                                                         org.osid.resourcing.FoundrySearch foundrySearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a foundry query from an inspector. The inspector is available 
     *  from a <code> FoundrySearchResults. </code> 
     *
     *  @param  foundryQueryInspector a foundry query inspector 
     *  @return the foundry query 
     *  @throws org.osid.NullArgumentException <code> foundryQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> foundryQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.FoundryQuery getFoundryQueryFromInspector(org.osid.resourcing.FoundryQueryInspector foundryQueryInspector);
}
