//
// org.osid.resourcing.JobLookupSession
//
//     The OSID Java specification for org.osid.resourcing.JobLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing;


/**
 *  <p>This session provides methods for retrieving <code> Job </code> 
 *  objects. </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated foundry view: All job methods in this session operate, 
 *      retrieve and pertain to jobs defined explicitly in the current 
 *      foundry. Using an isolated view is useful for managing <code> Jobs 
 *      </code> with the <code> JobAdminSession. </code> </li> 
 *      <li> federated foundry view: All job methods in this session operate, 
 *      retrieve and pertain to all jobs defined in this foundry and any other 
 *      jobs implicitly available in this foundry through foundry inheritence. 
 *      </li> 
 *      <li> active job view: All job lookup methods return active jobs. </li> 
 *      <li> any status job view: Jobs of any active or inactive status are 
 *      returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedFoundryView() </code> and <code> 
 *  useIsolatedFoundryView() </code> behave as a radio group and one should be 
 *  selected before invoking any lookup methods. </p>
 */

public interface JobLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Foundry </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Foundry Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFoundryId();


    /**
     *  Gets the <code> Foundry </code> associated with this session. 
     *
     *  @return the foundry 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.Foundry getFoundry()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Job </code> lookups. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupJobs();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeJobView();


    /**
     *  A complete view of the <code> Job </code> returns is desired. Methods 
     *  will return what is requested or result in an error. This view is used 
     *  when greater precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryJobView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include jobs in foundries which are children of this foundry in the 
     *  foundry hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedFoundryView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this foundry only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedFoundryView();


    /**
     *  Only active jobs are returned by methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveJobView();


    /**
     *  All active and inactive authorization enablers are returned by methods 
     *  in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusJobView();


    /**
     *  Gets the <code> Job </code> specified by its <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Job </code> may have a different <code> Id </code> than requested, 
     *  such as the case where a duplicate <code> Id </code> was assigned to a 
     *  <code> Job </code> and retained for compatibility. 
     *  
     *  In active mode, jobs are returned that are currently active. In any 
     *  status mode, active and inactive jobs are returned. 
     *
     *  @param  jobId <code> Id </code> of the <code> Job </code> 
     *  @return the job 
     *  @throws org.osid.NotFoundException <code> jobId </code> not found 
     *  @throws org.osid.NullArgumentException <code> jobId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.resourcing.Job getJob(org.osid.id.Id jobId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> JobList </code> corresponding to the given <code> 
     *  IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  jobs specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Jobs </code> may be omitted from the list and may 
     *  present the elements in any order including returning a unique set. 
     *  
     *  In active mode, jobs are returned that are currently active. In any 
     *  status mode, active and inactive jobs are returned. 
     *
     *  @param  jobIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Job </code> list 
     *  @throws org.osid.NotFoundException an <code> Id </code> was not found 
     *  @throws org.osid.NullArgumentException <code> jobIds </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.JobList getJobsByIds(org.osid.id.IdList jobIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> JobList </code> corresponding to the given job genus 
     *  <code> Type </code> which does not include jobs of genus types derived 
     *  from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  jobs or an error results. Otherwise, the returned list may contain 
     *  only those jobs that are accessible through this session. 
     *  
     *  In active mode, jobs are returned that are currently active. In any 
     *  status mode, active and inactive jobs are returned. 
     *
     *  @param  jobGenusType a job genus type 
     *  @return the returned <code> Job </code> list 
     *  @throws org.osid.NullArgumentException <code> jobGenusType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.JobList getJobsByGenusType(org.osid.type.Type jobGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> JobList </code> corresponding to the given job genus 
     *  <code> Type </code> and include any additional jobs with genus types 
     *  derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  jobs or an error results. Otherwise, the returned list may contain 
     *  only those jobs that are accessible through this session. 
     *  
     *  In active mode, jobs are returned that are currently active. In any 
     *  status mode, active and inactive jobs are returned. 
     *
     *  @param  jobGenusType a job genus type 
     *  @return the returned <code> Job </code> list 
     *  @throws org.osid.NullArgumentException <code> jobGenusType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.JobList getJobsByParentGenusType(org.osid.type.Type jobGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> JobList </code> containing the given job record <code> 
     *  Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  jobs or an error results. Otherwise, the returned list may contain 
     *  only those jobs that are accessible through this session. 
     *  
     *  In active mode, jobs are returned that are currently active. In any 
     *  status mode, active and inactive jobs are returned. 
     *
     *  @param  jobRecordType a job record type 
     *  @return the returned <code> Job </code> list 
     *  @throws org.osid.NullArgumentException <code> jobRecordType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.JobList getJobsByRecordType(org.osid.type.Type jobRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> JobList </code> from the given provider. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  jobs or an error results. Otherwise, the returned list may contain 
     *  only those jobs that are accessible through this session. 
     *  
     *  In active mode, jobs are returned that are currently active. In any 
     *  status mode, active and inactive jobs are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @return the returned <code> Job </code> list 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.JobList getJobsByProvider(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Jobs. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  jobs or an error results. Otherwise, the returned list may contain 
     *  only those jobs that are accessible through this session. 
     *  
     *  In active mode, jobs are returned that are currently active. In any 
     *  status mode, active and inactive jobs are returned. 
     *
     *  @return a list of <code> Jobs </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.JobList getJobs()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
