//
// org.osid.resourcing.JobSearch
//
//     The OSID Java specification for org.osid.resourcing.JobSearch.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing;


/**
 *  <p>The search interface for governing job searches. </p>
 */

public interface JobSearch
    extends org.osid.OsidSearch {


    /**
     *  Execute this search among the given list of jobs. 
     *
     *  @param  jobIds list of jobs 
     *  @throws org.osid.NullArgumentException <code> jobIds </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void searchAmongJobs(org.osid.id.IdList jobIds);


    /**
     *  Specify an ordering to the search results. 
     *
     *  @param  jobSearchOrder job search order 
     *  @throws org.osid.NullArgumentException <code> jobSearchOrder </code> 
     *          is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> jobSearchOrder </code> is 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderJobResults(org.osid.resourcing.JobSearchOrder jobSearchOrder);


    /**
     *  Gets the job search record corresponding to the given job search 
     *  record <code> Type. </code> This method is used to retrieve an object 
     *  implementing the requested record. 
     *
     *  @param  jobSearchRecordType a job search record type 
     *  @return the job search record 
     *  @throws org.osid.NullArgumentException <code> jobSearchRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(jobSearchRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.records.JobSearchRecord getJobSearchRecord(org.osid.type.Type jobSearchRecordType)
        throws org.osid.OperationFailedException;
}
