//
// org.osid.resourcing.Work
//
//     The OSID Java specification for org.osid.resourcing.Work.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing;


/**
 *  <p><code> Work </code> is an instance of a job and may require competence. 
 *  </p>
 */

public interface Work
    extends org.osid.OsidObject,
            org.osid.Subjugateable {


    /**
     *  Gets the <code> Id </code> of the job of which this work is a part. 
     *
     *  @return the job <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getJobId();


    /**
     *  Gets the job of which this work is a part. 
     *
     *  @return the job 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.Job getJob()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if specific competencies are needed for this work. 
     *
     *  @return <code> true </code> if competency if specified, <code> false 
     *          </code> if incompetence will do 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean needsCompetence();


    /**
     *  Gets the <code> Ids </code> of the competencies. 
     *
     *  @return the competency <code> Ids </code> 
     *  @throws org.osid.IllegalStateException <code> needsCompetence() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getCompetencyIds();


    /**
     *  Gets the competency. 
     *
     *  @return the competency 
     *  @throws org.osid.IllegalStateException <code> needsCompetence() 
     *          </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.CompetencyList getCompetencies()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the date this work was created. 
     *
     *  @return the created date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getCreatedDate();


    /**
     *  Tests if this work has been completed. 
     *
     *  @return <code> true </code> if this work is complete, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isComplete();


    /**
     *  Gets the completion date. 
     *
     *  @return the completion date 
     *  @throws org.osid.IllegalStateException <code> isComplete() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getCompletionDate();


    /**
     *  Gets the work record corresponding to the given <code> Work </code> 
     *  record <code> Type. </code> This method is used to retrieve an object 
     *  implementing the requested record. The <code> workRecordType </code> 
     *  may be the <code> Type </code> returned in <code> getRecordTypes() 
     *  </code> or any of its parents in a <code> Type </code> hierarchy where 
     *  <code> hasRecordType(workRecordType) </code> is <code> true </code> . 
     *
     *  @param  workRecordType the type of work record to retrieve 
     *  @return the work record 
     *  @throws org.osid.NullArgumentException <code> workRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(workRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.records.WorkRecord getWorkRecord(org.osid.type.Type workRecordType)
        throws org.osid.OperationFailedException;
}
