//
// org.osid.resourcing.WorkQuery
//
//     The OSID Java specification for org.osid.resourcing.WorkQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing;


/**
 *  <p>This is the query for searching works. Each method match specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface WorkQuery
    extends org.osid.OsidObjectQuery,
            org.osid.OsidSubjugateableQuery {


    /**
     *  Sets the job <code> Id </code> for this query. 
     *
     *  @param  jobId the job <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> jobId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchJobId(org.osid.id.Id jobId, boolean match);


    /**
     *  Clears the job <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearJobIdTerms();


    /**
     *  Tests if a <code> JobQuery </code> is available. 
     *
     *  @return <code> true </code> if a job query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobQuery();


    /**
     *  Gets the query for a job. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the job query 
     *  @throws org.osid.UnimplementedException <code> supportsJobQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobQuery() </code> is <code> true. </code> 
     */

    public org.osid.resourcing.JobQuery getJobQuery();


    /**
     *  Clears the job query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearJobTerms();


    /**
     *  Sets the competency <code> Id </code> for this query. 
     *
     *  @param  competencyId the competency <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> competencyId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCompetencyId(org.osid.id.Id competencyId, boolean match);


    /**
     *  Clears the competency <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCompetencyIdTerms();


    /**
     *  Tests if a <code> CompetencyQuery </code> is available. 
     *
     *  @return <code> true </code> if a competency query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCompetencyQuery();


    /**
     *  Gets the query for a competency. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the competency query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportscompetencyQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportscompetencyQuery() </code> is <code> true. </code> 
     */

    public org.osid.resourcing.CompetencyQuery getCompetencyQuery();


    /**
     *  Matches work that have any competency. 
     *
     *  @param  match <code> true </code> to match work with any competency, 
     *          <code> false </code> to match work with no competency 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCompetency(boolean match);


    /**
     *  Clears the competency query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCompetencyTerms();


    /**
     *  Matches the creation date between the given date range inclusive. 
     *
     *  @param  start start of date range 
     *  @param  end end of date range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> start </code> is 
     *          greater than <code> end </code> 
     *  @throws org.osid.NullArgumentException <code> start </code> or <code> 
     *          end </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCreatedDate(org.osid.calendaring.DateTime start, 
                                 org.osid.calendaring.DateTime end, 
                                 boolean match);


    /**
     *  Clears the creation date query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCreatedDateTerms();


    /**
     *  Matches the completion date between the given date range inclusive. 
     *
     *  @param  start start of date range 
     *  @param  end end of date range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> start </code> is 
     *          greater than <code> end </code> 
     *  @throws org.osid.NullArgumentException <code> start </code> or <code> 
     *          end </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCompletionDate(org.osid.calendaring.DateTime start, 
                                    org.osid.calendaring.DateTime end, 
                                    boolean match);


    /**
     *  Matches work that have any completion date. 
     *
     *  @param  match <code> true </code> to match completed work, <code> 
     *          false </code> to match incomplete work 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCompletionDate(boolean match);


    /**
     *  Clears the completion date query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCompletionDateTerms();


    /**
     *  Sets the commission <code> Id </code> for this query to match 
     *  commissions. 
     *
     *  @param  commissionId the availability <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> commissionId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCommissionId(org.osid.id.Id commissionId, boolean match);


    /**
     *  Clears the commission <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCommissionIdTerms();


    /**
     *  Tests if a <code> CommissionQuery </code> is available. 
     *
     *  @return <code> true </code> if a commission query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAvailabilityQuery();


    /**
     *  Gets the query for a commission. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the commission query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommissionQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommissionQuery() </code> is <code> true. </code> 
     */

    public org.osid.resourcing.CommissionQuery getCommissionQuery();


    /**
     *  Matches work that have any commission. 
     *
     *  @param  match <code> true </code> to match work with any commission, 
     *          <code> false </code> to match work with no availability 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCommission(boolean match);


    /**
     *  Clears the commission query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCommissionTerms();


    /**
     *  Sets the foundry <code> Id </code> for this query to match works 
     *  assigned to foundries. 
     *
     *  @param  foundryId the foundry <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> foundryId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchFoundryId(org.osid.id.Id foundryId, boolean match);


    /**
     *  Clears the foundry <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFoundryIdTerms();


    /**
     *  Tests if a <code> FoundryQuery </code> is available. 
     *
     *  @return <code> true </code> if a foundry query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFoundryQuery();


    /**
     *  Gets the query for a foundry. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the foundry query 
     *  @throws org.osid.UnimplementedException <code> supportsFoundryQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFoundryQuery() </code> is <code> true. </code> 
     */

    public org.osid.resourcing.FoundryQuery getFoundryQuery();


    /**
     *  Clears the foundry query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFoundryTerms();


    /**
     *  Gets the work query record corresponding to the given <code> Work 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @param  workRecordType a work record type 
     *  @return the work query record 
     *  @throws org.osid.NullArgumentException <code> workRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(workRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.records.WorkQueryRecord getWorkQueryRecord(org.osid.type.Type workRecordType)
        throws org.osid.OperationFailedException;
}
