//
// org.osid.resourcing.batch.AvailabilityBatchAdminSession
//
//     The OSID Java specification for org.osid.resourcing.batch.AvailabilityBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Availabilities 
 *  </code> in bulk. The data for create and update is provided by the 
 *  consumer via the form object. <code> OsidForms </code> are requested for 
 *  each create or update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create an 
 *  <code> Availability, </code> an <code> AvailabilityForm </code> is 
 *  requested using <code> getAvailabilityFormsForCreate() </code> specifying 
 *  the desired job, resource, and record <code> Types </code> or none if no 
 *  record <code> Types </code> are needed. Each of the returned <code> 
 *  AvailabilityForms </code> will indicate that it is to be used with a 
 *  create operation and can be used to examine metdata or validate data prior 
 *  to creation. Once an <code> AvailabilityForm </code> is submiited to a 
 *  create operation, it cannot be reused with another create operation unless 
 *  the first operation was unsuccessful. Each <code> AvailabilityForm </code> 
 *  corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> AvailabilityForms </code> returned from <code> 
 *  getAvailabilityFormsForCreate() </code> may be linked to the originating 
 *  request through the peer <code> Ids </code> of the <code> 
 *  AvailabilityForm. </code> In the case where there may be duplicates, any 
 *  <code> AvailabilityForm </code> of the same peer <code> Ids </code> may be 
 *  used for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> AvailabilityForms </code> are submitted for 
 *  create, a <code> CreateResponse </code> is returned for each <code> 
 *  AvailabilityForm, </code> although the ordering is not defined. Only 
 *  errors that pertain to the entire create operation are returned from 
 *  <code> createAvailabilities(), </code> errors specific to an individual 
 *  <code> AvailabilityForm </code> are indicated in the corresponding <code> 
 *  CreateResponse. </code> <code> CreateResponses </code> may be linked to 
 *  the originating <code> AvailabilityForm </code> through the <code> 
 *  AvailabilityForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> AvailabilityForms </code> are requested to the 
 *  <code> Availability </code> <code> Id </code> that is to be updated using 
 *  <code> getAvailabilityFormsForUpdate() </code> where the reference <code> 
 *  Id </code> in the <code> AvailabilityForm </code> may be used to link the 
 *  request. Similarly, the <code> AvailabilityForm </code> has metadata about 
 *  the data that can be updated and it can perform validation before 
 *  submitting the update. The <code> AvailabilityForm </code> can only be 
 *  used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> AvailabilityForms </code> are submitted for 
 *  update, an <code> UpdateResponse </code> is returned for each <code> 
 *  AvailabilityForm, </code> although the ordering is not defined. Only 
 *  errors that pertain to the entire update operation are returned from 
 *  <code> updateAvailabilities(), </code> errors specific to an individual 
 *  <code> AvailabilityForm </code> are indicated in the corresponding <code> 
 *  UpdateResponse. </code> <code> UpdateResponses </code> may be linked to 
 *  the originating <code> AvailabilityForm </code> through the <code> 
 *  AvailabilityForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> Availabilities </code> in bulk. To 
 *  unmap an <code> Availability </code> from the current <code> Foundry, 
 *  </code> the <code> AvailabilityFoundryAssignmentSession </code> should be 
 *  used. These delete operations attempt to remove the <code> Availability 
 *  </code> itself thus removing it from all known <code> Foundry </code> 
 *  catalogs. Bulk delete operations return the results in <code> 
 *  DeleteResponses. </code> </p>
 */

public interface AvailabilityBatchAdminSession
    extends org.osid.resourcing.AvailabilityAdminSession {


    /**
     *  Gets the availability forms for creating a bunch of new 
     *  availabilities. An <code> AvailabilityForm </code> is returned for 
     *  each job and resource pair. 
     *
     *  @param  peers the relationship peers 
     *  @param  availabilityRecordTypes array of availability record types to 
     *          be included in each create operation or an empty list if none 
     *  @return the availability forms 
     *  @throws org.osid.NotFoundException an <code> effortId </code> or 
     *          <code> resourceId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> peers </code> or <code> 
     *          availabilityRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.batch.AvailabilityBatchFormList getAvailabilityFormsForCreate(org.osid.resourcing.batch.AvailabilityPeerList peers, 
                                                                                             org.osid.type.Type[] availabilityRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Availabilities. </code> This method 
     *  returns an error if the entire operation fails. Otherwise, the status 
     *  of an individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  availabilityForms the availability forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> availabilityForms 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createAvailabilities(org.osid.resourcing.batch.AvailabilityBatchFormList availabilityForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the availability forms for updating an existing set of 
     *  availabilities. A new availability form should be requested for each 
     *  update transaction. 
     *
     *  @param  availabilityIds the <code> Ids </code> of the <code> 
     *          Availability </code> 
     *  @return the availability form 
     *  @throws org.osid.NotFoundException an <code> availabilityId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> availabilityIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.batch.AvailabilityBatchFormList getAvailabilityFormsForUpdate(org.osid.id.IdList availabilityIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing availabilities. This method returns an error if the 
     *  entire operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  availabilityForms the form containing the elements to be 
     *          updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> availabilityForms 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateAvailabilities(org.osid.resourcing.batch.AvailabilityBatchFormList availabilityForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Availabilities </code> in this <code> Foundry 
     *  </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllAvailabilities()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes availabilities for the given <code> Ids. </code> 
     *
     *  @param  availabilityIds the <code> Ids </code> of the availabilities 
     *          to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> availabilityIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAvailabilities(org.osid.id.IdList availabilityIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all availabilities for the given resource. 
     *
     *  @param  resourceId an <code> Id </code> of a resource 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAvailabilitiesForResource(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all availabilities for the given job. 
     *
     *  @param  jobId an <code> Id </code> of a job 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> jobId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAvailabilitiesForJob(org.osid.id.Id jobId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes availabilities expired before the given date. 
     *
     *  @param  date a date 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteIneffectiveAvailabilitiesByDate(org.osid.calendaring.DateTime date)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to an <code> Availability </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Availability </code> is determined by the provider. The new 
     *  <code> Id </code> is an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another availability, it is reassigned to the 
     *  given availability <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasAvailabilities(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
