//
// org.osid.resourcing.batch.CompetencyBatchAdminSession
//
//     The OSID Java specification for org.osid.resourcing.batch.CompetencyBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Competencies </code> 
 *  in bulk. The data for create and update is provided by the consumer via 
 *  the form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Competency, </code> a <code> CompetencyForm </code> is requested using 
 *  <code> getCompetencyFormsForCreate() </code> specifying the desired record 
 *  <code> Types </code> or none if no record <code> Types </code> are needed. 
 *  Each of the returned <code> CompetencyForms </code> will indicate that it 
 *  is to be used with a create operation and can be used to examine metdata 
 *  or validate data prior to creation. Once a <code> CompetencyForm </code> 
 *  is submiited to a create operation, it cannot be reused with another 
 *  create operation unless the first operation was unsuccessful. Each <code> 
 *  CompetencyForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> CompetencyForms </code> returned from <code> 
 *  getCompetencyFormsForCreate() </code> may be linked to the originating 
 *  request through the peer <code> Ids </code> of the <code> CompetencyForm. 
 *  </code> In the case where there may be duplicates, any <code> 
 *  CompetencyForm </code> of the same peer <code> Ids </code> may be used for 
 *  a create operation. </p> 
 *  
 *  <p> Once a batch of <code> CompetencyForms </code> are submitted for 
 *  create, a <code> CreateResponse </code> is returned for each <code> 
 *  CompetencyForm, </code> although the ordering is not defined. Only errors 
 *  that pertain to the entire create operation are returned from <code> 
 *  createCompetencies(), </code> errors specific to an individual <code> 
 *  CompetencyForm </code> are indicated in the corresponding <code> 
 *  CreateResponse. </code> <code> CreateResponses </code> may be linked to 
 *  the originating <code> CompetencyForm </code> through the <code> 
 *  CompetencyForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> CompetencyForms </code> are requested to the 
 *  <code> Competency </code> <code> Id </code> that is to be updated using 
 *  <code> getCompetencyFormsForUpdate() </code> where the reference <code> Id 
 *  </code> in the <code> CompetencyForm </code> may be used to link the 
 *  request. Similarly, the <code> CompetencyForm </code> has metadata about 
 *  the data that can be updated and it can perform validation before 
 *  submitting the update. The <code> CompetencyForm </code> can only be used 
 *  once for a successful update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> CompetencyForms </code> are submitted for 
 *  update, an <code> UpdateResponse </code> is returned for each <code> 
 *  CompetencyForm, </code> although the ordering is not defined. Only errors 
 *  that pertain to the entire update operation are returned from <code> 
 *  updateCompetencies(), </code> errors specific to an individual <code> 
 *  CompetencyForm </code> are indicated in the corresponding <code> 
 *  UpdateResponse. </code> <code> UpdateResponses </code> may be linked to 
 *  the originating <code> CompetencyForm </code> through the <code> 
 *  CompetencyForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> Competencies </code> in bulk. To 
 *  unmap a <code> Competency </code> from the current <code> Foundry, </code> 
 *  the <code> CompetencyFoundryAssignmentSession </code> should be used. 
 *  These delete operations attempt to remove the <code> Competency </code> 
 *  itself thus removing it from all known <code> Foundry </code> catalogs. 
 *  Bulk delete operations return the results in <code> DeleteResponses. 
 *  </code> </p>
 */

public interface CompetencyBatchAdminSession
    extends org.osid.resourcing.CompetencyAdminSession {


    /**
     *  Gets the competency forms for creating a bunch of new competencies. 
     *
     *  @param  number the number of forms to retrieve 
     *  @param  competencyRecordTypes array of competency record types to be 
     *          included in each create operation or an empty list if none 
     *  @return the competency forms 
     *  @throws org.osid.NullArgumentException <code> competencyRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.batch.CompetencyBatchFormList getCompetencyFormsForCreate(long number, 
                                                                                         org.osid.type.Type[] competencyRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Competencies. </code> This method returns 
     *  an error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  competencyForms the competency forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> competencyForms </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createCompetencies(org.osid.resourcing.batch.CompetencyBatchFormList competencyForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the competency forms for updating an existing set of 
     *  competencies. A new competency form should be requested for each 
     *  update transaction. 
     *
     *  @param  competencyIds the <code> Ids </code> of the <code> Competency 
     *          </code> 
     *  @return the competency form 
     *  @throws org.osid.NotFoundException a <code> competencyId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> competencyIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.batch.CompetencyBatchFormList getCompetencyFormsForUpdate(org.osid.id.IdList competencyIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing competencies. This method returns an error if the 
     *  entire operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  competencyForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> competencyForms </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateCompetencies(org.osid.resourcing.batch.CompetencyBatchFormList competencyForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Competencies </code> in this <code> Foundry </code> 
     *  . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllCompetencies()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes competencies for the given <code> Ids. </code> 
     *
     *  @param  competencyIds the <code> Ids </code> of the competencies to 
     *          delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> competencyIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteCompetencies(org.osid.id.IdList competencyIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Competency </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Competency </code> is determined by the provider. The new 
     *  <code> Id </code> is an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another competency, it is reassigned to the 
     *  given competency <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasCompetencies(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
