/**
 * <p>The Open Service Interface Definitions for the org.osid.resourcing
 * service.</p>
 * 
 * <p>The Resourcing OSID provides a means for resourcing work. The Resourcing 
 * OSID works in conjunction with the Workflow OSID, Learning OSID, and 
 * Tracking OSID to manage the assignment of <code> Resources </code> to 
 * <code> Work </code> as part an an overall work management system. </p> 
 * <h4> Work </h4> 
 * 
 * <p> <code> Work </code> is an abstract concept that represents a task that 
 * needs to be performed by workers. Workers may require a competency in order 
 * to perform the work. </p> 
 * <h4> Competencies </h4> 
 * 
 * <p> A <code> Competency </code> is described as a set of learning <code> 
 * Objectives. </code> A worker meets the requirements of <code> Work </code> 
 * if the worker <code> (Resource </code> ) has a <code> Proficiency </code> 
 * for the related learning <code> Objectives </code> managed in the Learning 
 * OSID. </p> 
 * <h4> Jobs </h4> 
 * 
 * <p> A <code> Job </code> is a collection of <code> Work </code> that is 
 * performed on an ongoing basis. The distinction between a <code> Job </code> 
 * and <code> Work </code> is that <code> Work </code> is a specific instance 
 * of a task while the <code> Job </code> represents the overall goal and may 
 * be perpetual. For example, a construction project is a <code> Job </code> 
 * that has many project components. One of the project components is the 
 * installation of electrical panels throughout the building. Each electrical 
 * panel is a <code> Work </code> that requires a certain <code> Competency. 
 * </code> The <code> Competency </code> indicates that the installation needs 
 * to be performed by an electrician with a <code> Proficiency </code> in such 
 * installations. </p> 
 * 
 * <p> A Job is an <code> OsidGovernator </code> that governs <code> Work 
 * </code> and the operation of matching <code> Resources </code> based on the 
 * <code> Proficiencies </code> of the <code> Resource </code> and the <code> 
 * Competencies </code> required by the <code> Work </code> . </p> 
 * <h4> Availabilities </h4> 
 * 
 * <p> <code> Availability </code> indicates the <code> Resources </code> 
 * available to assign to <code> Work </code> in a <code> Job. </code> An 
 * <code> Availability </code> is an <code> OsidRelationship </code> between a 
 * <code> Resource </code> and a <code> Job </code> qualified by a set of 
 * <code> Competencies </code> . </p> 
 * <h4> Commissions </h4> 
 * 
 * <p> A Commission is the assignment of a <code> Resource </code> to <code> 
 * Work. </code> A <code> Commission </code> is an <code> OsidRelationship 
 * </code> between a <code> Resource </code> and <code> Work </code> qualified 
 * by the <code> Competency </code> used. </p> 
 * 
 * <p> Commissions may be assigned manually or automatically based on the 
 * rules of the Job. For example, a call center may route trouble tickets to a 
 * set of resources in second tier support based on the subject matter of the 
 * problem report. The trouble ticket is the <code> Work </code> within the 
 * <code> Job </code> of the call center. The subject matter is described as a 
 * required <code> Competency </code> and each resource in the second tier 
 * support group has a set of <code> Proficiencies </code> in various areas. 
 * The system selects the best <code> Resource </code> match optimizing the 
 * load distribution based on the <code> Availability </code> and the existing 
 * <code> Commissions </code> of the <code> Resources </code> . </p> 
 * <h4> Effort </h4> 
 * 
 * <p> <code> Effort </code> tracks the effort expended by a <code> Resource 
 * </code> on Work. <code> Effort </code> is an <code> OsidRelationship 
 * </code> between a <code> Resource </code> and a <code> Commission </code> . 
 * </p> 
 * <h4> Foundry Cataloging </h4> 
 * 
 * <p> <code> Jobs, </code> <code> Work, </code> <code> Competencies, </code> 
 * <code> Availabilities, </code> <code> Commissions, </code> and <code> 
 * Effort </code> may be organized into federateable <code> OsidCatalogs. 
 * </code> A <code> Foundry </code> is the <code> OsidCatalog </code> for the 
 * Resourcing OSID. </p> 
 * <h4> Sub Packages </h4> 
 * 
 * <p> The Resourcing OSID contains a Resourcing Rules OSID for managing the 
 * rules for operating <code> Jobs </code> and enabling <code> Commissions 
 * </code> and <code> Availability </code> . </p>
 * 
 * <br/><hr/><br/>
 * 
 * <p>Copyright &copy; 2010 Ingenescus. All Rights Reserved. </p>
 * 
 * <p>This Work is being provided by the copyright holder(s) subject to the 
 * following license. By obtaining, using and/or copying this Work, you agree 
 * that you have read, understand, and will comply with the following terms 
 * and conditions. </p> 
 * 
 * <p> Permission to use, copy and distribute unmodified versions of this 
 * Work, for any purpose, without fee or royalty is hereby granted, provided 
 * that you include the above copyright notices and the terms of this license 
 * on ALL copies of the Work or portions thereof. </p> 
 * 
 * <p> You may modify or create Derivatives of this Work only for your 
 * internal purposes. You shall not distribute or transfer any such Derivative 
 * of this Work to any location or to any third party. For the purposes of 
 * this license, "Derivative" shall mean any derivative of the Work as defined 
 * in the United States Copyright Act of 1976, such as a translation or 
 * modification. </p> 
 * 
 * <p> This Work and the information contained herein is provided on an "AS 
 * IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT 
 * NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR 
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT 
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN 
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN 
 * CONNECTION WITH THE WORK OR THE USE OR OTHER DEALINGS IN THE WORK. </p> 
 * 
 * <p> The export of software employing encryption technology may require a 
 * specific license from the United States Government. It is the 
 * responsibility of any person or organization contemplating export to obtain 
 * such a license before exporting this Work. </p>
 */

package org.osid.resourcing;
