//
// org.osid.resourcing.rules.AvailabilityEnablerAdminSession
//
//     The OSID Java specification for org.osid.resourcing.rules.AvailabilityEnablerAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing.rules;


/**
 *  <p>This session creates and removes availability enablers. The data for 
 *  create and update is provided via the <code> AvailabilityEnablerForm. 
 *  </code> </p>
 */

public interface AvailabilityEnablerAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Foundry </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Foundry Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFoundryId();


    /**
     *  Gets the <code> Foundry </code> associated with this session. 
     *
     *  @return the foundry 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.Foundry getFoundry()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create availability enablers. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating an <code> AvailabilityEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer create 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> AvailabilityEnabler </code> 
     *          creation is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAvailabilityEnabler();


    /**
     *  Tests if this user can create a single <code> AvailabilityEnabler 
     *  </code> using the desired record types. While <code> 
     *  ResourcingRulesManager.getAvailabilityEnablerRecordTypes() </code> can 
     *  be used to examine which records are supported, this method tests 
     *  which record(s) are required for creating a specific <code> 
     *  AvailabilityEnabler. </code> Providing an empty array tests if an 
     *  <code> AvailabilityEnabler </code> can be created with no records. 
     *
     *  @param  availabilityEnablerRecordTypes array of availability enabler 
     *          record types 
     *  @return <code> true </code> if <code> AvailabilityEnabler </code> 
     *          creation using the specified record <code> Types </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          availabilityEnablerRecordTypes </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAvailabilityEnablerWithRecordTypes(org.osid.type.Type[] availabilityEnablerRecordTypes);


    /**
     *  Gets the availability enabler form for creating new availability 
     *  enablers. A new form should be requested for each create transaction. 
     *
     *  @param  availabilityEnablerRecordTypes array of availability enabler 
     *          record types 
     *  @return the availability enabler form 
     *  @throws org.osid.NullArgumentException <code> 
     *          availabilityEnablerRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form with 
     *          requested record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.AvailabilityEnablerForm getAvailabilityEnablerFormForCreate(org.osid.type.Type[] availabilityEnablerRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> AvailabilityEnabler. </code> 
     *
     *  @param  availabilityEnablerForm the form for this <code> 
     *          AvailabilityEnabler </code> 
     *  @return the new <code> AvailabilityEnabler </code> 
     *  @throws org.osid.IllegalStateException <code> availabilityEnablerForm 
     *          </code> already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> availabilityEnablerForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> availabilityEnablerForm 
     *          </code> did not originate from <code> 
     *          getAvailabilityEnablerFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.AvailabilityEnabler createAvailabilityEnabler(org.osid.resourcing.rules.AvailabilityEnablerForm availabilityEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update availability enablers. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating an <code> AvailabilityEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer update 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> AvailabilityEnabler </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateAvailabilityEnablers();


    /**
     *  Gets the availability enabler form for updating an existing 
     *  availability enabler. A new availability enabler form should be 
     *  requested for each update transaction. 
     *
     *  @param  availabilityEnablerId the <code> Id </code> of the <code> 
     *          AvailabilityEnabler </code> 
     *  @return the availability enabler form 
     *  @throws org.osid.NotFoundException <code> availabilityEnablerId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> availabilityEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.AvailabilityEnablerForm getAvailabilityEnablerFormForUpdate(org.osid.id.Id availabilityEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing availability enabler. 
     *
     *  @param  availabilityEnablerForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> availabilityEnablerForm 
     *          </code> already used in an jupdate transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> availabilityEnablerForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> availabilityEnablerForm 
     *          </code> did not originate from <code> 
     *          getAvailabilityEnablerFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateAvailabilityEnabler(org.osid.resourcing.rules.AvailabilityEnablerForm availabilityEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete availability enablers. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting an <code> AvailabilityEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer delete 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> AvailabilityEnabler </code> 
     *          deletion is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteAvailabilityEnablers();


    /**
     *  Deletes an <code> AvailabilityEnabler. </code> 
     *
     *  @param  availabilityEnablerId the <code> Id </code> of the <code> 
     *          AvailabilityEnabler </code> to remove 
     *  @throws org.osid.NotFoundException <code> availabilityEnablerId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> availabilityEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteAvailabilityEnabler(org.osid.id.Id availabilityEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for 
     *  availability enablers. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> AvailabilityEnabler </code> 
     *          aliasing is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageAvailabilityEnablerAliases();


    /**
     *  Adds an <code> Id </code> to an <code> AvailabilityEnabler </code> for 
     *  the purpose of creating compatibility. The primary <code> Id </code> 
     *  of the <code> AvailabilityEnabler </code> is determined by the 
     *  provider. The new <code> Id </code> performs as an alias to the 
     *  primary <code> Id </code> . If the alias is a pointer to another 
     *  availability enabler. it is reassigned to the given availability 
     *  enabler <code> Id. </code> 
     *
     *  @param  availabilityEnablerId the <code> Id </code> of an <code> 
     *          AvailabilityEnabler </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> availabilityEnablerId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> availabilityEnablerId 
     *          </code> or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasAvailabilityEnabler(org.osid.id.Id availabilityEnablerId, 
                                         org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
