//
// org.osid.resourcing.rules.AvailabilityEnablerRuleApplicationSession
//
//     The OSID Java specification for org.osid.resourcing.rules.AvailabilityEnablerRuleApplicationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing.rules;


/**
 *  <p>This session provides methods to apply <code> AvailabilityEnablers 
 *  </code> to <code> Availabilities. </code> An <code> Availability </code> 
 *  with multiple <code> AvailabilityEnablers </code> means any positive rule 
 *  evaluation across the enablers result in an accessible <code> 
 *  Availability. </code> </p>
 */

public interface AvailabilityEnablerRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Foundry </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Foundry Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFoundryId();


    /**
     *  Gets the <code> Foundry </code> associated with this session. 
     *
     *  @return the foundry 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.Foundry getFoundry()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter availability enabler/availability 
     *  mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known mapping 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignAvailabilityEnablers();


    /**
     *  Adds an existing <code> AvailabilityEnabler </code> to an <code> 
     *  Availability. </code> 
     *
     *  @param  availabilityEnablerId the <code> Id </code> of the <code> 
     *          AvailabilityEnabler </code> 
     *  @param  availabilityId the <code> Id </code> of the <code> 
     *          Availability </code> 
     *  @throws org.osid.AlreadyExistsException <code> availabilityEnablerId 
     *          </code> is already applied to <code> availabilityId </code> 
     *  @throws org.osid.NotFoundException <code> availabilityEnablerId 
     *          </code> or <code> availabilityId </code> not found 
     *  @throws org.osid.NullArgumentException <code> availabilityEnablerId 
     *          </code> or <code> availabilityId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignAvailabilityEnablerToAvailability(org.osid.id.Id availabilityEnablerId, 
                                                        org.osid.id.Id availabilityId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes an <code> AvailabilityEnabler </code> from an <code> 
     *  Availability. </code> 
     *
     *  @param  availabilityEnablerId the <code> Id </code> of the <code> 
     *          AvailabilityEnabler </code> 
     *  @param  availabilityId the <code> Id </code> of the <code> 
     *          Availability </code> 
     *  @throws org.osid.NotFoundException <code> availabilityEnablerId 
     *          </code> or <code> availabilityId </code> not found or <code> 
     *          availabilityEnablerId </code> not applied to <code> 
     *          availabilityId </code> 
     *  @throws org.osid.NullArgumentException <code> availabilityEnablerId 
     *          </code> or <code> availabilityId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignAvailabilityEnablerFromAvailability(org.osid.id.Id availabilityEnablerId, 
                                                            org.osid.id.Id availabilityId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> AvailabilityEnablers. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known sequencing operations will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> AvailabilityEnabler </code> 
     *          ordering is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceAvailabilityEnablers();


    /**
     *  Reorders availability enablers for an availability by moving the 
     *  specified availability enabler in front of a reference availability 
     *  enabler. 
     *
     *  @param  availabilityEnablerId the <code> Id </code> of an <code> 
     *          AvailabilityEnabler </code> 
     *  @param  availabilityId the <code> Id </code> of an <code> Availability 
     *          </code> 
     *  @param  referenceId the reference availability enabler <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> availabilityEnablerId, 
     *          availabilityId, </code> or <code> referenceId </code> not 
     *          found or, <code> availabilityEnablerId </code> or <code> 
     *          referenceId </code> not related to <code> availabilityId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> availabilityEnablerId, 
     *          availabilityId, </code> or <code> referenceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveAvailabilityEnablerAhead(org.osid.id.Id availabilityEnablerId, 
                                             org.osid.id.Id availabilityId, 
                                             org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders availability enablers for an availability by moving the 
     *  specified availability enabler behind a reference availability 
     *  enabler. 
     *
     *  @param  availabilityEnablerId the <code> Id </code> of an <code> 
     *          AvailabilityEnabler </code> 
     *  @param  availabilityId the <code> Id </code> of an <code> Availability 
     *          </code> 
     *  @param  referenceId the reference availability enabler <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> availabilityEnablerId, 
     *          availabilityId, </code> or <code> referenceId </code> not 
     *          found or, <code> availabilityEnablerId </code> or <code> 
     *          referenceId </code> not related to <code> availabilityId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> availabilityEnablerId, 
     *          availabilityId, </code> or <code> referenceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveAvailabilitynEnablerBehind(org.osid.id.Id availabilityEnablerId, 
                                               org.osid.id.Id availabilityId, 
                                               org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of availability enablers for an availability. 
     *
     *  @param  availabilityEnablerIds the <code> Ids </code> for a set of 
     *          <code> AvailabilityEnablers </code> 
     *  @param  availabilityId the <code> Id </code> of an <code> Availability 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> availabilityId </code> not 
     *          found or, an <code> availabilityEnablerId </code> not related 
     *          to <code> availabilityId </code> 
     *  @throws org.osid.NullArgumentException <code> availabilityEnablerIds 
     *          </code> or <code> availabilityId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderAvailabilityEnablers(org.osid.id.Id[] availabilityEnablerIds, 
                                          org.osid.id.Id availabilityId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
