//
// org.osid.resourcing.rules.AvailabilityEnablerRuleLookupSession
//
//     The OSID Java specification for org.osid.resourcing.rules.AvailabilityEnablerRuleLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing.rules;


/**
 *  <p>This session provides methods to retrieve <code> AvailabilityEnabler 
 *  </code> to <code> Availability </code> mappings. An <code> Availability 
 *  </code> with multiple <code> AvailabilityEnablers </code> means any 
 *  positive rule evaluation across the enablers result in an accessible 
 *  <code> Availability. </code> </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated foundry view: All methods in this session operate, 
 *      retrieve and pertain to availability enablers defined explicitly in 
 *      the current foundry </li> 
 *      <li> federated foundry view: All methods in this session operate, 
 *      retrieve and pertain to all availability enablers defined in this 
 *      foundry and any other availability enabler implicitly available in 
 *      this foundry through foundry inheritence. </li> 
 *  </ul>
 *  
 */

public interface AvailabilityEnablerRuleLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Foundry </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Foundry Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFoundryId();


    /**
     *  Gets the <code> Foundry </code> associated with this session. 
     *
     *  @return the foundry 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.Foundry getFoundry()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform lookups of availability 
     *  enabler/availability mappings. A return of true does not guarantee 
     *  successful authorization. A return of false indicates that it is known 
     *  lookup methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if looking up mappings is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupAvailabilityEnablerRules();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeAvailabilityEnablerRuleView();


    /**
     *  A complete view of the <code> AvailabilityEnabler </code> and <code> 
     *  Availability </code> returns is desired. Methods will return what is 
     *  requested or result in an error. This view is used when greater 
     *  precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryAvailabilityEnablerRuleView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include availability enabler in foundries which are children of this 
     *  foundry in the foundry hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedFoundryView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this foundry only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedFoundryView();


    /**
     *  Gets the <code> AvailabilityEnabler Id </code> associated with an 
     *  <code> Availability. </code> 
     *
     *  @param  availabilityId <code> Id </code> of the <code> Availability 
     *          </code> 
     *  @return the availability enabler <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> availabilityId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> availabilityId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAvailabilityEnablerIdsForAvailability(org.osid.id.Id availabilityId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> AvailabilityEnabler </code> associated with an <code> 
     *  Availability. </code> 
     *
     *  @param  availabilityId <code> Id </code> of the <code> Availability 
     *          </code> 
     *  @return the availability enablers 
     *  @throws org.osid.NotFoundException <code> availabilityId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> availabilityId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.AvailabilityEnablerList getAvailabilityEnablersForAvailability(org.osid.id.Id availabilityId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Availability </code> <code> Ids </code> mapped to an 
     *  <code> AvailabilityEnabler. </code> 
     *
     *  @param  availabilityEnablerId <code> Id </code> of an <code> 
     *          AvailabilityEnabler </code> 
     *  @return list of availability <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> availabilityEnablerId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> availabilityEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAvailabilityIdsForAvailabilityEnabler(org.osid.id.Id availabilityEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Availabilities </code> mapped to an <code> 
     *  AvailabilityEnabler. </code> 
     *
     *  @param  availabilityEnablerId <code> Id </code> of an <code> 
     *          AvailabilityEnabler </code> 
     *  @return list of availabilities 
     *  @throws org.osid.NotFoundException <code> availabilityEnablerId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> availabilityEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.AvailabilityList getAvailabilitiesForAvailabilityEnabler(org.osid.id.Id availabilityEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
