//
// org.osid.resourcing.rules.AvailabilityEnablerSearchSession
//
//     The OSID Java specification for org.osid.resourcing.rules.AvailabilityEnablerSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing.rules;


/**
 *  <p>This session provides methods for searching among <code> 
 *  AvailabilityEnabler </code> objects. The search query is constructed using 
 *  the <code> AvailabilityEnableryQuery. </code> </p> 
 *  
 *  <p> <code> getAvailabilityEnablersByQuery() </code> is the basic search 
 *  method and returns a list of <code> AvailabilityEnablers. </code> A more 
 *  advanced search may be performed with <code> 
 *  getAvailabilityEnablersBySearch(). </code> It accepts an <code> 
 *  AvailabilityEnablerSearch </code> in addition to the query for the purpose 
 *  of specifying additional options affecting the entire search, such as 
 *  resourcing. <code> getAvailabilityEnablersBySearch() </code> returns an 
 *  <code> AvailabilityEnablerSearchResults </code> that can be used to access 
 *  the resulting <code> AvailabilityEnablerList </code> or be used to perform 
 *  a search within the result set through <code> AvailabilityEnablerSearch. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated foundry view: searches include availability enablers in 
 *      foundries of which this foundry is an ancestor in the foundry 
 *      hierarchy </li> 
 *      <li> isolated foundry view: searches are restricted to availability 
 *      enablers in this foundry </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> AvailabilityEnablers </code> may have an availability enabler 
 *  query record indicated by their respective record types. The availability 
 *  enabler record query is accessed via the <code> AvailabilityEnablerQuery. 
 *  </code> </p>
 */

public interface AvailabilityEnablerSearchSession
    extends org.osid.resourcing.rules.AvailabilityEnablerQuerySession {


    /**
     *  Gets an availability enabler search. 
     *
     *  @return the availability enabler search. 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.AvailabilityEnablerSearch getAvailabilityEnablerSearch();


    /**
     *  Gets an availability enabler search order. The <code> 
     *  AvailabilityEnablerSearchOrder </code> is supplied to an <code> 
     *  AvailabilityEnablerSearch </code> to specify the ordering of results. 
     *
     *  @return the availability enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.AvailabilityEnablerSearchOrder getAvailabilityEnablerSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  availabilityEnablerQuery the availability enabler query 
     *  @param  availabilityEnablerSearch the availability enabler search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> availabilityEnablerQuery 
     *          </code> or <code> availabilityEnablerSearch </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> availabilityEnablerQuery 
     *          </code> or <code> availabilityEnablerSearch </code> is not of 
     *          this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.AvailabilityEnablerSearchResults getAvailabilityEnablersBySearch(org.osid.resourcing.rules.AvailabilityEnablerQuery availabilityEnablerQuery, 
                                                                                                      org.osid.resourcing.rules.AvailabilityEnablerSearch availabilityEnablerSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an availability enabler query from an inspector. The inspector is 
     *  available from an <code> AvailabilityEnablerSearchResults. </code> 
     *
     *  @param  availabilityEnablerQueryInspector an availability enabler 
     *          query inspector 
     *  @return the availability enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          availabilityEnablerQueryInspector </code> is <code> null 
     *          </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          availabilityEnablerQueryInspector </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.AvailabilityEnablerQuery getAvailabilityEnablerQueryFromInspector(org.osid.resourcing.rules.AvailabilityEnablerQueryInspector availabilityEnablerQueryInspector);
}
