//
// org.osid.resourcing.rules.CommissionEnablerFoundryAssignmentSession
//
//     The OSID Java specification for org.osid.resourcing.rules.CommissionEnablerFoundryAssignmentSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing.rules;


/**
 *  <p>This session provides methods to re-assign <code> CommissionEnabler 
 *  </code> to <code> Foundry </code> mappings. A <code> CommissionEnabler 
 *  </code> may appear in multiple <code> Foundry </code> objects and removing 
 *  the last reference to a <code> CommissionEnabler </code> is the equivalent 
 *  of deleting it. Each <code> Foundry </code> may have its own 
 *  authorizations governing who is allowed to operate on it. </p> 
 *  
 *  <p> Adding a reference of a <code> CommissionEnabler </code> to another 
 *  <code> Foundry </code> is not a copy operation (eg: does not change its 
 *  <code> Id </code> ). </p>
 */

public interface CommissionEnablerFoundryAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter commission enabler/foundry mappings. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignCommissionEnablers();


    /**
     *  Tests if this user can alter commission enabler/foundry mappings. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> foundryId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignCommissionEnablersToFoundry(org.osid.id.Id foundryId);


    /**
     *  Gets a list of foundries including and under the given foundry node in 
     *  which any commission enabler can be assigned. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @return list of assignable foundry <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableFoundryIds(org.osid.id.Id foundryId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of foundries including and under the given foundry node in 
     *  which a specific commission enabler can be assigned. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  commissionEnablerId the <code> Id </code> of the <code> 
     *          CommissionEnabler </code> 
     *  @return list of assignable foundry <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId </code> or 
     *          <code> commissionEnablerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableFoundryIdsForCommissionEnabler(org.osid.id.Id foundryId, 
                                                                          org.osid.id.Id commissionEnablerId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> CommissionEnabler </code> to a <code> Foundry. 
     *  </code> 
     *
     *  @param  commissionEnablerId the <code> Id </code> of the <code> 
     *          CommissionEnabler </code> 
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @throws org.osid.AlreadyExistsException <code> ccommissionEnablerId 
     *          </code> is already assigned to <code> foundryId </code> 
     *  @throws org.osid.NotFoundException <code> ccommissionEnablerId </code> 
     *          or <code> foundryId </code> not found 
     *  @throws org.osid.NullArgumentException <code> commissionEnablerId 
     *          </code> or <code> foundryId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignCommissionEnablerToFoundry(org.osid.id.Id commissionEnablerId, 
                                                 org.osid.id.Id foundryId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> CommissionEnabler </code> from a <code> Foundry. 
     *  </code> 
     *
     *  @param  commissionEnablerId the <code> Id </code> of the <code> 
     *          CommissionEnabler </code> 
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @throws org.osid.NotFoundException <code> commissionEnablerId </code> 
     *          or <code> foundryId </code> not found or <code> 
     *          commissionEnablerId </code> not assigned to <code> foundryId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> commissionEnablerId 
     *          </code> or <code> foundryId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignCommissionEnablerFromFoundry(org.osid.id.Id commissionEnablerId, 
                                                     org.osid.id.Id foundryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
