//
// org.osid.resourcing.rules.JobConstrainerAdminSession
//
//     The OSID Java specification for org.osid.resourcing.rules.JobConstrainerAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing.rules;


/**
 *  <p>This session creates and removes job constrainers. The data for create 
 *  and update is provided via the <code> JobConstrainerForm. </code> </p>
 */

public interface JobConstrainerAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Foundry </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Foundry Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFoundryId();


    /**
     *  Gets the <code> Foundry </code> associated with this session. 
     *
     *  @return the foundry 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.Foundry getFoundry()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create job constrainers. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known creating a <code> JobConstrainer </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer create operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> JobConstrainer </code> creation 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateJobConstrainer();


    /**
     *  Tests if this user can create a single <code> JobConstrainer </code> 
     *  using the desired record types. While <code> 
     *  ResourcingRulesManager.getJobConstrainerRecordTypes() </code> can be 
     *  used to examine which records are supported, this method tests which 
     *  record(s) are required for creating a specific <code> JobConstrainer. 
     *  </code> Providing an empty array tests if a <code> JobConstrainer 
     *  </code> can be created with no records. 
     *
     *  @param  jobConstrainerRecordTypes array of job constrainer record 
     *          types 
     *  @return <code> true </code> if <code> JobConstrainer </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          jobConstrainerRecordTypes </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateJobConstrainerWithRecordTypes(org.osid.type.Type[] jobConstrainerRecordTypes);


    /**
     *  Gets the job constrainer form for creating new job constrainers. A new 
     *  form should be requested for each create transaction. 
     *
     *  @param  jobConstrainerRecordTypes array of job constrainer record 
     *          types 
     *  @return the job constrainer form 
     *  @throws org.osid.NullArgumentException <code> 
     *          jobConstrainerRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form with 
     *          requested record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.JobConstrainerForm getJobConstrainerFormForCreate(org.osid.type.Type[] jobConstrainerRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> JobConstrainer. </code> 
     *
     *  @param  jobConstrainerForm the form for this <code> JobConstrainer 
     *          </code> 
     *  @return the new <code> JobConstrainer </code> 
     *  @throws org.osid.IllegalStateException <code> jobConstrainerForm 
     *          </code> already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> jobConstrainerForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> jobConstrainerForm 
     *          </code> did not originate from <code> 
     *          getJobConstrainerFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.JobConstrainer createJobConstrainer(org.osid.resourcing.rules.JobConstrainerForm jobConstrainerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update job constrainers. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known updating a <code> JobConstrainer </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer update operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> JobConstrainer </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateJobConstrainers();


    /**
     *  Gets the job constrainer form for updating an existing job 
     *  constrainer. A new job constrainer form should be requested for each 
     *  update transaction. 
     *
     *  @param  jobConstrainerId the <code> Id </code> of the <code> 
     *          JobConstrainer </code> 
     *  @return the job constrainer form 
     *  @throws org.osid.NotFoundException <code> jobConstrainerId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> jobConstrainerId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.JobConstrainerForm getJobConstrainerFormForUpdate(org.osid.id.Id jobConstrainerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing job constrainer. 
     *
     *  @param  jobConstrainerForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> jobConstrainerForm 
     *          </code> already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> jobConstrainerForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> jobConstrainerForm 
     *          </code> did not originate from <code> 
     *          getJobConstrainerFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateJobConstrainer(org.osid.resourcing.rules.JobConstrainerForm jobConstrainerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete job constrainers. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known deleting a <code> JobConstrainer </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer delete operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> JobConstrainer </code> deletion 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteJobConstrainers();


    /**
     *  Deletes a <code> JobConstrainer. </code> 
     *
     *  @param  jobConstrainerId the <code> Id </code> of the <code> 
     *          JobConstrainer </code> to remove 
     *  @throws org.osid.NotFoundException <code> jobConstrainerId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> jobConstrainerId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteJobConstrainer(org.osid.id.Id jobConstrainerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for job 
     *  constrainers. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> JobConstrainer </code> aliasing 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageJobConstrainerAliases();


    /**
     *  Adds an <code> Id </code> to a <code> JobConstrainer </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> JobConstrainer </code> is determined by the provider. The 
     *  new <code> Id </code> performs as an alias to the primary <code> Id 
     *  </code> . If the alias is a pointer to another job constrainer. it is 
     *  reassigned to the given job constrainer <code> Id. </code> 
     *
     *  @param  jobConstrainerId the <code> Id </code> of a <code> 
     *          JobConstrainer </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> jobConstrainerId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> jobConstrainerId </code> 
     *          or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasJobConstrainer(org.osid.id.Id jobConstrainerId, 
                                    org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
