//
// org.osid.resourcing.rules.JobConstrainerEnablerAdminSession
//
//     The OSID Java specification for org.osid.resourcing.rules.JobConstrainerEnablerAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing.rules;


/**
 *  <p>This session creates and removes job constrainer enablers. The data for 
 *  create and update is provided via the <code> JobConstrainerEnablerForm. 
 *  </code> </p>
 */

public interface JobConstrainerEnablerAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Foundry </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Foundry Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFoundryId();


    /**
     *  Gets the <code> Foundry </code> associated with this session. 
     *
     *  @return the foundry 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.Foundry getFoundry()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create job constrainer enablers. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known a <code> JobConstrainerEnabler </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer create operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> JobConstrainerEnabler </code> 
     *          creation is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateJobConstrainerEnabler();


    /**
     *  Tests if this user can create a single <code> JobConstrainerEnabler 
     *  </code> using the desired record types. While <code> 
     *  ResourcingRulesManager.getJobConstrainerEnablerRecordTypes() </code> 
     *  can be used to examine which records are supported, this method tests 
     *  which record(s) are required for creating a specific <code> 
     *  JobConstrainerEnabler. </code> Providing an empty array tests if a 
     *  <code> JobConstrainerEnabler </code> can be created with no records. 
     *
     *  @param  jobConstrainerEnablerRecordTypes array of job constrainer 
     *          enabler record types 
     *  @return <code> true </code> if <code> JobConstrainerEnabler </code> 
     *          creation using the specified record <code> Types </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          jobConstrainerEnablerRecordTypes </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateJobConstrainerEnablerWithRecordTypes(org.osid.type.Type[] jobConstrainerEnablerRecordTypes);


    /**
     *  Gets the job constrainer enabler form for creating new job constrainer 
     *  enablers. A new form should be requested for each create transaction. 
     *
     *  @param  jobConstrainerEnablerRecordTypes array of job constrainer 
     *          enabler record types 
     *  @return the job constrainer enabler form 
     *  @throws org.osid.NullArgumentException <code> 
     *          jobConstrainerEnablerRecordTypes </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form with 
     *          requested record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.JobConstrainerEnablerForm getJobConstrainerEnablerFormForCreate(org.osid.type.Type[] jobConstrainerEnablerRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> JobConstrainerEnabler. </code> 
     *
     *  @param  jobConstrainerEnablerForm the form for this <code> 
     *          JobConstrainerEnabler </code> 
     *  @return the new <code> JobConstrainerEnabler </code> 
     *  @throws org.osid.IllegalStateException <code> 
     *          jobConstrainerEnablerForm </code> already used in a create 
     *          transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> 
     *          jobConstrainerEnablerForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> jobConstrainerEnablerForm 
     *          </code> did not originate from <code> 
     *          getJobConstrainerEnablerFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.JobConstrainerEnabler createJobConstrainerEnabler(org.osid.resourcing.rules.JobConstrainerEnablerForm jobConstrainerEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update job constrainer enablers. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> JobConstrainerEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer update 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> JobConstrainerEnabler </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateJobConstrainerEnablers();


    /**
     *  Gets the job constrainer enabler form for updating an existing job 
     *  constrainer enabler. A new job constrainer enabler form should be 
     *  requested for each update transaction. 
     *
     *  @param  jobConstrainerEnablerId the <code> Id </code> of the <code> 
     *          JobConstrainerEnabler </code> 
     *  @return the job constrainer enabler form 
     *  @throws org.osid.NotFoundException <code> jobConstrainerEnablerId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> jobConstrainerEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.JobConstrainerEnablerForm getJobConstrainerEnablerFormForUpdate(org.osid.id.Id jobConstrainerEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing job constrainer enabler. 
     *
     *  @param  jobConstrainerEnablerForm the form containing the elements to 
     *          be updated 
     *  @throws org.osid.IllegalStateException <code> 
     *          jobConstrainerEnablerForm </code> already used in an update 
     *          transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> 
     *          jobConstrainerEnablerForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> jobConstrainerEnablerForm 
     *          </code> did not originate from <code> 
     *          getJobConstrainerEnablerFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateJobConstrainerEnabler(org.osid.resourcing.rules.JobConstrainerEnablerForm jobConstrainerEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete job constrainer enablers. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> JobConstrainerEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer delete 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> JobConstrainerEnabler </code> 
     *          deletion is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteJobConstrainerEnablers();


    /**
     *  Deletes a <code> JobConstrainerEnabler. </code> 
     *
     *  @param  jobConstrainerEnablerId the <code> Id </code> of the <code> 
     *          JobConstrainerEnabler </code> to remove 
     *  @throws org.osid.NotFoundException <code> jobConstrainerEnablerId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> jobConstrainerEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteJobConstrainerEnabler(org.osid.id.Id jobConstrainerEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for job 
     *  constrainer enablers. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> JobConstrainerEnabler </code> 
     *          aliasing is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageJobConstrainerEnablerAliases();


    /**
     *  Adds an <code> Id </code> to a <code> JobConstrainerEnabler </code> 
     *  for the purpose of creating compatibility. The primary <code> Id 
     *  </code> of the <code> JobConstrainerEnabler </code> is determined by 
     *  the provider. The new <code> Id </code> performs as an alias to the 
     *  primary <code> Id </code> . If the alias is a pointer to another job 
     *  constrainer enabler. it is reassigned to the given job constrainer 
     *  enabler <code> Id. </code> 
     *
     *  @param  jobConstrainerEnablerId the <code> Id </code> of a <code> 
     *          JobConstrainerEnabler </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> jobConstrainerEnablerId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> jobConstrainerEnablerId 
     *          </code> or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasJobConstrainerEnabler(org.osid.id.Id jobConstrainerEnablerId, 
                                           org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
