//
// org.osid.resourcing.rules.JobConstrainerLookupSession
//
//     The OSID Java specification for org.osid.resourcing.rules.JobConstrainerLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing.rules;


/**
 *  <p>This session provides methods for retrieving <code> JobConstrainers. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated foundry view: All job constrainer methods in this 
 *      session operate, retrieve and pertain to job constrainer defined 
 *      explicitly in the current foundry. Using an isolated view is useful 
 *      for managing <code> JobConstrainers </code> with the <code> 
 *      JobConstrainerAdminSession. </code> </li> 
 *      <li> federated foundry view: All job constrainer methods in this 
 *      session operate, retrieve and pertain to all job constrainer defined 
 *      in this foundry and any other job constrainer implicitly available in 
 *      this foundry through foundry inheritence. </li> 
 *      <li> active job constrainer view: All job constrainer lookup methods 
 *      return active job constrainers. </li> 
 *      <li> any status authorization enabler view: Jon constrainers of any 
 *      active or inactive status are returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedFoundryView() </code> and <code> 
 *  useIsolatedFoundryView() </code> behave as a radio group and one should be 
 *  selected before invoking the methods in this session. </p>
 */

public interface JobConstrainerLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Foundry </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Foundry Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFoundryId();


    /**
     *  Gets the <code> Foundry </code> associated with this session. 
     *
     *  @return the foundry 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.Foundry getFoundry()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> JobConstrainers </code> lookups. 
     *  A return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupJobConstrainers();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeJobConstrainerView();


    /**
     *  A complete view of the <code> JobConstrainer </code> returns is 
     *  desired. Methods will return what is requested or result in an error. 
     *  This view is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryJobConstrainerView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include job constrainer in foundries which are children of this 
     *  foundry in the foundry hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedFoundryView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this foundry only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedFoundryView();


    /**
     *  Only active job constrainers are returned by methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveJobConstrainerView();


    /**
     *  All active and inactive job constrainers are returned by methods in 
     *  this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusJobConstrainerView();


    /**
     *  Gets the <code> JobConstrainer </code> specified by its <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  JobConstrainer </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> JobConstrainer </code> and retained for 
     *  compatibility. 
     *  
     *  In active mode, job constrainers are returned that are currently 
     *  active. In any status mode, active and inactive job constrainers are 
     *  returned. 
     *
     *  @param  jobConstrainerId <code> Id </code> of the <code> 
     *          JobConstrainer </code> 
     *  @return the job constrainer 
     *  @throws org.osid.NotFoundException <code> jobConstrainerId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> jobConstrainerId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.resourcing.rules.JobConstrainer getJobConstrainer(org.osid.id.Id jobConstrainerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> JobConstrainerList </code> corresponding to the given 
     *  <code> IdList. </code> In plenary mode, the returned list contains all 
     *  of the job constrainer specified in the <code> Id </code> list, 
     *  
     *  in the order of the list, including duplicates, or an error results if 
     *  an <code> Id </code> in the supplied list is not found or 
     *  inaccessible. Otherwise, inaccessible <code> JobConstrainers </code> 
     *  may be omitted from the list and may present the elements in any order 
     *  including returning a unique set. 
     *  
     *  In active mode, job constrainers are returned that are currently 
     *  active. In any status mode, active and inactive job constrainers are 
     *  returned. 
     *
     *  @param  jobConstrainerIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> JobConstrainer </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> jobConstrainerIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.JobConstrainerList getJobConstrainersByIds(org.osid.id.IdList jobConstrainerIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> JobConstrainerList </code> corresponding to the given 
     *  job constrainer genus <code> Type </code> which does not include job 
     *  constrainer of genus types derived from the specified <code> Type. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  job constrainer or an error results. Otherwise, the returned list may 
     *  contain only those job constrainer that are accessible through this 
     *  session. 
     *  
     *  In active mode, job constrainers are returned that are currently 
     *  active. In any status mode, active and inactive job constrainers are 
     *  returned. 
     *
     *  @param  jobConstrainerGenusType a job constrainer genus type 
     *  @return the returned <code> JobConstrainer </code> list 
     *  @throws org.osid.NullArgumentException <code> jobConstrainerGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.JobConstrainerList getJobConstrainersByGenusType(org.osid.type.Type jobConstrainerGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> JobConstrainerList </code> corresponding to the given 
     *  job constrainer genus <code> Type </code> and include any additional 
     *  job constrainer with genus types derived from the specified <code> 
     *  Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  job constrainer or an error results. Otherwise, the returned list may 
     *  contain only those job constrainer that are accessible through this 
     *  session. 
     *  
     *  In active mode, job constrainers are returned that are currently 
     *  active. In any status mode, active and inactive job constrainers are 
     *  returned. 
     *
     *  @param  jobConstrainerGenusType a job constrainer genus type 
     *  @return the returned <code> JobConstrainer </code> list 
     *  @throws org.osid.NullArgumentException <code> jobConstrainerGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.JobConstrainerList getJobConstrainersByParentGenusType(org.osid.type.Type jobConstrainerGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> JobConstrainerList </code> containing the given job 
     *  constrainer record <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  job constrainer or an error results. Otherwise, the returned list may 
     *  contain only those job constrainer that are accessible through this 
     *  session. 
     *  
     *  In active mode, job constrainers are returned that are currently 
     *  active. In any status mode, active and inactive job constrainers are 
     *  returned. 
     *
     *  @param  jobConstrainerRecordType a job constrainer record type 
     *  @return the returned <code> JobConstrainer </code> list 
     *  @throws org.osid.NullArgumentException <code> jobConstrainerRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.JobConstrainerList getJobConstrainersByRecordType(org.osid.type.Type jobConstrainerRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> JobConstrainers. </code> 
     *  
     *  In plenary mode, the returned list contains all known job constrainer 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those job constrainer that are accessible through this session. 
     *  
     *  In active mode, job constrainers are returned that are currently 
     *  active. In any status mode, active and inactive job constrainers are 
     *  returned. 
     *
     *  @return the returned <code> JobConstrainer </code> list 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.JobConstrainerList getJobConstrainers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
