//
// org.osid.resourcing.rules.JobProcessorEnablerSearchSession
//
//     The OSID Java specification for org.osid.resourcing.rules.JobProcessorEnablerSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing.rules;


/**
 *  <p>This session provides methods for searching among <code> 
 *  JobProcessorEnabler </code> objects. The search query is constructed using 
 *  the <code> JobProcessorEnableryQuery. </code> </p> 
 *  
 *  <p> <code> getJobProcessorEnablersByQuery() </code> is the basic search 
 *  method and returns a list of <code> JobProcessorEnablers. </code> A more 
 *  advanced search may be performed with <code> 
 *  getJobProcessorEnablersBySearch(). </code> It accepts a <code> 
 *  JobProcessorEnablerSearch </code> in addition to the query for the purpose 
 *  of specifying additional options affecting the entire search, such as 
 *  resourcing. <code> getJobProcessorEnablersBySearch() </code> returns a 
 *  <code> JobProcessorEnablerSearchResults </code> that can be used to access 
 *  the resulting <code> JobProcessorEnablerList </code> or be used to perform 
 *  a search within the result set through <code> JobProcessorEnablerSearch. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated foundry view: searches include job processor enablers 
 *      in foundries of which this foundry is an ancestor in the foundry 
 *      hierarchy </li> 
 *      <li> isolated foundry view: searches are restricted to job processor 
 *      enablers in this foundry </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> JobProcessorEnablers </code> may have a query record indicated 
 *  by their respective record types. The query record is accessed via the 
 *  <code> JobProcessorEnablerQuery. </code> </p>
 */

public interface JobProcessorEnablerSearchSession
    extends org.osid.resourcing.rules.JobProcessorEnablerQuerySession {


    /**
     *  Gets a job processor enabler search. 
     *
     *  @return the job processor enabler search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.JobProcessorEnablerSearch getJobProcessorEnablerSearch();


    /**
     *  Gets a job processor enabler search order. The <code> 
     *  JobProcessorEnablerSearchOrder </code> is supplied to a <code> 
     *  JobProcessorEnablerSearch </code> to specify the ordering of results. 
     *
     *  @return the job processor enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.JobProcessorEnablerSearchOrder getJobProcessorEnablerSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  jobProcessorEnablerQuery the job processor enabler query 
     *  @param  jobProcessorEnablerSearch the job processor enabler search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> jobProcessorEnablerQuery 
     *          </code> or <code> jobProcessorEnablerSearch </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> jobProcessorEnablerQuery 
     *          </code> or <code> jobProcessorEnablerSearch </code> is not of 
     *          this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.JobProcessorEnablerSearchResults getJobProcessorEnablersBySearch(org.osid.resourcing.rules.JobProcessorEnablerQuery jobProcessorEnablerQuery, 
                                                                                                      org.osid.resourcing.rules.JobProcessorEnablerSearch jobProcessorEnablerSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a job processor enabler query from an inspector. The inspector is 
     *  available from a <code> JobProcessorEnablerSearchResults. </code> 
     *
     *  @param  jobProcessorEnablerQueryInspector a job processor enabler 
     *          query inspector 
     *  @return the job processor enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          jobProcessorEnablerQueryInspector </code> is <code> null 
     *          </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          jobProcessorEnablerQueryInspector </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.JobProcessorEnablerQuery getJobProcessorEnablerQueryFromInspector(org.osid.resourcing.rules.JobProcessorEnablerQueryInspector jobProcessorEnablerQueryInspector);
}
