//
// org.osid.resourcing.rules.ResourcingRulesProfile
//
//     The OSID Java specification for org.osid.resourcing.rules.ResourcingRulesProfile.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing.rules;


/**
 *  <p>The resourcing rules profile describes the interoperability among 
 *  resourcing rules services. </p>
 */

public interface ResourcingRulesProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any job federation is exposed. Federation is exposed when a 
     *  specific job may be identified, selected and used to create a lookup 
     *  or admin session. Federation is not exposed when a set of jobs appears 
     *  as a single job. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if looking up availability enabler is supported. 
     *
     *  @return <code> true </code> if availability enabler lookup is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAvailabilityEnablerLookup();


    /**
     *  Tests if querying availability enabler is supported. 
     *
     *  @return <code> true </code> if availability enabler query is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAvailabilityEnablerQuery();


    /**
     *  Tests if searching availability enabler is supported. 
     *
     *  @return <code> true </code> if availability enabler search is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAvailabilityEnablerSearch();


    /**
     *  Tests if an availability enabler administrative service is supported. 
     *
     *  @return <code> true </code> if availability enabler administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAvailabilityEnablerAdmin();


    /**
     *  Tests if an availability enabler notification service is supported. 
     *
     *  @return <code> true </code> if availability enabler notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAvailabilityEnablerNotification();


    /**
     *  Tests if an availability enabler foundry lookup service is supported. 
     *
     *  @return <code> true </code> if an availability enabler foundry lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAvailabilityEnablerFoundry();


    /**
     *  Tests if an availability enabler foundry service is supported. 
     *
     *  @return <code> true </code> if availability enabler foundry assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAvailabilityEnablerFoundryAssignment();


    /**
     *  Tests if an availability enabler foundry lookup service is supported. 
     *
     *  @return <code> true </code> if an availability enabler foundry service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAvailabilityEnablerSmartFoundry();


    /**
     *  Tests if an availability enabler rule lookup service is supported. 
     *
     *  @return <code> true </code> if an availability enabler rule lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAvailabilityEnablerRuleLookup();


    /**
     *  Tests if an availability enabler rule application service is 
     *  supported. 
     *
     *  @return <code> true </code> if an availability enabler rule 
     *          application service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAvailabilityEnablerRuleApplication();


    /**
     *  Tests if looking up commission enabler is supported. 
     *
     *  @return <code> true </code> if commission enabler lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommissionEnablerLookup();


    /**
     *  Tests if querying commission enabler is supported. 
     *
     *  @return <code> true </code> if commission enabler query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommissionEnablerQuery();


    /**
     *  Tests if searching commission enabler is supported. 
     *
     *  @return <code> true </code> if commission enabler search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommissionEnablerSearch();


    /**
     *  Tests if a commission enabler administrative service is supported. 
     *
     *  @return <code> true </code> if commission enabler administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommissionEnablerAdmin();


    /**
     *  Tests if a commission enabler notification service is supported. 
     *
     *  @return <code> true </code> if commission enabler notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommissionEnablerNotification();


    /**
     *  Tests if a commission enabler foundry lookup service is supported. 
     *
     *  @return <code> true </code> if a commission enabler foundry lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommissionEnablerFoundry();


    /**
     *  Tests if a commission enabler foundry service is supported. 
     *
     *  @return <code> true </code> if commission enabler foundry assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommissionEnablerFoundryAssignment();


    /**
     *  Tests if a commission enabler foundry lookup service is supported. 
     *
     *  @return <code> true </code> if a commission enabler foundry service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommissionEnablerSmartFoundry();


    /**
     *  Tests if a commission enabler rule lookup service is supported. 
     *
     *  @return <code> true </code> if a commission enabler rule lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommissionEnablerRuleLookup();


    /**
     *  Tests if a commission enabler rule application service is supported. 
     *
     *  @return <code> true </code> if a commission enabler rule application 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommissionEnablerRuleApplication();


    /**
     *  Tests if looking up job constrainer is supported. 
     *
     *  @return <code> true </code> if job constrainer lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobConstrainerLookup();


    /**
     *  Tests if querying job constrainer is supported. 
     *
     *  @return <code> true </code> if job constrainer query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobConstrainerQuery();


    /**
     *  Tests if searching job constrainer is supported. 
     *
     *  @return <code> true </code> if job constrainer search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobConstrainerSearch();


    /**
     *  Tests if a job constrainer administrative service is supported. 
     *
     *  @return <code> true </code> if job constrainer administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobConstrainerAdmin();


    /**
     *  Tests if a job constrainer notification service is supported. 
     *
     *  @return <code> true </code> if job constrainer notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobConstrainerNotification();


    /**
     *  Tests if a job constrainer foundry lookup service is supported. 
     *
     *  @return <code> true </code> if a job constrainer foundry lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobConstrainerFoundry();


    /**
     *  Tests if a job constrainer foundry service is supported. 
     *
     *  @return <code> true </code> if job constrainer foundry assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobConstrainerFoundryAssignment();


    /**
     *  Tests if a job constrainer foundry lookup service is supported. 
     *
     *  @return <code> true </code> if a job constrainer foundry service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobConstrainerSmartFoundry();


    /**
     *  Tests if a job constrainer rule lookup service is supported. 
     *
     *  @return <code> true </code> if a job constrainer rule lookup service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobConstrainerRuleLookup();


    /**
     *  Tests if a job constrainer rule application service is supported. 
     *
     *  @return <code> true </code> if a job constrainer rule application 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobConstrainerRuleApplication();


    /**
     *  Tests if looking up job constrainer enablers is supported. 
     *
     *  @return <code> true </code> if job constrainer enabler lookup is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobConstrainerEnablerLookup();


    /**
     *  Tests if querying job constrainer enablers is supported. 
     *
     *  @return <code> true </code> if job constrainer enabler query is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobConstrainerEnablerQuery();


    /**
     *  Tests if searching job constrainer enablers is supported. 
     *
     *  @return <code> true </code> if job constrainer enabler search is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobConstrainerEnablerSearch();


    /**
     *  Tests if a job constrainer enabler administrative service is 
     *  supported. 
     *
     *  @return <code> true </code> if job constrainer enabler administration 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobConstrainerEnablerAdmin();


    /**
     *  Tests if a job constrainer enabler notification service is supported. 
     *
     *  @return <code> true </code> if job constrainer enabler notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobConstrainerEnablerNotification();


    /**
     *  Tests if a job constrainer enabler foundry lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if a job constrainer enabler foundry 
     *          lookup service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobConstrainerEnablerFoundry();


    /**
     *  Tests if a job constrainer enabler foundry service is supported. 
     *
     *  @return <code> true </code> if job constrainer enabler foundry 
     *          assignment service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobConstrainerEnablerFoundryAssignment();


    /**
     *  Tests if a job constrainer enabler foundry lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if a job constrainer enabler foundry 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobConstrainerEnablerSmartFoundry();


    /**
     *  Tests if a job constrainer enabler rule lookup service is supported. 
     *
     *  @return <code> true </code> if a job constrainer enabler rule lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobConstrainerEnablerRuleLookup();


    /**
     *  Tests if a job constrainer enabler rule application service is 
     *  supported. 
     *
     *  @return <code> true </code> if job constrainer enabler rule 
     *          application service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobConstrainerEnablerRuleApplication();


    /**
     *  Tests if looking up job processor is supported. 
     *
     *  @return <code> true </code> if job processor lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobProcessorLookup();


    /**
     *  Tests if querying job processor is supported. 
     *
     *  @return <code> true </code> if job processor query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobProcessorQuery();


    /**
     *  Tests if searching job processor is supported. 
     *
     *  @return <code> true </code> if job processor search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobProcessorSearch();


    /**
     *  Tests if a job processor administrative service is supported. 
     *
     *  @return <code> true </code> if job processor administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobProcessorAdmin();


    /**
     *  Tests if a job processor notification service is supported. 
     *
     *  @return <code> true </code> if job processor notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobProcessorNotification();


    /**
     *  Tests if a job processor foundry lookup service is supported. 
     *
     *  @return <code> true </code> if a job processor foundry lookup service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobProcessorFoundry();


    /**
     *  Tests if a job processor foundry service is supported. 
     *
     *  @return <code> true </code> if job processor foundry assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobProcessorFoundryAssignment();


    /**
     *  Tests if a job processor foundry lookup service is supported. 
     *
     *  @return <code> true </code> if a job processor foundry service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobProcessorSmartFoundry();


    /**
     *  Tests if a job processor rule lookup service is supported. 
     *
     *  @return <code> true </code> if a job processor rule lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobProcessorRuleLookup();


    /**
     *  Tests if a job processor rule application service is supported. 
     *
     *  @return <code> true </code> if job processor rule application service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobProcessorRuleApplication();


    /**
     *  Tests if looking up job processor enablers is supported. 
     *
     *  @return <code> true </code> if job processor enabler lookup is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobProcessorEnablerLookup();


    /**
     *  Tests if querying job processor enablers is supported. 
     *
     *  @return <code> true </code> if job processor enabler query is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobProcessorEnablerQuery();


    /**
     *  Tests if searching job processor enablers is supported. 
     *
     *  @return <code> true </code> if job processor enabler search is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobProcessorEnablerSearch();


    /**
     *  Tests if a job processor enabler administrative service is supported. 
     *
     *  @return <code> true </code> if job processor enabler administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobProcessorEnablerAdmin();


    /**
     *  Tests if a job processor enabler notification service is supported. 
     *
     *  @return <code> true </code> if job processor enabler notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobProcessorEnablerNotification();


    /**
     *  Tests if a job processor enabler foundry lookup service is supported. 
     *
     *  @return <code> true </code> if a job processor enabler foundry lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobProcessorEnablerFoundry();


    /**
     *  Tests if a job processor enabler foundry service is supported. 
     *
     *  @return <code> true </code> if job processor enabler foundry 
     *          assignment service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobProcessorEnablerFoundryAssignment();


    /**
     *  Tests if a job processor enabler foundry lookup service is supported. 
     *
     *  @return <code> true </code> if a job processor enabler foundry service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobProcessorEnablerSmartFoundry();


    /**
     *  Tests if a job processor enabler rule lookup service is supported. 
     *
     *  @return <code> true </code> if an processor enabler rule lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobProcessorEnablerRuleLookup();


    /**
     *  Tests if a job processor enabler rule application service is 
     *  supported. 
     *
     *  @return <code> true </code> if job processor enabler rule application 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobProcessorEnablerRuleApplication();


    /**
     *  Gets the supported <code> AvailabilityEnabler </code> record types. 
     *
     *  @return a list containing the supported <code> AvailabilityEnabler 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAvailabilityEnablerRecordTypes();


    /**
     *  Tests if the given <code> AvailabilityEnabler </code> record type is 
     *  supported. 
     *
     *  @param  availabilityEnablerRecordType a <code> Type </code> indicating 
     *          an <code> AvailabilityEnabler </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          availabilityEnablerRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAvailabilityEnablerRecordType(org.osid.type.Type availabilityEnablerRecordType);


    /**
     *  Gets the supported <code> AvailabilityEnabler </code> search record 
     *  types. 
     *
     *  @return a list containing the supported <code> AvailabilityEnabler 
     *          </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAvailabilityEnablerSearchRecordTypes();


    /**
     *  Gets the supported <code> CommissionEnabler </code> record types. 
     *
     *  @return a list containing the supported <code> CommissionEnabler 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCommissionEnablerRecordTypes();


    /**
     *  Tests if the given <code> CommissionEnabler </code> record type is 
     *  supported. 
     *
     *  @param  commissionEnablerRecordType a <code> Type </code> indicating a 
     *          <code> CommissionEnabler </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          commissionEnablerRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommissionEnablerRecordType(org.osid.type.Type commissionEnablerRecordType);


    /**
     *  Gets the supported <code> CommissionEnabler </code> search record 
     *  types. 
     *
     *  @return a list containing the supported <code> CommissionEnabler 
     *          </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCommissionEnablerSearchRecordTypes();


    /**
     *  Tests if the given <code> CommissionEnabler </code> search record type 
     *  is supported. 
     *
     *  @param  commissionEnablerSearchRecordType a <code> Type </code> 
     *          indicating a <code> CommissionEnabler </code> search record 
     *          type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          commissionEnablerSearchRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommissionEnablerSearchRecordType(org.osid.type.Type commissionEnablerSearchRecordType);


    /**
     *  Gets the supported <code> JobConstrainer </code> record types. 
     *
     *  @return a list containing the supported <code> JobConstrainer </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getJobConstrainerRecordTypes();


    /**
     *  Tests if the given <code> JobConstrainer </code> record type is 
     *  supported. 
     *
     *  @param  jobConstrainerRecordType a <code> Type </code> indicating a 
     *          <code> JobConstrainer </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> jobConstrainerRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobConstrainerRecordType(org.osid.type.Type jobConstrainerRecordType);


    /**
     *  Gets the supported <code> JobConstrainer </code> search record types. 
     *
     *  @return a list containing the supported <code> JobConstrainer </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getJobConstrainerSearchRecordTypes();


    /**
     *  Tests if the given <code> JobConstrainer </code> search record type is 
     *  supported. 
     *
     *  @param  jobConstrainerSearchRecordType a <code> Type </code> 
     *          indicating a <code> JobConstrainer </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          jobConstrainerSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobConstrainerSearchRecordType(org.osid.type.Type jobConstrainerSearchRecordType);


    /**
     *  Gets the supported <code> JobConstrainerEnabler </code> record types. 
     *
     *  @return a list containing the supported <code> JobConstrainerEnabler 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getJobConstrainerEnablerRecordTypes();


    /**
     *  Tests if the given <code> JobConstrainerEnabler </code> record type is 
     *  supported. 
     *
     *  @param  jobConstrainerEnablerRecordType a <code> Type </code> 
     *          indicating a <code> JobConstrainerEnabler </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          jobConstrainerEnablerRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobConstrainerEnablerRecordType(org.osid.type.Type jobConstrainerEnablerRecordType);


    /**
     *  Gets the supported <code> JobConstrainerEnabler </code> search record 
     *  types. 
     *
     *  @return a list containing the supported <code> JobConstrainerEnabler 
     *          </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getJobConstrainerEnablerSearchRecordTypes();


    /**
     *  Tests if the given <code> JobConstrainerEnabler </code> search record 
     *  type is supported. 
     *
     *  @param  jobConstrainerEnablerSearchRecordType a <code> Type </code> 
     *          indicating a <code> JobConstrainerEnabler </code> search 
     *          record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          jobConstrainerEnablerSearchRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobConstrainerEnablerSearchRecordType(org.osid.type.Type jobConstrainerEnablerSearchRecordType);


    /**
     *  Gets the supported <code> JobProcessor </code> record types. 
     *
     *  @return a list containing the supported <code> JobProcessor </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getJobProcessorRecordTypes();


    /**
     *  Tests if the given <code> JobProcessor </code> record type is 
     *  supported. 
     *
     *  @param  jobProcessorRecordType a <code> Type </code> indicating a 
     *          <code> JobProcessor </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> jobProcessorRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobProcessorRecordType(org.osid.type.Type jobProcessorRecordType);


    /**
     *  Gets the supported <code> JobProcessor </code> search record types. 
     *
     *  @return a list containing the supported <code> JobProcessor </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getJobProcessorSearchRecordTypes();


    /**
     *  Tests if the given <code> JobProcessor </code> search record type is 
     *  supported. 
     *
     *  @param  jobProcessorSearchRecordType a <code> Type </code> indicating 
     *          a <code> JobProcessor </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          jobProcessorSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobProcessorSearchRecordType(org.osid.type.Type jobProcessorSearchRecordType);


    /**
     *  Gets the supported <code> JobProcessorEnabler </code> record types. 
     *
     *  @return a list containing the supported <code> JobProcessorEnabler 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getJobProcessorEnablerRecordTypes();


    /**
     *  Tests if the given <code> JobProcessorEnabler </code> record type is 
     *  supported. 
     *
     *  @param  jobProcessorEnablerRecordType a <code> Type </code> indicating 
     *          a <code> JobProcessorEnabler </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          jobProcessorEnablerRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobProcessorEnablerRecordType(org.osid.type.Type jobProcessorEnablerRecordType);


    /**
     *  Gets the supported <code> JobProcessorEnabler </code> search record 
     *  types. 
     *
     *  @return a list containing the supported <code> JobProcessorEnabler 
     *          </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getJobProcessorEnablerSearchRecordTypes();


    /**
     *  Tests if the given <code> JobProcessorEnabler </code> search record 
     *  type is supported. 
     *
     *  @param  jobProcessorEnablerSearchRecordType a <code> Type </code> 
     *          indicating a <code> JobProcessorEnabler </code> search record 
     *          type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          jobProcessorEnablerSearchRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobProcessorEnablerSearchRecordType(org.osid.type.Type jobProcessorEnablerSearchRecordType);
}
