//
// org.osid.resourcing.rules.ResourcingRulesProxyManager
//
//     The OSID Java specification for org.osid.resourcing.rules.ResourcingRulesProxyManager.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing.rules;


/**
 *  <p>The resourcing rules proxy manager provides access to resourcing rules 
 *  sessions and provides interoperability tests for various aspects of this 
 *  service. Methods in this manager pass a <code> Proxy </code> for passing 
 *  information from server environments. The sessions included in this 
 *  manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> AvailabilityEnablerLookupSession: </code> a session to 
 *      retrieve availability enabler </li> 
 *      <li> <code> AvailabilityEnablerQuerySession: </code> a session to 
 *      query for availability enabler </li> 
 *      <li> <code> AvailabilityEnablerSearchSession: </code> a session to 
 *      search for availability enabler </li> 
 *      <li> <code> AvailabilityEnablerAdminSession: </code> a session to 
 *      create and delete availability enabler </li> 
 *      <li> <code> AvailabilityEnablerNotificationSession: </code> a session 
 *      to receive notifications pertaining to availability enabler changes 
 *      </li> 
 *      <li> <code> AvailabilityEnablerFoundrySession: </code> a session to 
 *      look up availability enabler foundry mappings </li> 
 *      <li> <code> AvailabilityEnablerFoundryAssignmentSession: </code> a 
 *      session to manage availability enabler to foundry mappings </li> 
 *      <li> <code> AvailabilityEnablerSmartFoundrySession: </code> a session 
 *      to manage dynamic foundries of availability enabler </li> 
 *      <li> <code> AvailabilityEnablerRuleLookupSession: </code> a session to 
 *      look up availability enabler to availability mappings </li> 
 *      <li> <code> AvailabilityEnablerRuleApplicationSession: </code> a 
 *      session to apply availability enabler to availabilities </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> CommissionEnablerLookupSession: </code> a session to 
 *      retrieve commission enabler </li> 
 *      <li> <code> CommissionEnablerQuerySession: </code> a session to query 
 *      for commission enabler </li> 
 *      <li> <code> CommissionEnablerSearchSession: </code> a session to 
 *      search for commission enabler </li> 
 *      <li> <code> CommissionEnablerAdminSession: </code> a session to create 
 *      and delete commission enabler </li> 
 *      <li> <code> CommissionEnablerNotificationSession: </code> a session to 
 *      receive notifications pertaining to commission enabler changes </li> 
 *      <li> <code> CommissionEnablerFoundrySession: </code> a session to look 
 *      up commission enabler foundry mappings </li> 
 *      <li> <code> CommissionEnablerFoundryAssignmentSession: </code> a 
 *      session to manage commission enabler to foundry mappings </li> 
 *      <li> <code> CommissionEnablerSmartFoundrySession: </code> a session to 
 *      manage dynamic foundries of commission enabler </li> 
 *      <li> <code> CommissionEnablerRuleLookupSession: </code> a session to 
 *      look up commission enabler to commission mappings </li> 
 *      <li> <code> CommissionEnablerRuleApplicationSession: </code> a session 
 *      to apply commission enabler to commissions </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> JobConstrainerLookupSession: </code> a session to retrieve 
 *      job constrainer </li> 
 *      <li> <code> JobConstrainerQuerySession: </code> a session to query for 
 *      job constrainer </li> 
 *      <li> <code> JobConstrainerSearchSession: </code> a session to search 
 *      for job constrainer </li> 
 *      <li> <code> JobConstrainerAdminSession: </code> a session to create 
 *      and delete job constrainer </li> 
 *      <li> <code> JobConstrainerNotificationSession: </code> a session to 
 *      receive notifications pertaining to job constrainer changes </li> 
 *      <li> <code> JobConstrainerFoundrySession: </code> a session to look up 
 *      job constrainer foundry mappings </li> 
 *      <li> <code> JobConstrainerFoundryAssignmentSession: </code> a session 
 *      to manage job constrainer to foundry mappings </li> 
 *      <li> <code> JobConstrainerSmartFoundrySession: </code> a session to 
 *      manage dynamic foundries of job constrainer </li> 
 *      <li> <code> JobConstrainerRuleLookupSession: </code> a session to look 
 *      up job constrainer to job mappings </li> 
 *      <li> <code> JobConstrainerRuleApplicationSession: </code> a session to 
 *      apply job constrainer to jobss </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> JobConstrainerEnablerLookupSession: </code> a session to 
 *      retrieve job constrainer enablers </li> 
 *      <li> <code> JobConstrainerEnablerQuerySession: </code> a session to 
 *      query for job constrainer enablers </li> 
 *      <li> <code> JobConstrainerEnablerSearchSession: </code> a session to 
 *      search for job constrainer enablers </li> 
 *      <li> <code> JobConstrainerEnablerAdminSession: </code> a session to 
 *      create and delete job constrainer enablers </li> 
 *      <li> <code> JobConstrainerEnablerNotificationSession: </code> a 
 *      session to receive notifications pertaining to job constrainer enabler 
 *      changes </li> 
 *      <li> <code> JobConstrainerEnablerFoundrySession: </code> a session to 
 *      look up job constrainer enabler foundry mappings </li> 
 *      <li> <code> JobConstrainerEnablerFoundryAssignmentSession: </code> a 
 *      session to manage job constrainer enabler to foundry mappings </li> 
 *      <li> <code> JobConstrainerEnablerSmartFoundrySession: </code> a 
 *      session to manage dynamic foundries of job constrainer enablers </li> 
 *      <li> <code> JobConstrainerEnableRuleLookupSession: </code> a session 
 *      to look up job constrainer enabler mappings </li> 
 *      <li> <code> JobConstrainerEnablerRuleApplicationSession: </code> a 
 *      session to apply job constrainer enablers </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> JobProcessorLookupSession: </code> a session to retrieve 
 *      job processor </li> 
 *      <li> <code> JobProcessorQuerySession: </code> a session to query for 
 *      job processor </li> 
 *      <li> <code> JobProcessorSearchSession: </code> a session to search for 
 *      job processor </li> 
 *      <li> <code> JobProcessorAdminSession: </code> a session to create and 
 *      delete job processor </li> 
 *      <li> <code> JobProcessorNotificationSession: </code> a session to 
 *      receive notifications pertaining to job processor changes </li> 
 *      <li> <code> JobProcessorFoundrySession: </code> a session to look up 
 *      job processor foundry mappings </li> 
 *      <li> <code> JobProcessorFoundryAssignmentSession: </code> a session to 
 *      manage job processor to foundry mappings </li> 
 *      <li> <code> JobProcessorSmartFoundrySession: </code> a session to 
 *      manage dynamic foundries of job processor </li> 
 *      <li> <code> JobProcessorRuleLookupSession: </code> a session to look 
 *      up job processor to job mappings </li> 
 *      <li> <code> JobProcessorRuleApplicationSession: </code> a session to 
 *      apply job processor to jobss </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> JobProcessorEnablerLookupSession: </code> a session to 
 *      retrieve job processor enablers </li> 
 *      <li> <code> JobProcessorEnablerQuerySession: </code> a session to 
 *      query for job processor enablers </li> 
 *      <li> <code> JobProcessorEnablerSearchSession: </code> a session to 
 *      search for job processor enablers </li> 
 *      <li> <code> JobProcessorEnablerAdminSession: </code> a session to 
 *      create and delete job processor enablers </li> 
 *      <li> <code> JobProcessorEnablerNotificationSession: </code> a session 
 *      to receive notifications pertaining to job processor enabler changes 
 *      </li> 
 *      <li> <code> JobProcessorEnablerFoundrySession: </code> a session to 
 *      look up job processor enabler foundry mappings </li> 
 *      <li> <code> JobProcessorEnablerFoundryAssignmentSession: </code> a 
 *      session to manage job processor enabler to foundry mappings </li> 
 *      <li> <code> JobProcessorEnablerSmartFoundrySession: </code> a session 
 *      to manage dynamic foundries of job processor enablers </li> 
 *      <li> <code> JobProcessorEnablerRuleLookupSession: </code> a session to 
 *      look up job processor enabler mappings </li> 
 *      <li> <code> JobProcessorEnablerRuleApplicationSession: </code> a 
 *      session to apply job processor enablers </li> 
 *  </ul>
 *  
 */

public interface ResourcingRulesProxyManager
    extends org.osid.OsidProxyManager,
            org.osid.resourcing.rules.ResourcingRulesProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the availability 
     *  enabler lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AvailabilityEnablerLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAvailabilityEnablerLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAvailabilityEnablerLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.resourcing.rules.AvailabilityEnablerLookupSession getAvailabilityEnablerLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the availability 
     *  enabler lookup service for the given foundry. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AvailabilityEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Foundry </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAvailabilityEnablerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAvailabilityEnablerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.AvailabilityEnablerLookupSession getAvailabilityEnablerLookupSessionForFoundry(org.osid.id.Id foundryId, 
                                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the availability 
     *  enabler query service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AvailabilityEnablerQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAvailabilityEnablerQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAvailabilityEnablerQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.AvailabilityEnablerQuerySession getAvailabilityEnablerQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the availability 
     *  enabler query service for the given foundry. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AvailabilityEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Foundry </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAvailabilityEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAvailabilityEnablerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.AvailabilityEnablerQuerySession getAvailabilityEnablerQuerySessionForFoundry(org.osid.id.Id foundryId, 
                                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the availability 
     *  enabler search service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AvailabilityEnablerSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAvailabilityEnablerSearch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAvailabilityEnablerSearch() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.resourcing.rules.AvailabilityEnablerSearchSession getAvailabilityEnablerSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the availability 
     *  enabler earch service for the given foundry. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AvailabilityEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Foundry </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAvailabilityEnablerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAvailabilityEnablerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.AvailabilityEnablerSearchSession getAvailabilityEnablerSearchSessionForFoundry(org.osid.id.Id foundryId, 
                                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the availability 
     *  enabler administration service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AvailabilityEnablerAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAvailabilityEnablerAdmin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAvailabilityEnablerAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.AvailabilityEnablerAdminSession getAvailabilityEnablerAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the availability 
     *  enabler administration service for the given foundry. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AvailabilityEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Foundry </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAvailabilityEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAvailabilityEnablerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.AvailabilityEnablerAdminSession getAvailabilityEnablerAdminSessionForFoundry(org.osid.id.Id foundryId, 
                                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the availability 
     *  enabler notification service. 
     *
     *  @param  availabilityConstrainerReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return an <code> AvailabilityEnablerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          availabilityConstrainerReceiver </code> or <code> proxy 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAvailabilityEnablerNotification() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAvailabilityEnablerNotification() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.resourcing.rules.AvailabilityEnablerNotificationSession getAvailabilityEnablerNotificationSession(org.osid.resourcing.rules.AvailabilityEnablerReceiver availabilityConstrainerReceiver, 
                                                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the availability 
     *  enabler notification service for the given foundry. 
     *
     *  @param  availabilityConstrainerReceiver the notification callback 
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AvailabilityEnablerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no foundry found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          availabilityConstrainerReceiver, foundryId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAvailabilityEnablerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAvailabilityEnablerNotification() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.resourcing.rules.AvailabilityEnablerNotificationSession getAvailabilityEnablerNotificationSessionForFoundry(org.osid.resourcing.rules.AvailabilityEnablerReceiver availabilityConstrainerReceiver, 
                                                                                                                                org.osid.id.Id foundryId, 
                                                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup availability 
     *  enabler/foundry mappings for availability enablers. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AvailabilityEnablerFoundrySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAvailabilityEnablerFoundry() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAvailabilityEnablerFoundry() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.resourcing.rules.AvailabilityEnablerFoundrySession getAvailabilityEnablerFoundrySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning 
     *  availability enabler to foundries. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AvailabilityEnablerFoundryAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAvailabilityEnablerFoundryAssignment() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAvailabilityEnablerFoundryAssignment() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.resourcing.rules.AvailabilityEnablerFoundryAssignmentSession getAvailabilityEnablerFoundryAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage availability enabler 
     *  smart foundries. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AvailabilityEnablerSmartFoundrySession </code> 
     *  @throws org.osid.NotFoundException no <code> Foundry </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAvailabilityEnablerSmartFoundry() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAvailabilityEnablerSmartFoundry() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.resourcing.rules.AvailabilityEnablerSmartFoundrySession getAvailabilityEnablerSmartFoundrySession(org.osid.id.Id foundryId, 
                                                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the availability 
     *  enabler mapping lookup service for looking up the rules applied to tan 
     *  availability. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AvailabilityEnablerRuleLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAvailabilityEnablerRuleLookup() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAvailabilityEnablerRuleLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.resourcing.rules.AvailabilityEnablerRuleLookupSession getAvailabilityEnablerRuleLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the availability 
     *  enabler mapping lookup service for the given foundry for looking up 
     *  rules applied to an availability. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AvailabilityEnablerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Foundry </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAvailabilityEnablerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAvailabilityEnablerRuleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.AvailabilityEnablerRuleLookupSession getAvailabilityEnablerRuleLookupSessionForFoundry(org.osid.id.Id foundryId, 
                                                                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the availability 
     *  enabler assignment service to apply to availabilities. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AvailabilityEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAvailabilityEnablerRuleApplication() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAvailabilityEnablerRuleApplication() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.resourcing.rules.AvailabilityEnablerRuleApplicationSession getAvailabilityEnablerRuleApplicationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the availability 
     *  enabler assignment service for the given foundry to apply to 
     *  availabilities. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AvailabilityEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Foundry </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAvailabilityEnablerRuleApplication() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAvailabilityEnablerRuleApplication() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.resourcing.rules.AvailabilityEnablerRuleApplicationSession getAvailabilityEnablerRuleApplicationSessionForFoundry(org.osid.id.Id foundryId, 
                                                                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the commission 
     *  enabler lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> CommissionEnablerLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommissionEnablerLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommissionEnablerLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.CommissionEnablerLookupSession getCommissionEnablerLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the commission 
     *  enabler lookup service for the given foundry. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return a <code> CommissionEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Foundry </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommissionEnablerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommissionEnablerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.CommissionEnablerLookupSession getCommissionEnablerLookupSessionForFoundry(org.osid.id.Id foundryId, 
                                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the commission 
     *  enabler query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> CommissionEnablerQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommissionEnablerQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommissionEnablerQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.CommissionEnablerQuerySession getCommissionEnablerQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the commission 
     *  enabler query service for the given foundry. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return a <code> CommissionEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Foundry </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommissionEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommissionEnablerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.CommissionEnablerQuerySession getCommissionEnablerQuerySessionForFoundry(org.osid.id.Id foundryId, 
                                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the commission 
     *  enabler search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> CommissionEnablerSearchSession </code> 
     *  @throws org.osid.NullArgumentException a <code> 
     *          CommissionEnablerSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommissionEnablerSearch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommissionEnablerSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.CommissionEnablerSearchSession getCommissionEnablerSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the commission 
     *  enabler earch service for the given foundry. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return a <code> CommissionEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Foundry </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommissionEnablerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommissionEnablerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.CommissionEnablerSearchSession getCommissionEnablerSearchSessionForFoundry(org.osid.id.Id foundryId, 
                                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the commission 
     *  enabler administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> CommissionEnablerAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommissionEnablerAdmin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommissionEnablerAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.CommissionEnablerAdminSession getCommissionEnablerAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the commission 
     *  enabler administration service for the given foundry. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return a <code> CommissionEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Foundry </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommissionEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommissionEnablerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.CommissionEnablerAdminSession getCommissionEnablerAdminSessionForFoundry(org.osid.id.Id foundryId, 
                                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the commission 
     *  enabler notification service. 
     *
     *  @param  commissionConstrainerReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> CommissionEnablerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          commissionConstrainerReceiver </code> or <code> proxy </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommissionEnablerNotification() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommissionEnablerNotification() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.resourcing.rules.CommissionEnablerNotificationSession getCommissionEnablerNotificationSession(org.osid.resourcing.rules.CommissionEnablerReceiver commissionConstrainerReceiver, 
                                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the commission 
     *  enabler notification service for the given foundry. 
     *
     *  @param  commissionConstrainerReceiver the notification callback 
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return a <code> CommissionEnablerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no foundry found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          commissionConstrainerReceiver, foundryId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommissionEnablerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommissionEnablerNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.CommissionEnablerNotificationSession getCommissionEnablerNotificationSessionForFoundry(org.osid.resourcing.rules.CommissionEnablerReceiver commissionConstrainerReceiver, 
                                                                                                                            org.osid.id.Id foundryId, 
                                                                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup commission 
     *  enabler/foundry mappings for commission enablers. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> CommissionEnablerFoundrySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommissionEnablerFoundry() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommissionEnablerFoundry() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.CommissionEnablerFoundrySession getCommissionEnablerFoundrySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning 
     *  commission enabler to foundries. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> CommissionEnablerFoundryAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommissionEnablerFoundryAssignment() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommissionEnablerFoundryAssignment() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.resourcing.rules.CommissionEnablerFoundryAssignmentSession getCommissionEnablerFoundryAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage commission enabler smart 
     *  foundries. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return a <code> CommissionEnablerSmartFoundrySession </code> 
     *  @throws org.osid.NotFoundException no <code> Foundry </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommissionEnablerSmartFoundry() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommissionEnablerSmartFoundry() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.resourcing.rules.CommissionEnablerSmartFoundrySession getCommissionEnablerSmartFoundrySession(org.osid.id.Id foundryId, 
                                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the commission 
     *  enabler mapping lookup service for looking up the rules applied to a 
     *  commission. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> CommissionEnablerRuleLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommissionEnablerRuleLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommissionEnablerRuleLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.resourcing.rules.CommissionEnablerRuleLookupSession getCommissionEnablerRuleLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the commission 
     *  enabler mapping lookup service for the given foundry for looking up 
     *  rules applied to a commission. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return a <code> CommissionEnablerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Foundry </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommissionEnablerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommissionEnablerRuleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.CommissionEnablerRuleLookupSession getCommissionEnablerRuleLookupSessionForFoundry(org.osid.id.Id foundryId, 
                                                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the commission 
     *  enabler assignment service to apply to commissions. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> CommissionEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommissionEnablerRuleApplication() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommissionEnablerRuleApplication() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.resourcing.rules.CommissionEnablerRuleApplicationSession getCommissionEnablerRuleApplicationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the commission 
     *  enabler assignment service for the given foundry to apply to 
     *  commissions. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return a <code> CommissionEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Foundry </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommissionEnablerRuleApplication() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommissionEnablerRuleApplication() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.resourcing.rules.CommissionEnablerRuleApplicationSession getCommissionEnablerRuleApplicationSessionForFoundry(org.osid.id.Id foundryId, 
                                                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job 
     *  constrainer lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> JobConstrainerLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobConstrainerLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobConstrainerLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.JobConstrainerLookupSession getJobConstrainerLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job 
     *  constrainer lookup service for the given foundry. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return a <code> JobConstrainerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Foundry </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobConstrainerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobConstrainerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.JobConstrainerLookupSession getJobConstrainerLookupSessionForFoundry(org.osid.id.Id foundryId, 
                                                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job 
     *  constrainer query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> JobConstrainerQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobConstrainerQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobConstrainerQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.JobConstrainerQuerySession getJobConstrainerQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job 
     *  constrainer query service for the given foundry. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return a <code> JobConstrainerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Foundry </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobConstrainerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobConstrainerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.JobConstrainerQuerySession getJobConstrainerQuerySessionForFoundry(org.osid.id.Id foundryId, 
                                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job 
     *  constrainer search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> JobConstrainerSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobConstrainerSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobConstrainerSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.JobConstrainerSearchSession getJobConstrainerSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job 
     *  constrainer earch service for the given foundry. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return a <code> JobConstrainerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Foundry </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobConstrainerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobConstrainerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.JobConstrainerSearchSession getJobConstrainerSearchSessionForFoundry(org.osid.id.Id foundryId, 
                                                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job 
     *  constrainer administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> JobConstrainerAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobConstrainerAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobConstrainerAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.JobConstrainerAdminSession getJobConstrainerAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job 
     *  constrainer administration service for the given foundry. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return a <code> JobConstrainerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Foundry </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobConstrainerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobConstrainerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.JobConstrainerAdminSession getJobConstrainerAdminSessionForFoundry(org.osid.id.Id foundryId, 
                                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job 
     *  constrainer notification service. 
     *
     *  @param  jobConstrainerReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> JobConstrainerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> jobConstrainerReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobConstrainerNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobConstrainerNotification() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.resourcing.rules.JobConstrainerNotificationSession getJobConstrainerNotificationSession(org.osid.resourcing.rules.JobConstrainerReceiver jobConstrainerReceiver, 
                                                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job 
     *  constrainer notification service for the given foundry. 
     *
     *  @param  jobConstrainerReceiver the notification callback 
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return a <code> JobConstrainerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no foundry found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> jobConstrainerReceiver, 
     *          foundryId </code> or <code> proxy </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobConstrainerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobConstrainerNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.JobConstrainerNotificationSession getJobConstrainerNotificationSessionForFoundry(org.osid.resourcing.rules.JobConstrainerReceiver jobConstrainerReceiver, 
                                                                                                                      org.osid.id.Id foundryId, 
                                                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup job constrainer/foundry 
     *  mappings for job constrainers. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> JobConstrainerFoundrySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobConstrainerFoundry() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobConstrainerFoundry() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.JobConstrainerFoundrySession getJobConstrainerFoundrySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning job 
     *  constrainer to foundries. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> JobConstrainerFoundryAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobConstrainerFoundryAssignment() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobConstrainerFoundryAssignment() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.resourcing.rules.JobConstrainerFoundryAssignmentSession getJobConstrainerFoundryAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage job constrainer smart 
     *  foundries. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return a <code> JobConstrainerSmartFoundrySession </code> 
     *  @throws org.osid.NotFoundException no <code> Foundry </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobConstrainerSmartFoundry() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobConstrainerSmartFoundry() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.resourcing.rules.JobConstrainerSmartFoundrySession getJobConstrainerSmartFoundrySession(org.osid.id.Id foundryId, 
                                                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job 
     *  constrainer mapping lookup service for looking up the rules applied to 
     *  a job. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> JobConstrainerRuleLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobConstrainerRuleLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobConstrainerRuleLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.JobConstrainerRuleLookupSession getJobConstrainerRuleLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job 
     *  constrainer mapping lookup service for the given foundry for looking 
     *  up rules applied to a job. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return a <code> JobConstrainerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Foundry </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobConstrainerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobConstrainerRuleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.JobConstrainerRuleLookupSession getJobConstrainerRuleLookupSessionForFoundry(org.osid.id.Id foundryId, 
                                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job 
     *  constrainer assignment service to apply to jobs. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> JobConstrainerRuleApplicationSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobConstrainerRuleApplication() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobConstrainerRuleApplication() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.resourcing.rules.JobConstrainerRuleApplicationSession getJobConstrainerRuleApplicationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job 
     *  constrainer assignment service for the given foundry to apply to jobs. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return a <code> JobConstrainerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Foundry </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobConstrainerRuleApplication() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobConstrainerRuleApplication() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.JobConstrainerRuleApplicationSession getJobConstrainerRuleApplicationSessionForFoundry(org.osid.id.Id foundryId, 
                                                                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job 
     *  constrainer enabler lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> JobConstrainerEnablerLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobConstrainerEnablerLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobConstrainerEnablerLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.resourcing.rules.JobConstrainerEnablerLookupSession getJobConstrainerEnablerLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job 
     *  constrainer enabler lookup service for the given foundry. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return a <code> JobConstrainerEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Foundry </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobConstrainerEnablerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobConstrainerEnablerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.JobConstrainerEnablerLookupSession getJobConstrainerEnablerLookupSessionForFoundry(org.osid.id.Id foundryId, 
                                                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job 
     *  constrainer enabler query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> JobConstrainerEnablerQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobConstrainerEnablerQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobConstrainerEnablerQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.resourcing.rules.JobConstrainerEnablerQuerySession getJobConstrainerEnablerQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job 
     *  constrainer enabler query service for the given foundry. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return a <code> JobConstrainerEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Foundry </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobConstrainerEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobConstrainerEnablerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.JobConstrainerEnablerQuerySession getJobConstrainerEnablerQuerySessionForFoundry(org.osid.id.Id foundryId, 
                                                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job 
     *  constrainer enabler search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> JobConstrainerEnablerSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobConstrainerEnablerSearch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobConstrainerEnablerSearch() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.resourcing.rules.JobConstrainerEnablerSearchSession getJobConstrainerEnablerSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job 
     *  constrainer enablers earch service for the given foundry. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return a <code> JobConstrainerEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Foundry </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobConstrainerEnablerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobConstrainerEnablerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.JobConstrainerEnablerSearchSession getJobConstrainerEnablerSearchSessionForFoundry(org.osid.id.Id foundryId, 
                                                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job 
     *  constrainer enabler administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> JobConstrainerEnablerAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobConstrainerEnablerAdmin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobConstrainerEnablerAdmin() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.resourcing.rules.JobConstrainerEnablerAdminSession getJobConstrainerEnablerAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job 
     *  constrainer enabler administration service for the given foundry. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return a <code> JobConstrainerEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Foundry </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobConstrainerEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobConstrainerEnablerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.JobConstrainerEnablerAdminSession getJobConstrainerEnablerAdminSessionForFoundry(org.osid.id.Id foundryId, 
                                                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job 
     *  constrainer enabler notification service. 
     *
     *  @param  jobConstrainerEnablerReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> JobConstrainerEnablerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          jobConstrainerEnablerReceiver </code> or <code> proxy </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobConstrainerEnablerNotification() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobConstrainerEnablerNotification() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.resourcing.rules.JobConstrainerEnablerNotificationSession getJobConstrainerEnablerNotificationSession(org.osid.resourcing.rules.JobConstrainerEnablerReceiver jobConstrainerEnablerReceiver, 
                                                                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job 
     *  constrainer enabler notification service for the given foundry. 
     *
     *  @param  jobConstrainerEnablerReceiver the notification callback 
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return a <code> JobConstrainerEnablerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no foundry found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          jobConstrainerEnablerReceiver, foundryId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobConstrainerEnablerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobConstrainerEnablerNotification() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.resourcing.rules.JobConstrainerEnablerNotificationSession getJobConstrainerEnablerNotificationSessionForFoundry(org.osid.resourcing.rules.JobConstrainerEnablerReceiver jobConstrainerEnablerReceiver, 
                                                                                                                                    org.osid.id.Id foundryId, 
                                                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup job constrainer 
     *  enabler/foundry mappings for job constrainer enablers. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> JobConstrainerEnablerFoundrySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobConstrainerEnablerFoundry() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobConstrainerEnablerFoundry() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.resourcing.rules.JobConstrainerEnablerFoundrySession getJobConstrainerEnablerFoundrySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning job 
     *  constrainer enablers to foundries. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> JobConstrainerEnablerFoundryAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobConstrainerEnablerFoundryAssignment() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobConstrainerEnablerFoundryAssignment() </code> 
     *              is <code> true. </code> 
     */

    public org.osid.resourcing.rules.JobConstrainerEnablerFoundryAssignmentSession getJobConstrainerEnablerFoundryAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage job constrainer enabler 
     *  smart foundries. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return a <code> JobConstrainerEnablerSmartFoundrySession </code> 
     *  @throws org.osid.NotFoundException no <code> Foundry </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobConstrainerEnablerSmartFoundry() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobConstrainerEnablerSmartFoundry() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.resourcing.rules.JobConstrainerEnablerSmartFoundrySession getJobConstrainerEnablerSmartFoundrySession(org.osid.id.Id foundryId, 
                                                                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job 
     *  constrainer enabler mapping lookup service . 
     *
     *  @param  proxy a proxy 
     *  @return a <code> JobConstrainerEnablerRuleLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobConstrainerEnablerRuleLookup() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobConstrainerEnablerRuleLookup() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.resourcing.rules.JobConstrainerEnablerRuleLookupSession getJobConstrainerEnablerRuleLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job 
     *  constrainer enabler mapping lookup service for the given foundry. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return a <code> JobConstrainerEnablerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Foundry </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobConstrainerEnablerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobConstrainerEnablerRuleLookup() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.resourcing.rules.JobConstrainerEnablerRuleLookupSession getJobConstrainerEnablerRuleLookupSessionForFoundry(org.osid.id.Id foundryId, 
                                                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job 
     *  constrainer enabler assignment service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> JobConstrainerEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobConstrainerEnablerRuleApplication() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobConstrainerEnablerRuleApplication() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.resourcing.rules.JobConstrainerEnablerRuleApplicationSession getJobConstrainerEnablerRuleApplicationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job 
     *  constrainer enabler assignment service for the given foundry. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return a <code> JobConstrainerEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Foundry </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobConstrainerEnablerRuleApplication() </code> or 
     *          <code> supportsVisibleFederation() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobConstrainerEnablerRuleApplication() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.resourcing.rules.JobConstrainerEnablerRuleApplicationSession getJobConstrainerEnablerRuleApplicationSessionForFoundry(org.osid.id.Id foundryId, 
                                                                                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job processor 
     *  lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> JobProcessorLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobProcessorLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobProcessorLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.JobProcessorLookupSession getJobProcessorLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job processor 
     *  lookup service for the given foundry. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return a <code> JobProcessorLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Foundry </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobProcessorLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobProcessorLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.JobProcessorLookupSession getJobProcessorLookupSessionForFoundry(org.osid.id.Id foundryId, 
                                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job processor 
     *  query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> JobProcessorQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobProcessorQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobProcessorQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.JobProcessorQuerySession getJobProcessorQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job processor 
     *  query service for the given foundry. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return a <code> JobProcessorQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Foundry </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobProcessorQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobProcessorQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.JobProcessorQuerySession getJobProcessorQuerySessionForFoundry(org.osid.id.Id foundryId, 
                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job processor 
     *  search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> JobProcessorSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobProcessorSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobProcessorSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.JobProcessorSearchSession getJobProcessorSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job processor 
     *  earch service for the given foundry. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return a <code> JobProcessorSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Foundry </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobProcessorSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobProcessorSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.JobProcessorSearchSession getJobProcessorSearchSessionForFoundry(org.osid.id.Id foundryId, 
                                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job processor 
     *  administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> JobProcessorAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobProcessorAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobProcessorAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.JobProcessorAdminSession getJobProcessorAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job processor 
     *  administration service for the given foundry. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return a <code> JobProcessorAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Foundry </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobProcessorAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobProcessorAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.JobProcessorAdminSession getJobProcessorAdminSessionForFoundry(org.osid.id.Id foundryId, 
                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job processor 
     *  notification service. 
     *
     *  @param  jobProcessorReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> JobProcessorNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> jobProcessorReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobProcessorNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobProcessorNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.JobProcessorNotificationSession getJobProcessorNotificationSession(org.osid.resourcing.rules.JobProcessorReceiver jobProcessorReceiver, 
                                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job processor 
     *  notification service for the given foundry. 
     *
     *  @param  jobProcessorReceiver the notification callback 
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return a <code> JobProcessorNotificationSession </code> 
     *  @throws org.osid.NotFoundException no foundry found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> jobProcessorReceiver, 
     *          foundryId </code> or <code> proxy </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobProcessorNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobProcessorNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.JobProcessorNotificationSession getJobProcessorNotificationSessionForFoundry(org.osid.resourcing.rules.JobProcessorReceiver jobProcessorReceiver, 
                                                                                                                  org.osid.id.Id foundryId, 
                                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup job processor/foundry 
     *  mappings for job processors. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> JobProcessorFoundrySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobProcessorFoundry() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobProcessorFoundry() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.JobProcessorFoundrySession getJobProcessorFoundrySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning job 
     *  processor to foundries. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> JobProcessorFoundryAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobProcessorFoundryAssignment() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobProcessorFoundryAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.resourcing.rules.JobProcessorFoundryAssignmentSession getJobProcessorFoundryAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage job processor smart 
     *  foundries. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return a <code> JobProcessorSmartFoundrySession </code> 
     *  @throws org.osid.NotFoundException no <code> Foundry </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobProcessorSmartFoundry() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobProcessorSmartFoundry() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.JobProcessorSmartFoundrySession getJobProcessorSmartFoundrySession(org.osid.id.Id foundryId, 
                                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job processor 
     *  mapping lookup service for looking up the rules applied to a job. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> JobProcessorRuleLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobProcessorRuleLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobProcessorRuleLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.JobProcessorRuleLookupSession getJobProcessorRuleLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job processor 
     *  mapping lookup service for the given foundry for looking up rules 
     *  applied to a job. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return a <code> JobProcessorRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Foundry </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobProcessorRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobProcessorRuleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.JobProcessorRuleLookupSession getJobProcessorRuleLookupSessionForFoundry(org.osid.id.Id foundryId, 
                                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job processor 
     *  assignment service to apply to jobs. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> JobProcessorRuleApplicationSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobProcessorRuleApplication() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobProcessorRuleApplication() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.resourcing.rules.JobProcessorRuleApplicationSession getJobProcessorRuleApplicationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job processor 
     *  assignment service for the given foundry to apply to jobs. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return a <code> JobProcessorRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Foundry </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobProcessorRuleApplication() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobProcessorRuleApplication() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.JobProcessorRuleApplicationSession getJobProcessorRuleApplicationSessionForFoundry(org.osid.id.Id foundryId, 
                                                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job processor 
     *  enabler lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> JobProcessorEnablerLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobProcessorEnablerLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobProcessorEnablerLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.resourcing.rules.JobProcessorEnablerLookupSession getJobProcessorEnablerLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job processor 
     *  enabler lookup service for the given foundry. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return a <code> JobProcessorEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Foundry </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobProcessorEnablerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobProcessorEnablerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.JobProcessorEnablerLookupSession getJobProcessorEnablerLookupSessionForFoundry(org.osid.id.Id foundryId, 
                                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job processor 
     *  enabler query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> JobProcessorEnablerQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobProcessorEnablerQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobProcessorEnablerQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.JobProcessorEnablerQuerySession getJobProcessorEnablerQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job processor 
     *  enabler query service for the given foundry. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return a <code> JobProcessorEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Foundry </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobProcessorEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobProcessorEnablerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.JobProcessorEnablerQuerySession getJobProcessorEnablerQuerySessionForFoundry(org.osid.id.Id foundryId, 
                                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job processor 
     *  enabler search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> JobProcessorEnablerSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobProcessorEnablerSearch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobProcessorEnablerSearch() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.resourcing.rules.JobProcessorEnablerSearchSession getJobProcessorEnablerSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job processor 
     *  enablers earch service for the given foundry. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return a <code> JobProcessorEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Foundry </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobProcessorEnablerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobProcessorEnablerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.JobProcessorEnablerSearchSession getJobProcessorEnablerSearchSessionForFoundry(org.osid.id.Id foundryId, 
                                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job processor 
     *  enabler administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> JobProcessorEnablerAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobProcessorEnablerAdmin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobProcessorEnablerAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.JobProcessorEnablerAdminSession getJobProcessorEnablerAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job processor 
     *  enabler administration service for the given foundry. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return a <code> JobProcessorEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Foundry </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobProcessorEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobProcessorEnablerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.JobProcessorEnablerAdminSession getJobProcessorEnablerAdminSessionForFoundry(org.osid.id.Id foundryId, 
                                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job processor 
     *  enabler notification service. 
     *
     *  @param  jobProcessorEnablerReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> JobProcessorEnablerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          jobProcessorEnablerReceiver </code> or <code> proxy </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobProcessorEnablerNotification() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobProcessorEnablerNotification() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.resourcing.rules.JobProcessorEnablerNotificationSession getJobProcessorEnablerNotificationSession(org.osid.resourcing.rules.JobProcessorEnablerReceiver jobProcessorEnablerReceiver, 
                                                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job processor 
     *  enabler notification service for the given foundry. 
     *
     *  @param  jobProcessorEnablerReceiver the notification callback 
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return a <code> JobProcessorEnablerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no foundry found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          jobProcessorEnablerReceiver, foundryId </code> or <code> proxy 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobProcessorEnablerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobProcessorEnablerNotification() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.resourcing.rules.JobProcessorEnablerNotificationSession getJobProcessorEnablerNotificationSessionForFoundry(org.osid.resourcing.rules.JobProcessorEnablerReceiver jobProcessorEnablerReceiver, 
                                                                                                                                org.osid.id.Id foundryId, 
                                                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup job processor 
     *  enabler/foundry mappings for job processor enablers. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> JobProcessorEnablerFoundrySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobProcessorEnablerFoundry() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobProcessorEnablerFoundry() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.resourcing.rules.JobProcessorEnablerFoundrySession getJobProcessorEnablerFoundrySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning job 
     *  processor enablers to foundries. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> JobProcessorEnablerFoundryAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobProcessorEnablerFoundryAssignment() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobProcessorEnablerFoundryAssignment() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.resourcing.rules.JobProcessorEnablerFoundryAssignmentSession getJobProcessorEnablerFoundryAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage job processor enabler 
     *  smart foundries. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return a <code> JobProcessorEnablerSmartFoundrySession </code> 
     *  @throws org.osid.NotFoundException no <code> Foundry </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobProcessorEnablerSmartFoundry() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobProcessorEnablerSmartFoundry() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.resourcing.rules.JobProcessorEnablerSmartFoundrySession getJobProcessorEnablerSmartFoundrySession(org.osid.id.Id foundryId, 
                                                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job processor 
     *  enabler mapping lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> JobProcessorEnablerRuleLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobProcessorEnablerRuleLookup() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobProcessorEnablerRuleLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.resourcing.rules.JobProcessorEnablerRuleLookupSession getJobProcessorEnablerRuleLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job processor 
     *  enabler mapping lookup service for the given foundry. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return a <code> JobProcessorEnablerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Foundry </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobProcessorEnablerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobProcessorEnablerRuleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.rules.JobProcessorEnablerRuleLookupSession getJobProcessorEnablerRuleLookupSessionForFoundry(org.osid.id.Id foundryId, 
                                                                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job processor 
     *  enabler assignment service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> JobProcessorEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobProcessorEnablerRuleApplication() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobProcessorEnablerRuleApplication() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.resourcing.rules.JobProcessorEnablerRuleApplicationSession getJobProcessorEnablerRuleApplicationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the job processor 
     *  enabler assignment service for the given foundry. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  proxy a proxy 
     *  @return a <code> JobProcessorEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Foundry </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJobProcessorEnablerRuleApplication() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobProcessorEnablerRuleApplication() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.resourcing.rules.JobProcessorEnablerRuleApplicationSession getJobProcessorEnablerRuleApplicationSessionForFoundry(org.osid.id.Id foundryId, 
                                                                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;
}
