//
// org.osid.room.Building
//
//     The OSID Java specification for org.osid.room.Building.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.room;


/**
 *  <p>A <code> Building </code> represents a collection of floors. </p>
 */

public interface Building
    extends org.osid.OsidObject,
            org.osid.Temporal {


    /**
     *  Gets the address of this building. 
     *
     *  @return the building address <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAddressId();


    /**
     *  Gets the building address. 
     *
     *  @return the building address. 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.Address getAddress()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the formal name for this building (e.g. Guggenheim Laboratory). 
     *  The display name may or may not differ from this name but may be based 
     *  on the code (e.g. Building 35). 
     *
     *  @return the name 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getOfficialName();


    /**
     *  Gets the building number or code (e.g. 35). 
     *
     *  @return the building number 
     *  @compliance mandatory This method must be implemented. 
     */

    public String getNumber();


    /**
     *  Tests if this building is a subdivision of another building. 
     *
     *  @return <code> true </code> if this building is a subdivisiaion, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isSubdivision();


    /**
     *  Gets the enclosing building <code> Id </code> if this building is a 
     *  subdivision. 
     *
     *  @return the enclosing building <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> isSubdivision() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getEnclosingBuildingId();


    /**
     *  Gets the enclosing building if this building is a subdivision. 
     *
     *  @return the enlcosing building 
     *  @throws org.osid.IllegalStateException <code> isSubdivision() </code> 
     *          is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.Building getEnclosingBuilding()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the subdivision building <code> Ids </code> if this building is 
     *  subdivided. 
     *
     *  @return the subdivision building <code> Ids </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getSubdivisionIds();


    /**
     *  Gets the subdivision buildings if this building is subdivided. 
     *
     *  @return the subdivision buildings 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.BuildingList getSubdivisions()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if an area is available. 
     *
     *  @return <code> true </code> if an area is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasArea();


    /**
     *  Gets the gross square footage of this building. 
     *
     *  @return the gross area 
     *  @throws org.osid.IllegalStateException <code> hasArea() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getGrossArea();


    /**
     *  Gets the building record corresponding to the given <code> Building 
     *  </code> record <code> Type. </code> This method is used to retrieve an 
     *  object implementing the requested record. The <code> 
     *  buildingRecordType </code> may be the <code> Type </code> returned in 
     *  <code> getRecordTypes() </code> or any of its parents in a <code> Type 
     *  </code> hierarchy where <code> hasRecordType(buildingRecordType) 
     *  </code> is <code> true </code> . 
     *
     *  @param  buildingRecordType the type of building record to retrieve 
     *  @return the building record 
     *  @throws org.osid.NullArgumentException <code> buildingRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(buildingRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.records.BuildingRecord getBuildingRecord(org.osid.type.Type buildingRecordType)
        throws org.osid.OperationFailedException;
}
