//
// org.osid.room.BuildingForm
//
//     The OSID Java specification for org.osid.room.BuildingForm.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.room;


/**
 *  <p>This is the form for creating and updating <code> Buildings. </code> 
 *  Like all <code> OsidForm </code> objects, various data elements may be set 
 *  here for use in the create and update methods in the <code> 
 *  BuildingAdminSession. </code> For each data element that may be set, 
 *  metadata may be examined to provide display hints or data constraints. 
 *  </p>
 */

public interface BuildingForm
    extends org.osid.OsidObjectForm,
            org.osid.OsidTemporalForm {


    /**
     *  Gets the metadata for an address. 
     *
     *  @return metadata for the address 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getAddressMetadata();


    /**
     *  Sets the address. 
     *
     *  @param  addressId the new address 
     *  @throws org.osid.InvalidArgumentException <code> addressId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> addressId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setAddress(org.osid.id.Id addressId);


    /**
     *  Clears the address. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAddress();


    /**
     *  Gets the metadata for an official name. 
     *
     *  @return metadata for the official name 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getOfficialNameMetadata();


    /**
     *  Sets the official name. 
     *
     *  @param  name the new name 
     *  @throws org.osid.InvalidArgumentException <code> name </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> name </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setOfficialName(String name);


    /**
     *  Clears the official name. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOfficialName();


    /**
     *  Gets the metadata for a number. 
     *
     *  @return metadata for the number 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getNumberMetadata();


    /**
     *  Sets the building number. 
     *
     *  @param  number the new number 
     *  @throws org.osid.InvalidArgumentException <code> number </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> number </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setNumber(String number);


    /**
     *  Clears the building number. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearNumber();


    /**
     *  Gets the metadata for an enclosing building. 
     *
     *  @return metadata for the enclosing building 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getEnclosingBuildingMetadata();


    /**
     *  Sets the enclosing building. 
     *
     *  @param  buildingId the new enclosing building 
     *  @throws org.osid.InvalidArgumentException <code> buildingId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> buildingId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setEnclosingBuilding(org.osid.id.Id buildingId);


    /**
     *  Clears the enclosing building. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEnclosingBuilding();


    /**
     *  Gets the metadata for the gross area. 
     *
     *  @return metadata for the area 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getGrossAreaMetadata();


    /**
     *  Sets the gross area. 
     *
     *  @param  area the new area 
     *  @throws org.osid.InvalidArgumentException <code> area </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setGrossArea(java.math.BigDecimal area);


    /**
     *  Clears the area. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGrossArea();


    /**
     *  Gets the <code> BuildingFormRecord </code> corresponding to the given 
     *  building record <code> Type. </code> 
     *
     *  @param  buildingRecordType the building record type 
     *  @return the building form record 
     *  @throws org.osid.NullArgumentException <code> buildingRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(buildingRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.records.BuildingFormRecord getBuildingFormRecord(org.osid.type.Type buildingRecordType)
        throws org.osid.OperationFailedException;
}
