//
// org.osid.room.BuildingSearchSession
//
//     The OSID Java specification for org.osid.room.BuildingSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.room;


/**
 *  <p>This session provides methods for searching <code> Building </code> 
 *  objects. The search query is constructed using the <code> BuildingQuery. 
 *  </code> The building record <code> Type </code> also specifies the record 
 *  for the building query. </p> 
 *  
 *  <p> <code> getBuildingsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Building </code> elements. A more advanced search 
 *  may be performed with <code> getBuildingsBySearch(). </code> It accepts a 
 *  <code> BuildingSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getBuildingsBySearch() </code> returns a <code> 
 *  BuildingSearchResults </code> that can be used to access the resulting 
 *  <code> BuildingList </code> or be used to perform a search within the 
 *  result set through <code> BuildingSearch. </code> </p> 
 *  
 *  <p> Buildings may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> BuildingQuery. </code> 
 *  The returns in this session may not be cast directly to these interfaces. 
 *  </p>
 */

public interface BuildingSearchSession
    extends org.osid.room.BuildingQuerySession {


    /**
     *  Gets a building search. 
     *
     *  @return the building search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.BuildingSearch getBuildingSearch();


    /**
     *  Gets a building search order. The <code> BuildingSearchOrder </code> 
     *  is supplied to a <code> BuildingSearch </code> to specify the ordering 
     *  of results. 
     *
     *  @return the building search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.BuildingSearchOrder getBuildingSearchOrder();


    /**
     *  Gets the search results matching the given search. 
     *
     *  @param  buildingQuery the building query 
     *  @param  buildingSearch the building search 
     *  @return the building search results 
     *  @throws org.osid.NullArgumentException <code> buildingQuery </code> or 
     *          <code> buildingSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> buildingQuery </code> or 
     *          <code> buildingSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.BuildingSearchResults getBuildingsBySearch(org.osid.room.BuildingQuery buildingQuery, 
                                                                    org.osid.room.BuildingSearch buildingSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a building query from an inspector. The inspector is available 
     *  from a <code> BuildingSearchResults. </code> 
     *
     *  @param  buildingQueryInspector a query inspector 
     *  @return the building query 
     *  @throws org.osid.NullArgumentException <code> buildingQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> buildingQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.BuildingQuery getBuildingQueryFromInspector(org.osid.room.BuildingQueryInspector buildingQueryInspector);
}
