//
// org.osid.room.CampusAdminSession
//
//     The OSID Java specification for org.osid.room.CampusAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.room;


/**
 *  <p>This session creates and removes campuses. The data for create and 
 *  update is provided by the consumer via the form object. </p>
 */

public interface CampusAdminSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can create <code> Campuses. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> Campus </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not wish to offer create operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Campus </code> creation is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateCampuses();


    /**
     *  Tests if this user can create a single <code> Campus </code> using the 
     *  desired record interface types. While <code> 
     *  RoomManager.getCampusRecordTypes() </code> can be used to examine 
     *  which record interfaces are supported, this method tests which 
     *  record(s) are required for creating a specific <code> Campus. </code> 
     *  Providing an empty array tests if a <code> Campus </code> can be 
     *  created with no records. 
     *
     *  @param  campusRecordTypes array of campus record types 
     *  @return <code> true </code> if <code> Campus </code> creation using 
     *          the specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> campusRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateCampusWithRecordTypes(org.osid.type.Type[] campusRecordTypes);


    /**
     *  Gets the campus form for creating new campuses. A new form should be 
     *  requested for each create transaction. 
     *
     *  @param  campusRecordTypes array of campus record types 
     *  @return the campus form 
     *  @throws org.osid.NullArgumentException <code> campusRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get foem for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.CampusForm getCampusFormForCreate(org.osid.type.Type[] campusRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Campus. </code> 
     *
     *  @param  campusForm the form for this <code> Campus </code> 
     *  @return the new <code> Campus </code> 
     *  @throws org.osid.IllegalStateException <code> campusForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> campusForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> campusForm </code> did 
     *          not originate from <code> getCampusFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.Campus createCampus(org.osid.room.CampusForm campusForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Campuses. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> Campus </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not wish to offer update operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Campus </code> modification is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateCampuses();


    /**
     *  Gets the campus form for updating an existing campus. A new campus 
     *  form should be requested for each update transaction. 
     *
     *  @param  campusId the <code> Id </code> of the <code> Campus </code> 
     *  @return the campus form 
     *  @throws org.osid.NotFoundException <code> campusId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> campusId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.CampusForm getCampusFormForUpdate(org.osid.id.Id campusId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing campus. 
     *
     *  @param  campusForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> campusForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> campusForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> campusForm </code> did 
     *          not originate from <code> getCampusFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateCampus(org.osid.room.CampusForm campusForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> Campuses </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> Campus </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not wish to offer delete operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Campus </code> deletion is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteCampuses();


    /**
     *  Deletes a <code> Campus. </code> 
     *
     *  @param  campusId the <code> Id </code> of the <code> Campus </code> to 
     *          remove 
     *  @throws org.osid.NotFoundException <code> campusId </code> not found 
     *  @throws org.osid.NullArgumentException <code> campusId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteCampus(org.osid.id.Id campusId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Campuses. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Campus </code> aliasing is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageCampusAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Campus </code> for the purpose 
     *  of creating compatibility. The primary <code> Id </code> of the <code> 
     *  Campus </code> is determined by the provider. The new <code> Id 
     *  </code> performs as an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another campus, it is reassigned to the given 
     *  campus <code> Id. </code> 
     *
     *  @param  campusId the <code> Id </code> of a <code> Campus </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> campusId </code> not found 
     *  @throws org.osid.NullArgumentException <code> campusId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasCampus(org.osid.id.Id campusId, org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
