//
// org.osid.room.FloorQueryInspector
//
//     The OSID Java specification for org.osid.room.FloorQueryInspector.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.room;


/**
 *  <p>This is the query inspector for examining for floor queries. </p>
 */

public interface FloorQueryInspector
    extends org.osid.OsidObjectQueryInspector,
            org.osid.OsidTemporalQueryInspector,
            org.osid.OsidSubjugateableQueryInspector {


    /**
     *  Gets the building <code> Id </code> terms. 
     *
     *  @return the building <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getBuildingIdTerms();


    /**
     *  Gets the building terms. 
     *
     *  @return the building terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.BuildingQueryInspector[] getBuildingTerms();


    /**
     *  Gets the terms terms. 
     *
     *  @return the terms terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.StringTerm[] getNumberTerms();


    /**
     *  Gets the gross area terms. 
     *
     *  @return the gross area terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DecimalRangeTerm[] getGrossAreaTerms();


    /**
     *  Gets the room <code> Id </code> terms. 
     *
     *  @return the room <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getRoomIdTerms();


    /**
     *  Gets the room terms. 
     *
     *  @return the room terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.RoomQueryInspector[] getRoomTerms();


    /**
     *  Gets the campus <code> Id </code> terms. 
     *
     *  @return the campus <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getCampusIdTerms();


    /**
     *  Gets the campus terms. 
     *
     *  @return the campus terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.CampusQueryInspector[] getCampusTerms();


    /**
     *  Gets the floor query inspector record corresponding to the given 
     *  <code> Floor </code> record <code> Type. </code> 
     *
     *  @param  floorRecordType a floor record type 
     *  @return the floor query inspector record 
     *  @throws org.osid.NullArgumentException <code> floorRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(floorRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.records.FloorQueryInspectorRecord getFloorQueryInspectorRecord(org.osid.type.Type floorRecordType)
        throws org.osid.OperationFailedException;
}
