//
// org.osid.room.FloorSearchSession
//
//     The OSID Java specification for org.osid.room.FloorSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.room;


/**
 *  <p>This session provides methods for searching <code> Floor </code> 
 *  objects. The search query is constructed using the <code> FloorQuery. 
 *  </code> The floor record <code> Type </code> also specifies the record for 
 *  the floor query. </p> 
 *  
 *  <p> <code> getFloorsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Floor </code> elements. A more advanced search 
 *  may be performed with <code> getFloorsBySearch(). </code> It accepts a 
 *  <code> FloorSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getFlooreBySearch() </code> returns a <code> 
 *  FloorSearchResults </code> that can be used to access the resulting <code> 
 *  FloorList </code> or be used to perform a search within the result set 
 *  through <code> FloorSearch. </code> </p> 
 *  
 *  <p> Floors may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> FloorQuery. </code> The 
 *  returns in this session may not be cast directly to these interfaces. </p>
 */

public interface FloorSearchSession
    extends org.osid.room.FloorQuerySession {


    /**
     *  Gets a floor search. 
     *
     *  @return the floor search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.FloorSearch getFloorSearch();


    /**
     *  Gets a floor search order. The <code> FloorSearchOrder </code> is 
     *  supplied to a <code> FloorSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the floor search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.FloorSearchOrder getFloorSearchOrder();


    /**
     *  Gets the search results matching the given search. 
     *
     *  @param  floorQuery the floor query 
     *  @param  floorSearch the floor search 
     *  @return the floor search results 
     *  @throws org.osid.NullArgumentException <code> floorQuery </code> or 
     *          <code> floorSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> floorQuery </code> or 
     *          <code> floorSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.FloorSearchResults getFloorsBySearch(org.osid.room.FloorQuery floorQuery, 
                                                              org.osid.room.FloorSearch floorSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an entry query from an inspector. The inspector is available from 
     *  an <code> FloorSearchResults. </code> 
     *
     *  @param  floorQueryInspector a query inspector 
     *  @return the entry query 
     *  @throws org.osid.NullArgumentException <code> floorQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> floorQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.FloorQuery getFloorQueryFromInspector(org.osid.room.FloorQueryInspector floorQueryInspector);
}
