//
// org.osid.room.Room
//
//     The OSID Java specification for org.osid.room.Room.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.room;


/**
 *  <p>A <code> Room. </code> </p>
 */

public interface Room
    extends org.osid.OsidObject,
            org.osid.Temporal,
            org.osid.Subjugateable {


    /**
     *  Gets the <code> Id </code> of the building. 
     *
     *  @return the building <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBuildingId();


    /**
     *  Gets the building. 
     *
     *  @return the building 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.Building getBuilding()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the floor <code> Id. </code> 
     *
     *  @return the floor <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFloorId();


    /**
     *  Gets the floor. 
     *
     *  @return the floor 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.Floor getFloor()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this room is a subdivision of another room. 
     *
     *  @return <code> true </code> if this room is a subdivisiaion, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isSubdivision();


    /**
     *  Gets the enclosing room <code> Id </code> if this room is a 
     *  subdivision. 
     *
     *  @return the enclosing room <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> isSubdivision() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getEnclosingRoomId();


    /**
     *  Gets the enclosing room if this room is a subdivision. 
     *
     *  @return the enlcosing room 
     *  @throws org.osid.IllegalStateException <code> isSubdivision() </code> 
     *          is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.Room getEnclosingRoom()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the subdivision room <code> Ids </code> if this room is 
     *  subdivided. 
     *
     *  @return the subdivision room <code> Ids </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getSubdivisionIds();


    /**
     *  Gets the subdivision rooms if this room is subdivided. 
     *
     *  @return the subdivision rooms 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.RoomList getSubdivisions()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the designated or formal name of the room (e.g. Twenty Chimneys). 
     *  The display name may be mapped to this designated name, room number, 
     *  or some other room label. 
     *
     *  @return the room number 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getDesignatedName();


    /**
     *  Gets the complete room number including the building and floor (e.g. 
     *  W20-306). 
     *
     *  @return the room number 
     *  @compliance mandatory This method must be implemented. 
     */

    public String getRoomNumber();


    /**
     *  Gets the room number within a floor (e.g. 06). 
     *
     *  @return the room code 
     *  @compliance mandatory This method must be implemented. 
     */

    public String getCode();


    /**
     *  Tests if an area is available. 
     *
     *  @return <code> true </code> if an area is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasArea();


    /**
     *  Gets the area of this room in square feet. 
     *
     *  @return the area in square feet 
     *  @throws org.osid.IllegalStateException <code> hasArea() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getArea();


    /**
     *  Gets the limit on occupancy of this room. 
     *
     *  @return the occupancy limit 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getOccupancyLimit();


    /**
     *  Gets the <code> Ids </code> of any resources in this room such as 
     *  projectors, white boards, or other classes of equiptment. 
     *
     *  @return the resource <code> Ids </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getResourceIds();


    /**
     *  Gets a list of resources in this room such as projectors, white 
     *  boards, or other classes of equiptment. These classes of equipment are 
     *  expressed as resources although they may be managed at the individual 
     *  item level in the Inventory OSID. These resources are to facilitate 
     *  searches among equipped rooms. 
     *
     *  @return a list of resources 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceList getResources()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the room record corresponding to the given <code> Room </code> 
     *  record <code> Type. </code> This method is used to retrieve an object 
     *  implementing the requested record. The <code> roomRecordType </code> 
     *  may be the <code> Type </code> returned in <code> getRecordTypes() 
     *  </code> or any of its parents in a <code> Type </code> hierarchy where 
     *  <code> hasRecordType(roomRecordType) </code> is <code> true </code> . 
     *
     *  @param  roomRecordType the type of room record to retrieve 
     *  @return the room record 
     *  @throws org.osid.NullArgumentException <code> roomRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(roomRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.records.RoomRecord getRoomRecord(org.osid.type.Type roomRecordType)
        throws org.osid.OperationFailedException;
}
