//
// org.osid.room.RoomAdminSession
//
//     The OSID Java specification for org.osid.room.RoomAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.room;


/**
 *  <p>This session creates, updates, and deletes <code> Rooms. </code> The 
 *  data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Room, </code> a <code> RoomForm </code> is requested using <code> 
 *  getRoomFormForCreate() </code> specifying the desired floor and record 
 *  <code> Types </code> or none if no record <code> Types </code> are needed. 
 *  The returned <code> RoomForm </code> will indicate that it is to be used 
 *  with a create operation and can be used to examine metdata or validate 
 *  data prior to creation. Once the <code> RoomForm </code> is submiited to a 
 *  create operation, it cannot be reused with another create operation unless 
 *  the first operation was unsuccessful. Each <code> RoomForm </code> 
 *  corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> RoomForms </code> are requested to the <code> Room 
 *  </code> <code> Id </code> that is to be updated using <code> 
 *  getRoomFormForUpdate(). </code> Similarly, the <code> RoomForm </code> has 
 *  metadata about the data that can be updated and it can perform validation 
 *  before submitting the update. The <code> RoomForm </code> can only be used 
 *  once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Rooms. </code> To unmap a <code> 
 *  Room </code> from the current <code> Campus, </code> the <code> 
 *  RoomCampusAssignmentSession </code> should be used. These delete 
 *  operations attempt to remove the <code> Room </code> itself thus removing 
 *  it from all known <code> Campus </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface RoomAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Campus </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Campus Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCampusId();


    /**
     *  Gets the <code> Campus </code> associated with this session. 
     *
     *  @return the campus 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.Campus getCampus()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create hournal entries. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known creating a <code> Room </code> will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer create operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Room </code> creation is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateRooms();


    /**
     *  Tests if this user can create a single <code> Room </code> using the 
     *  desired record interface types. While <code> 
     *  RoomManager.getRoomRecordTypes() </code> can be used to examine which 
     *  record interfaces are supported, this method tests which record(s) are 
     *  required for creating a specific <code> Room. </code> Providing an 
     *  empty array tests if a <code> Room </code> can be created with no 
     *  records. 
     *
     *  @param  roomRecordTypes array of room record types 
     *  @return <code> true </code> if <code> Room </code> creation using the 
     *          specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> roomRecordTypes </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateRoomWithRecordTypes(org.osid.type.Type[] roomRecordTypes);


    /**
     *  Gets the room form for creating new entries. A new form should be 
     *  requested for each create transaction. 
     *
     *  @param  floorId the <code> Id </code> for the floor 
     *  @param  roomRecordTypes array of room record types 
     *  @return the room form 
     *  @throws org.osid.NotFoundException <code> floorId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> floorId </code> or 
     *          <code> roomRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get from for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.RoomForm getRoomFormForCreate(org.osid.id.Id floorId, 
                                                       org.osid.type.Type[] roomRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Room. </code> 
     *
     *  @param  roomForm the form for this <code> Room </code> 
     *  @return the new <code> Room </code> 
     *  @throws org.osid.IllegalStateException <code> roomForm </code> already 
     *          used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> roomForm </code> did not 
     *          originate from <code> getRoomFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.Room createRoom(org.osid.room.RoomForm roomForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update rooms. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known updating a <code> Room </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer update operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Room </code> modification is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateRooms();


    /**
     *  Gets the room form for updating an existing room. A new room form 
     *  should be requested for each update transaction. 
     *
     *  @param  roomId the <code> Id </code> of the <code> Room </code> 
     *  @return the room form 
     *  @throws org.osid.NotFoundException <code> roomId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> roomId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.RoomForm getRoomFormForUpdate(org.osid.id.Id roomId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing room. 
     *
     *  @param  roomForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> roomForm </code> already 
     *          used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> roomForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> roomForm </code> did not 
     *          originate from <code> getRoomFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateRoom(org.osid.room.RoomForm roomForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete rooms. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known deleting an <code> Room </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer delete operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Room </code> deletion is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteRooms();


    /**
     *  Deletes an <code> Room. </code> 
     *
     *  @param  roomId the <code> Id </code> of the <code> Room </code> to 
     *          remove 
     *  @throws org.osid.NotFoundException <code> roomId </code> not found 
     *  @throws org.osid.NullArgumentException <code> roomId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteRoom(org.osid.id.Id roomId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Comnents. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Room </code> aliasing is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageRoomAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Room </code> for the purpose of 
     *  creating compatibility. The primary <code> Id </code> of the <code> 
     *  Room </code> is determined by the provider. The new <code> Id </code> 
     *  performs as an alias to the primary <code> Id. </code> If the alias is 
     *  a pointer to another room, it is reassigned to the given room <code> 
     *  Id. </code> 
     *
     *  @param  roomId the <code> Id </code> of a <code> Room </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> roomId </code> not found 
     *  @throws org.osid.NullArgumentException <code> roomId </code> or <code> 
     *          aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasRoom(org.osid.id.Id roomId, org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
