//
// org.osid.room.RoomCampusAssignmentSession
//
//     The OSID Java specification for org.osid.room.RoomCampusAssignmentSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.room;


/**
 *  <p>This session provides methods to re-assign <code> Rooms </code> to 
 *  <code> Campuses. </code> A <code> Room </code> may map to multiple <code> 
 *  Campuses </code> and removing the last reference to a <code> Room </code> 
 *  is the equivalent of deleting it. Each <code> Campus </code> may have its 
 *  own authorizations governing who is allowed to operate on it. </p> 
 *  
 *  <p> Adding a reference of a <code> Room </code> to another <code> Campus 
 *  </code> is not a copy operation (eg: does not change its <code> Id </code> 
 *  ). </p>
 */

public interface RoomCampusAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter room/campus mappings. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignRooms();


    /**
     *  Tests if this user can alter room/campus mappings. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @param  campusId the <code> Id </code> of the <code> Campus </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> campusId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignRoomsToCampus(org.osid.id.Id campusId);


    /**
     *  Gets a list of campuses including and under the given campus node in 
     *  which any room can be assigned. 
     *
     *  @param  campusId the <code> Id </code> of the <code> Campus </code> 
     *  @return list of assignable campus <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> campusId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableCampusIds(org.osid.id.Id campusId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of campuses including and under the given campus node in 
     *  which a specific room can be assigned. 
     *
     *  @param  campusId the <code> Id </code> of the <code> Campus </code> 
     *  @param  roomId the <code> Id </code> of the <code> Room </code> 
     *  @return list of assignable campus <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> campusId </code> or 
     *          <code> roomId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableCampusIdsForRoom(org.osid.id.Id campusId, 
                                                            org.osid.id.Id roomId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> Room </code> to a <code> Campus. </code> 
     *
     *  @param  roomId the <code> Id </code> of the <code> Room </code> 
     *  @param  campusId the <code> Id </code> of the <code> Campus </code> 
     *  @throws org.osid.AlreadyExistsException <code> roomId </code> is 
     *          already assigned to <code> campusId </code> 
     *  @throws org.osid.NotFoundException <code> roomId </code> or <code> 
     *          campusId </code> not found 
     *  @throws org.osid.NullArgumentException <code> roomId </code> or <code> 
     *          campusId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignRoomToCampus(org.osid.id.Id roomId, 
                                   org.osid.id.Id campusId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> Room </code> from a <code> Campus. </code> 
     *
     *  @param  roomId the <code> Id </code> of the <code> Room </code> 
     *  @param  campusId the <code> Id </code> of the <code> Campus </code> 
     *  @throws org.osid.NotFoundException <code> roomId </code> or <code> 
     *          campusId </code> not found or <code> roomId </code> not 
     *          assigned to <code> campusId </code> 
     *  @throws org.osid.NullArgumentException <code> roomId </code> or <code> 
     *          campusId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignRoomFromCampus(org.osid.id.Id roomId, 
                                       org.osid.id.Id campusId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
