//
// org.osid.room.RoomForm
//
//     The OSID Java specification for org.osid.room.RoomForm.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.room;


/**
 *  <p>This is the form for creating and updating <code> Room </code> objects. 
 *  Like all <code> OsidForm </code> objects, various data elements may be set 
 *  here for use in the create and update methods in the <code> 
 *  RoomAdminSession. </code> For each data element that may be set, metadata 
 *  may be examined to provide display hints or data constraints. </p>
 */

public interface RoomForm
    extends org.osid.OsidObjectForm,
            org.osid.OsidTemporalForm,
            org.osid.OsidSubjugateableForm {


    /**
     *  Gets the metadata for an enclosing room. 
     *
     *  @return metadata for the enclosing room 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getEnclosingRoomMetadata();


    /**
     *  Sets the enclosing room. 
     *
     *  @param  roomId the new enclosing room 
     *  @throws org.osid.InvalidArgumentException <code> roomId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> roomId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setEnclosingRoom(org.osid.id.Id roomId);


    /**
     *  Clears the enclosing room. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEnclosingRoom();


    /**
     *  Gets the metadata for a designated name. 
     *
     *  @return metadata for the designated name 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getDesignatedNameMetadata();


    /**
     *  Sets the designated name. 
     *
     *  @param  name the new name 
     *  @throws org.osid.InvalidArgumentException <code> name </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> name </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setDesignatedName(String name);


    /**
     *  Clears the designated name. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDesignatedName();


    /**
     *  Gets the metadata for a code. 
     *
     *  @return metadata for the code 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getCodeMetadata();


    /**
     *  Sets the room code. 
     *
     *  @param  code the new code 
     *  @throws org.osid.InvalidArgumentException <code> code </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> code </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setCode(String code);


    /**
     *  Clears the room code. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCode();


    /**
     *  Gets the metadata for the area. 
     *
     *  @return metadata for the area 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getAreaMetadata();


    /**
     *  Sets the area. 
     *
     *  @param  area the new area 
     *  @throws org.osid.InvalidArgumentException <code> area </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> area </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setArea(java.math.BigDecimal area);


    /**
     *  Clears the area. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearArea();


    /**
     *  Gets the metadata for the room occupancy limit. 
     *
     *  @return metadata for the area 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getOccupancyLimitMetadata();


    /**
     *  Sets the occupancy limit of the room. 
     *
     *  @param  linit the new linit 
     *  @throws org.osid.InvalidArgumentException <code> limit </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setOccupancyLimit(long linit);


    /**
     *  Clears the occupancy limit. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOccupancyLimit();


    /**
     *  Gets the metadata for the room resources. 
     *
     *  @return metadata for the resources 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getResourcesMetadata();


    /**
     *  Sets the resources. 
     *
     *  @param  resourceIds the new resources 
     *  @throws org.osid.InvalidArgumentException <code> resourceIds </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> resourceIds </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setResources(org.osid.id.IdList resourceIds);


    /**
     *  Clears the resources. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearResources();


    /**
     *  Gets the <code> RoomFormRecord </code> corresponding to the given room 
     *  record <code> Type. </code> 
     *
     *  @param  roomRecordType the room record type 
     *  @return the room form record 
     *  @throws org.osid.NullArgumentException <code> roomRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(roomRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.records.RoomFormRecord getRoomFormRecord(org.osid.type.Type roomRecordType)
        throws org.osid.OperationFailedException;
}
