//
// org.osid.room.RoomQueryInspector
//
//     The OSID Java specification for org.osid.room.RoomQueryInspector.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.room;


/**
 *  <p>The query inspector for examining room queries. </p>
 */

public interface RoomQueryInspector
    extends org.osid.OsidObjectQueryInspector,
            org.osid.OsidTemporalQueryInspector,
            org.osid.OsidSubjugateableQueryInspector {


    /**
     *  Gets the building <code> Id </code> terms. 
     *
     *  @return the building <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getBuildingIdTerms();


    /**
     *  Gets the building terms. 
     *
     *  @return the building terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.BuildingQueryInspector[] getBuildingTerms();


    /**
     *  Gets the floor <code> Id </code> terms. 
     *
     *  @return the floor <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getFloorIdTerms();


    /**
     *  Gets the floor terms. 
     *
     *  @return the floor terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.FloorQueryInspector[] getFloorTerms();


    /**
     *  Gets the enclosing room <code> Id </code> terms. 
     *
     *  @return the enclosing room <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getEnclosingRoomIdTerms();


    /**
     *  Gets the enclosing room terms. 
     *
     *  @return the enclosing room terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.RoomQueryInspector[] getEnclosingRoomTerms();


    /**
     *  Gets the subdivision room <code> Id </code> terms. 
     *
     *  @return the subdivision room <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getSubdivisionIdTerms();


    /**
     *  Gets the subdivision room terms. 
     *
     *  @return the subdivision room terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.RoomQueryInspector[] getSubdivisionTerms();


    /**
     *  Gets the offical name terms. 
     *
     *  @return the name terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.StringTerm[] getDesignatedNameTerms();


    /**
     *  Gets the room building number terms. 
     *
     *  @return the room number terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.StringTerm[] getRoomNumberTerms();


    /**
     *  Gets the room code number terms. 
     *
     *  @return the room code terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.StringTerm[] getCodeTerms();


    /**
     *  Gets the area terms. 
     *
     *  @return the area terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DecimalRangeTerm[] getAreaTerms();


    /**
     *  Gets the occupancy limit terms. 
     *
     *  @return the occupancy limit terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.CardinalRangeTerm[] getOccupancyLimitTerms();


    /**
     *  Gets the resource <code> Id </code> terms. 
     *
     *  @return the resource <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getResourceIdTerms();


    /**
     *  Gets the resource terms. 
     *
     *  @return the resource terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceQueryInspector[] getResourceTerms();


    /**
     *  Gets the campus <code> Id </code> terms. 
     *
     *  @return the campus <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getCampusIdTerms();


    /**
     *  Gets the campus terms. 
     *
     *  @return the campus terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.CampusQueryInspector[] getCampusTerms();


    /**
     *  Gets the room query inspector record corresponding to the given <code> 
     *  Room </code> record <code> Type. </code> 
     *
     *  @param  roomRecordType a room record type 
     *  @return the room query inspector record 
     *  @throws org.osid.NullArgumentException <code> roomRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(roomRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.records.RoomQueryInspectorRecord getRoomQueryInspectorRecord(org.osid.type.Type roomRecordType)
        throws org.osid.OperationFailedException;
}
