//
// org.osid.room.RoomSearchOrder
//
//     The OSID Java specification for org.osid.room.RoomSearchOrder.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.room;


/**
 *  <p>An interface for specifying the ordering of search results. </p>
 */

public interface RoomSearchOrder
    extends org.osid.OsidObjectSearchOrder,
            org.osid.OsidTemporalSearchOrder,
            org.osid.OsidSubjugateableSearchOrder {


    /**
     *  Specifies a preference for ordering the result set by the building. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByBuilding(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a building search order is available. 
     *
     *  @return <code> true </code> if a building search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBuildingSearchOrder();


    /**
     *  Gets the building search order. 
     *
     *  @return the building search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBuildingSearchOrder() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBuildingSearchOrder() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.room.BuildingSearchOrder getBuildingSearchOrder();


    /**
     *  Specifies a preference for ordering the result set by the floor. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByFloor(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a floor order is available. 
     *
     *  @return <code> true </code> if a floor search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFloorSearchOrder();


    /**
     *  Gets the floor search order. 
     *
     *  @return the floor search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsFloorSearchOrder() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFloorSearchOrder() </code> is <code> true. </code> 
     */

    public org.osid.room.FloorSearchOrder getFloorSearchOrder();


    /**
     *  Specifies a preference for ordering the result set by the enclosing 
     *  room. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByEnclosingRoom(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a room search order is available. 
     *
     *  @return <code> true </code> if a room order is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEnclosingRoomSearchOrder();


    /**
     *  Gets the room search order. 
     *
     *  @return the enclosing room search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEnclosingRoomSearchOrder() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEnclosingRoomSearchOrder() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.room.RoomSearchOrder getEnclosingRoomSearchOrder();


    /**
     *  Specifies a preference for ordering the result set by the room number. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByRoomNumber(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the room code. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByCode(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the room area. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByArea(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the room 
     *  occupancy limit. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByOccupancyLimit(org.osid.SearchOrderStyle style);


    /**
     *  Gets the room search order record corresponding to the given room 
     *  record <code> Type. </code> Multiple retrievals return the same 
     *  underlying object. 
     *
     *  @param  roomRecordType a room record type 
     *  @return the room search order record 
     *  @throws org.osid.NullArgumentException <code> roomRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(roomRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.records.RoomSearchOrderRecord getRoomSearchOrderRecord(org.osid.type.Type roomRecordType)
        throws org.osid.OperationFailedException;
}
