//
// org.osid.room.batch.FloorBatchAdminSession
//
//     The OSID Java specification for org.osid.room.batch.FloorBatchAdminSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.room.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Floors </code> in 
 *  bulk. The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Floor, </code> a <code> FloorForm </code> is requested using <code> 
 *  getFloorFormsForCreate() </code> specifying the desired building and 
 *  record <code> Types </code> or none if no record <code> Types </code> are 
 *  needed. Each of the returned <code> FloorForms </code> will indicate that 
 *  it is to be used with a create operation and can be used to examine 
 *  metdata or validate data prior to creation. Once a <code> FloorForm 
 *  </code> is submiited to a create operation, it cannot be reused with 
 *  another create operation unless the first operation was unsuccessful. Each 
 *  <code> FloorForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> FloorForms </code> returned from <code> 
 *  getFloorFormsForCreate() </code> may be linked to the originating request 
 *  through the peer <code> Ids </code> of the <code> FloorForm. </code> In 
 *  the case where there may be duplicates, any <code> FloorForm </code> of 
 *  the same peer <code> Ids </code> may be used for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> FloorForms </code> are submitted for create, a 
 *  <code> CreateResponse </code> is returned for each <code> FloorForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire create operation are returned from <code> createFloors(), 
 *  </code> errors specific to an individual <code> FloorForm </code> are 
 *  indicated in the corresponding <code> CreateResponse. </code> <code> 
 *  CreateResponses </code> may be linked to the originating <code> FloorForm 
 *  </code> through the <code> FloorForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> FloorForms </code> are requested to the <code> 
 *  Floor </code> <code> Id </code> that is to be updated using <code> 
 *  getFloorFormsForUpdate() </code> where the reference <code> Id </code> in 
 *  the <code> FloorForm </code> may be used to link the request. Similarly, 
 *  the <code> FloorForm </code> has metadata about the data that can be 
 *  updated and it can perform validation before submitting the update. The 
 *  <code> FloorForm </code> can only be used once for a successful update and 
 *  cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> FloorForms </code> are submitted for update, an 
 *  <code> UpdateResponse </code> is returned for each <code> FloorForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire update operation are returned from <code> updateFloors(), 
 *  </code> errors specific to an individual <code> FloorForm </code> are 
 *  indicated in the corresponding <code> UpdateResponse. </code> <code> 
 *  UpdateResponses </code> may be linked to the originating <code> FloorForm 
 *  </code> through the <code> FloorForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> Floors </code> in bulk. To unmap a 
 *  <code> Floor </code> from the current <code> Campus, </code> the <code> 
 *  FloorCampusAssignmentSession </code> should be used. These delete 
 *  operations attempt to remove the <code> Floor </code> itself thus removing 
 *  it from all known <code> Campus </code> catalogs. Bulk delete operations 
 *  return the results in <code> DeleteResponses. </code> </p>
 */

public interface FloorBatchAdminSession
    extends org.osid.room.FloorAdminSession {


    /**
     *  Gets the floor forms for creating a bunch of new floors. A FloorForm 
     *  is returned for each building <code> Id. </code> 
     *
     *  @param  buildingIds an <code> Id </code> of a building 
     *  @param  floorRecordTypes array of floor record types to be included in 
     *          each create operation or an empty list if none 
     *  @return the floor forms 
     *  @throws org.osid.NotFoundException a <code> buildingId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> buildingId </code> or 
     *          <code> floorRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.batch.FloorBatchFormList getFloorFormsForCreate(org.osid.id.IdList buildingIds, 
                                                                         org.osid.type.Type[] floorRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Floors. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  floorForms the floor forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> floorForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createFloors(org.osid.room.batch.FloorBatchFormList floorForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the floor forms for updating an existing set of floors. A new 
     *  floor form should be requested for each update transaction. 
     *
     *  @param  floorIds the <code> Ids </code> of the <code> Floor </code> 
     *  @return the floor form 
     *  @throws org.osid.NotFoundException a <code> floorId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> floorIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.batch.FloorBatchFormList getFloorFormsForUpdate(org.osid.id.IdList floorIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing floors. This method returns an error if the entire 
     *  operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  floorForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> floorForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateFloors(org.osid.room.batch.FloorBatchFormList floorForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Floors </code> in this <code> Campus </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllFloors()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes floors for the given <code> Ids. </code> 
     *
     *  @param  floorIds the <code> Ids </code> of the floors to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> floorIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteFloors(org.osid.id.IdList floorIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all floors for the given building. 
     *
     *  @param  buildingId an <code> Id </code> of a building 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> buildingId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteFloorsForBuilding(org.osid.id.Id buildingId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes floors expired before the given date. 
     *
     *  @param  date a date 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteIneffectiveFloorsByDate(org.osid.calendaring.DateTime date)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Floor </code> for the purpose of 
     *  creating compatibility. The primary <code> Id </code> of the <code> 
     *  Floor </code> is determined by the provider. The new <code> Id </code> 
     *  is an alias to the primary <code> Id. </code> If the alias is a 
     *  pointer to another floor, it is reassigned to the given entry <code> 
     *  Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasFloors(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
