//
// org.osid.room.construction.ProjectSearchSession
//
//     The OSID Java specification for org.osid.room.construction.ProjectSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.room.construction;


/**
 *  <p>This session provides methods for searching <code> Project </code> 
 *  objects. The search query is constructed using the <code> ProjectQuery. 
 *  </code> The project record <code> Type </code> also specifies the record 
 *  for the project query. </p> 
 *  
 *  <p> <code> getProjectsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Project </code> elements. A more advanced search 
 *  may be performed with <code> getProjectsBySearch(). </code> It accepts a 
 *  <code> ProjectSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getProjectsBySearch() </code> returns a <code> 
 *  ProjectSearchResults </code> that can be used to access the resulting 
 *  <code> ProjectList </code> or be used to perform a search within the 
 *  result set through <code> ProjectSearch. </code> </p> 
 *  
 *  <p> Projects may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> ProjectQuery. </code> 
 *  The returns in this session may not be cast directly to these interfaces. 
 *  </p>
 */

public interface ProjectSearchSession
    extends org.osid.room.construction.ProjectQuerySession {


    /**
     *  Gets a project search. 
     *
     *  @return the project search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.construction.ProjectSearch getProjectSearch();


    /**
     *  Gets a project search order. The <code> ProjectSearchOrder </code> is 
     *  supplied to a <code> ProjectSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the project search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.construction.ProjectSearchOrder getProjectSearchOrder();


    /**
     *  Gets the search results matching the given search. 
     *
     *  @param  projectQuery the project query 
     *  @param  projectSearch the project search 
     *  @return the project search results 
     *  @throws org.osid.NullArgumentException <code> projectQuery </code> or 
     *          <code> projectSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> projectQuery </code> or 
     *          <code> projectSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.construction.ProjectSearchResults getProjectsBySearch(org.osid.room.construction.ProjectQuery projectQuery, 
                                                                               org.osid.room.construction.ProjectSearch projectSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a project query from an inspector. The inspector is available 
     *  from a <code> ProjectSearchResults. </code> 
     *
     *  @param  projectQueryInspector a query inspector 
     *  @return the project query 
     *  @throws org.osid.NullArgumentException <code> projectQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> projectQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.construction.ProjectQuery getProjectQueryFromInspector(org.osid.room.construction.ProjectQueryInspector projectQueryInspector);
}
