//
// org.osid.room.construction.RenovationSearchSession
//
//     The OSID Java specification for org.osid.room.construction.RenovationSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.room.construction;


/**
 *  <p>This session provides methods for searching <code> Renovation </code> 
 *  objects. The search query is constructed using the <code> RenovationQuery. 
 *  </code> The renovation record <code> Type </code> also specifies the 
 *  record for the renovation query. </p> 
 *  
 *  <p> <code> getRenovationsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Renovation </code> elements. A more advanced 
 *  search may be performed with <code> getRenovationsBySearch(). </code> It 
 *  accepts a <code> RenovationSearch </code> in addition to the query for the 
 *  purpose of specifying additional options affecting the entire search, such 
 *  as ordering. <code> getRenovationeBySearch() </code> returns a <code> 
 *  RenovationSearchResults </code> that can be used to access the resulting 
 *  <code> RenovationList </code> or be used to perform a search within the 
 *  result set through <code> RenovationSearch. </code> </p> 
 *  
 *  <p> Renovations may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> RenovationQuery. 
 *  </code> The returns in this session may not be cast directly to these 
 *  interfaces. </p>
 */

public interface RenovationSearchSession
    extends org.osid.room.construction.RenovationQuerySession {


    /**
     *  Gets a renovation search. 
     *
     *  @return the renovation search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.construction.RenovationSearch getRenovationSearch();


    /**
     *  Gets a renovation search order. The <code> RenovationSearchOrder 
     *  </code> is supplied to a <code> RenovationSearch </code> to specify 
     *  the ordering of results. 
     *
     *  @return the renovation search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.construction.RenovationSearchOrder getRenovationSearchOrder();


    /**
     *  Gets the search results matching the given search. 
     *
     *  @param  renovationQuery the renovation query 
     *  @param  renovationSearch the renovation search 
     *  @return the renovation search results 
     *  @throws org.osid.NullArgumentException <code> renovationQuery </code> 
     *          or <code> renovationSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> renovationQuery </code> 
     *          or <code> renovationSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.construction.RenovationSearchResults getRenovationsBySearch(org.osid.room.construction.RenovationQuery renovationQuery, 
                                                                                     org.osid.room.construction.RenovationSearch renovationSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an entry query from an inspector. The inspector is available from 
     *  an <code> RenovationSearchResults. </code> 
     *
     *  @param  renovationQueryInspector a query inspector 
     *  @return the entry query 
     *  @throws org.osid.NullArgumentException <code> renovationQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> renovationQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.construction.RenovationQuery getRenovationQueryFromInspector(org.osid.room.construction.RenovationQueryInspector renovationQueryInspector);
}
