//
// org.osid.room.construction.RoomConstructionProxyManager
//
//     The OSID Java specification for org.osid.room.construction.RoomConstructionProxyManager.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.room.construction;


/**
 *  <p>The room construction manager provides access to room construction 
 *  sessions and provides interoperability tests for various aspects of this 
 *  service. Methods in this manager accept a <code> Proxy </code> for passing 
 *  information from a server environment. The sessions included in this 
 *  manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> RenovationLookupSession: </code> a session to retrieve 
 *      renovationes </li> 
 *      <li> <code> RenovationQuerySession: </code> a session to query 
 *      renovationes </li> 
 *      <li> <code> RenovationSearchSession: </code> a session to search for 
 *      renovationes </li> 
 *      <li> <code> RenovationAdminSession: </code> a session to create, 
 *      update and delete renovationes </li> 
 *      <li> <code> RenovationNotificationSession: </code> a session to 
 *      receive notifications for changes in renovationes </li> 
 *      <li> <code> RenovationCampusSession: </code> a session to look up 
 *      renovation campus mappings </li> 
 *      <li> <code> RenovationCampusAssignmentSession: </code> a session to 
 *      manage renovation campus mappings </li> 
 *      <li> <code> RenovationSmartCampusSession: </code> a session to manage 
 *      smart campuses of renovationes </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> ProjectLookupSession: </code> a session to retrieve 
 *      projects </li> 
 *      <li> <code> ProjectQuerySession: </code> a session to query projects 
 *      </li> 
 *      <li> <code> ProjectSearchSession: </code> a session to search for 
 *      projects </li> 
 *      <li> <code> ProjectAdminSession: </code> a session to create, update 
 *      and delete projects </li> 
 *      <li> <code> ProjectNotificationSession: </code> a session to receive 
 *      notifications for changes in projects </li> 
 *      <li> <code> ProjectCampusSession: </code> a session to look up project 
 *      campus mappings </li> 
 *      <li> <code> ProjectCampusAssignmentSession: </code> a session to 
 *      manage project campus mappings </li> 
 *      <li> <code> ProjectSmartCampusSession: </code> a session to manage 
 *      smart campuses of projects </li> 
 *  </ul>
 *  
 *  
 *  <p> The room construction manager also provides a profile for determing 
 *  the supported search types supported by this service. </p>
 */

public interface RoomConstructionProxyManager
    extends org.osid.OsidProxyManager,
            org.osid.room.construction.RoomConstructionProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the renovation 
     *  lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RenovationLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRenovationLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRenovationLookup() </code> is <code> true. </code> 
     */

    public org.osid.room.construction.RenovationLookupSession getRenovationLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the renovation 
     *  lookup service for the given campus. 
     *
     *  @param  campusId the <code> Id </code> of the <code> Campus </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RenovationLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Campus </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> campusId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRenovationLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRenovationLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.room.construction.RenovationLookupSession getRenovationLookupSessionForCampus(org.osid.id.Id campusId, 
                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the renovation 
     *  query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RenovationQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRenovationQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRenovationQuery() </code> is <code> true. </code> 
     */

    public org.osid.room.construction.RenovationQuerySession getRenovationQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the renovation 
     *  query service for the given campus. 
     *
     *  @param  campusId the <code> Id </code> of the <code> Campus </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RenovationQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Renovation </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> campusId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRenovationQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRenovationQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.room.construction.RenovationQuerySession getRenovationQuerySessionForCampus(org.osid.id.Id campusId, 
                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the renovation 
     *  search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RenovationSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRenovationSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRenovationSearch() </code> is <code> true. </code> 
     */

    public org.osid.room.construction.RenovationSearchSession getRenovationSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the renovation 
     *  search service for the given campus. 
     *
     *  @param  campusId the <code> Id </code> of the <code> Campus </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RenovationSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Renovation </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> campusId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRenovationSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRenovationSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.room.construction.RenovationSearchSession getRenovationSearchSessionForCampus(org.osid.id.Id campusId, 
                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the renovation 
     *  administrative service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RenovationAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRenovationAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRenovationAdmin() </code> is <code> true. </code> 
     */

    public org.osid.room.construction.RenovationAdminSession getRenovationAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the renovation 
     *  administration service for the given campus. 
     *
     *  @param  campusId the <code> Id </code> of the <code> Campus </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RenovationAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Renovation </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> campusId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRenovationAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRenovationAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.room.construction.RenovationAdminSession getRenovationAdminSessionForCampus(org.osid.id.Id campusId, 
                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the renovation 
     *  notification service. 
     *
     *  @param  renovationReceiver the receiver 
     *  @param  proxy a proxy 
     *  @return a <code> RenovationNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> renovationReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRenovationNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRenovationNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.room.construction.RenovationNotificationSession getRenovationNotificationSession(org.osid.room.construction.RenovationReceiver renovationReceiver, 
                                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the renovation 
     *  notification service for the given campus. 
     *
     *  @param  renovationReceiver the receiver 
     *  @param  campusId the <code> Id </code> of the <code> Campus </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RenovationNotificationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Renovation </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> renovationReceiver, 
     *          campusId </code> or <code> proxy </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRenovationNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRenovationNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.room.construction.RenovationNotificationSession getRenovationNotificationSessionForCampus(org.osid.room.construction.RenovationReceiver renovationReceiver, 
                                                                                                              org.osid.id.Id campusId, 
                                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving renovation to campus mappings. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RenovationCampusSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRenovationCampus() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRenovationCampus() </code> is <code> true. </code> 
     */

    public org.osid.room.construction.RenovationCampusSession getRenovationCampusSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning renovation to campus mappings. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RenovationCampusAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRenovationCampusAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRenovationCampusAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.room.construction.RenovationCampusAssignmentSession getRenovationCampusAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for managing dynamic renovation campuses for the 
     *  given campus. 
     *
     *  @param  campusId the <code> Id </code> of a campus 
     *  @param  proxy a proxy 
     *  @return a <code> RenovationSmartCampusSession </code> 
     *  @throws org.osid.NotFoundException <code> campusId </code> not found 
     *  @throws org.osid.NullArgumentException <code> campusId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRenovationSmartCampus() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRenovationSmartCampus() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.room.construction.RenovationSmartCampusSession getRenovationSmartCampusSession(org.osid.id.Id campusId, 
                                                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the project lookup 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ProjectLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsProjectLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProjectLookup() </code> is <code> true. </code> 
     */

    public org.osid.room.construction.ProjectLookupSession getProjectLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the project lookup 
     *  service for the given campus. 
     *
     *  @param  campusId the <code> Id </code> of the <code> Campus </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ProjectLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Campus </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> campusId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsProjectLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProjectLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.room.construction.ProjectLookupSession getProjectLookupSessionForCampus(org.osid.id.Id campusId, 
                                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the project query 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ProjectQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsProjectQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProjectQuery() </code> is <code> true. </code> 
     */

    public org.osid.room.construction.ProjectQuerySession getProjectQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the project query 
     *  service for the given campus. 
     *
     *  @param  campusId the <code> Id </code> of the <code> Campus </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ProjectQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Project </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> campusId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsProjectQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProjectQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.room.construction.ProjectQuerySession getProjectQuerySessionForCampus(org.osid.id.Id campusId, 
                                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the project search 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ProjectSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsProjectSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProjectSearch() </code> is <code> true. </code> 
     */

    public org.osid.room.construction.ProjectSearchSession getProjectSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the project search 
     *  service for the given campus. 
     *
     *  @param  campusId the <code> Id </code> of the <code> Campus </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ProjectSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Project </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> campusId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsProjectSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProjectSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.room.construction.ProjectSearchSession getProjectSearchSessionForCampus(org.osid.id.Id campusId, 
                                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the project 
     *  administrative service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ProjectAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsProjectAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProjectAdmin() </code> is <code> true. </code> 
     */

    public org.osid.room.construction.ProjectAdminSession getProjectAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the project 
     *  administration service for the given campus. 
     *
     *  @param  campusId the <code> Id </code> of the <code> Campus </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ProjectAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Project </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> campusId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsProjectAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProjectAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.room.construction.ProjectAdminSession getProjectAdminSessionForCampus(org.osid.id.Id campusId, 
                                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the project 
     *  notification service. 
     *
     *  @param  ProjectReceiver the receiver 
     *  @param  proxy a proxy 
     *  @return a <code> ProjectNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> ProjectReceiver </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProjectNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProjectNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.room.construction.ProjectNotificationSession getProjectNotificationSession(org.osid.room.construction.ProjectReceiver ProjectReceiver, 
                                                                                               org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the project 
     *  notification service for the given campus. 
     *
     *  @param  ProjectReceiver the receiver 
     *  @param  campusId the <code> Id </code> of the <code> Campus </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ProjectNotificationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Project </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> ProjectReceiver, 
     *          campusId </code> or <code> proxy </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProjectNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProjectNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.room.construction.ProjectNotificationSession getProjectNotificationSessionForCampus(org.osid.room.construction.ProjectReceiver ProjectReceiver, 
                                                                                                        org.osid.id.Id campusId, 
                                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving project to campus mappings. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ProjectCampusSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsProjectCampus() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProjectCampus() </code> is <code> true. </code> 
     */

    public org.osid.room.construction.ProjectCampusSession getProjectCampusSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning project to campus mappings. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ProjectCampusAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProjectCampusAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProjectCampusAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.room.construction.ProjectCampusAssignmentSession getProjectCampusAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for managing dynamic project campuses for the given 
     *  campus. 
     *
     *  @param  campusId the <code> Id </code> of a campus 
     *  @param  proxy a proxy 
     *  @return a <code> ProjectSmartCampusSession </code> 
     *  @throws org.osid.NotFoundException <code> campusId </code> not found 
     *  @throws org.osid.NullArgumentException <code> campusId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProjectSmartCampus() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProjectSmartCampus() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.room.construction.ProjectSmartCampusSession getProjectSmartCampusSession(org.osid.id.Id campusId, 
                                                                                             org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets a <code> RoomConstructionBatchProxyManager. </code> 
     *
     *  @return a <code> RoomConstructionBatchProxyManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRoomConstructionBatch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRoomConstructionBatch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.room.construction.batch.RoomConstructionBatchProxyManager getRoomConstructionBatchProxyManager()
        throws org.osid.OperationFailedException;
}
