//
// org.osid.room.construction.batch.ProjectBatchAdminSession
//
//     The OSID Java specification for org.osid.room.construction.batch.ProjectBatchAdminSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.room.construction.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Projects </code> in 
 *  bulk. The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Project, </code> a <code> ProjectForm </code> is requested using <code> 
 *  getProjectFormsForCreate() </code> specifying the building and desired 
 *  record <code> Types </code> or none if no record <code> Types </code> are 
 *  needed. Each of the returned <code> ProjectForms </code> will indicate 
 *  that it is to be used with a create operation and can be used to examine 
 *  metdata or validate data prior to creation. Once a <code> ProjectForm 
 *  </code> is submiited to a create operation, it cannot be reused with 
 *  another create operation unless the first operation was unsuccessful. Each 
 *  <code> ProjectForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> ProjectForms </code> returned from <code> 
 *  getProjectFormsForCreate() </code> may be linked to the originating 
 *  request through the peer <code> Ids </code> of the <code> ProjectForm. 
 *  </code> In the case where there may be duplicates, any <code> ProjectForm 
 *  </code> of the same peer <code> Ids </code> may be used for a create 
 *  operation. </p> 
 *  
 *  <p> Once a batch of <code> ProjectForms </code> are submitted for create, 
 *  a <code> CreateResponse </code> is returned for each <code> ProjectForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire create operation are returned from <code> createProjects(), 
 *  </code> errors specific to an individual <code> ProjectForm </code> are 
 *  indicated in the corresponding <code> CreateResponse. </code> <code> 
 *  CreateResponses </code> may be linked to the originating <code> 
 *  ProjectForm </code> through the <code> ProjectForm </code> <code> Id 
 *  </code> . </p> 
 *  
 *  <p> For updates, <code> ProjectForms </code> are requested to the <code> 
 *  Project </code> <code> Id </code> that is to be updated using <code> 
 *  getProjectFormsForUpdate() </code> where the reference <code> Id </code> 
 *  in the <code> ProjectForm </code> may be used to link the request. 
 *  Similarly, the <code> ProjectForm </code> has metadata about the data that 
 *  can be updated and it can perform validation before submitting the update. 
 *  The <code> ProjectForm </code> can only be used once for a successful 
 *  update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> ProjectForms </code> are submitted for update, 
 *  an <code> UpdateResponse </code> is returned for each <code> ProjectForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire update operation are returned from <code> updateProjects(), 
 *  </code> errors specific to an individual <code> ProjectForm </code> are 
 *  indicated in the corresponding <code> UpdateResponse. </code> <code> 
 *  UpdateResponses </code> may be linked to the originating <code> 
 *  ProjectForm </code> through the <code> ProjectForm </code> <code> Id. 
 *  </code> </p> 
 *  
 *  <p> The delete operations delete <code> Projects </code> in bulk. To unmap 
 *  a <code> Project </code> from the current <code> Campus, </code> the 
 *  <code> ProjectCampusAssignmentSession </code> should be used. These delete 
 *  operations attempt to remove the <code> Project </code> itself thus 
 *  removing it from all known <code> Campus </code> catalogs. Bulk delete 
 *  operations return the results in <code> DeleteResponses. </code> </p>
 */

public interface ProjectBatchAdminSession
    extends org.osid.room.construction.ProjectAdminSession {


    /**
     *  Gets the project forms for creating a bunch of new projects. A project 
     *  form is returned for each supplied building. 
     *
     *  @param  buildingIds a list of building <code> Ids </code> 
     *  @param  projectRecordTypes array of project record types to be 
     *          included in each create operation or an empty list if none 
     *  @return the project forms 
     *  @throws org.osid.NotFoundException a <code> buildingId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> buildingid </code> or 
     *          <code> projectRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.construction.batch.ProjectBatchFormList getProjectFormsForCreate(org.osid.id.IdList buildingIds, 
                                                                                          org.osid.type.Type[] projectRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Projects. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  projectForms the project forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> projectForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createProjects(org.osid.room.construction.batch.ProjectBatchFormList projectForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the project forms for updating an existing set of projects. A new 
     *  project form should be requested for each update transaction. 
     *
     *  @param  projectIds the <code> Ids </code> of the <code> Project 
     *          </code> 
     *  @return the project form 
     *  @throws org.osid.NotFoundException a <code> projectId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> projectIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.construction.batch.ProjectBatchFormList getProjectFormsForUpdate(org.osid.id.IdList projectIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing projects. This method returns an error if the entire 
     *  operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  projectForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> projectForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateProjects(org.osid.room.construction.batch.ProjectBatchFormList projectForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Projects </code> in this <code> Campus </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllProjects()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes projects for the given <code> Ids. </code> 
     *
     *  @param  projectIds the <code> Ids </code> of the projects to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> projectIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteProjects(org.osid.id.IdList projectIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all projects for a building. 
     *
     *  @param  buildingId a building <code> Id </code> 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> buildingId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteProjectsForBuilding(org.osid.id.Id buildingId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes projects expired before the given date. 
     *
     *  @param  date a date 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteIneffectiveProjectsByDate(org.osid.calendaring.DateTime date)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Project </code> for the purpose 
     *  of creating compatibility. The primary <code> Id </code> of the <code> 
     *  Project </code> is determined by the provider. The new <code> Id 
     *  </code> is an alias to the primary <code> Id. </code> If the alias is 
     *  a pointer to another project, it is reassigned to the given entry 
     *  <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasProjects(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
