//
// org.osid.room.construction.batch.RenovationBatchAdminSession
//
//     The OSID Java specification for org.osid.room.construction.batch.RenovationBatchAdminSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.room.construction.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Renovations </code> 
 *  in bulk. The data for create and update is provided by the consumer via 
 *  the form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Renovation, </code> a <code> RenovationForm </code> is requested using 
 *  <code> getRenovationFormsForCreate() </code> specifying the desired record 
 *  <code> Types </code> or none if no record <code> Types </code> are needed. 
 *  Each of the returned <code> RenovationForms </code> will indicate that it 
 *  is to be used with a create operation and can be used to examine metdata 
 *  or validate data prior to creation. Once a <code> RenovationForm </code> 
 *  is submiited to a create operation, it cannot be reused with another 
 *  create operation unless the first operation was unsuccessful. Each <code> 
 *  RenovationForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> RenovationForms </code> returned from <code> 
 *  getRenovationFormsForCreate() </code> may be linked to the originating 
 *  request through the peer <code> Ids </code> of the <code> RenovationForm. 
 *  </code> In the case where there may be duplicates, any <code> 
 *  RenovationForm </code> of the same peer <code> Ids </code> may be used for 
 *  a create operation. </p> 
 *  
 *  <p> Once a batch of <code> RenovationForms </code> are submitted for 
 *  create, a <code> CreateResponse </code> is returned for each <code> 
 *  RenovationForm, </code> although the ordering is not defined. Only errors 
 *  that pertain to the entire create operation are returned from <code> 
 *  createRenovations(), </code> errors specific to an individual <code> 
 *  RenovationForm </code> are indicated in the corresponding <code> 
 *  CreateResponse. </code> <code> CreateResponses </code> may be linked to 
 *  the originating <code> RenovationForm </code> through the <code> 
 *  RenovationForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> RenovationForms </code> are requested to the 
 *  <code> Renovation </code> <code> Id </code> that is to be updated using 
 *  <code> getRenovationFormsForUpdate() </code> where the reference <code> Id 
 *  </code> in the <code> RenovationForm </code> may be used to link the 
 *  request. Similarly, the <code> RenovationForm </code> has metadata about 
 *  the data that can be updated and it can perform validation before 
 *  submitting the update. The <code> RenovationForm </code> can only be used 
 *  once for a successful update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> RenovationForms </code> are submitted for 
 *  update, an <code> UpdateResponse </code> is returned for each <code> 
 *  RenovationForm, </code> although the ordering is not defined. Only errors 
 *  that pertain to the entire update operation are returned from <code> 
 *  updateRenovations(), </code> errors specific to an individual <code> 
 *  RenovationForm </code> are indicated in the corresponding <code> 
 *  UpdateResponse. </code> <code> UpdateResponses </code> may be linked to 
 *  the originating <code> RenovationForm </code> through the <code> 
 *  RenovationForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> Renovations </code> in bulk. To 
 *  unmap a <code> Renovation </code> from the current <code> Campus, </code> 
 *  the <code> RenovationCampusAssignmentSession </code> should be used. These 
 *  delete operations attempt to remove the <code> Renovation </code> itself 
 *  thus removing it from all known <code> Campus </code> catalogs. Bulk 
 *  delete operations return the results in <code> DeleteResponses. </code> 
 *  </p>
 */

public interface RenovationBatchAdminSession
    extends org.osid.room.construction.RenovationAdminSession {


    /**
     *  Gets the renovation forms for creating a bunch of new renovations. 
     *
     *  @param  number the number of forms to retrieve 
     *  @param  renovationRecordTypes array of renovation record types to be 
     *          included in each create operation or an empty list if none 
     *  @return the renovation forms 
     *  @throws org.osid.NullArgumentException <code> renovationRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.construction.batch.RenovationBatchFormList getRenovationFormsForCreate(long number, 
                                                                                                org.osid.type.Type[] renovationRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Renovations. </code> This method returns 
     *  an error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  renovationForms the renovation forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> renovationForms </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createRenovations(org.osid.room.construction.batch.RenovationBatchFormList renovationForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the renovation forms for updating an existing set of renovations. 
     *  A new renovation form should be requested for each update transaction. 
     *
     *  @param  renovationIds the <code> Ids </code> of the <code> Renovation 
     *          </code> 
     *  @return the renovation form 
     *  @throws org.osid.NotFoundException a <code> renovationId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> renovationIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.construction.batch.RenovationBatchFormList getRenovationFormsForUpdate(org.osid.id.IdList renovationIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing renovations. This method returns an error if the 
     *  entire operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  renovationForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> renovationForms </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateRenovations(org.osid.room.construction.batch.RenovationBatchFormList renovationForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Renovations </code> in this <code> Campus </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllRenovations()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes renovations for the given <code> Ids. </code> 
     *
     *  @param  renovationIds the <code> Ids </code> of the renovations to 
     *          delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> renovationIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteRenovations(org.osid.id.IdList renovationIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes renovations expired before the given date. 
     *
     *  @param  date a date 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteIneffectiveRenovationsByDate(org.osid.calendaring.DateTime date)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Renovation </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Renovation </code> is determined by the provider. The new 
     *  <code> Id </code> is an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another renovation, it is reassigned to the 
     *  given entry <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasRenovations(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
