//
// org.osid.room.squatting.DeedLookupSession
//
//     The OSID Java specification for org.osid.room.squatting.DeedLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.room.squatting;


/**
 *  <p>This session provides methods for retrieving <code> Deed </code> 
 *  objects. The <code> Deed </code> represents a relationship between an 
 *  owner and a building. </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated campus view: All room methods in this session operate, 
 *      retrieve and pertain to deeds defined explicitly in the current 
 *      campus. Using an isolated view is useful for managing deeds with the 
 *      <code> DeedAdminSession. </code> </li> 
 *      <li> federated campus view: All deed lookup methods in this session 
 *      operate, retrieve and pertain to all deeds defined in this campus and 
 *      any other campuses implicitly available in this campus through campus 
 *      inheritence. </li> 
 *      <li> effective deed view: All deed lookup methods return effective 
 *      deeds. </li> 
 *      <li> any effective deed view: deeds of any effective date are 
 *      returned. </li> 
 *  </ul>
 *  
 */

public interface DeedLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Campus </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Campus Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCampusId();


    /**
     *  Gets the <code> Campus </code> associated with this session. 
     *
     *  @return the campus 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.Campus getCampus()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Deed </code> lookups. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not offer lookup operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupDeeds();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeDeedView();


    /**
     *  A complete view of the <code> Deed </code> returns is desired. Methods 
     *  will return what is requested or result in an error. This view is used 
     *  when greater precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryDeedView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include deeds in campuses which are children of this campus in the 
     *  campus hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCampusView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this campus only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCampusView();


    /**
     *  Only deeds whose effective dates are current are returned by methods 
     *  in this session 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useEffectiveDeedView();


    /**
     *  Deeds of any effective dates are returned by all methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyEffectiveDeedView();


    /**
     *  Gets the <code> Deed </code> specified by its <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Deed </code> may have a different <code> Id </code> than requested, 
     *  such as the case where a duplicate <code> Id </code> was assigned to a 
     *  <code> Deed </code> and retained for compatibility. 
     *  
     *  In effective mode, deeds are returned that are currently effective. In 
     *  any effective mode, effective deeds and those currently expired are 
     *  returned. 
     *
     *  @param  deedId <code> Id </code> of the <code> Deed </code> 
     *  @return the deed 
     *  @throws org.osid.NotFoundException <code> deedId </code> not found 
     *  @throws org.osid.NullArgumentException <code> deedId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.room.squatting.Deed getDeed(org.osid.id.Id deedId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> DeedList </code> corresponding to the given <code> 
     *  IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  deeds specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Deeds </code> may be omitted from the list and may 
     *  present the elements in any order including returning a unique set. 
     *  
     *  In effective mode, deeds are returned that are currently effective. In 
     *  any effective mode, effective deeds and those currently expired are 
     *  returned. 
     *
     *  @param  deedIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Deed </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> deedIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.squatting.DeedList getDeedsByIds(org.osid.id.IdList deedIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> DeedList </code> corresponding to the given deed genus 
     *  <code> Type </code> which does not include deeds of genus types 
     *  derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  deeds or an error results. Otherwise, the returned list may contain 
     *  only those deeds that are accessible through this session. 
     *  
     *  In effective mode, deeds are returned that are currently effective. In 
     *  any effective mode, effective deeds and those currently expired are 
     *  returned. 
     *
     *  @param  deedGenusType a deed genus type 
     *  @return the returned <code> Deed </code> list 
     *  @throws org.osid.NullArgumentException <code> deedGenusType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.squatting.DeedList getDeedsByGenusType(org.osid.type.Type deedGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> DeedList </code> corresponding to the given deed genus 
     *  <code> Type </code> and include any additional deeds with genus types 
     *  derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  deeds or an error results. Otherwise, the returned list may contain 
     *  only those deeds that are accessible through this session. 
     *  
     *  In effective mode, deeds are returned that are currently effective. In 
     *  any effective mode, effective deeds and those currently expired are 
     *  returned. 
     *
     *  @param  deedGenusType a deed genus type 
     *  @return the returned <code> Deed </code> list 
     *  @throws org.osid.NullArgumentException <code> deedGenusType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.squatting.DeedList getDeedsByParentGenusType(org.osid.type.Type deedGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> DeedList </code> containing the given deed record <code> 
     *  Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  deeds or an error results. Otherwise, the returned list may contain 
     *  only those deeds that are accessible through this session. 
     *  
     *  In effective mode, deeds are returned that are currently effective. In 
     *  any effective mode, effective deeds and those currently expired are 
     *  returned. 
     *
     *  @param  deedRecordType a deed record type 
     *  @return the returned <code> Deed </code> list 
     *  @throws org.osid.NullArgumentException <code> deedRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.squatting.DeedList getDeedsByRecordType(org.osid.type.Type deedRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all deeds effective during the entire given date range 
     *  inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known deeds or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  deeds that are accessible through this session. 
     *  
     *  In effective mode, deeds are returned that are currently effective. In 
     *  any effective mode, effective deeds and those currently expired are 
     *  returned. 
     *
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Deed </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.squatting.DeedList getDeedsOnDate(org.osid.calendaring.DateTime from, 
                                                           org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all deeds with a genus type and effective during the 
     *  entire given date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known deeds or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  deeds that are accessible through this session. 
     *  
     *  In effective mode, deeds are returned that are currently effective. In 
     *  any effective mode, effective deeds and those currently expired are 
     *  returned. 
     *
     *  @param  deedGenusType a deed genus type 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Deed </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> deedGenusType, from 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.squatting.DeedList getDeedsByGenusTypeOnDate(org.osid.type.Type deedGenusType, 
                                                                      org.osid.calendaring.DateTime from, 
                                                                      org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> DeedList </code> containing the given building <code> . 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  deeds or an error results. Otherwise, the returned list may contain 
     *  only those deeds that are accessible through this session. 
     *  
     *  In effective mode, deeds are returned that are currently effective. In 
     *  any effective mode, effective deeds and those currently expired are 
     *  returned. 
     *
     *  @param  buildingId a building <code> Id </code> 
     *  @return the returned <code> Deed </code> list 
     *  @throws org.osid.NullArgumentException <code> buildingId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.squatting.DeedList getDeedsForBuilding(org.osid.id.Id buildingId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> DeedList </code> containing the given building and genus 
     *  type <code> . </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  deeds or an error results. Otherwise, the returned list may contain 
     *  only those deeds that are accessible through this session. 
     *  
     *  In effective mode, deeds are returned that are currently effective. In 
     *  any effective mode, effective deeds and those currently expired are 
     *  returned. 
     *
     *  @param  buildingId a building <code> Id </code> 
     *  @param  deedGenusType a deed genus type 
     *  @return the returned <code> Deed </code> list 
     *  @throws org.osid.NullArgumentException <code> buildingId </code> or 
     *          <code> deedGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.squatting.DeedList getDeedsByGenusTypeForBuilding(org.osid.id.Id buildingId, 
                                                                           org.osid.type.Type deedGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all deeds for a building effective during the entire 
     *  given date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known deeds or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  deeds that are accessible through this session. 
     *  
     *  In effective mode, deeds are returned that are currently effective. In 
     *  any effective mode, effective deeds and those currently expired are 
     *  returned. 
     *
     *  @param  buildingId a building <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Deed </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> buildingId, from </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.squatting.DeedList getDeedsForBuildingOnDate(org.osid.id.Id buildingId, 
                                                                      org.osid.calendaring.DateTime from, 
                                                                      org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all deeds for a building with a genus type and 
     *  effective during the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known deeds or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  deeds that are accessible through this session. 
     *  
     *  In effective mode, deeds are returned that are currently effective. In 
     *  any effective mode, effective deeds and those currently expired are 
     *  returned. 
     *
     *  @param  buildingId a building <code> Id </code> 
     *  @param  deedGenusType a deed genus type 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Deed </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> buildingId, 
     *          deedGenusType, from </code> or <code> to </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.squatting.DeedList getDeedsByGenusTypeForBuildingOnDate(org.osid.id.Id buildingId, 
                                                                                 org.osid.type.Type deedGenusType, 
                                                                                 org.osid.calendaring.DateTime from, 
                                                                                 org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> DeedList </code> containing the given owner resource. 
     *  <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  deeds or an error results. Otherwise, the returned list may contain 
     *  only those deeds that are accessible through this session. 
     *  
     *  In effective mode, deeds are returned that are currently effective. In 
     *  any effective mode, effective deeds and those currently expired are 
     *  returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @return the returned <code> Deed </code> list 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.squatting.DeedList getDeedsForOwner(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> DeedList </code> containing the given owner and genus 
     *  type <code> . </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  deeds or an error results. Otherwise, the returned list may contain 
     *  only those deeds that are accessible through this session. 
     *  
     *  In effective mode, deeds are returned that are currently effective. In 
     *  any effective mode, effective deeds and those currently expired are 
     *  returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  deedGenusType a deed genus type 
     *  @return the returned <code> Deed </code> list 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> or 
     *          <code> deedGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.squatting.DeedList getDeedsByGenusTypeForOwner(org.osid.id.Id resourceId, 
                                                                        org.osid.type.Type deedGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all deeds for an owner resource effective during the 
     *  entire given date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known deeds or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  deeds that are accessible through this session. 
     *  
     *  In effective mode, deeds are returned that are currently effective. In 
     *  any effective mode, effective deeds and those currently expired are 
     *  returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Deed </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, from </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.squatting.DeedList getDeedsForOwnerOnDate(org.osid.id.Id resourceId, 
                                                                   org.osid.calendaring.DateTime from, 
                                                                   org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all deeds for a resource owner with a genus type and 
     *  effective during the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known deeds or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  deeds that are accessible through this session. 
     *  
     *  In effective mode, deeds are returned that are currently effective. In 
     *  any effective mode, effective deeds and those currently expired are 
     *  returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  deedGenusType a deed genus type 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Deed </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, 
     *          deedGenusType, from </code> or <code> to </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.squatting.DeedList getDeedsByGenusTypeForOwnerOnDate(org.osid.id.Id resourceId, 
                                                                              org.osid.type.Type deedGenusType, 
                                                                              org.osid.calendaring.DateTime from, 
                                                                              org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> DeedList </code> for the given building and owner. 
     *  <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  deeds or an error results. Otherwise, the returned list may contain 
     *  only those deeds that are accessible through this session. 
     *  
     *  In effective mode, deeds are returned that are currently effective. In 
     *  any effective mode, effective deeds and those currently expired are 
     *  returned. 
     *
     *  @param  buildingId a building <code> Id </code> 
     *  @param  resourceId a resource <code> Id </code> 
     *  @return the returned <code> Deed </code> list 
     *  @throws org.osid.NullArgumentException <code> buildingId </code> or 
     *          <code> resourceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.squatting.DeedList getDeedsForBuildingAndOwner(org.osid.id.Id buildingId, 
                                                                        org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> DeedList </code> for the given buildin, owner, and genus 
     *  type <code> . </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  deeds or an error results. Otherwise, the returned list may contain 
     *  only those deeds that are accessible through this session. 
     *  
     *  In effective mode, deeds are returned that are currently effective. In 
     *  any effective mode, effective deeds and those currently expired are 
     *  returned. 
     *
     *  @param  buildingId a building <code> Id </code> 
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  deedGenusType a deed genus type 
     *  @return the returned <code> Deed </code> list 
     *  @throws org.osid.NullArgumentException <code> buildingId, resourceId, 
     *          </code> or <code> deedGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.squatting.DeedList getDeedsByGenusTypeForBuildingAndOwner(org.osid.id.Id buildingId, 
                                                                                   org.osid.id.Id resourceId, 
                                                                                   org.osid.type.Type deedGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all deeds for a building and owner resource effective 
     *  during the entire given date range inclusive but not confined to the 
     *  date range. 
     *  
     *  In plenary mode, the returned list contains all known deeds or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  deeds that are accessible through this session. 
     *  
     *  In effective mode, deeds are returned that are currently effective. In 
     *  any effective mode, effective deeds and those currently expired are 
     *  returned. 
     *
     *  @param  buildingId a building <code> Id </code> 
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Deed </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> buildingId, resourceId, 
     *          from, </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.squatting.DeedList getDeedsForBuildingAndOwnerOnDate(org.osid.id.Id buildingId, 
                                                                              org.osid.id.Id resourceId, 
                                                                              org.osid.calendaring.DateTime from, 
                                                                              org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all deeds for a building and owner with a genus type 
     *  and effective during the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known deeds or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  deeds that are accessible through this session. 
     *  
     *  In effective mode, deeds are returned that are currently effective. In 
     *  any effective mode, effective deeds and those currently expired are 
     *  returned. 
     *
     *  @param  buildingId a building <code> Id </code> 
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  deedGenusType a deed genus type 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Deed </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> buildingId, resourceId, 
     *          deedGenusType, from, </code> or <code> to </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.squatting.DeedList getDeedsByGenusTypeForBuildingAndOwnerOnDate(org.osid.id.Id buildingId, 
                                                                                         org.osid.id.Id resourceId, 
                                                                                         org.osid.type.Type deedGenusType, 
                                                                                         org.osid.calendaring.DateTime from, 
                                                                                         org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Deeds. </code> 
     *  
     *  In plenary mode, the returned list contains all known deeds or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  deeds that are accessible through this session. 
     *  
     *  In effective mode, deeds are returned that are currently effective. In 
     *  any effective mode, effective deeds and those currently expired are 
     *  returned. 
     *
     *  @return a list of <code> Deeds </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.squatting.DeedList getDeeds()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
