//
// org.osid.room.squatting.RoomSquattingManager
//
//     The OSID Java specification for org.osid.room.squatting.RoomSquattingManager.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.room.squatting;


/**
 *  <p>The room squatting manager provides access to room squatting sessions 
 *  and provides interoperability tests for various aspects of this service. 
 *  The sessions included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> LeaseLookupSession: </code> a session to retrieve leasees 
 *      </li> 
 *      <li> <code> LeaseQuerySession: </code> a session to query leasees 
 *      </li> 
 *      <li> <code> LeaseSearchSession: </code> a session to search for 
 *      leasees </li> 
 *      <li> <code> LeaseAdminSession: </code> a session to create, update and 
 *      delete leasees </li> 
 *      <li> <code> LeaseNotificationSession: </code> a session to receive 
 *      notifications for changes in leasees </li> 
 *      <li> <code> LeaseCampusSession: </code> a session to look up lease 
 *      campus mappings </li> 
 *      <li> <code> LeaseCampusAssignmentSession: </code> a session to manage 
 *      lease campus mappings </li> 
 *      <li> <code> LeaseSmartCampusSession: </code> a session to manage smart 
 *      campuses of leasees </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> DeedLookupSession: </code> a session to retrieve deeds 
 *      </li> 
 *      <li> <code> DeedQuerySession: </code> a session to query deeds </li> 
 *      <li> <code> DeedSearchSession: </code> a session to search for deeds 
 *      </li> 
 *      <li> <code> DeedAdminSession: </code> a session to create, update and 
 *      delete deeds </li> 
 *      <li> <code> DeedNotificationSession: </code> a session to receive 
 *      notifications for changes in deeds </li> 
 *      <li> <code> DeedCampusSession: </code> a session to look up deed 
 *      campus mappings </li> 
 *      <li> <code> DeedCampusAssignmentSession: </code> a session to manage 
 *      deed campus mappings </li> 
 *      <li> <code> DeedSmartCampusSession: </code> a session to manage smart 
 *      campuses of deeds </li> 
 *  </ul>
 *  
 *  
 *  <p> The room squatting manager also provides a profile for determing the 
 *  supported search types supported by this service. </p>
 */

public interface RoomSquattingManager
    extends org.osid.OsidManager,
            org.osid.room.squatting.RoomSquattingProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the lease lookup 
     *  service. 
     *
     *  @return a <code> LeaseLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsLeaseLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLeaseLookup() </code> is <code> true. </code> 
     */

    public org.osid.room.squatting.LeaseLookupSession getLeaseLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the lease lookup 
     *  service for the given campus. 
     *
     *  @param  campusId the <code> Id </code> of the <code> Lease </code> 
     *  @return a <code> LeaseLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Campus </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> campusId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsLeaseLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLeaseLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.room.squatting.LeaseLookupSession getLeaseLookupSessionForCampus(org.osid.id.Id campusId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the lease query 
     *  service. 
     *
     *  @return a <code> LeaseQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsLeaseQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLeaseQuery() </code> is <code> true. </code> 
     */

    public org.osid.room.squatting.LeaseQuerySession getLeaseQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the lease query 
     *  service for the given campus. 
     *
     *  @param  campusId the <code> Id </code> of the <code> Lease </code> 
     *  @return a <code> LeaseQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Campus </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> campusId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsLeaseQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLeaseQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.room.squatting.LeaseQuerySession getLeaseQuerySessionForCampus(org.osid.id.Id campusId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the lease search 
     *  service. 
     *
     *  @return a <code> LeaseSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsLeaseSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLeaseSearch() </code> is <code> true. </code> 
     */

    public org.osid.room.squatting.LeaseSearchSession getLeaseSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the lease search 
     *  service for the given campus. 
     *
     *  @param  campusId the <code> Id </code> of the <code> Lease </code> 
     *  @return a <code> LeaseSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Campus </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> campusId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsLeaseSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLeaseSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.room.squatting.LeaseSearchSession getLeaseSearchSessionForCampus(org.osid.id.Id campusId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the lease 
     *  administrative service. 
     *
     *  @return a <code> LeaseAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsLeaseAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLeaseAdmin() </code> is <code> true. </code> 
     */

    public org.osid.room.squatting.LeaseAdminSession getLeaseAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the lease 
     *  administrative service for the given campus. 
     *
     *  @param  campusId the <code> Id </code> of the <code> Lease </code> 
     *  @return a <code> LeaseAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Campus </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> campusId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsLeaseAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLeaseAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.room.squatting.LeaseAdminSession getLeaseAdminSessionForCampus(org.osid.id.Id campusId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the lease 
     *  notification service. 
     *
     *  @param  leaseReceiver the receiver 
     *  @return a <code> LeaseNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> leaseReceiver </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsLeaseNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLeaseNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.room.squatting.LeaseNotificationSession getLeaseNotificationSession(org.osid.room.squatting.LeaseReceiver leaseReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the lease 
     *  notification service for the given campus. 
     *
     *  @param  leaseReceiver the receiver 
     *  @param  campusId the <code> Id </code> of the <code> Campus </code> 
     *  @return a <code> LeaseNotificationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Campus </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> leaseReceiver </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsLeaseNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLeaseNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.room.squatting.LeaseNotificationSession getLeaseNotificationSessionForCampus(org.osid.room.squatting.LeaseReceiver leaseReceiver, 
                                                                                                 org.osid.id.Id campusId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving lease to campus mappings. 
     *
     *  @return a <code> LeaseCampusSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsLeaseCampus() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLeaseCampus() </code> is <code> true. </code> 
     */

    public org.osid.room.squatting.LeaseCampusSession getLeaseCampusSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning lease to campus mappings. 
     *
     *  @return a <code> LeaseCampusAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsLeaseCampusAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLeaseCampusAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.room.squatting.LeaseCampusAssignmentSession getLeaseCampusAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session associated with the lease smart campus for the given 
     *  campus. 
     *
     *  @param  campusId the <code> Id </code> of the campus 
     *  @return a <code> LeaseSmartCampusSession </code> 
     *  @throws org.osid.NotFoundException <code> campusId </code> not found 
     *  @throws org.osid.NullArgumentException <code> campusId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsLeaseSmartCampus() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLeaseSmartCampus() </code> is <code> true. </code> 
     */

    public org.osid.room.squatting.LeaseSmartCampusSession getLeaseSmartCampusSession(org.osid.id.Id campusId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the deed lookup 
     *  service. 
     *
     *  @return a <code> DeedLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsDeedLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDeedLookup() </code> is <code> true. </code> 
     */

    public org.osid.room.squatting.DeedLookupSession getDeedLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the deed lookup 
     *  service for the given campus. 
     *
     *  @param  campusId the <code> Id </code> of the <code> Deed </code> 
     *  @return a <code> DeedLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Campus </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> campusId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsDeedLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDeedLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.room.squatting.DeedLookupSession getDeedLookupSessionForCampus(org.osid.id.Id campusId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the deed query 
     *  service. 
     *
     *  @return a <code> DeedQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsDeedQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDeedQuery() </code> is <code> true. </code> 
     */

    public org.osid.room.squatting.DeedQuerySession getDeedQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the deed query 
     *  service for the given campus. 
     *
     *  @param  campusId the <code> Id </code> of the <code> Deed </code> 
     *  @return a <code> DeedQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Campus </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> campusId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsDeedQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDeedQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.room.squatting.DeedQuerySession getDeedQuerySessionForCampus(org.osid.id.Id campusId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the deed search 
     *  service. 
     *
     *  @return a <code> DeedSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsDeedSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDeedSearch() </code> is <code> true. </code> 
     */

    public org.osid.room.squatting.DeedSearchSession getDeedSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the deed search 
     *  service for the given campus. 
     *
     *  @param  campusId the <code> Id </code> of the <code> Deed </code> 
     *  @return a <code> DeedSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Campus </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> campusId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsDeedSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDeedSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.room.squatting.DeedSearchSession getDeedSearchSessionForCampus(org.osid.id.Id campusId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the deed 
     *  administrative service. 
     *
     *  @return a <code> DeedAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsDeedAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDeedAdmin() </code> is <code> true. </code> 
     */

    public org.osid.room.squatting.DeedAdminSession getDeedAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the deed 
     *  administrative service for the given campus. 
     *
     *  @param  campusId the <code> Id </code> of the <code> Deed </code> 
     *  @return a <code> DeedAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Campus </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> campusId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsDeedAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDeedAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.room.squatting.DeedAdminSession getDeedAdminSessionForCampus(org.osid.id.Id campusId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the deed 
     *  notification service. 
     *
     *  @param  DeedReceiver the receiver 
     *  @return a <code> DeedNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> DeedReceiver </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDeedNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDeedNotification() </code> is <code> true. </code> 
     */

    public org.osid.room.squatting.DeedNotificationSession getDeedNotificationSession(org.osid.room.squatting.DeedReceiver DeedReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the deed 
     *  notification service for the given campus. 
     *
     *  @param  DeedReceiver the receiver 
     *  @param  campusId the <code> Id </code> of the <code> Campus </code> 
     *  @return a <code> DeedNotificationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Campus </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> DeedReceiver </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDeedNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDeedNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.room.squatting.DeedNotificationSession getDeedNotificationSessionForCampus(org.osid.room.squatting.DeedReceiver DeedReceiver, 
                                                                                               org.osid.id.Id campusId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving deed to campus mappings. 
     *
     *  @return a <code> DeedCampusSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsDeedCampus() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDeedCampus() </code> is <code> true. </code> 
     */

    public org.osid.room.squatting.DeedCampusSession getDeedCampusSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning deed to campus mappings. 
     *
     *  @return a <code> DeedCampusAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDeedCampusAssignment() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDeedCampusAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.room.squatting.DeedCampusAssignmentSession getDeedCampusAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session associated with the deed smart campus for the given 
     *  campus. 
     *
     *  @param  campusId the <code> Id </code> of the campus 
     *  @return a <code> DeedSmartCampusSession </code> 
     *  @throws org.osid.NotFoundException <code> campusId </code> not found 
     *  @throws org.osid.NullArgumentException <code> campusId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDeedSmartCampus() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDeedSmartCampus() </code> is <code> true. </code> 
     */

    public org.osid.room.squatting.DeedSmartCampusSession getDeedSmartCampusSession(org.osid.id.Id campusId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets a <code> RoomSquattingBatchManager. </code> 
     *
     *  @return a <code> RoomSquattingBatchManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRoomSquattingBatch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRoomSquattingBatch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.room.squatting.batch.RoomSquattingBatchManager getRoomSquattingBatchManager()
        throws org.osid.OperationFailedException;
}
