//
// org.osid.rules.RuleSearchSession
//
//     The OSID Java specification for org.osid.rules.RuleSearchSession.
//
// Copyright (C) 2009 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.rules;


/**
 *  <p>This session provides methods for searching <code> Rule </code> 
 *  objects. The search query is constructed using the <code> RuleQuery. 
 *  </code> The rule record <code> Type </code> also specifies the record for 
 *  the rule query. </p> 
 *  
 *  <p> <code> getRulesByQuery() </code> is the basic search method and 
 *  returns a list of <code> Rule </code> elements. A more advanced search may 
 *  be performed with <code> getRulesBySearch(). </code> It accepts a <code> 
 *  RuleSearch </code> in addition to the query for the purpose of specifying 
 *  additional options affecting the entire search, such as ordering. <code> 
 *  getRulesBySearch() </code> returns a <code> RuleSearchResults </code> that 
 *  can be used to access the resulting <code> RuleList </code> or be used to 
 *  perform a search within the result set through <code> RuleSearch. </code> 
 *  </p> 
 *  
 *  <p> Rules may have a query record indicated by their respective record 
 *  types. The rule query record is accessed via the <code> RuleQuery. </code> 
 *  The returns in this session may not be cast directly to these interfaces. 
 *  </p>
 */

public interface RuleSearchSession
    extends org.osid.rules.RuleQuerySession {


    /**
     *  Gets a rule search. 
     *
     *  @return the rule search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.RuleSearch getRuleSearch();


    /**
     *  Gets a rule search order. The <code> RuleSearchOrder </code> is 
     *  supplied to a <code> RuleSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the rule search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.RuleSearchOrder getRuleSearchOrder();


    /**
     *  Gets the search results matching the given search. 
     *
     *  @param  ruleQuery the rule query 
     *  @param  ruleSearch the rule search 
     *  @return the search results 
     *  @throws org.osid.NullArgumentException <code> ruleQuery </code> or 
     *          <code> ruleSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> ruleQuery </code> or 
     *          <code> ruleSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.RuleSearchResults getRulesBySearch(org.osid.rules.RuleQuery ruleQuery, 
                                                             org.osid.rules.RuleSearch ruleSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a rule query from an inspector. The inspector is available from a 
     *  <code> RuleSearchResults. </code> 
     *
     *  @param  ruleQueryInspector a rule query inspector 
     *  @return the rule query 
     *  @throws org.osid.NullArgumentException <code> ruleQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> ruleQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.RuleQuery getRuleQueryFromInspector(org.osid.rules.RuleQueryInspector ruleQueryInspector);
}
