//
// org.osid.rules.check.AgendaEngineAssignmentSession
//
//     The OSID Java specification for org.osid.rules.check.AgendaEngineAssignmentSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.rules.check;


/**
 *  <p>This session provides methods to re-assign <code> Agendas </code> to 
 *  <code> Engine </code> mappings. An <code> Agenda </code> may appear in 
 *  multiple <code> Engine </code> objects and removing the last reference to 
 *  an <code> Agenda </code> is the equivalent of deleting it. Each <code> 
 *  Engine </code> may have its own authorizations governing who is allowed to 
 *  operate on it. </p> 
 *  
 *  <p> Adding a reference of an <code> Agenda </code> to another <code> 
 *  Engine </code> is not a copy operation (eg: does not change its <code> Id 
 *  </code> ). </p>
 */

public interface AgendaEngineAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter agenda/engine mappings. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if check is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignAgendas();


    /**
     *  Tests if this user can alter agenda/engine mappings. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @param  engineId the <code> Id </code> of the <code> Engine </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> engineId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignAgendasToEngine(org.osid.id.Id engineId);


    /**
     *  Gets a list of engines including and under the given engine node in 
     *  which any agenda can be assigned. 
     *
     *  @param  engineId the <code> Id </code> of the <code> Engine </code> 
     *  @return list of assignable engine <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> engineId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableEngineIds(org.osid.id.Id engineId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of engines including and under the given engine node in 
     *  which a specific agenda can be assigned. 
     *
     *  @param  engineId the <code> Id </code> of the <code> Engine </code> 
     *  @param  agendaId the <code> Id </code> of the <code> Agenda </code> 
     *  @return list of assignable engine <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> engineId </code> or 
     *          <code> agendaId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableEngineIdsForAgenda(org.osid.id.Id engineId, 
                                                              org.osid.id.Id agendaId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> Agenda </code> to a <code> Engine. </code> 
     *
     *  @param  agendaId the <code> Id </code> of the <code> Agenda </code> 
     *  @param  engineId the <code> Id </code> of the <code> Engine </code> 
     *  @throws org.osid.AlreadyExistsException <code> agendaId </code> is 
     *          already assigned to <code> engineId </code> 
     *  @throws org.osid.NotFoundException <code> agendaId </code> or <code> 
     *          engineId </code> not found 
     *  @throws org.osid.NullArgumentException <code> agendaId </code> or 
     *          <code> engineId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignAgendaToEngine(org.osid.id.Id agendaId, 
                                     org.osid.id.Id engineId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes an <code> Agenda </code> from a <code> Engine. </code> 
     *
     *  @param  agendaId the <code> Id </code> of the <code> Agenda </code> 
     *  @param  engineId the <code> Id </code> of the <code> Engine </code> 
     *  @throws org.osid.NotFoundException <code> agendaId </code> or <code> 
     *          engineId </code> not found or <code> agendaId </code> not 
     *          assigned to <code> engineId </code> 
     *  @throws org.osid.NullArgumentException <code> agendaId </code> or 
     *          <code> engineId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignAgendaFromEngine(org.osid.id.Id agendaId, 
                                         org.osid.id.Id engineId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
