//
// org.osid.rules.check.AgendaEngineSession
//
//     The OSID Java specification for org.osid.rules.check.AgendaEngineSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.rules.check;


/**
 *  <p>This session provides methods to retrieve <code> Agenda </code> to 
 *  <code> Engine </code> checks. An <code> Agenda </code> may appear in 
 *  multiple <code> Engine </code> objects. Each engine may have its own 
 *  authorizations governing who is allowed to look at it. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *  </ul>
 *  
 */

public interface AgendaEngineSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can perform lookups of agenda/engine checks. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known lookup methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @return <code> false </code> if looking up mappings is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupAgendaEngineMappings();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeAgendaEngineView();


    /**
     *  A complete view of the <code> Agenda </code> and <code> Engine </code> 
     *  returns is desired. Methods will return what is requested or result in 
     *  an error. This view is used when greater precision is desired at the 
     *  expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryAgendaEngineView();


    /**
     *  Gets the list of <code> Agenda Ids </code> associated with a <code> 
     *  Engine. </code> 
     *
     *  @param  engineId <code> Id </code> of the <code> Engine </code> 
     *  @return list of related agenda <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> engineId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> engineId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAgendaIdsByEngine(org.osid.id.Id engineId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> Agendas </code> associated with a <code> 
     *  Engine. </code> 
     *
     *  @param  engineId <code> Id </code> of the <code> Engine </code> 
     *  @return list of related agendas 
     *  @throws org.osid.NotFoundException <code> engineId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> engineId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.check.AgendaList getAgendasByEngine(org.osid.id.Id engineId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> Agenda Ids </code> corresponding to a list of 
     *  <code> Engines. </code> 
     *
     *  @param  engineIds list of engine <code> Ids </code> 
     *  @return list of agenda <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> engineIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAgendaIdsByEngines(org.osid.id.IdList engineIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> Agenda </code> corresponding to a list of 
     *  <code> Engines. </code> 
     *
     *  @param  engineIds list of engine <code> Ids </code> 
     *  @return list of agendas 
     *  @throws org.osid.NullArgumentException <code> engineIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.check.AgendaList getAgendasByEngines(org.osid.id.IdList engineIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Engine </code> <code> Ids </code> mapped to an <code> 
     *  Agenda. </code> 
     *
     *  @param  agendaId <code> Id </code> of an <code> Agenda </code> 
     *  @return list of engines 
     *  @throws org.osid.NotFoundException <code> agendaId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> agendaId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getEngineIdsByAgenda(org.osid.id.Id agendaId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Engines </code> mapped to an <code> Agenda. </code> 
     *
     *  @param  agendaId <code> Id </code> of an <code> Agenda </code> 
     *  @return list of engines 
     *  @throws org.osid.NotFoundException <code> agendaId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> agendaId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.EngineList getEnginesByAgenda(org.osid.id.Id agendaId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
