//
// org.osid.rules.check.AgendaSearchSession
//
//     The OSID Java specification for org.osid.rules.check.AgendaSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.rules.check;


/**
 *  <p>This session provides methods for searching among <code> Agenda </code> 
 *  objects. The search query is constructed using the <code> AgendaQuery. 
 *  </code> </p> 
 *  
 *  <p> <code> getAgendasByQuery() </code> is the basic search method and 
 *  returns a list of <code> Agendas. </code> A more advanced search may be 
 *  performed with <code> getAgendasBySearch(). </code> It accepts an <code> 
 *  AgendaSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getAgendasBySearch() </code> returns an <code> 
 *  AgendaSearchResults </code> that can be used to access the resulting 
 *  <code> AgendaList </code> or be used to perform a search within the result 
 *  set through <code> AgendaSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated engine view: searches include agendas in engines of 
 *      which this engine is an ancestor in the engine hierarchy </li> 
 *      <li> isolated engine view: searches are restricted to agendas in this 
 *      engine </li> 
 *  </ul>
 *  
 *  
 *  <p> Agendas may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> AgendaQuery. </code> 
 *  </p>
 */

public interface AgendaSearchSession
    extends org.osid.rules.check.AgendaQuerySession {


    /**
     *  Gets an agenda search. 
     *
     *  @return the agenda search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.check.AgendaSearch getAgendaSearch();


    /**
     *  Gets an agenda search order. The <code> AgendaSearchOrder </code> is 
     *  supplied to an <code> AgendaSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the agenda search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.check.AgendaSearchOrder getAgendaSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  agendaQuery the agenda query 
     *  @param  agendaSearch the agenda search 
     *  @return the agenda search results 
     *  @throws org.osid.NullArgumentException <code> agendaQuery </code> or 
     *          <code> agendaSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> agendaQuery </code> or 
     *          <code> agendaSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.check.AgendaSearchResults getAgendasBySearch(org.osid.rules.check.AgendaQuery agendaQuery, 
                                                                       org.osid.rules.check.AgendaSearch agendaSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an agenda query from an inspector. The inspector is available 
     *  from an <code> AgendaSearchResults. </code> 
     *
     *  @param  agendaQueryInspector an agenda query inspector 
     *  @return the agenda query 
     *  @throws org.osid.NullArgumentException <code> agendaQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> agendaQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.check.AgendaQuery getAgendaQueryFromInspector(org.osid.rules.check.AgendaQueryInspector agendaQueryInspector);
}
