//
// org.osid.rules.check.Check
//
//     The OSID Java specification for org.osid.rules.check.Check.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.rules.check;


/**
 *  <p>A <code> Check </code> is something that needs to checked. Some basic 
 *  checks are baked into this interface but can be extended through a check 
 *  record or it can reference an external rule evaluation. Each type of check 
 *  is unique and should not be combined. </p> 
 *  
 *  <p> <code> Checks </code> come in a variety of flavors indicated by the 
 *  boolean methods in this interface. Each type of <code> Check </code> may 
 *  be accompanied by data required to evaluate the check. </p> 
 *  
 *  <ul>
 *      <li> Fail Check </li> 
 *      <li> Time Check By Date </li> 
 *      <li> Time Check by Event </li> 
 *      <li> Time Check By Cyclic Event </li> 
 *      <li> Hold Check </li> 
 *      <li> Inquiry Check </li> 
 *      <li> Process Check </li> 
 *  </ul>
 *  
 */

public interface Check
    extends org.osid.OsidRule {


    /**
     *  Tests if this check is a placeholder check that always fails when 
     *  evaluated. A failure check can be used to block certain conditions 
     *  specified in an <code> Instruction. </code> If <code> isFailCheck() 
     *  </code> is <code> true, </code> then <code> isTimeCheckByDate(), 
     *  </code> <code> isTimeCheckByEvent(), </code> <code> 
     *  isTimeCheckByCyclicEvent(), </code> <code> isHoldCheck(), 
     *  isInquiryCheck(), </code> and <code> isProcessCheck() </code> must be 
     *  <code> false. </code> 
     *
     *  @return <code> true </code> if this is a fail check, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isFailCheck();


    /**
     *  Tests if this check is for a time check specified by a date. If <code> 
     *  isTimeCheckByDate() </code> is <code> true, </code> then <code> 
     *  isFailCheck(), </code> <code> isTimeCheckByEvent(), </code> <code> 
     *  isTimeCheckByCyclicEvent(), </code> <code> isHoldCheck(), </code> 
     *  <code> isInquiryCheck(), </code> and <code> isProcessCheck() </code> 
     *  must be <code> false. </code> 
     *
     *  @return <code> true </code> if this check is for a time specified by 
     *          date, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isTimeCheckByDate();


    /**
     *  Gets the time check start date. The check passes if the current time 
     *  is within the time interval inclusive. If the start time of the 
     *  interval is undefined, then the check for the start time always 
     *  passes. If the end time of the interval is undefined, then the check 
     *  for the deadline always passes. 
     *
     *  @return the start of the time period 
     *  @throws org.osid.IllegalStateException <code> isTimeCheckByDate() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getTimeCheckStartDate();


    /**
     *  Gets the time check end date. The check passes if the current time is 
     *  within the time interval inclusive. If the start time of the interval 
     *  is undefined, then the check for the start time always passes. If the 
     *  end time of the interval is undefined, then the check for the deadline 
     *  always passes. 
     *
     *  @return the end of the time period 
     *  @throws org.osid.IllegalStateException <code> isTimeCheckByDate() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getTimeCheckEndDate();


    /**
     *  Tests if this check is for a time check specified by an event. The 
     *  starting and ending times of the event are used as a time interval to 
     *  perform the time check. If <code> isTimeCheckByEvent() </code> is 
     *  <code> true, </code> then <code> isFailCheck(), </code> <code> 
     *  isTimeCheckByDate(), </code> <code> isTimeCheckByCyclicEvent(), 
     *  </code> <code> isHoldCheck(), </code> <code> isInquiryCheck(), </code> 
     *  and <code> isProcessCheck() </code> must be <code> false. </code> 
     *
     *  @return <code> true </code> if this check is for a time speciifed by 
     *          event, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isTimeCheckByEvent();


    /**
     *  Gets the time check event <code> Id. </code> 
     *
     *  @return the event <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> isTimeCheckByEvent() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getTimeCheckEventId();


    /**
     *  Gets the time check event. 
     *
     *  @return the event 
     *  @throws org.osid.IllegalStateException <code> isTimeCheckByEvent() 
     *          </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Event getTimeCheckEvent()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this check is for a time check specified by a cyclic event. 
     *  The time check is performed using the starting and ending dates of the 
     *  derived event. If the event is a rceurring event, the time must be 
     *  within the starting and ending dates of at least one of the events in 
     *  the series. If <code> isTimeCheckByCyclicEvent() </code> is <code> 
     *  true, </code> then <code> isFailCheck(), </code> <code> 
     *  isTimeCheckByDate(), </code> <code> isTimeCheckByEvent(), </code> 
     *  <code> isHoldCheck(), isInquiryCheck(), </code> and <code> 
     *  isProcessCheck() </code> must be <code> false. </code> 
     *
     *  @return <code> true </code> if this check is for a time check 
     *          specified by cyclic event, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isTimeCheckByCyclicEvent();


    /**
     *  Gets the time check cyclic event <code> Id. </code> 
     *
     *  @return the cyclic event <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> 
     *          isTimeCheckByCyclicEvent() </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getTimeCheckCyclicEventId();


    /**
     *  Gets the time check cyclic event. 
     *
     *  @return the cyclic event 
     *  @throws org.osid.IllegalStateException <code> 
     *          isTimeCheckByCyclicEvent() </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.cycle.CyclicEvent getTimeCheckCyclicEvent()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this check is for a hold service block. If a block exists for 
     *  the agent being checked, the check fails. If <code> isHoldCheck() 
     *  </code> is <code> true, </code> then <code> isFailCheck(), </code> 
     *  <code> isTimeCheckByDate(), </code> <code> isTimeCheckByEvent(), 
     *  </code> <code> isTimeCheckByCyclicEvent(), </code> <code> 
     *  isInquiryCheck(), </code> and <code> isProcessCheck() </code> must be 
     *  <code> false. </code> 
     *
     *  @return <code> true </code> if this check is for a block, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isHoldCheck();


    /**
     *  Gets the <code> Block Id </code> for this check, 
     *
     *  @return the <code> Block Id </code> 
     *  @throws org.osid.IllegalStateException <code> isHoldCheck() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getHoldCheckBlockId();


    /**
     *  Gets the <code> Block </code> for this check. 
     *
     *  @return the <code> Block </code> 
     *  @throws org.osid.IllegalStateException <code> isHoldCheck() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.Block getHoldCheckBlock()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this check is for a hold service block. If a block exists for 
     *  the agent being checked, the check fails. If <code> isInquiryCheck() 
     *  </code> is <code> true, </code> then <code> isFailCheck(), </code> 
     *  <code> isTimeCheckByDate(), </code> <code> isTimeCheckByEvent(), 
     *  </code> <code> isTimeCheckByCyclicEvent(), </code> <code> 
     *  isHoldCheck(), </code> and <code> isProcessCheck() </code> must be 
     *  <code> false. </code> 
     *
     *  @return <code> true </code> if this check is for a block, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isInquiryCheck();


    /**
     *  Gets the <code> Audit Id </code> for this check, 
     *
     *  @return the <code> Block Id </code> 
     *  @throws org.osid.IllegalStateException <code> isInquiryCheck() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getInquiryCheckAuditId();


    /**
     *  Gets the <code> Audit </code> for this check. 
     *
     *  @return the <code> Audit </code> 
     *  @throws org.osid.IllegalStateException <code> isInquiryCheck() </code> 
     *          is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.Audit getInquiryCheckAudit()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this check is for a another agenda. The agenda for the 
     *  specified agenda is retrieved and processed before continuing with the 
     *  checks in this agenda. If <code> isProcessCheck() </code> is <code> 
     *  true, </code> then <code> isFailCheck(), </code> <code> 
     *  isTimeCheckByDate(), </code> <code> isTimeCheckByEvent(), </code> 
     *  <code> isTimeCheckByCyclicEvent(), </code> <code> isHoldCheck(), 
     *  </code> and <code> isInquiryCheck() </code> must be <code> false. 
     *  </code> 
     *
     *  @return <code> true </code> if this check is for another agenda, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isProcessCheck();


    /**
     *  Gets the <code> Agenda Id </code> for this check. 
     *
     *  @return the <code> Block Id </code> 
     *  @throws org.osid.IllegalStateException <code> isProcessCheck() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getProcessCheckAgendaId();


    /**
     *  Gets the <code> Agenda </code> for this check. 
     *
     *  @return the <code> Agenda </code> 
     *  @throws org.osid.IllegalStateException <code> isProcessCheck() </code> 
     *          is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.check.Agenda getProcessCheckAgenda()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the check record corresponding to the given <code> Check </code> 
     *  record <code> Type. </code> This method is used to retrieve an object 
     *  implementing the requested record. The <code> checkRecordType </code> 
     *  may be the <code> Type </code> returned in <code> getRecordTypes() 
     *  </code> or any of its parents in a <code> Type </code> hierarchy where 
     *  <code> hasRecordType(checkRecordType) </code> is <code> true </code> . 
     *
     *  @param  checkRecordType the type of check record to retrieve 
     *  @return the check record 
     *  @throws org.osid.NullArgumentException <code> checkRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(checkRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.check.records.CheckRecord getCheckRecord(org.osid.type.Type checkRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
