//
// org.osid.rules.check.CheckForm
//
//     The OSID Java specification for org.osid.rules.check.CheckForm.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.rules.check;


/**
 *  <p>This is the form for creating and updating <code> Checks. </code> Like 
 *  all <code> OsidForm </code> objects, various data elements may be set here 
 *  for use in the create and update methods in the <code> CheckAdminSession. 
 *  </code> For each data element that may be set, metadata may be examined to 
 *  provide display hints or data constraints. </p> 
 *  
 *  <p> Checks come in a variety of flavors. Each type of Check </p> 
 *  
 *  <ul>
 *      <li> Fail Check </li> 
 *      <li> Time Check By Date </li> 
 *      <li> Time Check by Event </li> 
 *      <li> Time Check By Cyclic Event </li> 
 *      <li> Hold Check </li> 
 *  </ul>
 *  
 *  
 *  <p> is determined based on what data is set. If multiple fields are set, 
 *  the provider will pick one at random. </p>
 */

public interface CheckForm
    extends org.osid.OsidRuleForm {


    /**
     *  Gets the metadata for making this a fail check. 
     *
     *  @return metadata for the competency 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getFailCheckMetadata();


    /**
     *  Makes this check a fail check. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setFailCheck();


    /**
     *  Removes the fail check setting. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFailCheck();


    /**
     *  Gets the metadata for making this a time check and for the start date. 
     *
     *  @return metadata for time check start date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getTimeCheckStartDateMetadata();


    /**
     *  Sets the start date and make this a time check,. 
     *
     *  @param  date the new start date 
     *  @throws org.osid.InvalidArgumentException <code> date </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setTimeCheckStartDate(org.osid.calendaring.DateTime date);


    /**
     *  Removes the start date. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTimeCheckStartDate();


    /**
     *  Gets the metadata for making this a time check and for the end date. 
     *
     *  @return metadata for time check end date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getTimeCheckEndDateMetadata();


    /**
     *  Sets the end date and make this a time check,. 
     *
     *  @param  date the new end date 
     *  @throws org.osid.InvalidArgumentException <code> date </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setTimeCheckEndDate(org.osid.calendaring.DateTime date);


    /**
     *  Removes the end date. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTimeCheckEndDate();


    /**
     *  Gets the metadata for making this a time check and for the event. 
     *
     *  @return metadata for time check event 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getTimeCheckEventMetadata();


    /**
     *  Sets the event and make this a time check,. 
     *
     *  @param  eventId the new event 
     *  @throws org.osid.InvalidArgumentException <code> eventId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> eventId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setTimeCheckEvent(org.osid.id.Id eventId);


    /**
     *  Removes the event. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTimeCheckEvent();


    /**
     *  Gets the metadata for making this a time check and for the cyclic 
     *  event. 
     *
     *  @return metadata for time check cyclic event 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getTimeCheckCyclicEventMetadata();


    /**
     *  Sets the cyclic event and make this a time check,. 
     *
     *  @param  cyclicEventId the new cyclic event 
     *  @throws org.osid.InvalidArgumentException <code> cyclicEventId </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> cyclicEventId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setTimeCheckCyclicEvent(org.osid.id.Id cyclicEventId);


    /**
     *  Removes the cyclic event. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTimeCheckCyclicEvent();


    /**
     *  Gets the metadata for making this a hold check and for the block. 
     *
     *  @return metadata for hold check block 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getHoldCheckBlockMetadata();


    /**
     *  Sets the block and make this a hold check,. 
     *
     *  @param  blockId the new block 
     *  @throws org.osid.InvalidArgumentException <code> blockId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> blockId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setHoldCheckBlock(org.osid.id.Id blockId);


    /**
     *  Removes the block. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearHoldCheckBlock();


    /**
     *  Gets the metadata for making this an inquiry check and for the audit. 
     *
     *  @return metadata for inquiry check audit 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getInquiryCheckAuditMetadata();


    /**
     *  Sets the audit and make this an inquiry check,. 
     *
     *  @param  auditId the new audit 
     *  @throws org.osid.InvalidArgumentException <code> auditId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> auditId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setInqiiryCheckAudit(org.osid.id.Id auditId);


    /**
     *  Removes the audit. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearInquiryCheckAudit();


    /**
     *  Gets the metadata for making this a process check and for the agenda. 
     *
     *  @return metadata for process check agenda 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getProcessCheckAgendaMetadata();


    /**
     *  Sets the agenda and make this a process check,. 
     *
     *  @param  agendaId the new agenda 
     *  @throws org.osid.InvalidArgumentException <code> agendaId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> agendaId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setProcessCheckAgenda(org.osid.id.Id agendaId);


    /**
     *  Removes the agenda. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProcessCheckAgenda();


    /**
     *  Gets the <code> CheckFormRecord </code> corresponding to the given 
     *  check record <code> Type. </code> 
     *
     *  @param  checkRecordType a check record type 
     *  @return the check form record 
     *  @throws org.osid.NullArgumentException <code> checkRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(checkRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.check.records.CheckFormRecord getCheckFormRecord(org.osid.type.Type checkRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
