//
// org.osid.rules.check.Instruction
//
//     The OSID Java specification for org.osid.rules.check.Instruction.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.rules.check;


/**
 *  <p>A <code> Instruction </code> appliies a <code> Check </code> to an 
 *  <code> Agenda. </code> </p>
 */

public interface Instruction
    extends org.osid.OsidRelationship,
            org.osid.OsidEnabler {


    /**
     *  Gets the <code> Id </code> of the agenda. 
     *
     *  @return the agenda <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAgendaId();


    /**
     *  Gets the agenda. 
     *
     *  @return the agenda 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.check.Agenda getAgenda()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of the check. 
     *
     *  @return the check <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCheckId();


    /**
     *  Gets the check. 
     *
     *  @return the check 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.check.Check getCheck()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the message to be returned upon failure of the check evaluation. 
     *
     *  @return the message 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getMessage();


    /**
     *  Tests if failure of the check should be interpreted as a warning and 
     *  not a failure. 
     *
     *  @return <code> true </code> if this is a warning, <code> false </code> 
     *          if an error 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isWarning();


    /**
     *  Tests if evaluation of the next instruction should continue if the 
     *  check in this instruction fails. While the overall evaluation of the 
     *  agenda still fails, if true, allows for other messages to be gathered. 
     *
     *  @return <code> true </code> if this processing should continue on 
     *          failure, <code> false </code> if processing should cease upon 
     *          failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean continueOnFail();


    /**
     *  Gets the instruction record corresponding to the given <code> 
     *  Instruction </code> record <code> Type. </code> This method is used to 
     *  retrieve an object implementing the requested record. The <code> 
     *  instructionRecordType </code> may be the <code> Type </code> returned 
     *  in <code> getRecordTypes() </code> or any of its parents in a <code> 
     *  Type </code> hierarchy where <code> 
     *  hasRecordType(instructionRecordType) </code> is <code> true </code> . 
     *
     *  @param  instructionRecordType the type of instruction record to 
     *          retrieve 
     *  @return the instruction record 
     *  @throws org.osid.NullArgumentException <code> instructionRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(instructionRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.check.records.InstructionRecord getInstructionRecord(org.osid.type.Type instructionRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
