//
// org.osid.rules.check.InstructionAdminSession
//
//     The OSID Java specification for org.osid.rules.check.InstructionAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.rules.check;


/**
 *  <p>This session creates, updates, and deletes <code> Instructions. </code> 
 *  The data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create an 
 *  <code> Instruction, </code> an <code> InstructionForm </code> is requested 
 *  using <code> getInstructionFormForCreate() </code> specifying the desired 
 *  agenda, check, and record <code> Types </code> or none if no record <code> 
 *  Types </code> are needed. The returned <code> InstructionForm </code> will 
 *  indicate that it is to be used with a create operation and can be used to 
 *  examine metdata or validate data prior to creation. Once the <code> 
 *  InstructionForm </code> is submiited to a create operation, it cannot be 
 *  reused with another create operation unless the first operation was 
 *  unsuccessful. Each <code> InstructionForm </code> corresponds to an 
 *  attempted transaction. </p> 
 *  
 *  <p> For updates, <code> InstructionForms </code> are requested to the 
 *  <code> Instruction </code> <code> Id </code> that is to be updated using 
 *  <code> getInstructionFormForUpdate(). </code> Similarly, the <code> 
 *  InstructionForm </code> has metadata about the data that can be updated 
 *  and it can perform validation before submitting the update. The <code> 
 *  InstructionForm </code> can only be used once for a successful update and 
 *  cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Instructions. </code> To unmap an 
 *  <code> Instruction </code> from the current <code> Engine, </code> the 
 *  <code> InstructionEngineAssignmentSession </code> should be used. These 
 *  delete operations attempt to remove the <code> Instruction </code> itself 
 *  thus removing it from all known <code> Engine </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface InstructionAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Engine </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Engine Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getEngineId();


    /**
     *  Gets the <code> Engine </code> associated with this session. 
     *
     *  @return the engine 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.Engine getEngine()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> Instructions. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating an <code> Instruction </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer create operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Instruction </code> creation is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateInstructions();


    /**
     *  Tests if this user can create a single <code> Instruction </code> 
     *  using the desired record types. While <code> 
     *  RulesCheckManager.getInstructionRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> Instruction. </code> 
     *  Providing an empty array tests if an <code> Instruction </code> can be 
     *  created with no records. 
     *
     *  @param  instructionRecordTypes array of instruction record types 
     *  @return <code> true </code> if <code> Instruction </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> instructionRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateInstructionWithRecordTypes(org.osid.type.Type[] instructionRecordTypes);


    /**
     *  Gets the instruction form for creating new instructions. A new form 
     *  should be requested for each create transaction. 
     *
     *  @param  agendaId an agenda <code> Id </code> 
     *  @param  checkId a check <code> Id </code> 
     *  @param  instructionRecordTypes array of instruction record types 
     *  @return the instruction form 
     *  @throws org.osid.NotFoundException <code> agendaId </code> or <code> 
     *          checkId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> agendaId, checkId, 
     *          </code> or <code> instructionRecordTypes </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.check.InstructionForm getInstructionFormForCreate(org.osid.id.Id agendaId, 
                                                                            org.osid.id.Id checkId, 
                                                                            org.osid.type.Type[] instructionRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Instruction. </code> 
     *
     *  @param  instructionForm the form for this <code> Instruction </code> 
     *  @return the new <code> Instruction </code> 
     *  @throws org.osid.IllegalStateException <code> instructionForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException i <code> nstructionForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> instructionForm </code> 
     *          did not orginate from <code> getInstructionFormForCreate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.check.Instruction createInstruction(org.osid.rules.check.InstructionForm instructionForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Instructions. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating an <code> Instruction </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer update operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Instruction </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateInstructions();


    /**
     *  Gets the instruction form for updating an existing instruction. A new 
     *  instruction form should be requested for each update transaction. 
     *
     *  @param  instructionId the <code> Id </code> of the <code> Instruction 
     *          </code> 
     *  @return the instruction form 
     *  @throws org.osid.NotFoundException <code> instructionId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> instructionId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.check.InstructionForm getInstructionFormForUpdate(org.osid.id.Id instructionId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Updates an existing instruction. 
     *
     *  @param  instructionForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> instructionForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> instructionId </code> or 
     *          <code> instructionForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> instructionForm </code> 
     *          did not orginate from <code> getInstructionFormForUpdate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateInstruction(org.osid.rules.check.InstructionForm instructionForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> Instructions. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting an <code> Instruction </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer delete operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Instruction </code> deletion is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteInstructions();


    /**
     *  Deletes an <code> Instruction. </code> 
     *
     *  @param  instructionId the <code> Id </code> of the <code> Instruction 
     *          </code> to remove 
     *  @throws org.osid.NotFoundException <code> instructionId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> instructionId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteInstruction(org.osid.id.Id instructionId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Instructions. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Instruction </code> aliasing is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageInstructionAliases();


    /**
     *  Adds an <code> Id </code> to an <code> Instruction </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Instruction </code> is determined by the provider. The new 
     *  <code> Id </code> performs as an alias to the primary <code> Id 
     *  </code> . If the alias is a pointer to another instruction, it is 
     *  reassigned to the given instruction <code> Id. </code> 
     *
     *  @param  instructionId the <code> Id </code> of an <code> Instruction 
     *          </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> instructionId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> instructionId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasInstruction(org.osid.id.Id instructionId, 
                                 org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> Instructions. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known sequencing operations will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Instruction </code> ordering is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceInstructions();


    /**
     *  Reorders instructions in an agenda by moving the specified instruction 
     *  in front of a reference instruction. 
     *
     *  @param  instructionId the <code> Id </code> of an <code> Instruction 
     *          </code> 
     *  @param  agendaId the <code> Id </code> of an <code> Agenda </code> 
     *  @param  referenceId the reference instruction <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> instructionId, agendaId, 
     *          </code> or <code> referenceId </code> not found or, <code> 
     *          instructionId </code> or <code> referenceId </code> not 
     *          related to <code> agendaId </code> 
     *  @throws org.osid.NullArgumentException <code> instructionId, agendaId 
     *          </code> or <code> referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveInstructionAhead(org.osid.id.Id instructionId, 
                                     org.osid.id.Id agendaId, 
                                     org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders instructions in an agenda by moving the specified instruction 
     *  behind a reference instruction. 
     *
     *  @param  instructionId the <code> Id </code> of an <code> Instruction 
     *          </code> 
     *  @param  agendaId the <code> Id </code> of an <code> Agenda </code> 
     *  @param  referenceId the reference instruction <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> instructionId, agendaId, 
     *          </code> or <code> referenceId </code> not found or, <code> 
     *          instructionId </code> or <code> referenceId </code> not 
     *          related to <code> agendaId </code> 
     *  @throws org.osid.NullArgumentException <code> instructionId, agendaId 
     *          </code> or <code> referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveInstructionBehind(org.osid.id.Id instructionId, 
                                      org.osid.id.Id agendaId, 
                                      org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of instructions in an agenda. 
     *
     *  @param  instructionIds the <code> Ids </code> for a set of <code> 
     *          Instructions </code> 
     *  @param  agendaId the <code> Id </code> of an <code> Agenda </code> 
     *  @throws org.osid.NotFoundException <code> agendaId </code> not found 
     *          or, an <code> instructionId </code> not related to <code> 
     *          agendaId </code> 
     *  @throws org.osid.NullArgumentException <code> instructionIds </code> 
     *          or <code> agendaId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderInstructions(org.osid.id.Id[] instructionIds, 
                                  org.osid.id.Id agendaId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
