//
// org.osid.rules.check.InstructionLookupSession
//
//     The OSID Java specification for org.osid.rules.check.InstructionLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.rules.check;


/**
 *  <p>This session defines methods for retrieving instructions. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated engine view: All instruction methods in this session 
 *      operate, retrieve and pertain to instructions defined explicitly in 
 *      the current engine. Using an isolated view is useful for managing 
 *      <code> Instructions </code> with the <code> InstructionAdminSession. 
 *      </code> </li> 
 *      <li> federated engine view: All instruction lookup methods in this 
 *      session operate, retrieve and pertain to all instructions defined in 
 *      this engine and any other instructions implicitly available in this 
 *      engine through engine inheritence. </li> 
 *      <li> active instruction view: All instruction lookup methods return 
 *      active instructions. </li> 
 *      <li> any status instruction view: instructions of any active or 
 *      inactive status are returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedEngineView() </code> and <code> 
 *  useIsolatedEngineView() </code> behave as a radio group and one should be 
 *  selected before invoking any lookup methods. </p> 
 *  
 *  <p> Instructions may have an additional records indicated by their 
 *  respective record types. The record may not be accessed through a cast of 
 *  the <code> Instructions. </code> </p>
 */

public interface InstructionLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Engine </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Engine Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getEngineId();


    /**
     *  Gets the <code> Engine </code> associated with this session. 
     *
     *  @return the engine 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.Engine getEngine()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Instruction </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupInstructions();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeInstructionView();


    /**
     *  A complete view of the <code> Instruction </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryInstructionView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include instructions in engines which are children of this engine in 
     *  the engine hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedEngineView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this engine only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedEngineView();


    /**
     *  Only active instructions are returned by methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveInstructionView();


    /**
     *  All active and inactive instructions of are returned by methods in 
     *  this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusInstructionView();


    /**
     *  Gets the <code> Instruction </code> specified by its <code> Id. 
     *  </code> In plenary mode, the exact <code> Id </code> is found or a 
     *  <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Instruction </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to an <code> Instruction </code> and retained for 
     *  compatibility. 
     *
     *  @param  instructionId the <code> Id </code> of the <code> Instruction 
     *          </code> to retrieve 
     *  @return the returned <code> Instruction </code> 
     *  @throws org.osid.NotFoundException no <code> Instruction </code> found 
     *          with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> instructionId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.check.Instruction getInstruction(org.osid.id.Id instructionId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> InstructionList </code> corresponding to the given 
     *  <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  instructions specified in the <code> Id </code> list, in the order of 
     *  the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Instructions </code> may be omitted from the list 
     *  and may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In active mode, instructions are returned that are currently active. 
     *  In any status mode, active and inactive instructions are returned. 
     *
     *  @param  instructionIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Instruction </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> instructionIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.check.InstructionList getInstructionsByIds(org.osid.id.IdList instructionIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> InstructionList </code> corresponding to the given 
     *  instruction genus <code> Type </code> which does not include 
     *  instructions of types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  instructions or an error results. Otherwise, the returned list may 
     *  contain only those instructions that are accessible through this 
     *  session. 
     *  
     *  In active mode, instructions are returned that are currently active. 
     *  In any status mode, active and inactive instructions are returned. 
     *
     *  @param  instructionGenusType an instruction genus type 
     *  @return the returned <code> Instruction </code> list 
     *  @throws org.osid.NullArgumentException <code> instructionGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.check.InstructionList getInstructionsByGenusType(org.osid.type.Type instructionGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> InstructionList </code> corresponding to the given 
     *  instruction genus <code> Type </code> and include any additional 
     *  instructions with genus types derived from the specified <code> Type. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  instructions or an error results. Otherwise, the returned list may 
     *  contain only those instructions that are accessible through this 
     *  session. 
     *  
     *  In active mode, instructions are returned that are currently active. 
     *  In any status mode, active and inactive instructions are returned. 
     *
     *  @param  instructionGenusType an instruction genus type 
     *  @return the returned <code> Instruction </code> list 
     *  @throws org.osid.NullArgumentException <code> instructionGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.check.InstructionList getInstructionsByParentGenusType(org.osid.type.Type instructionGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> InstructionList </code> containing the given 
     *  instruction record <code> Type. </code> 
     *  
     *  In plenary mode, the returned list contains all known instructions or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  instructions that are accessible through this session. 
     *  
     *  In active mode, instructions are returned that are currently active. 
     *  In any status mode, active and inactive instructions are returned. 
     *
     *  @param  instructionRecordType an instruction record type 
     *  @return the returned <code> Instruction </code> list 
     *  @throws org.osid.NullArgumentException <code> instructionRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.check.InstructionList getInstructionsByRecordType(org.osid.type.Type instructionRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> InstructionList </code> effective for the entire given 
     *  date range inclusive but not confined to the date range. <code> 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  instructions or an error results. Otherwise, the returned list may 
     *  contain only those instructions that are accessible through this 
     *  session. 
     *  
     *  In active mode, instructions are returned that are currently active. 
     *  In any status mode, active and inactive instructions are returned. 
     *
     *  @param  from a start date 
     *  @param  to an end date 
     *  @return the returned <code> Instruction </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.check.InstructionList getInstructionsOnDate(org.osid.calendaring.DateTime from, 
                                                                      org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> InstructionList </code> for the given agenda. 
     *  
     *  In plenary mode, the returned list contains all known instructions or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  instructions that are accessible through this session. 
     *  
     *  In active mode, instructions are returned that are currently active. 
     *  In any status mode, active and inactive instructions are returned. 
     *
     *  @param  agendaId an agenda <code> Id </code> 
     *  @return the returned <code> Instruction </code> list 
     *  @throws org.osid.NullArgumentException <code> agendaId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.check.InstructionList getInstructionsForAgenda(org.osid.id.Id agendaId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> InstructionList </code> for the given agenda and 
     *  effective for the entire given date range inclusive but not confined 
     *  to the date range. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  instructions or an error results. Otherwise, the returned list may 
     *  contain only those instructions that are accessible through this 
     *  session. 
     *  
     *  In active mode, instructions are returned that are currently active. 
     *  In any status mode, active and inactive instructions are returned. 
     *
     *  @param  agendaId an agenda <code> Id </code> 
     *  @param  from a start date 
     *  @param  to an end date 
     *  @return the returned <code> Instruction </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> agendaId, from, </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.check.InstructionList getInstructionsForAgendaOnDate(org.osid.id.Id agendaId, 
                                                                               org.osid.calendaring.DateTime from, 
                                                                               org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> InstructionList </code> for the given check. 
     *  
     *  In plenary mode, the returned list contains all known instructions or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  instructions that are accessible through this session. 
     *  
     *  In active mode, instructions are returned that are currently active. 
     *  In any status mode, active and inactive instructions are returned. 
     *
     *  @param  checkId a check <code> Id </code> 
     *  @return the returned <code> Instruction </code> list 
     *  @throws org.osid.NullArgumentException <code> checkId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.check.InstructionList getInstructionsForCheck(org.osid.id.Id checkId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> InstructionList </code> for the given check and 
     *  effective for the entire given date range inclusive but not confined 
     *  to the date range. 
     *  
     *  In plenary mode, the returned list contains all known instructions or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  instructions that are accessible through this session. 
     *  
     *  In active mode, instructions are returned that are currently active. 
     *  In any status mode, active and inactive instructions are returned. 
     *
     *  @param  checkId a check <code> Id </code> 
     *  @param  from a start date 
     *  @param  to an end date 
     *  @return the returned <code> Instruction </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> checkId, from, </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.check.InstructionList getInstructionsForCheckOnDate(org.osid.id.Id checkId, 
                                                                              org.osid.calendaring.DateTime from, 
                                                                              org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> InstructionList </code> for the given agenda and check. 
     *  
     *  In plenary mode, the returned list contains all known instructions or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  instructions that are accessible through this session. 
     *  
     *  In active mode, instructions are returned that are currently active. 
     *  In any status mode, active and inactive instructions are returned. 
     *
     *  @param  agendaId an agenda <code> Id </code> 
     *  @param  checkId a check <code> Id </code> 
     *  @return the returned <code> Instruction </code> list 
     *  @throws org.osid.NullArgumentException <code> agendaId </code> or 
     *          <code> checkId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.check.InstructionList getInstructionsForAgendaAndCheck(org.osid.id.Id agendaId, 
                                                                                 org.osid.id.Id checkId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> InstructionList </code> for the given agenda and check 
     *  and effective for the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known instructions or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  instructions that are accessible through this session. 
     *  
     *  In active mode, instructions are returned that are currently active. 
     *  In any status mode, active and inactive instructions are returned. 
     *
     *  @param  agendaId an agenda <code> Id </code> 
     *  @param  checkId a check <code> Id </code> 
     *  @param  from a start date 
     *  @param  to an end date 
     *  @return the returned <code> Instruction </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> agendaId, checkId, from, 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.check.InstructionList getInstructionsForAgendaAndCheckOnDate(org.osid.id.Id agendaId, 
                                                                                       org.osid.id.Id checkId, 
                                                                                       org.osid.calendaring.DateTime from, 
                                                                                       org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all instructions. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  instructions, including duplicates, or an error results if an <code> 
     *  Id </code> in the supplied list is not found or inaccessible. 
     *  Otherwise, inaccessible <code> Instructions </code> may be omitted 
     *  from the list and may present the elements in any order including 
     *  returning a unique set. 
     *  
     *  In active mode, instructions are returned that are currently active. 
     *  In any status mode, active and inactive instructions are returned. 
     *
     *  @return the returned <code> Instruction </code> list 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.check.InstructionList getInstructions()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
