//
// org.osid.search.EngineSearchSession
//
//     The OSID Java specification for org.osid.search.EngineSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.search;


/**
 *  <p>This session provides methods for searching <code> Engine </code> 
 *  objects. The search query is constructed using the <code> EngineQuery. 
 *  </code> The engine record <code> Type </code> also specifies the record 
 *  for the engine query. </p> 
 *  
 *  <p> <code> getEnginesByQuery() </code> is the basic search method and 
 *  returns a list of <code> Engine </code> elements. A more advanced search 
 *  may be performed with <code> getEnginesBySearch(). </code> It accepts an 
 *  <code> EngineSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getEnginesBySearch() </code> returns an <code> 
 *  EngineSearchResults </code> that can be used to access the resulting 
 *  <code> EngineList </code> or be used to perform a search within the result 
 *  set through <code> EngineSearch. </code> </p> 
 *  
 *  <p> Engines may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> EngineQuery. </code> 
 *  The returns in this session may not be cast directly to these interfaces. 
 *  </p>
 */

public interface EngineSearchSession
    extends org.osid.search.EngineQuerySession {


    /**
     *  Gets an engine search. 
     *
     *  @return the engine search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.EngineSearch getEngineSearch();


    /**
     *  Gets an engine search order. The <code> EngineSearchOrder </code> is 
     *  supplied to an <code> EngineSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the engine search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.EngineSearchOrder getEngineSearchOrder();


    /**
     *  Gets the search results matching the given search. 
     *
     *  @param  engineQuery the engine query 
     *  @param  engineSearch the engine search 
     *  @return the search results 
     *  @throws org.osid.NullArgumentException <code> engineQuery </code> or 
     *          <code> engineSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> engineQuery </code> or 
     *          <code> engineSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.EngineSearchResults getEnginesBySearch(org.osid.search.EngineQuery engineQuery, 
                                                                  org.osid.search.EngineSearch engineSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an engine query from an inspector. The inspector is available 
     *  from an <code> EngineSearchResults. </code> 
     *
     *  @param  engineQueryInspector a query inspector 
     *  @return the engine query 
     *  @throws org.osid.NullArgumentException <code> engineQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> engineQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.EngineQuery getEngineQueryFromInspector(org.osid.search.EngineQueryInspector engineQueryInspector);
}
