//
// org.osid.search.SearchProfile
//
//     The OSID Java specification for org.osid.search.SearchProfile.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.search;


/**
 *  <p>The search profile describes the interoperability among search 
 *  services. </p>
 */

public interface SearchProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any engine federation is exposed. Federation is exposed when 
     *  a specific engine may be identified, selected and used to create a 
     *  lookup or admin session. Federation is not exposed when a set of 
     *  engines appears as a single engine. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if search is supported. 
     *
     *  @return <code> true </code> if search is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSearch();


    /**
     *  Tests for the availability of an engine lookup service. 
     *
     *  @return <code> true </code> if engine lookup is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEngineLookup();


    /**
     *  Tests if querying for engines is available. 
     *
     *  @return <code> true </code> if engine query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEngineQuery();


    /**
     *  Tests if searching for engines is available. 
     *
     *  @return <code> true </code> if engine search is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEngineSearch();


    /**
     *  Tests for the availability of an engine administrative service for 
     *  creating and deleting engines. 
     *
     *  @return <code> true </code> if engine administration is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEngineAdmin();


    /**
     *  Tests for the availability of an engine notification service. 
     *
     *  @return <code> true </code> if engine notification is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsEngineNotification();


    /**
     *  Tests for the availability of an engine hierarchy traversal service. 
     *
     *  @return <code> true </code> if engine hierarchy traversal is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEngineHierarchy();


    /**
     *  Tests for the availability of an engine hierarchy design service. 
     *
     *  @return <code> true </code> if engine hierarchy design is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsEngineHierarchyDesign();


    /**
     *  Gets the supported query record types. 
     *
     *  @return a list containing the supported query record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getQueryRecordTypes();


    /**
     *  Tests if the given query record type is supported. 
     *
     *  @param  queryRecordType a <code> Type </code> indicating a query 
     *          record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> queryRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueryRecordType(org.osid.type.Type queryRecordType);


    /**
     *  Gets the supported search record types. 
     *
     *  @return a list containing the supported search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSearchRecordTypes();


    /**
     *  Tests if the given search record type is supported. 
     *
     *  @param  searchRecordType a <code> Type </code> indicating a search 
     *          record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> searchRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSearchRecordType(org.osid.type.Type searchRecordType);


    /**
     *  Gets the supported <code> Engine </code> record types. 
     *
     *  @return a list containing the supported engine record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getEngineRecordTypes();


    /**
     *  Tests if the given <code> Engine </code> record type is supported. 
     *
     *  @param  engineRecordType a <code> Type </code> indicating an <code> 
     *          Engine </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> engineRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEngineRecordType(org.osid.type.Type engineRecordType);


    /**
     *  Gets the supported engine search record types. 
     *
     *  @return a list containing the supported engine search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getEngineSearchRecordTypes();


    /**
     *  Tests if the given engine search record type is supported. 
     *
     *  @param  engineSearchRecordType a <code> Type </code> indicating an 
     *          engine record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> engineSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEngineSearchRecordType(org.osid.type.Type engineSearchRecordType);
}
