//
// org.osid.sequencing.AntimatroidNotificationSession
//
//     The OSID Java specification for org.osid.sequencing.AntimatroidNotificationSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN INPUT OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.sequencing;


/**
 *  <p>This session defines methods to receive notifications on adds/changes 
 *  to <code> Antimatroid </code> objects. This session is intended for 
 *  consumers needing to synchronize their state with this service without the 
 *  use of polling. Notifications are cancelled when this session is closed. 
 *  </p>
 */

public interface AntimatroidNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can register for <code> Antimatroid </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForAntimatroidNotifications();


    /**
     *  Reliable notifications are desired. In reliable mode, notifications 
     *  are to be acknowledged using <code> 
     *  acknowledgeAntimatroidNotification() </code> . 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void reliableAntimatroidNotifications();


    /**
     *  Unreliable notifications are desired. In unreliable mode, 
     *  notifications do not need to be acknowledged. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void unreliableAntimatroidNotifications();


    /**
     *  Acknowledge an antimatroid notification. 
     *
     *  @param  notificationId the <code> Id </code> of the notification 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void acknowledgeAntimatroidNotification(org.osid.id.Id notificationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new antimatroids. <code> 
     *  AntimatroidReceiver.newAntimatroids() </code> is invoked when a new 
     *  <code> Antimatroid </code> is created. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewAntimatroids()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated antimatroids. <code> 
     *  AntimatroidReceiver.changedAntimatroids() </code> is invoked when an 
     *  antimatroid is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedAntimatroids()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated antimatroid. <code> 
     *  AntimatroidReceiver.changedAntimatroids() </code> is invoked when the 
     *  specified antimatroid is changed. 
     *
     *  @param  antimatroidId the Id of the <code> Antimatroid </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> antimatroidId is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedAntimatroid(org.osid.id.Id antimatroidId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted antimatroids. <code> 
     *  AntimatroidReceiver.deletedAntimatroids() </code> is invoked when an 
     *  antimatroid is deleted. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedAntimatroids()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted antimatroid. <code> 
     *  AntimatroidReceiver.deletedAntimatroids() </code> is invoked when the 
     *  specified antimatroid is deleted. 
     *
     *  @param  antimatroidId the <code> Id </code> of the <code> Antimatroid 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> antimatroidId is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedAntimatroid(org.osid.id.Id antimatroidId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated antimatroid hierarchy 
     *  structure. <code> AntimatroidReceiver.changedChildOfAntimatroids() 
     *  </code> is invoked when a node experiences a change in its children. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedAntimatroidHierarchy()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated antimatroid hierarchy 
     *  structure. <code> AntimatroidReceiver.changedChildOfAntimatroids() 
     *  </code> is invoked when the specified node or any of its ancestors 
     *  experiences a change in its children. 
     *
     *  @param  antimatroidId the <code> Id </code> of the <code> Antimatroid 
     *          </code> node to monitor 
     *  @throws org.osid.NullArgumentException <code> antimatroidId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedAntimatroidHierarchyForAncestors(org.osid.id.Id antimatroidId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated antimatroid hierarchy 
     *  structure. <code> AntimatroidReceiver.changedChildOfAntimatroids() 
     *  </code> is invoked when the specified node or any of its descendants 
     *  experiences a change in its children. 
     *
     *  @param  antimatroidId the <code> Id </code> of the <code> Antimatroid 
     *          </code> node to monitor 
     *  @throws org.osid.NullArgumentException <code> antimatroidId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedAntimatroidHierarchyForDescendants(org.osid.id.Id antimatroidId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
